(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    358797,       7250]
NotebookOptionsPosition[    354297,       7098]
NotebookOutlinePosition[    354697,       7115]
CellTagsIndexPosition[    354654,       7112]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Electronic supplement to

@article{
ancey16jnnfm,
   Author = {Ancey, C. and Bates, B.M.},
   Title = {Stokes\[CloseCurlyQuote] third problem for Herschel-Bulkley \
fluids},
   Journal = {Journal of Non-Newtonian Fluid Mechanics},
   Volume = {submitted},
 Year = {2016} }

Copyright C. Ancey February 2017, christophe.ancey@epfl.ch

Run when initializing the code before all computations. The details of the \
code are given in the appendices of the paper.\
\>", "Text",
 CellChangeTimes->{{3.6782725741048*^9, 3.6782726077578*^9}, {
  3.6782747248998003`*^9, 3.6782747255588*^9}, {3.6782748298678*^9, 
  3.6782748486678*^9}, {3.6970226359634*^9, 3.6970226406364*^9}, {
  3.698474249934*^9, 3.698474259401*^9}}],

Cell[CellGroupData[{

Cell["Definition of functions", "Section",
 CellChangeTimes->{{3.6782727990188003`*^9, 3.6782728116438003`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6782728135938005`*^9, 3.6782728290938005`*^9}, 
   3.6782747233808002`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"UserDirectory", "=", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\"\<FileName\>\"", "/.", 
      RowBox[{"NotebookInformation", "[", 
       RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ")"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetDirectory", "[", "UserDirectory", "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Qmatrix", "[", 
    RowBox[{"n_", ",", "r_", ",", "\[CapitalGamma]_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Q1", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", "l"}]}], "\[Rule]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", "r"}], ")"}]}], "+", "\[CapitalGamma]"}]}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Q2", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "-", "1"}]}]}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r"}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Q3", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "+", "1"}]}]}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r"}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Q", "=", 
       RowBox[{"Normal", "[", 
        RowBox[{"Q1", " ", "+", " ", "Q2", "+", "Q3"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", 
          RowBox[{"n", "-", "1"}]}], "]"}], "]"}], "=", " ", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "-", "r"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Q", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", " ", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "-", "r"}], ")"}]}]}], ";", "Q"}]}], " ", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rvector", "[", 
    RowBox[{"n_", ",", "h_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "r", "}"}], ",", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{
         RowBox[{"h", "^", "2"}], ",", "n"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"r", "[", 
        RowBox[{"[", "n", "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"h", "^", "2"}], "+", 
        RowBox[{"2", "h", " ", 
         RowBox[{"F", "[", 
          RowBox[{"a", ",", "n", ",", "h"}], "]"}]}]}]}], ";", "r"}]}], 
    "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P3matrix", "[", 
    RowBox[{"n_", ",", "r_", ",", "\[CapitalGamma]_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P1", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", "l"}]}], "\[Rule]", 
           RowBox[{
            RowBox[{"2", "r"}], "+", "\[CapitalGamma]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"P2", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "-", "1"}]}]}], "\[Rule]", 
           RowBox[{"-", "r"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"P3", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "+", "1"}]}]}], "\[Rule]", 
           RowBox[{"-", "r"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"P", "=", 
       RowBox[{"Normal", "[", 
        RowBox[{"P1", " ", "+", " ", "P2", "+", "P3"}], "]"}]}], " ", ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", 
          RowBox[{"n", "-", "1"}]}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"-", "2"}], "r"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"-", "2"}], "r"}]}], ";", "P"}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673519836729*^9, 3.673519839715*^9}, {3.673519974267*^9,
    3.67352007606*^9}, {3.6735201186940002`*^9, 3.673520157052*^9}, {
   3.673520225333*^9, 3.6735202312860003`*^9}, {3.6735202989969997`*^9, 
   3.6735204178199997`*^9}, {3.673520465983*^9, 3.673520467894*^9}, {
   3.673933585831375*^9, 3.6739336253549824`*^9}, {3.673934412367329*^9, 
   3.673934414789464*^9}, {3.674224574240368*^9, 3.674224612260051*^9}, {
   3.6743888214645185`*^9, 3.6743888219898863`*^9}, {3.6744633847262077`*^9, 
   3.6744633852422075`*^9}, {3.6744635078592076`*^9, 3.674463536304208*^9}, {
   3.6744697089440002`*^9, 3.6744697297209997`*^9}, {3.6744822796024*^9, 
   3.6744823142254*^9}, {3.6744829757714*^9, 3.6744830328884*^9}, {
   3.6744836346714*^9, 3.6744836369944*^9}, {3.674738196498*^9, 
   3.67473820008*^9}, {3.6749668440980015`*^9, 3.674966852913001*^9}, 
   3.674967075761001*^9, {3.6749673111140013`*^9, 3.6749673574820013`*^9}, {
   3.674967592404001*^9, 3.6749676188500013`*^9}, {3.674968680113001*^9, 
   3.674968772826001*^9}, {3.6782734125458*^9, 3.6782734209608*^9}, {
   3.6970252287824*^9, 3.6970252373494*^9}, {3.6970252943564*^9, 
   3.6970253696934*^9}, {3.697352217387*^9, 3.697352221399*^9}, {
   3.697352275051*^9, 3.697352277311*^9}}],

Cell[BoxData["\<\"D:\\\\\"\>"], "Output",
 CellChangeTimes->{
  3.6747382009*^9, 3.674824422137*^9, 3.674965493812001*^9, 
   3.6749673605580015`*^9, 3.674967473182001*^9, 3.674967620307001*^9, 
   3.674968692970001*^9, 3.674968775670001*^9, 3.674977881699404*^9, 
   3.674978585223404*^9, 3.674979691866404*^9, 3.6782747278448*^9, 
   3.6782786843328*^9, 3.696336935717*^9, 3.696352611481*^9, 
   3.6967421629642*^9, 3.6970261461024*^9, 3.6970268375164003`*^9, 
   3.6970295120284*^9, 3.697127761506*^9, 3.6971742223190002`*^9, 
   3.697174276691*^9, 3.697175717017*^9, 3.69729157331*^9, 
   3.6973522288199997`*^9, 3.6973522790699997`*^9, 3.697375051823*^9, 
   3.6973875113109555`*^9, 3.6974314956056004`*^9, 3.6974340310526*^9, 
   3.698223887302*^9, 3.6982259887939997`*^9, 3.698326748826*^9, 
   3.6983766466569996`*^9, {3.698383291203*^9, 3.6983832997509995`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Boundary ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "z"], TraditionalForm]]],
 " u = - a s (Eq. B10) --- Figure B12"
}], "Section",
 CellChangeTimes->{{3.6739665004081616`*^9, 3.6739665088465996`*^9}, {
   3.6739701396406593`*^9, 3.6739701506262136`*^9}, {3.6739768840636225`*^9, 
   3.6739768858450317`*^9}, {3.6742269616087046`*^9, 3.674226963655799*^9}, 
   3.674404850061*^9, {3.6744616820462074`*^9, 3.6744616836282077`*^9}, {
   3.674469746836*^9, 3.674469748141*^9}, {3.6782729577258005`*^9, 
   3.6782729598208003`*^9}, 3.6782734398698*^9, {3.6782734799688005`*^9, 
   3.6782735088608003`*^9}, {3.6782748017558002`*^9, 3.6782748151478004`*^9}, 
   3.698474302811*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"boundary", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"a_", ",", "k_", ",", "h_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"-", "a"}], " ", "h", " ", "k"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Usol", "[", 
     RowBox[{"x_", ",", "t_", ",", "a_"}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xf", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"2", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "a"}], ")"}], "/", "a"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"t", " ", 
       RowBox[{
        RowBox[{"xf", "^", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"xf", "^", "2"}]}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "^", "2"}], "/", 
           RowBox[{"xf", "^", "2"}]}], "/", "t"}]}], ")"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Xisol", "[", "a_", "]"}], ":=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], "/", "a"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "finding", " ", "the", " ", "0", " ", "of", " ", "s", " ", "using", " ", 
     "the", " ", "secant", " ", "method"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fnc", "[", 
     RowBox[{"gamma_", ",", "gk_", ",", "k_", ",", "U_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "ukp", ",", "Us", ",", "gsmiddle", ",", "Smat", ",", "U1", ",", 
        "Gsmiddle", ",", "RR"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ukp", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"h", "^", "2"}], "/", "2"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", " ", 
            RowBox[{"gk", " ", 
             RowBox[{"F", "[", 
              RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Us", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"U", ",", 
          RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"gsmiddle", "=", 
        RowBox[{
         RowBox[{"kr", " ", "gk"}], "+", 
         RowBox[{"gamma", 
          RowBox[{"(", 
           RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Gsmiddle", "=", 
        RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"RR", "=", 
        RowBox[{"Rvector", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Smat", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Qmatrix", "[", 
            RowBox[{
             RowBox[{"k", "+", "1"}], ",", "r", ",", " ", "Gsmiddle"}], "]"}],
            ".", "Us"}], "+", 
          RowBox[{"Rvector", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"U1", "=", 
        RowBox[{
         RowBox[{"Inverse", "[", 
          RowBox[{"P3matrix", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "r", ",", " ", "Gsmiddle"}], "]"}], 
          "]"}], ".", "Smat"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"U1", " ", "[", 
        RowBox[{"[", 
         RowBox[{"k", "+", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "parameters", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kr", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"N1", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"s0", "=", 
    RowBox[{"N1", " ", "h"}]}], "\[IndentingNewLine]", 
   RowBox[{"tinit", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s0", "/", 
       RowBox[{"Xisol", "[", "a", "]"}]}], ")"}], "^", "2"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "conditions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Usol", "[", 
        RowBox[{
         RowBox[{"i", " ", "h"}], ",", "tinit", ",", "a"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "N1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t1", "=", "tinit"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"Usol", "[", 
             RowBox[{"x", ",", "tinit", ",", "a"}], "]"}], ",", "x", ",", 
            "x"}], "]"}]}], "/.", 
         RowBox[{"x", "\[Rule]", "s0"}]}], ")"}]}], "/", 
      RowBox[{"F", "[", 
       RowBox[{"a", ",", "N1", ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temps", "=", 
     RowBox[{"{", "t1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FileGamma", "=", 
     RowBox[{"{", "g1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6739291182704935`*^9, 3.673929229485534*^9}, {
   3.6739293428258495`*^9, 3.67392939347196*^9}, {3.673929590604376*^9, 
   3.6739295943391967`*^9}, {3.6739670738931627`*^9, 3.673967141228506*^9}, {
   3.6739680319267387`*^9, 3.6739680477565284`*^9}, {3.673968161300024*^9, 
   3.6739681659099035`*^9}, 3.6739683634936314`*^9, 3.673969959636938*^9, {
   3.673970921686137*^9, 3.6739709218736563`*^9}, 3.6739777694458017`*^9, {
   3.673977888755495*^9, 3.6739779063198833`*^9}, {3.6739784566446724`*^9, 
   3.6739784626765747`*^9}, {3.6739785742354403`*^9, 3.673978591299775*^9}, {
   3.6739786252565527`*^9, 3.6739786254596977`*^9}, {3.6739787155318804`*^9, 
   3.6739787189384975`*^9}, 3.6740093860723753`*^9, 3.674009487036134*^9, {
   3.67400994474065*^9, 3.6740099531635857`*^9}, {3.6742270049570503`*^9, 
   3.674227009285633*^9}, 3.674228227061883*^9, 3.6742282710040298`*^9, {
   3.6742283563568144`*^9, 3.674228363435691*^9}, {3.674228838905471*^9, 
   3.674228856782359*^9}, 3.6742298096929507`*^9, {3.6742299850239697`*^9, 
   3.674229989243194*^9}, {3.674316421293583*^9, 3.674316466235029*^9}, 
   3.6743165230019073`*^9, 3.674316879418*^9, 3.674317315226*^9, 
   3.674317360684*^9, {3.6743182695*^9, 3.6743182769700003`*^9}, {
   3.6743989727132587`*^9, 3.674398973493326*^9}, 3.674399221369187*^9, {
   3.6743996650494323`*^9, 3.674399686002122*^9}, {3.6743999100826592`*^9, 
   3.674399910694292*^9}, {3.674400007407155*^9, 3.6744000078663387`*^9}, 
   3.6744035918570004`*^9, 3.674403624744*^9, {3.674403740209*^9, 
   3.674403784679*^9}, {3.67440486255*^9, 3.674404864105*^9}, 
   3.6744049388710003`*^9, {3.674405195928*^9, 3.6744052264779997`*^9}, {
   3.67440526416*^9, 3.674405322318*^9}, {3.674405609501*^9, 
   3.674405629849*^9}, {3.674405761408*^9, 3.6744057669119997`*^9}, {
   3.674405806807*^9, 3.674405837641*^9}, 3.6744612301762075`*^9, {
   3.6744612697822075`*^9, 3.6744612849092073`*^9}, 3.674461388519208*^9, {
   3.674461817672208*^9, 3.6744619275892076`*^9}, {3.674461988960208*^9, 
   3.674462026118208*^9}, {3.6744625809052076`*^9, 3.6744625815692077`*^9}, {
   3.674468050223*^9, 3.674468070862*^9}, 3.674468976007*^9, {
   3.6744823696754*^9, 3.6744823716884003`*^9}, {3.6744824255064*^9, 
   3.6744824341384*^9}, {3.6745236327366023`*^9, 3.6745236362876024`*^9}, 
   3.6745423102896004`*^9, {3.6782735316798*^9, 3.6782736139898005`*^9}, {
   3.6782736852208004`*^9, 3.6782736898298*^9}, {3.6970267997424*^9, 
   3.6970268088444*^9}, {3.6970268844934*^9, 3.6970269117813997`*^9}, 
   3.6970313258213997`*^9, {3.697127852106*^9, 3.6971278608719997`*^9}, 
   3.697128761984*^9, 3.6971292467130003`*^9, {3.697129563598*^9, 
   3.697129571961*^9}, {3.69712963295*^9, 3.697129660777*^9}, 
   3.697130093326*^9, {3.697130336433*^9, 3.6971303610959997`*^9}, {
   3.69717541492*^9, 3.6971754290150003`*^9}, 3.6971754887790003`*^9, {
   3.697175759744*^9, 3.697175762127*^9}, {3.697175884408*^9, 
   3.697175903302*^9}, 3.6973522928310003`*^9, {3.697354910458*^9, 
   3.6973549144300003`*^9}, 3.697355857472*^9, {3.697356341334*^9, 
   3.697356348351*^9}, {3.697356382861*^9, 3.6973564127460003`*^9}, 
   3.697356678274*^9, {3.697357013251*^9, 3.697357013473*^9}, 
   3.6973580079639997`*^9, 3.697358472505*^9, {3.697359013234*^9, 
   3.697359013488*^9}, 3.697359478927*^9, {3.6973750356879997`*^9, 
   3.6973750396619997`*^9}, 3.697375082679*^9, {3.697376377199*^9, 
   3.697376377525*^9}, {3.697376760086*^9, 3.697376781965*^9}, {
   3.6973921288386927`*^9, 3.697392136874468*^9}, {3.697392234342211*^9, 
   3.697392247332252*^9}, 3.6973923478257093`*^9}],

Cell[BoxData["0.02`"], "Output",
 CellChangeTimes->{
  3.674317316421*^9, 3.674317361016*^9, 3.674318278676*^9, 3.67431876766*^9, 
   3.674388831064004*^9, 3.674389031708366*^9, 3.6743891342347918`*^9, 
   3.674389674610982*^9, 3.674399222627493*^9, 3.674399252682413*^9, 
   3.6743995893040714`*^9, 3.674399759369116*^9, 3.674399927587222*^9, 
   3.674400335782*^9, 3.674400409392*^9, 3.674403597803*^9, 
   3.6744036561540003`*^9, 3.674403687608*^9, {3.674403764921*^9, 
   3.674403802057*^9}, 3.6744049437469997`*^9, 3.674405856578*^9, 
   3.674405893824*^9, 3.6744612902652073`*^9, 3.674461389677208*^9, 
   3.6744618997032075`*^9, 3.6744619343592076`*^9, {3.674461989870208*^9, 
   3.674462026436208*^9}, 3.6744625829052076`*^9, 3.674468071578*^9, 
   3.6744689783859997`*^9, 3.6744823269594*^9, 3.6744823995334*^9, 
   3.6744824427743998`*^9, 3.6745231733816023`*^9, 3.6745236365956025`*^9, {
   3.6745423035556006`*^9, 3.6745423110586004`*^9}, 3.6745431132786007`*^9, {
   3.6782747351878004`*^9, 3.6782747538858004`*^9}, 3.6970268547234*^9, 
   3.6970268938374*^9, 3.6970269312934*^9, 3.6970295165713997`*^9, {
   3.6970313327894*^9, 3.6970313465494003`*^9}, 3.6971288722279997`*^9, 
   3.697129166502*^9, 3.6971292471219997`*^9, {3.6971295640810003`*^9, 
   3.697129572675*^9}, {3.697129633289*^9, 3.697129662631*^9}, {
   3.697130094323*^9, 3.697130118325*^9}, {3.697130337145*^9, 
   3.6971303471289997`*^9}, 3.6971742787720003`*^9, {3.6971754155220003`*^9, 
   3.697175453307*^9}, {3.6971754895299997`*^9, 3.697175501144*^9}, 
   3.697175719709*^9, 3.697175762992*^9, 3.697352297671*^9, 
   3.6973548069700003`*^9, {3.697354897395*^9, 3.69735492275*^9}, 
   3.6973563527539997`*^9, {3.6973563924560003`*^9, 3.697356413645*^9}, 
   3.697356771219*^9, {3.697357001942*^9, 3.697357013807*^9}, 
   3.6973576747790003`*^9, 3.697358011605*^9, 3.69735847406*^9, 
   3.697359013797*^9, 3.697359484112*^9, {3.697375016639*^9, 
   3.697375082968*^9}, 3.69737637788*^9, {3.697376761475*^9, 
   3.697376783954*^9}, 3.6973781850699997`*^9, 3.697387515330448*^9, 
   3.6973916782719297`*^9, 3.6973921381484923`*^9, 3.6973922490198727`*^9, 
   3.6974315323636*^9}],

Cell[BoxData["0.00019999999999999996`"], "Output",
 CellChangeTimes->{
  3.674317316421*^9, 3.674317361016*^9, 3.674318278676*^9, 3.67431876766*^9, 
   3.674388831064004*^9, 3.674389031708366*^9, 3.6743891342347918`*^9, 
   3.674389674610982*^9, 3.674399222627493*^9, 3.674399252682413*^9, 
   3.6743995893040714`*^9, 3.674399759369116*^9, 3.674399927587222*^9, 
   3.674400335782*^9, 3.674400409392*^9, 3.674403597803*^9, 
   3.6744036561540003`*^9, 3.674403687608*^9, {3.674403764921*^9, 
   3.674403802057*^9}, 3.6744049437469997`*^9, 3.674405856578*^9, 
   3.674405893824*^9, 3.6744612902652073`*^9, 3.674461389677208*^9, 
   3.6744618997032075`*^9, 3.6744619343592076`*^9, {3.674461989870208*^9, 
   3.674462026436208*^9}, 3.6744625829052076`*^9, 3.674468071578*^9, 
   3.6744689783859997`*^9, 3.6744823269594*^9, 3.6744823995334*^9, 
   3.6744824427743998`*^9, 3.6745231733816023`*^9, 3.6745236365956025`*^9, {
   3.6745423035556006`*^9, 3.6745423110586004`*^9}, 3.6745431132786007`*^9, {
   3.6782747351878004`*^9, 3.6782747538858004`*^9}, 3.6970268547234*^9, 
   3.6970268938374*^9, 3.6970269312934*^9, 3.6970295165713997`*^9, {
   3.6970313327894*^9, 3.6970313465494003`*^9}, 3.6971288722279997`*^9, 
   3.697129166502*^9, 3.6971292471219997`*^9, {3.6971295640810003`*^9, 
   3.697129572675*^9}, {3.697129633289*^9, 3.697129662631*^9}, {
   3.697130094323*^9, 3.697130118325*^9}, {3.697130337145*^9, 
   3.6971303471289997`*^9}, 3.6971742787720003`*^9, {3.6971754155220003`*^9, 
   3.697175453307*^9}, {3.6971754895299997`*^9, 3.697175501144*^9}, 
   3.697175719709*^9, 3.697175762992*^9, 3.697352297671*^9, 
   3.6973548069700003`*^9, {3.697354897395*^9, 3.69735492275*^9}, 
   3.6973563527539997`*^9, {3.6973563924560003`*^9, 3.697356413645*^9}, 
   3.697356771219*^9, {3.697357001942*^9, 3.697357013807*^9}, 
   3.6973576747790003`*^9, 3.697358011605*^9, 3.69735847406*^9, 
   3.697359013797*^9, 3.697359484112*^9, {3.697375016639*^9, 
   3.697375082968*^9}, 3.69737637788*^9, {3.697376761475*^9, 
   3.697376783954*^9}, 3.6973781850699997`*^9, 3.697387515330448*^9, 
   3.6973916782719297`*^9, 3.6973921381484923`*^9, 3.6973922490198727`*^9, 
   3.6974315323666*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"Usol", "[", 
     RowBox[{"x", ",", "tinit", ",", "a"}], "]"}], ",", "x", ",", "x"}], 
   "]"}], "/.", 
  RowBox[{"x", "\[Rule]", "s0"}]}], "\[IndentingNewLine]", 
 RowBox[{"F", "[", 
  RowBox[{"a", ",", "N1", ",", "h"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6974315369376*^9, 3.6974315720576*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.5`"}]], "Output",
 CellChangeTimes->{{3.6974315379536*^9, 3.6974315724976*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.01`"}]], "Output",
 CellChangeTimes->{{3.6974315379536*^9, 3.6974315724996*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"fnc", "[", 
   RowBox[{"5", ",", "g1", ",", 
    RowBox[{"N1", "+", "1"}], ",", "U0"}], "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.697129830208*^9, 3.6971298439519997`*^9}, 
   3.697354975045*^9, {3.697355007756*^9, 3.6973550571099997`*^9}, {
   3.697355163495*^9, 3.6973551861809998`*^9}, {3.6973567810030003`*^9, 
   3.697356819561*^9}, {3.697356918101*^9, 3.697356924369*^9}}],

Cell[BoxData["0.667053621744572`"], "Output",
 CellChangeTimes->{{3.69735503895*^9, 3.697355057455*^9}, {3.697355164061*^9, 
   3.697355186457*^9}, 3.697355879899*^9, 3.6973563555439997`*^9, {
   3.6973563941619997`*^9, 3.697356415493*^9}, {3.697356774158*^9, 
   3.697356797715*^9}, {3.697356914498*^9, 3.697356924659*^9}, {
   3.697357005209*^9, 3.697357018086*^9}, 3.697358014763*^9, 
   3.697358481443*^9, 3.6973875324070835`*^9, 3.6973922569916487`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", "U0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gk", "=", "g1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etape", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{"Dynamic", "[", "etape", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nmax", "=", 
   RowBox[{"N1", "+", "10000"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"etape", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "-", "N1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"Nmax", "-", "N1"}], ")"}]}]}], ";", " ", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"ii", "=", "2"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "1", "]"}], "=", "gk"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "2", "]"}], "=", 
     RowBox[{"2", "gk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ecart", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"xx", "[", "2", "]"}], "-", 
       RowBox[{"xx", "[", "1", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ecart", ">", 
       RowBox[{
        RowBox[{"h", "^", "2"}], " ", 
        RowBox[{"xx", "[", "ii", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"ii", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"xx", "[", "ii", "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xx", "[", "ii", "]"}], "-", 
             RowBox[{"xx", "[", 
              RowBox[{"ii", "-", "1"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}], "-", 
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", 
                RowBox[{"ii", "-", "1"}], "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}]}], ")"}]}], 
          RowBox[{"fnc", "[", 
           RowBox[{
            RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", "U"}], 
           "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ecart", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"xx", "[", "ii", "]"}], "-", 
          RowBox[{"xx", "[", 
           RowBox[{"ii", "+", "1"}], "]"}]}], "]"}]}], ";", 
       RowBox[{"ii", "+=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"gs", "=", 
     RowBox[{"xx", "[", "ii", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ukp", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
      RowBox[{"0.5", 
       RowBox[{"h", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"gk", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Us", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"U", ",", 
       RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gsmiddle", "=", 
     RowBox[{
      RowBox[{"kr", " ", "gk"}], "+", 
      RowBox[{"gs", 
       RowBox[{"(", 
        RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Gsmiddle", "=", 
     RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Smat", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Qmatrix", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], ".", 
        "Us"}], "+", 
       RowBox[{"Rvector", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"U1", "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"P3matrix", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], "]"}], 
      ".", "Smat"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"FileGamma", ",", "gs"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"U", "=", "U1"}], ";", 
    RowBox[{"gk", "=", "gs"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", "0"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", 
     RowBox[{"N1", "+", "1"}], ",", "Nmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673966517050609*^9, 3.673966648861612*^9}, {
   3.6739666797556033`*^9, 3.6739667339020443`*^9}, {3.6739667659054856`*^9, 
   3.6739668163015313`*^9}, {3.6739668732540045`*^9, 3.67396691474284*^9}, {
   3.673966958903792*^9, 3.673966961216581*^9}, {3.6739670161994834`*^9, 
   3.67396701752775*^9}, {3.6739679274154677`*^9, 3.6739679396824503`*^9}, {
   3.6739679876094847`*^9, 3.6739679968292255`*^9}, {3.6739680750720124`*^9, 
   3.6739680801819315`*^9}, {3.673968127327625*^9, 3.673968206945562*^9}, 
   3.6739682994086266`*^9, {3.6739683921685934`*^9, 3.6739683927467794`*^9}, {
   3.6739699452135077`*^9, 3.6739699819987087`*^9}, {3.6739709681598845`*^9, 
   3.673970974316795*^9}, {3.6739710618261585`*^9, 3.673971119363633*^9}, {
   3.673971182432926*^9, 3.673971276177367*^9}, {3.673971315759741*^9, 
   3.6739713318083544`*^9}, {3.673971391814762*^9, 3.673971418208219*^9}, {
   3.6739717154078617`*^9, 3.6739717156578884`*^9}, 3.673971807183363*^9, {
   3.6739718759094987`*^9, 3.6739718888952217`*^9}, {3.6739765537468605`*^9, 
   3.6739765628884764`*^9}, {3.6739766217541704`*^9, 
   3.6739766366151457`*^9}, {3.673976769988827*^9, 3.673976821213117*^9}, 
   3.673976967306955*^9, {3.6740099737124968`*^9, 3.674009978291089*^9}, {
   3.674227038851217*^9, 3.6742270638694887`*^9}, {3.6742272186202755`*^9, 
   3.6742272204485545`*^9}, {3.6742272616717043`*^9, 3.67422729129984*^9}, {
   3.6742282940689316`*^9, 3.6742282961160192`*^9}, {3.674228382203255*^9, 
   3.67422840751849*^9}, {3.6742285603915777`*^9, 3.674228576971459*^9}, {
   3.6742295568536983`*^9, 3.674229615125483*^9}, {3.6742296550515847`*^9, 
   3.674229744920472*^9}, {3.674229826100938*^9, 3.6742298407743626`*^9}, {
   3.674229932627836*^9, 3.6742299537863226`*^9}, 3.674230023590584*^9, 
   3.6742302341199503`*^9, {3.6742327273011885`*^9, 3.6742327591326485`*^9}, 
   3.674232834953163*^9, {3.6743147973416324`*^9, 3.6743148918267193`*^9}, {
   3.6743156882281895`*^9, 3.6743157043149037`*^9}, {3.6743157502710843`*^9, 
   3.6743157663497877`*^9}, {3.6743158145639315`*^9, 
   3.6743158519423094`*^9}, {3.6743161713331785`*^9, 3.674316175726901*^9}, {
   3.6743162639664307`*^9, 3.674316268007161*^9}, {3.6743163070900087`*^9, 
   3.6743163356198316`*^9}, 3.674316497458014*^9, {3.6743165323978844`*^9, 
   3.674316532905239*^9}, 3.67431685601*^9, {3.674318740052*^9, 
   3.674318772635*^9}, {3.6743888447684307`*^9, 3.674388951511136*^9}, {
   3.674388990361424*^9, 3.674388996832595*^9}, 3.6743890440401077`*^9, {
   3.67438920945475*^9, 3.6743892144690447`*^9}, {3.674389317973166*^9, 
   3.674389320486865*^9}, {3.674398897753016*^9, 3.674398937115638*^9}, {
   3.674398997458021*^9, 3.6743991214656167`*^9}, {3.674399325794737*^9, 
   3.674399333855121*^9}, {3.6743993711944*^9, 3.6743994502043953`*^9}, 
   3.674399485407956*^9, {3.674399524548998*^9, 3.6743995284914713`*^9}, {
   3.6743996996895046`*^9, 3.674399728790809*^9}, {3.6744000691983523`*^9, 
   3.6744000767915335`*^9}, {3.67440018919532*^9, 3.6744001969348583`*^9}, 
   3.674400350852*^9, 3.674400402828*^9, {3.674404954777*^9, 
   3.6744049571280003`*^9}, {3.674405889367*^9, 3.674405889743*^9}, 
   3.674406570192*^9, 3.6744824552974*^9, {3.6745431096206007`*^9, 
   3.6745431253316007`*^9}, 3.6970268589574003`*^9, {3.697129155329*^9, 
   3.6971291558*^9}, {3.697354851495*^9, 3.6973548520150003`*^9}, 
   3.697357227417*^9, {3.697359481856*^9, 3.6973594822469997`*^9}, {
   3.697375029752*^9, 3.697375030007*^9}, 3.697376788369*^9}],

Cell[BoxData[
 ProgressIndicatorBox[Dynamic[$CellContext`etape]]], "Output",
 CellChangeTimes->{
  3.6742295516499763`*^9, 3.6742297545933266`*^9, 3.6742298419931965`*^9, {
   3.6742299400660725`*^9, 3.6742299544738812`*^9}, {3.674229995415718*^9, 
   3.6742300243406134`*^9}, 3.6742302394017534`*^9, 3.67423276067968*^9, 
   3.6742328081847034`*^9, 3.674232854642743*^9, 3.6743148929025774`*^9, 
   3.6743158571420975`*^9, 3.6743158874306035`*^9, 3.6743162794284806`*^9, 
   3.674316370184701*^9, {3.674316473151373*^9, 3.674316498488763*^9}, 
   3.674316533989072*^9, {3.674316852803*^9, 3.674316881249*^9}, 
   3.6743187767320004`*^9, 3.6743890037971377`*^9, 3.674389045364587*^9, 
   3.6743896799400973`*^9, 3.674399529708704*^9, 3.674399770074535*^9, 
   3.674400198190196*^9, {3.6744003432980003`*^9, 3.674400351166*^9}, 
   3.674400418021*^9, 3.674403660801*^9, 3.674403716627*^9, 3.674403768797*^9,
    3.67440380629*^9, 3.674404957752*^9, {3.674405875675*^9, 
   3.6744058980290003`*^9}, 3.6744680903459997`*^9, 3.6744689869960003`*^9, 
   3.6744824604393997`*^9, 3.674523184048602*^9, 3.6745236583816023`*^9, 
   3.674542334611601*^9, 3.6745431264456005`*^9, {3.6782747374008*^9, 
   3.6782747571238003`*^9}, 3.6970268617794*^9, 3.6970268985014*^9, 
   3.697128877618*^9, 3.697129156453*^9, 3.697354819514*^9, 3.697356955909*^9,
    3.697357020447*^9, 3.6973572361879997`*^9, 3.697358017634*^9, 
   3.697358489126*^9, 3.697359015578*^9, 3.697359485927*^9, {
   3.6973750446099997`*^9, 3.69737505635*^9}, 3.697375086797*^9, 
   3.697376386052*^9, {3.697376768913*^9, 3.6973767901070004`*^9}, 
   3.69737818762*^9, 3.697387537238209*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.6742295516499763`*^9, 3.6742297545933266`*^9, 3.6742298419931965`*^9, {
   3.6742299400660725`*^9, 3.6742299544738812`*^9}, {3.674229995415718*^9, 
   3.6742300243406134`*^9}, 3.6742302394017534`*^9, 3.67423276067968*^9, 
   3.6742328081847034`*^9, 3.674232854642743*^9, 3.6743148929025774`*^9, 
   3.6743158571420975`*^9, 3.6743158874306035`*^9, 3.6743162794284806`*^9, 
   3.674316370184701*^9, {3.674316473151373*^9, 3.674316498488763*^9}, 
   3.674316533989072*^9, {3.674316852803*^9, 3.674316881249*^9}, 
   3.6743187767320004`*^9, 3.6743890037971377`*^9, 3.674389045364587*^9, 
   3.6743896799400973`*^9, 3.674399529708704*^9, 3.674399770074535*^9, 
   3.674400198190196*^9, {3.6744003432980003`*^9, 3.674400351166*^9}, 
   3.674400418021*^9, 3.674403660801*^9, 3.674403716627*^9, 3.674403768797*^9,
    3.67440380629*^9, 3.674404957752*^9, {3.674405875675*^9, 
   3.6744058980290003`*^9}, 3.6744680903459997`*^9, 3.6744689869960003`*^9, 
   3.6744824604393997`*^9, 3.674523184048602*^9, 3.6745236583816023`*^9, 
   3.674542334611601*^9, 3.6745431264456005`*^9, {3.6782747374008*^9, 
   3.6782747571238003`*^9}, 3.6970268617794*^9, 3.6970268985014*^9, 
   3.697128877618*^9, 3.697129156453*^9, 3.697354819514*^9, 3.697356955909*^9,
    3.697357020447*^9, 3.6973572361879997`*^9, 3.697358017634*^9, 
   3.697358489126*^9, 3.697359015578*^9, 3.697359485927*^9, {
   3.6973750446099997`*^9, 3.69737505635*^9}, 3.697375086797*^9, 
   3.697376386052*^9, {3.697376768913*^9, 3.6973767901070004`*^9}, 
   3.69737818762*^9, 3.6973875472109146`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{"s0", "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        RowBox[{"1", "-", "a"}]]}], 
      SqrtBox["a"]], " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"t", "-", "tinit"}], " ", "]"}]}]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.673971840765055*^9, 3.673971841030751*^9}, {
   3.6742330759309063`*^9, 3.674233077212247*^9}, {3.674233235226675*^9, 
   3.6742332547912445`*^9}, {3.6744011321870003`*^9, 3.674401163651*^9}, {
   3.674401596632*^9, 3.674401608967*^9}, {3.674401805447*^9, 
   3.674401805767*^9}, {3.674403563542*^9, 3.6744035642060003`*^9}, 
   3.674404507383*^9, {3.674406050126*^9, 3.674406068204*^9}, {
   3.674406441612*^9, 3.6744064420950003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0Gk81IsCh/GxhFMd3WQJJeNkZAtJpdLvok1Sok4kFOrDcY9t2uQmGrsW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1.2}, {0., 1.5983862409038672`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6744011505290003`*^9, 3.674401164582*^9}, {
   3.674401601624*^9, 3.674401610568*^9}, {3.674401798417*^9, 
   3.674401806126*^9}, 3.6744035645290003`*^9, 3.67440446508*^9, 
   3.6744045081809998`*^9, {3.674406429849*^9, 3.6744064424300003`*^9}, 
   3.674469612951*^9, 3.6782782991838*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"tps", "[", "2", "]"}], "=", 
    RowBox[{"tinit", "+", 
     RowBox[{
      RowBox[{"h", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tps", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"tps", "[", "2", "]"}], "+", 
     RowBox[{
      RowBox[{"h", "/", "3"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"4", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tps", "[", "k", "]"}], "=", 
      RowBox[{
       RowBox[{"tps", "[", 
        RowBox[{"k", "-", "2"}], "]"}], "+", 
       RowBox[{
        RowBox[{"h", "/", "3"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "+", 
          RowBox[{"4", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "1"}], "]"}], "]"}]}], "+", 
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "2"}], "]"}], "]"}]}]}], ")"}]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "4", ",", 
       RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674401245474*^9, 3.6744014430889997`*^9}, {
   3.674401481816*^9, 3.674401511163*^9}, {3.674406079924*^9, 
   3.6744060817799997`*^9}, 3.674523199246602*^9, 3.6782741213088*^9}],

Cell[BoxData["0.0002253515357755661`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674468914316*^9, 3.674469615178*^9, 3.6744828985794*^9, 
   3.6745236007506027`*^9, 3.6745242020596027`*^9, 3.6745430951536007`*^9, 
   3.67455288995*^9, 3.6782783018318005`*^9, 3.69735842751*^9, 
   3.697358984929*^9, 3.69735946577*^9, 3.6973595865150003`*^9, 
   3.6973763619449997`*^9, 3.6973767213389997`*^9, 3.6973836318059998`*^9}],

Cell[BoxData["0.00028017265127276643`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674468914316*^9, 3.674469615178*^9, 3.6744828985794*^9, 
   3.6745236007506027`*^9, 3.6745242020596027`*^9, 3.6745430951536007`*^9, 
   3.67455288995*^9, 3.6782783018318005`*^9, 3.69735842751*^9, 
   3.697358984929*^9, 3.69735946577*^9, 3.6973595865150003`*^9, 
   3.6973763619449997`*^9, 3.6973767213389997`*^9, 3.697383631808*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"figure", " ", "B13"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"des", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"tps", "[", "k", "]"}], ",", 
           RowBox[{"s0", "+", 
            RowBox[{"k", " ", "h"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", 
           RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}], ",", "12"}], "}"}]}],
        ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[SubscriptBox[\"x\", \"f\"],
FontSlant->\"Italic\"]\)\>\""}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", " ", 
      RowBox[{
       RowBox[{"s0", "+", 
        RowBox[{
         FractionBox[
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox[
            RowBox[{"1", "-", "a"}]]}], 
          SqrtBox["a"]], " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"t", "-", "tinit"}], " ", "]"}]}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "2.5"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674401540975*^9, 3.674401584967*^9}, {3.674406462454*^9,
    3.674406525742*^9}, {3.674468922807*^9, 3.674468923031*^9}, {
   3.6745236140116024`*^9, 3.674523614251602*^9}, {3.6745242133616023`*^9, 
   3.6745242138486023`*^9}, 3.674552896487*^9, {3.6745530048380003`*^9, 
   3.674553094742*^9}, {3.6782737355348005`*^9, 3.6782737470788*^9}, {
   3.697358453676*^9, 3.6973584539300003`*^9}, {3.6973589928640003`*^9, 
   3.697358996869*^9}, {3.6973836423450003`*^9, 3.697383642775*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], 
      StyleBox[PointBox[CompressedData["
1:eJws23dcTf8fB3AyQoiMzEhkZGSveJFZ9t4RkhnZIzv5KitSCBVSkoZ2Snvv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        "]],
       FontFamily->"Times"]}, {}}, {}, {}, {{}, {}}}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVjns41PkCh+c3v9Ri7KJ9NpU0dTCaxard9sTG5xslqTOd3ZJNupjKFNLy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       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times", 12},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"x\\\", \
\\\"f\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6744015417860003`*^9, 3.674401585866*^9, {3.674406434427*^9, 
   3.674406463814*^9}, {3.6744064989630003`*^9, 3.674406526631*^9}, {
   3.67446891675*^9, 3.674468923367*^9}, 3.674469617216*^9, 
   3.6744829009834003`*^9, {3.6745236027306023`*^9, 3.6745236146066027`*^9}, {
   3.6745242046796026`*^9, 3.6745242146106024`*^9}, 3.6745430990756006`*^9, {
   3.6745528921549997`*^9, 3.674552896891*^9}, {3.674553021333*^9, 
   3.674553049718*^9}, {3.674553082395*^9, 3.674553095638*^9}, 
   3.6782783050868*^9, {3.697358429677*^9, 3.697358454317*^9}, {
   3.697358986958*^9, 3.6973589976689997`*^9}, 3.6973594687139997`*^9, 
   3.697359588198*^9, 3.697376363951*^9, 3.697376723804*^9, {
   3.697383635493*^9, 3.6973836431879997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ComparaisonF(a).eps\>\"", ",", "des", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674553106828*^9, 3.674553122342*^9}}],

Cell[BoxData["\<\"ComparaisonF(a).eps\"\>"], "Output",
 CellChangeTimes->{3.674553125358*^9, 3.697383653928*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"tps", "[", "k", "]"}], ",", 
    RowBox[{"s0", "+", 
     RowBox[{"k", " ", "h"}]}]}], "}"}], "/.", 
  RowBox[{"k", "->", 
   RowBox[{"Length", "[", "FileGamma", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s0", "+", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       RowBox[{"1", "-", "a"}]]}], 
     SqrtBox["a"]], " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"t", "-", "tinit"}], " ", "]"}]}]}], " ", "/.", 
  RowBox[{"t", "->", "3.3010737955744434`"}]}]}], "Input",
 CellChangeTimes->{{3.697383683349*^9, 3.697383709854*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.3010737955744434`", ",", "2.569`"}], "}"}]], "Output",
 CellChangeTimes->{{3.697383688058*^9, 3.697383711099*^9}}],

Cell[BoxData["2.5893866176869698`"], "Output",
 CellChangeTimes->{{3.697383688058*^9, 3.697383711101*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2.569", "-", "2.5893866176869698"}], ")"}], "/", 
   "2.5893866176869698"}], "*", "100"}]], "Input",
 CellChangeTimes->{{3.697383723284*^9, 3.6973837384440002`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.7873145534821925`"}]], "Output",
 CellChangeTimes->{3.697383739053*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Boundary condition ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "z"], TraditionalForm]]],
 " u = - a (Equation B4 with a = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Gamma]", "."], "c"], TraditionalForm]]],
 ")---Figures 6 to 8, B11"
}], "Section",
 CellChangeTimes->{{3.6739665004081616`*^9, 3.6739665088465996`*^9}, {
   3.6739701396406593`*^9, 3.6739701506262136`*^9}, {3.6739768840636225`*^9, 
   3.6739768858450317`*^9}, {3.6742269616087046`*^9, 3.674226963655799*^9}, 
   3.674404850061*^9, 3.6744442207022076`*^9, 3.6744633655892076`*^9, {
   3.674471336668*^9, 3.674471342572*^9}, {3.6782741411178*^9, 
   3.6782741506538*^9}, {3.6782741893878*^9, 3.6782742300718*^9}, {
   3.6782742604068003`*^9, 3.6782742621198*^9}, {3.6782747905878*^9, 
   3.6782747950918*^9}, {3.698474306385*^9, 3.698474319105*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"boundary", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"a_", ",", "k_", ",", "h_"}], "]"}], ":=", 
    RowBox[{"-", "a"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"x_", ",", "xl_", ",", "a_"}], "]"}], ":=", " ", 
    RowBox[{"a", "  ", "xl", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "/", "xl"}], ")"}], " ", "^", "2"}]}], ")"}], " ", "/",
       "2"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"secant", " ", "method"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fnc", "[", 
     RowBox[{"gamma_", ",", "gk_", ",", "k_", ",", "U_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "ukp", ",", "Us", ",", "gsmiddle", ",", "Smat", ",", "U1", ",", 
        "Gsmiddle", ",", "RR"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ukp", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"h", "^", "2"}], "/", "2"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", " ", 
            RowBox[{"Rey", " ", "gk", " ", 
             RowBox[{"F", "[", 
              RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Us", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"U", ",", 
          RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"gsmiddle", "=", 
        RowBox[{
         RowBox[{"kr", " ", "gk"}], "+", 
         RowBox[{"gamma", 
          RowBox[{"(", 
           RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Gsmiddle", "=", 
        RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"RR", "=", 
        RowBox[{"Rvector", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Smat", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Qmatrix", "[", 
            RowBox[{
             RowBox[{"k", "+", "1"}], ",", "r", ",", 
             RowBox[{"Rey", " ", "Gsmiddle"}]}], "]"}], ".", "Us"}], "+", 
          RowBox[{"Rvector", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"U1", "=", 
        RowBox[{
         RowBox[{"Inverse", "[", 
          RowBox[{"P3matrix", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "r", ",", " ", 
            RowBox[{"Rey", " ", "Gsmiddle"}]}], "]"}], "]"}], ".", "Smat"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"U1", " ", "[", 
        RowBox[{"[", 
         RowBox[{"k", "+", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "parameters", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.001"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"mesh", " ", "size"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", "0.5"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"a", "=", 
     FormBox[
      SubscriptBox[
       OverscriptBox["\[Gamma]", "."], "c"],
      TraditionalForm]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.5"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "free", " ", "parameter", " ", "implicit", " ", "discretization"}], ",", 
     " ", 
     RowBox[{"k", " ", "=", " ", 
      RowBox[{
      "0.5", " ", "for", " ", "the", " ", "Crank", " ", "Nicolson", " ", 
       "scheme"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kr", "=", "0"}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "free", " ", "parameter", " ", "implicit", " ", "discretization"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rey", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"N1", "=", "600"}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "size", " ", "of", " ", "the", " ", "initial", " ", "disturbance"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"s0", "=", 
    RowBox[{"N1", " ", "h"}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "front", " ", "position"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tinit", "=", "0"}], " ", ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "time"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"i", " ", "h"}], ",", "s0", ",", "a"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "N1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t1", "=", "tinit"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "+", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"g", "[", 
              RowBox[{"x", ",", "s0", ",", "a"}], "]"}], ",", "x", ",", "x"}],
             "]"}]}], "/.", 
          RowBox[{"x", "\[Rule]", "s0"}]}], ")"}]}], "/", 
       RowBox[{"F", "[", 
        RowBox[{"a", ",", "N1", ",", "h"}], "]"}]}], "/", "Rey"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temps", "=", 
     RowBox[{"{", "t1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FileGamma", "=", 
     RowBox[{"{", "g1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6739291182704935`*^9, 3.673929229485534*^9}, {
   3.6739293428258495`*^9, 3.67392939347196*^9}, {3.673929590604376*^9, 
   3.6739295943391967`*^9}, {3.6739670738931627`*^9, 3.673967141228506*^9}, {
   3.6739680319267387`*^9, 3.6739680477565284`*^9}, {3.673968161300024*^9, 
   3.6739681659099035`*^9}, 3.6739683634936314`*^9, 3.673969959636938*^9, {
   3.673970921686137*^9, 3.6739709218736563`*^9}, 3.6739777694458017`*^9, {
   3.673977888755495*^9, 3.6739779063198833`*^9}, {3.6739784566446724`*^9, 
   3.6739784626765747`*^9}, {3.6739785742354403`*^9, 3.673978591299775*^9}, {
   3.6739786252565527`*^9, 3.6739786254596977`*^9}, {3.6739787155318804`*^9, 
   3.6739787189384975`*^9}, 3.6740093860723753`*^9, 3.674009487036134*^9, {
   3.67400994474065*^9, 3.6740099531635857`*^9}, {3.6742270049570503`*^9, 
   3.674227009285633*^9}, 3.674228227061883*^9, 3.6742282710040298`*^9, {
   3.6742283563568144`*^9, 3.674228363435691*^9}, {3.674228838905471*^9, 
   3.674228856782359*^9}, 3.6742298096929507`*^9, {3.6742299850239697`*^9, 
   3.674229989243194*^9}, {3.674316421293583*^9, 3.674316466235029*^9}, 
   3.6743165230019073`*^9, 3.674316879418*^9, 3.674317315226*^9, 
   3.674317360684*^9, {3.6743182695*^9, 3.6743182769700003`*^9}, {
   3.6743989727132587`*^9, 3.674398973493326*^9}, 3.674399221369187*^9, {
   3.6743996650494323`*^9, 3.674399686002122*^9}, {3.6743999100826592`*^9, 
   3.674399910694292*^9}, {3.674400007407155*^9, 3.6744000078663387`*^9}, 
   3.6744035918570004`*^9, 3.674403624744*^9, {3.674403740209*^9, 
   3.674403784679*^9}, {3.67440486255*^9, 3.674404864105*^9}, 
   3.6744049388710003`*^9, {3.674405195928*^9, 3.6744052264779997`*^9}, {
   3.67440526416*^9, 3.674405322318*^9}, {3.674405609501*^9, 
   3.674405629849*^9}, {3.674405761408*^9, 3.6744057669119997`*^9}, {
   3.674405806807*^9, 3.674405837641*^9}, 3.674444228283208*^9, 
   3.674471346639*^9, {3.674528733520602*^9, 3.6745287413756027`*^9}, {
   3.6745531358050003`*^9, 3.674553184454*^9}, 3.674995963836*^9, {
   3.6749960042209997`*^9, 3.6749960331870003`*^9}, {3.674996276995*^9, 
   3.674996277434*^9}, {3.6749963076809998`*^9, 3.674996334329*^9}, {
   3.6782735544398003`*^9, 3.6782735554158*^9}, {3.6782742697278004`*^9, 
   3.6782743068848*^9}, {3.6782744069568005`*^9, 3.6782744199818*^9}, {
   3.6782745081648*^9, 3.6782745135728*^9}, {3.6782746536868*^9, 
   3.6782746822928*^9}, {3.6782748885318003`*^9, 3.6782750013078003`*^9}, 
   3.696352632855*^9, {3.6963536507790003`*^9, 3.6963536510439997`*^9}, {
   3.6967422231472*^9, 3.6967422428142*^9}, 3.6967422798452*^9, {
   3.6967426106432*^9, 3.6967426108761997`*^9}, {3.6967427823272*^9, 
   3.6967427879892*^9}, {3.6967429171991997`*^9, 3.6967429677802*^9}, {
   3.6970264553993998`*^9, 3.6970264757754*^9}, {3.6970265118084*^9, 
   3.6970265914463997`*^9}, {3.6970266243754*^9, 3.6970266670604*^9}, {
   3.6970267898964*^9, 3.6970267904714003`*^9}, 3.6970319164524*^9, {
   3.697175799314*^9, 3.6971758094560003`*^9}, 3.697175846976*^9, {
   3.697175912818*^9, 3.697175924999*^9}, {3.697175977591*^9, 
   3.6971760038389997`*^9}, {3.697182502799*^9, 3.697182524038*^9}, {
   3.69718268627*^9, 3.697182750234*^9}, {3.697183383778*^9, 
   3.697183450841*^9}, 3.697183493835*^9, {3.697291617468*^9, 
   3.69729166388*^9}, {3.6972919484890003`*^9, 3.6972919487980003`*^9}, {
   3.6972919915299997`*^9, 3.697291993273*^9}, {3.697352322678*^9, 
   3.697352323105*^9}, 3.6973523671429996`*^9, {3.697376923284*^9, 
   3.697376949637*^9}, {3.697377334901*^9, 3.6973773555959997`*^9}, 
   3.697378476325153*^9, 3.6973791645955195`*^9, {3.697382663883668*^9, 
   3.6973826644827013`*^9}, {3.6973827605971994`*^9, 3.6973828200526*^9}, 
   3.6973830102004757`*^9, {3.6973830979704957`*^9, 3.6973831038518324`*^9}, {
   3.6973859989639997`*^9, 3.6973860036140003`*^9}, {3.697386063782*^9, 
   3.6973861040699997`*^9}, {3.697386212472*^9, 3.697386297541*^9}, {
   3.697386338686*^9, 3.697386339301*^9}, {3.697386370177*^9, 
   3.697386395914*^9}, 3.697386439685*^9, {3.697386492395*^9, 
   3.69738649379*^9}, 3.6973868731940002`*^9, {3.697388518637288*^9, 
   3.697388519102985*^9}, {3.697388596371099*^9, 3.697388636705883*^9}, 
   3.6973890688010387`*^9, {3.69738965566579*^9, 3.6973897119124794`*^9}, {
   3.69739086689566*^9, 3.6973908677656174`*^9}, 3.6974316076396*^9, {
   3.6974316384386*^9, 3.6974316671085997`*^9}, {3.6974316983966*^9, 
   3.6974317136766*^9}, {3.6974317511806*^9, 3.6974317689556*^9}, {
   3.6974318011976*^9, 3.6974318165016003`*^9}, {3.6974320269636*^9, 
   3.6974320277785997`*^9}, 3.6974322132046003`*^9, 3.6974323358216*^9, {
   3.6974339080246*^9, 3.6974339480776*^9}, {3.6974340091486*^9, 
   3.6974340095956*^9}, {3.6974341336296*^9, 3.6974341923956003`*^9}, {
   3.6974351809796*^9, 3.6974352080285997`*^9}, {3.6974352664056*^9, 
   3.6974353205656*^9}, 3.6974353883336*^9, 3.698223896716*^9, 
   3.698223934665*^9, 3.698224288326*^9, {3.698226004046*^9, 
   3.6982260508929996`*^9}, {3.6982267041809998`*^9, 3.698226707436*^9}, {
   3.69822685956*^9, 3.69822686341*^9}, 3.6982268992349997`*^9, 
   3.698226937709*^9, 3.698326974757*^9, 3.698327140381*^9, {
   3.6983271764379997`*^9, 3.698327204469*^9}, {3.698327254711*^9, 
   3.6983272791549997`*^9}, {3.69832746663*^9, 3.69832747574*^9}, {
   3.698333093021*^9, 3.6983330945480003`*^9}, 3.698335444591*^9, 
   3.698336695349*^9, 3.698474347064*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"check", " ", "that", " ", "g1"}], " ", ">", " ", 
    RowBox[{"0", " ", 
     RowBox[{"(", 
      RowBox[{"initial", " ", "velocity", " ", "increment"}], ")"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]", "g1"}]], "Input",
 CellChangeTimes->{{3.6974318363136*^9, 3.6974318374406*^9}, {
  3.698473836763*^9, 3.6984738593929996`*^9}}],

Cell[BoxData["0.33333333333333326`"], "Output",
 CellChangeTimes->{{3.6974316906916*^9, 3.6974317184236*^9}, {
   3.6974318256316*^9, 3.6974318382076*^9}, 3.6974339930736*^9, {
   3.6974341447036*^9, 3.6974341742446003`*^9}, 3.6974352233836*^9, {
   3.6974352762846003`*^9, 3.6974352951986*^9}, {3.698223911682*^9, 
   3.6982239397609997`*^9}, 3.698225992276*^9, 3.698226026227*^9, 
   3.698226058743*^9, 3.698226879373*^9, 3.698226910133*^9, 3.698226949833*^9,
    3.6983267539709997`*^9, 3.6983269773450003`*^9, 3.69832720877*^9, {
   3.6983272733780003`*^9, 3.69832728187*^9}, 3.698327479276*^9, 
   3.6983331001619997`*^9, {3.698335432236*^9, 3.698335447526*^9}, 
   3.698336750889*^9, 3.6983833049939995`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "check", " ", "the", " ", "condition", " ", "for", " ", "incipient", " ", 
    "motion", " ", "given", " ", "by", " ", 
    RowBox[{"Eq", ".", " ", "23"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Interpolation", "[", "U0", "]"}], "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1", ",", "N1"}], "}"}]}], "]"}], "*", "h"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "s0"}], ")"}], "/", "Rey"}], " ", "h"}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"g", "[", 
               RowBox[{"x", ",", "s0", ",", "a"}], "]"}], ",", "x", ",", 
              "x"}], "]"}], "/.", 
            RowBox[{"x", "\[Rule]", "s0"}]}], ")"}]}], ")"}], "/", "2"}], "/",
        "a"}], "/", "Rey"}], " ", 
     RowBox[{"h", "^", "2"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.698473864617*^9, 3.698473903777*^9}}],

Cell[BoxData["0.05999975013888888`"], "Output",
 CellChangeTimes->{
  3.697386857446*^9, 3.697387602313092*^9, 3.6973890940705166`*^9, {
   3.697389673387472*^9, 3.697389720738407*^9}, 3.6973908774057813`*^9, 
   3.6974317326856003`*^9, 3.6974320527925997`*^9, 3.6974323447716*^9, 
   3.6974342623276*^9, {3.6974352795116*^9, 3.6974353010425997`*^9}, 
   3.6982239450360003`*^9, 3.698225995459*^9, 3.6982260300959997`*^9, 
   3.698226063205*^9, 3.698226882436*^9, 3.698226914115*^9, 
   3.6982269537279997`*^9, 3.698326759035*^9, 3.6983272108389997`*^9, 
   3.698327485373*^9, 3.698335454377*^9, 3.6983367546549997`*^9}],

Cell[BoxData["0.0011001666666666668`"], "Output",
 CellChangeTimes->{
  3.697386857446*^9, 3.697387602313092*^9, 3.6973890940705166`*^9, {
   3.697389673387472*^9, 3.697389720738407*^9}, 3.6973908774057813`*^9, 
   3.6974317326856003`*^9, 3.6974320527925997`*^9, 3.6974323447716*^9, 
   3.6974342623276*^9, {3.6974352795116*^9, 3.6974353010425997`*^9}, 
   3.6982239450360003`*^9, 3.698225995459*^9, 3.6982260300959997`*^9, 
   3.698226063205*^9, 3.698226882436*^9, 3.698226914115*^9, 
   3.6982269537279997`*^9, 3.698326759035*^9, 3.6983272108389997`*^9, 
   3.698327485373*^9, 3.698335454377*^9, 3.698336754657*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tempsGarder", "=", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"51", ",", "126", ",", "338"}], "}"}], "+", "N1"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "times", " ", "at", " ", "which", " ", "the", " ", "solution", " ", "is", 
     " ", "plot"}], " ", ";", " ", 
    RowBox[{
    "I", " ", "use", " ", "the", " ", "interpolating", " ", "function", " ", 
     "\"\<poly\>\"", " ", "to", " ", "find", " ", "the", " ", "values", " ", 
     "of", " ", "k", " ", "corresponding", " ", "to", " ", "these", " ", 
     "times"}]}], " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vitesse", "=", 
   RowBox[{"{", "U0", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vitesse1", "=", 
   RowBox[{"{", "U0", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"acceleration0", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"detailG", "=", 
   RowBox[{"{", "g1", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6747145904519997`*^9, 3.6747146184820004`*^9}, {
   3.674714661651*^9, 3.67471466609*^9}, {3.674824441616*^9, 
   3.6748244440620003`*^9}, {3.6749655028100014`*^9, 3.674965509632001*^9}, {
   3.674994901243*^9, 3.674994937771*^9}, {3.6750001498789997`*^9, 
   3.675000151304*^9}, {3.675000820224*^9, 3.675000820863*^9}, 
   3.675001597612*^9, {3.6782743425328*^9, 3.6782743613978004`*^9}, 
   3.6782744205798*^9, {3.6782750169878*^9, 3.6782750194038*^9}, 
   3.696336819093*^9, {3.6974340801376*^9, 3.6974340805296*^9}, 
   3.6982243190030003`*^9, {3.698226726*^9, 3.69822673401*^9}, {
   3.698226801211*^9, 3.698226803257*^9}, {3.698335394394*^9, 
   3.698335413712*^9}, {3.698336700035*^9, 3.6983367020039997`*^9}, {
   3.698338362889*^9, 3.6983383755369997`*^9}, {3.6984739195220003`*^9, 
   3.6984739683450003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", "U0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gk", "=", "g1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etape", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{"Dynamic", "[", "etape", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nmax", "=", 
   RowBox[{"N1", "+", "2000"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"etape", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "-", "N1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"Nmax", "-", "N1"}], ")"}]}]}], ";", " ", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"ii", "=", "2"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "1", "]"}], "=", "gk"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "2", "]"}], "=", 
     RowBox[{"0.5", "gk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ecart", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"xx", "[", "2", "]"}], "-", 
       RowBox[{"xx", "[", "1", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ecart", ">", 
       RowBox[{
        RowBox[{"h", "^", "2"}], " ", 
        RowBox[{"xx", "[", "ii", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"ii", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"xx", "[", "ii", "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xx", "[", "ii", "]"}], "-", 
             RowBox[{"xx", "[", 
              RowBox[{"ii", "-", "1"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}], "-", 
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", 
                RowBox[{"ii", "-", "1"}], "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}]}], ")"}]}], 
          RowBox[{"fnc", "[", 
           RowBox[{
            RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", "U"}], 
           "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ecart", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"xx", "[", "ii", "]"}], "-", 
          RowBox[{"xx", "[", 
           RowBox[{"ii", "+", "1"}], "]"}]}], "]"}]}], ";", 
       RowBox[{"ii", "+=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"gs", "=", 
     RowBox[{"xx", "[", "ii", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ukp", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
      RowBox[{"0.5", 
       RowBox[{"h", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"gk", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Us", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"U", ",", 
       RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gsmiddle", "=", 
     RowBox[{
      RowBox[{"kr", " ", "gk"}], "+", 
      RowBox[{"gs", 
       RowBox[{"(", 
        RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Gsmiddle", "=", 
     RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Smat", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Qmatrix", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "r", ",", 
          RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], ".", "Us"}], "+", 
       RowBox[{"Rvector", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"U1", "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"P3matrix", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "r", ",", 
         RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], "]"}], ".", "Smat"}]}], 
    ";", 
    RowBox[{
     RowBox[{"U1", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MemberQ", "[", 
       RowBox[{"tempsGarder", ",", "k"}], "]"}], ",", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"vitesse1", ",", "U1"}], "]"}], ";", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"vitesse", ",", "U"}], "]"}], ";", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"detailG", ",", "gs"}], "]"}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"FileGamma", ",", "gs"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"acceleration0", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"U1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", 
          RowBox[{"U", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "h"}], "/", "gs"}]}],
      "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"U", "=", "U1"}], ";", 
    RowBox[{"gk", "=", "gs"}]}], ",", "\[IndentingNewLine]", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", 
     RowBox[{"N1", "+", "1"}], ",", "Nmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673966517050609*^9, 3.673966648861612*^9}, {
   3.6739666797556033`*^9, 3.6739667339020443`*^9}, {3.6739667659054856`*^9, 
   3.6739668163015313`*^9}, {3.6739668732540045`*^9, 3.67396691474284*^9}, {
   3.673966958903792*^9, 3.673966961216581*^9}, {3.6739670161994834`*^9, 
   3.67396701752775*^9}, {3.6739679274154677`*^9, 3.6739679396824503`*^9}, {
   3.6739679876094847`*^9, 3.6739679968292255`*^9}, {3.6739680750720124`*^9, 
   3.6739680801819315`*^9}, {3.673968127327625*^9, 3.673968206945562*^9}, 
   3.6739682994086266`*^9, {3.6739683921685934`*^9, 3.6739683927467794`*^9}, {
   3.6739699452135077`*^9, 3.6739699819987087`*^9}, {3.6739709681598845`*^9, 
   3.673970974316795*^9}, {3.6739710618261585`*^9, 3.673971119363633*^9}, {
   3.673971182432926*^9, 3.673971276177367*^9}, {3.673971315759741*^9, 
   3.6739713318083544`*^9}, {3.673971391814762*^9, 3.673971418208219*^9}, {
   3.6739717154078617`*^9, 3.6739717156578884`*^9}, 3.673971807183363*^9, {
   3.6739718759094987`*^9, 3.6739718888952217`*^9}, {3.6739765537468605`*^9, 
   3.6739765628884764`*^9}, {3.6739766217541704`*^9, 
   3.6739766366151457`*^9}, {3.673976769988827*^9, 3.673976821213117*^9}, 
   3.673976967306955*^9, {3.6740099737124968`*^9, 3.674009978291089*^9}, {
   3.674227038851217*^9, 3.6742270638694887`*^9}, {3.6742272186202755`*^9, 
   3.6742272204485545`*^9}, {3.6742272616717043`*^9, 3.67422729129984*^9}, {
   3.6742282940689316`*^9, 3.6742282961160192`*^9}, {3.674228382203255*^9, 
   3.67422840751849*^9}, {3.6742285603915777`*^9, 3.674228576971459*^9}, {
   3.6742295568536983`*^9, 3.674229615125483*^9}, {3.6742296550515847`*^9, 
   3.674229744920472*^9}, {3.674229826100938*^9, 3.6742298407743626`*^9}, {
   3.674229932627836*^9, 3.6742299537863226`*^9}, 3.674230023590584*^9, 
   3.6742302341199503`*^9, {3.6742327273011885`*^9, 3.6742327591326485`*^9}, 
   3.674232834953163*^9, {3.6743147973416324`*^9, 3.6743148918267193`*^9}, {
   3.6743156882281895`*^9, 3.6743157043149037`*^9}, {3.6743157502710843`*^9, 
   3.6743157663497877`*^9}, {3.6743158145639315`*^9, 
   3.6743158519423094`*^9}, {3.6743161713331785`*^9, 3.674316175726901*^9}, {
   3.6743162639664307`*^9, 3.674316268007161*^9}, {3.6743163070900087`*^9, 
   3.6743163356198316`*^9}, 3.674316497458014*^9, {3.6743165323978844`*^9, 
   3.674316532905239*^9}, 3.67431685601*^9, {3.674318740052*^9, 
   3.674318772635*^9}, {3.6743888447684307`*^9, 3.674388951511136*^9}, {
   3.674388990361424*^9, 3.674388996832595*^9}, 3.6743890440401077`*^9, {
   3.67438920945475*^9, 3.6743892144690447`*^9}, {3.674389317973166*^9, 
   3.674389320486865*^9}, {3.674398897753016*^9, 3.674398937115638*^9}, {
   3.674398997458021*^9, 3.6743991214656167`*^9}, {3.674399325794737*^9, 
   3.674399333855121*^9}, {3.6743993711944*^9, 3.6743994502043953`*^9}, 
   3.674399485407956*^9, {3.674399524548998*^9, 3.6743995284914713`*^9}, {
   3.6743996996895046`*^9, 3.674399728790809*^9}, {3.6744000691983523`*^9, 
   3.6744000767915335`*^9}, {3.67440018919532*^9, 3.6744001969348583`*^9}, 
   3.674400350852*^9, 3.674400402828*^9, {3.674404954777*^9, 
   3.6744049571280003`*^9}, {3.674405889367*^9, 3.674405889743*^9}, 
   3.674406570192*^9, 3.6745532295360003`*^9, {3.674714673302*^9, 
   3.6747146995880003`*^9}, {3.674824468844*^9, 3.67482452548*^9}, {
   3.674965562012001*^9, 3.674965618154001*^9}, 3.674981584487404*^9, {
   3.674994954341*^9, 3.6749949547650003`*^9}, {3.675000121108*^9, 
   3.6750001448900003`*^9}, 3.675001578362*^9, {3.675001614281*^9, 
   3.6750016149049997`*^9}, {3.6782745520148*^9, 3.6782745806388*^9}, 
   3.696337361131*^9, 3.69635266474*^9, {3.697377411708*^9, 
   3.69737741234*^9}, {3.6973785550956583`*^9, 3.69737855547668*^9}, 
   3.6973791762591867`*^9, 3.6973792386827574`*^9, {3.697386766977*^9, 
   3.697386767462*^9}, {3.6982243402939997`*^9, 3.698224343285*^9}, {
   3.6982267176870003`*^9, 3.698226720244*^9}, 3.698333115974*^9, 
   3.698383315927*^9}],

Cell[BoxData[
 ProgressIndicatorBox[Dynamic[$CellContext`etape]]], "Output",
 CellChangeTimes->{
  3.6973785571617765`*^9, 3.6973791771602383`*^9, 3.6973792411638994`*^9, 
   3.697382739522994*^9, {3.697382776553112*^9, 3.69738282512389*^9}, 
   3.697385445329*^9, 3.6973860092469997`*^9, 3.697386112236*^9, 
   3.697386505965*^9, 3.697386770493*^9, 3.6974320620106*^9, 
   3.6974340843616*^9, 3.6974352335916*^9, {3.6974352840196*^9, 
   3.6974353330106*^9}, 3.69822395199*^9, 3.698224260837*^9, 
   3.698224292828*^9, 3.6982243440880003`*^9, 3.698224683738*^9, 
   3.698226070948*^9, 3.698226736792*^9, 3.6982268867679996`*^9, 
   3.6982269201070004`*^9, 3.698226959994*^9, 3.698326786233*^9, 
   3.698326980559*^9, 3.6983271448789997`*^9, 3.6983272137799997`*^9, 
   3.698327291421*^9, 3.698327489399*^9, 3.6983331166099997`*^9, 
   3.6983354597390003`*^9, 3.698336758684*^9, 3.698338386882*^9, 
   3.69837665216*^9, 3.698383324245*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"to", " ", "save", " ", "the", " ", "output"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"FileGamma", ">>", "\"\<fileGamma.cal\>\""}]}]], "Input",
 CellChangeTimes->{{3.698390953634*^9, 3.698390968417*^9}, {3.698473974889*^9,
   3.698473988993*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"style", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"DotDashed", ",", "Thick", ",", "Purple"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Red", ",", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Blue", ",", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", " ", "Black"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"teps", "=", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0.1", ",", "0.2", ",", "0.4"}], "}"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "dimensionless", " ", "times", " ", "at", " ", "which", " ", "the", " ", 
    "solution", " ", "is", " ", "plot"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.672589687756*^9, 3.67258971424*^9}, {
   3.672627707759601*^9, 3.6726277814736013`*^9}, {3.672627922897601*^9, 
   3.6726279244806013`*^9}, {3.6726424826786013`*^9, 3.672642495366601*^9}, {
   3.6726428232496014`*^9, 3.6726428305496016`*^9}, {3.674992914133*^9, 
   3.674992956604*^9}, 3.674994032932*^9, {3.674995342915*^9, 
   3.674995355082*^9}, {3.6782744526848*^9, 3.6782744577248*^9}, 
   3.6963369486359997`*^9, {3.6983384061280003`*^9, 3.698338416432*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Dashing", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], "}"}], "]"}], 
     ",", 
     RowBox[{"Thickness", "[", "Large", "]"}], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0.5, 0, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.33333333333333337`, 0., 0.33333333333333337`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0.5, 0, 0.5]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0.5, 0, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0.5, 0, 0.5],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->GrayLevel[0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "GrayLevel[0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["GrayLevelColorValueSelector"], {
             0, {Left, Bottom}}, {Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      GrayLevel[0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->GrayLevel[0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "GrayLevel[0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["GrayLevelColorValueSelector"], {
           0, {Left, Bottom}}, {Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    GrayLevel[0],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6749929080150003`*^9, 3.674992956921*^9, 3.674994035119*^9, {
   3.67499533206*^9, 3.674995355664*^9}, 3.675000658763*^9, 3.675001221899*^9,
    3.6750022130950003`*^9, 3.6782786182728004`*^9, 3.6782790709268003`*^9, 
   3.696337216664*^9, 3.696352950403*^9, 3.6967425976692*^9, 
   3.698224249852*^9, 3.698224307902*^9, {3.6982246443859997`*^9, 
   3.698224667293*^9}, 3.698225021793*^9, 3.698226638061*^9, 
   3.698226782484*^9, 3.6982271390769997`*^9, 3.69832683287*^9, 
   3.6983270221470003`*^9, 3.698333060104*^9, {3.698336620539*^9, 
   3.698336627704*^9}, 3.698337926584*^9, {3.698339558722*^9, 
   3.698339571898*^9}, 3.698377787104*^9, 3.698389113496*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0.1`", ",", "0.2`", ",", "0.4`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6749929080150003`*^9, 3.674992956921*^9, 3.674994035119*^9, {
   3.67499533206*^9, 3.674995355664*^9}, 3.675000658763*^9, 3.675001221899*^9,
    3.6750022130950003`*^9, 3.6782786182728004`*^9, 3.6782790709268003`*^9, 
   3.696337216664*^9, 3.696352950403*^9, 3.6967425976692*^9, 
   3.698224249852*^9, 3.698224307902*^9, {3.6982246443859997`*^9, 
   3.698224667293*^9}, 3.698225021793*^9, 3.698226638061*^9, 
   3.698226782484*^9, 3.6982271390769997`*^9, 3.69832683287*^9, 
   3.6983270221470003`*^9, 3.698333060104*^9, {3.698336620539*^9, 
   3.698336627704*^9}, 3.698337926584*^9, {3.698339558722*^9, 
   3.698339571898*^9}, 3.698377787104*^9, 3.6983891135*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"desvit", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ListLinePlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vitesse", "[", 
             RowBox[{"[", 
              RowBox[{"k", ",", "i"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"(", "i", " ", ")"}], "h"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "@", 
             RowBox[{"vitesse", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
        "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
            RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", 
         "teps"}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"u\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], " ", "]"}], 
    ",", " ", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"0.94", "-", " ", 
       RowBox[{"u", " ", "/", "a"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "0.2"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}]}], " ", "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.674716751762*^9, {3.674992478973*^9, 3.674992559709*^9}, {
   3.674992735513*^9, 3.6749927398129997`*^9}, 3.674992905258*^9, {
   3.6749929641289997`*^9, 3.674992990105*^9}, {3.6749930367060003`*^9, 
   3.674993059422*^9}, 3.67499310205*^9, {3.674993292458*^9, 
   3.6749932928199997`*^9}, 3.674994047824*^9, {3.6749953602130003`*^9, 
   3.674995361733*^9}, {3.696336957229*^9, 3.6963369600369997`*^9}, 
   3.698224651809*^9, {3.69838920125*^9, 3.6983892017299995`*^9}, {
   3.698389242429*^9, 3.6983892711049995`*^9}, {3.698389311069*^9, 
   3.6983894457889996`*^9}, {3.698389482637*^9, 3.698389583147*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.005555555555555556], 
          AbsoluteThickness[1.6], FontFamily -> "Times", 
          Dashing[{0, Small, Small, Small}], 
          Thickness[Large], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJw9mXVcFPkbx9FTDzsQz8BEEfQHGGfHxzi7sBU95ezuDkSxW+xGQGmka3fZ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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[0.005555555555555556], 
          AbsoluteThickness[1.6], FontFamily -> "Times", 
          RGBColor[1, 0, 0], 
          Dashing[Medium]], 
         LineBox[CompressedData["
1:eJw9mHdcjf0bx5PMx0xIohARoSiV+JCZiiihJ3tlZRN6jCJ7JEQkJS1p73nO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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[0.005555555555555556], 
          AbsoluteThickness[1.6], FontFamily -> "Times", 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJw92HdczfsfB3A3LteMbkZZIUnGtUfhRcOsJFf2uFahbEkihEhIKhFpaJf2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          "]]}, {
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[0.005555555555555556], 
          AbsoluteThickness[1.6], FontFamily -> "Times", 
          RGBColor[0, 0, 1], 
          Dashing[Medium]], 
         LineBox[CompressedData["
1:eJw92nk8VG0fBnBt2ktaFKJNUbTv26WF9h5pU1E92uVpESqkTYtSEUkliZIk
+74OxjDrGfvOWMY2tKpUqnfo551/+tyfMcc5577v63ud0Xjzk8aHeiooKAT1
UlDo/DfgiOXbrZPF6Hj9MXeTuRG8K1j/Gv9/vB/MthTHzfLxD0eLJGv3o5g+
+FDvtf9//xSKTkd/Wi4f248IWVNtZ41bo8PWzfn/z5+DS9r2/lry8fmmybP6
BTtguMmrWSP+//lLGPTpZbqCfLy06p87D09cwRyxcVKzVvfxnCAzC9XIlY8T
1g3qOe3GddyaldwUo9V9/Jv4MdBx7CP5eHFUtm3Ks1v4Xfw5/pxW9+9zgXLo
uNTt8nGcxjXZlri7uMQo6s3U6v79rhgRENirn3zszR4XZnXUDUXcfqsqJnWf
z31odOjIQuXjsu9dvxCmOkM7Lk7qPj8PnDyaaLNJPlabUTFJ8fIDTPg5y2T0
pO7z9cSgzbb+koli7D64pPOIONl+e2fAxO7z98KeJFvrY/Lx40ddL5y6vviH
zsTu63kM2xNljQ0TxCgRfdta+/IJdsSY6ftP6L4+b5jzMxVM5eMxvXcM0Yt4
ivUGo6cqT+i+Xh841O9KyhwvhsmirgNCzfterO347uv3xXXHFDUt+XjjAucV
+6W+qGFkjeJx3ffjOSb8Vte0k49btnQe8TmmP9+ZMm5c9/3xwyiH5xy2phi3
LRt+vv7oh3sOCgsPa3bfL3+EJtgp95GPp90YJb8Ef5SfH7XjuUb3/XuB71NK
ey6Rj/nPDWI+/3oBbTPB6Nyx3ffzJSZXfH54WD4+Lr9bo3sHIPbBzkvt6t33
NwDsZ79zbsjHA4r8Ty0b8Ar7l39wGaHefb9fYZxkTriPmhhBnZerFIjEsTnL
J6t13/9APE9g5r1RFWN95+FGvYbxywWeeqrd8/EaYV+V9r8dI0Zz5+1WD4L5
pwPuU8d0z08Q8hUXzXw5WozOuyee8AaLhV7zx47unq83MOnvEnBfRQwd03vp
X7SD4fxa7VIfle75C4Z6llGGzSgxuPKjqc54C8nLuadqR3bP51tsjRJf3ywf
H3NrdcC8EDTdnt43dkT3/IbA+MPOj+rysfzk5JccirXiHQaXhnfPdyh6Gczr
Va0sxjb54pFPKQ7d/zUVyt3zHwbTKQlJj4eJ8UJ+94r8w5DkbRP3Wal7PYSh
Kmaxxnr5uO1X/rmmyeEYcnDEu6dDu9dHOKKSB2u/HyLG6q4FEA5e39mCZUO6
10s4/MJcSp0Hi+ExuuuCINmiszVvUPf6iUB5yPD5qvLx39OLgF3Mzqt7B3av
pwgEXO6xxHeAGHO6XpHYuW2sWVX/7vUVCcY7tklNPr7K4slXUCQmtJVLtvfr
Xm+RaBz7eOWdvmLkyWdffk/wX7+OIemK3esvCoGCoYZtfcSY2HXAKCiG1DRM
7NO9HqMgUr3SZtRbjDNHOycgGgfe/Dxu36t7fUbj3ESzzf49xcj4oi2f4Wh4
nYp6kt2je73G4PabodtkCmIM/3uC2KRy4exAhe71G4NJq0YNMv7NoOvssmOA
TNc/NzoYWs+xuLz4BjfuB4OIp+9fcTbEQnZBxaKunaH1HYszqfuqB3xj0LPr
gmMRdNVxhu4XhtZ7HLxe3t+29jMD478LBlrbEo32fWRo/cfBYfjoSaffM/Dr
vNz8OCxJzhZdaGVoP8Tj1KVWo2syBp86D2cSD3NJQNCNJob2Rzw+RI8sd2pg
sLJz+ZfFo2j6HqmDlKH9koBaoRfnZC2D+53Ld28C+hz/cNGsmqH9kwC1OU7D
DKsYVNt1TkgCvr6ytdepYGg/JYLn25zct4zBrK4Fnoh3a3uVSIoZ2l+JWDSh
ThBVyODyg1XyJZOI1z3CH13NZ2i/JeGY8l1symWQM6FrglGf/yxlmJih/ZeE
EPWBKjlCBuM70781CadGfFl7m8/QfkzGuMVXt+lzGZzu3B6nkjHMvGzRBw5D
+zMZ8ZETvz9mM0jrnN3PyXgffOW+fjpD+zUFuuM0FatTGQz7uyExb+64bQ7J
DO3fFMQcfOugnMig6/Z9T0HIlXcX/eMY2s+pKIwcuHdGDIOu03NIRZCVnkpM
JEP7OxUadx3eLAhnoND1YqFk6gS1qBCG9jsL/dPWHJ4WzCCQs0G+o1kI1VC5
8/Q1Q/ufhdWHE+4NeMXASL4bla+yYDXE9ITVC4bygAWT2sk6Bc8ZtHfqw2ZB
WdGQNfsZQ/nAwiBZ3Zzb3gx8VTs3RBrGmM1wqnzEUF6kId5uS7juQwZruyY4
DR0xZxNtPBjKjzQcKxX5xbsx+PCq8wTTYNfD6Uj7XYbyJA1XnrL7z3Zh4NV5
drw08KxTnA87M5QvaUh6/qzhwXUG+vLFtW5QOnTdPSeyrjKUN+lgDc5dJr3E
oPFn5wWnQ1nn8vw+jgzlTzpSjPMGj7Nn0Lla5EsGHhvaM+adYyiP0vFBZ9wu
QxsGXZcrToe5ib1wixVD+ZSOdw8Wjzc5yaDrcMoZyPxyd9suS4byKgN7Ja+P
bD/GoCuOtmbg67Dk3RsPM5RfGfB/8kNv+QEGf+tDBm7XeFRP3c9QnmXAxTfF
RtmMQVccFGWAUxvU3LaLoXzLgGTIHf3cHQwudm7n0WyEF3udDdrKUN6x8WZj
T9cLRgymdG0gNk7zfjlv2MRQ/snf78M6NGI9A6arXrDxW9FxYrEhQ3nIlufK
fxmeqxic7dwOFWzET8gwMNJnKB/ZsP0UHdR7GQPNzuWskYmSNvtPkYsYystM
HCrcMHbvfAZZnctvfyaYR6bTes1hKD8zIfCQqvvPYHCyc3qfZ+L0aY1Py3QZ
ytNMnJiON3naDFS6Nnwm1mtcWntQi6F85WBA4xje+/EMUjtPbxIHgdcMZtpq
MJS3HKxds9T+myqDI4c7XxxMZRa8OaPCUP5y4D3CitU8nEFneZInLFQPaCWa
KnXnMQdGu1yecAcx6EzHc00cfG2u/ndW/+58zsLmff8O8ejDYG/XAeXjLYbP
P/bozussWIcJVNf/FkGxK6CykJE60/7pDxHldxbujwpNl30VoXM2RoRkweOZ
08e5n0WU51kY9vhd3/PvRehqd++z4Oc1VTFOJqJ8z8aPy7YtHxtE+N253WZl
Y7qbUuLkOhHlfTa4WxdY7ZCIENC5nK2ycTBYR/lyuYjyPxtzciY/CSgWYfPf
CwZnw4nBWfki8iAbOt9xrEYswtfO6fiSDc+B5SHtAhH5wMXWvlcr+3NF8Om8
3AVcmGfatI/MFJEXXMSc/tKhniaCYdcN5KLWZVWLRrKI/ODiQvNzjlq8CO+6
eODCItzYZXi0iDzhotTUa5liuAienfH+k4v9idGln4NF5AsPgnetB8oDRVje
NSE8FFk6laS+EJE3PGT/Tlri4ytCfWe8OvKwNq3s1llvEfnDw8RJWlkbvET4
G388GMoqPqh6iMgjHgL0NvST3hOhK1568uG3PWJw0G0R+cTHmfG7eljcEKFr
+67iY6TftdpJV0XkFR8aSx2jSh1F6Noe1/gof+VsfdtORH7xsffDu4kLbEX4
u/z4sLX+kl5xWkSe8eErrdty8T8RCjqnt58Awev65KgdE5FvAgS2++hHHhTh
QtcZCqDt88PXYL+IvBNgwKJ/P+XuEUGrawEKcEJNfd6enSLyT/75ZutjlcYi
CAVdL1zyib5nullEHgrw6Yp2YME6EWzcOwNViK3zR0euMxCRj0IoBTFhcfoi
jO1a0EL0nvj4+YSlIvJSCPOFGdduLBAhs+vxSgjXAk+zhtki8lOIwwv+1Vk5
XYT/OuM0Vwij9yeaHuqIyFMhZkoG+TROEmFk1wYRIVD/5pq540TkqwgHHk+v
t1MTIbkzDnbI13X2JrukUSLyVoSdHXN6fx8mwqGuxy8RpkXPcJo5WET+yvcJ
994P834iDPq74eC7z/+Iay8ReSzfF5/i+XG/hehaLvIcsd08cUr5dyH5zCDE
fYbdjzYhuqbDVJ4bc2dkDv8gJK8ZOHyx6qctk9+Xrg0s//y7DasX1AvJbwZs
54HnV1QL0XU4eQ8a7tTrlWG5kDwXo3/rNZFhkZD2u/w5Z7L0/Qr5ffrruxjF
tWcGLhQKaf+LcVLv2nidbCF5L8afPZazR2YIKQ/ESFa7sLwjWUj+i7HTYqBh
ZZyQ8kGMD17H1yVGCqkPyJ8r1n9a6x4ipLwQw+JM2+rDr4XUD8S4ZJq1bO4L
IeWHvFc/Y8355SOkviDGGu35U9IeCSlPxNg1z3H0JQ8h9Qcx4ne+77v4npDy
RYzg05Iv75yF1CdyUBoXWOPjJKS8yUFa5DPRuotC6hc5WL90bML780LKnxx0
OJx/6WotpL6RA/O2QW66J4WURzkYcnrmhYxjQuofObAascxi+0Eh5VMOxhq7
mNTsFVIfyUH++7NrLXYJKa9y4Nd79+LWrULqJzlY9d1l+vHNQsqvHBxzPq5V
t1ZIfSUHIWlGmiarhJRnOWhV8FLPWiak/pIDi2/eY2ctFFK+5SDgVeIEz9lC
6jO5+HXISPerrpDyLheWRbGLt0wRUr/JBevz5s2vxgsp/3IxpfeZI+1qQuo7
uejrf/n66lFCysNciJKK39xWElL/ycWWe4VFwgFCdC13x1woBJUMGNhHSH0o
F09a9Q1W/RHg79cHuXB1OX7D9ruA+lEuvAbE57z4LKD8lL+/zHmSSJ4bf6c3
F1M3LL30qUFAeZqLw8GzpcNqBNSfctGuI9yqWy6gfM1DdKWlYEWhgPpUHgTz
z/xjLBZQ3uZhyfsVFWY8AfWrPOwdtcT2IFtA+ZuHjoFpqodTBNS38rDo8ny+
eZyA8jgPRmd/39gdIaD+lQe3FQ5bNslz8G8+58HRabj2kgAB9bE8BM/VHjTJ
V0B5nYcoL43ffR8LqJ/lwXLNnt/17gLK7zxUaK8anHZHQH0tD0W2S6Z53hBQ
nudhUMJrk8OXBdTf8rBY9PnBLHsB5Xs+ZJUXa79ZC6jP5ePTkagV8ScElPf5
0FnQHmZzVED9Lh8zLSJm6ZkLKP/zMfvkenbVHgH1vXxYKGofu7NdQB7IP4/I
cfP/EVD/y4e13TZZyVoB+ZCPb0etuedWCqgP5oM3yCFReamAvMhHUWx+2qt5
AuqH+Vg0uLF8wQwB+ZEPxz+agzPkLv3ti/mozq03XjdBQJ7k46vqqxCemoD6
Yz76J/HHrRkpIF8KMFuW+jpliID6ZAF+6L5f1+neX28K4L4js8ezHgLqlwVg
7oTk9P3JJ38KUL1GJeF4G5/6ZgGUN1gm8lr55FEBgoJVCyfJXf3bPwuwNu/e
ADsJn3wqwCXrRbt4JXzqowVQfHgtfWQen7wqgINrjaGpgE/9tADfFVPrn2by
ya8CPP7g7Feawqe+WgBD9wg75Tg+eVaARKfAkwbhfOqvhXgTVHb5TBCffCuE
dFFSuLc/n/psIabFJfxhefPJu0LM/rHGUvKAT/22EEqTCr79uMsn/wpxNijP
T+kmn/puIZZvif5v/GU+eViI8dNaTPTs+NR/C9H6pPng3DN8/P16shArt0+8
P9+ST324EOJd/avnHOKTl4WY/mOose5ePvXjQuQWBUk1d/LJz0K41GzyHmLE
p75ciJ67/7NtX8snTwtRJrhgXbGCT/25CBpj2jyTF/PJ1yJMtDSo9JrDpz5d
hMMrG9af1OWTt0W4c+SfCn0tPvXrIph8/fxgsAaf/C3CFZMNNgWj+NS3i6C1
RmDvNZRPHhdBkdf6ekc/PvXvIvRcOEVBqQeffC5C+fwPjuzvPOrjRdiVyJps
/YlHXhdhYP9h7RoyHvXzIthE7PrMruWR30UI8Ro+5nA5j/p6EY7KYo/1LOCR
58UQ6LCkj4Q88rwYReMC7uhyeOR5Mfxaav9NSOGR58W4+O2z+apYHnlejHc/
jNyyQnnkeTGCftu0GgbyyPNi6JtUnk3z5ZHnxagM7jNrwSMeeV6Mf94fGRPo
xiPPi1G8//KsEbd45HkxTN1E5+2v8MjzYnzfK/hUYccjz4vh9eWb95IzPPK8
GG2M6JzHcR55XgyPGNH1xgM88rwYl1k2WQtMeeR5CU4Zr1xyZRuPPC/BUM3I
mqyNPPK8BEO016T0M+CR5yXwSrwgWi3v9X89L8HGs4XDHebxyPMS7DLIuRui
xyPPSxC69x3KtXjkeQl+rAuZ0keDR56XYGqZm6HOKB55XgKjuapP1w7hkecl
QGb2tAOKPPJcPt6g+fncby55XoI1Oc8+O3/lkuclUAgT6Hm+45LnJZhwR9vv
aT2XPC+Bktn8Lb6VXPK8FKP2n1/iU8glz0vRPMnm34ciLnleCtsbbzNuc7jk
eSniwwLM7VO45HkpjFWkyw/HcMnzUgy+2GqyMYRLnpfCqn11uF4Al553SiGt
PrV2gA8Xrl2ey9+v/6pR84BLzz+lOPzbdF70HS55XoolJ3Vcrl7jkuelGMav
mbjpApc8L8X4j0N/DbPhkuelSBi8cHSuJZc8L8WvRzU2dw5yyfMy3NnzcNRq
Uy55XoaFhyp/fNnKJc/LsHSU/kT/DVzyvAwtqgauG1ZxyfMyhB23Xfl+MZc8
L8P8zWaL787mkudlwLar57SncsnzMiw3tfqVPJ5Lnpfhk2sUd/MYLnleBg2L
/IpSJS55XobWINPF5v245HkZvh4orqr7k02el8H3Y67I/Fs2eV6GUR1Ffcvf
ZZPnZfA8d+a2UX02eV4GhcBZu1kV2eR5OTxVnllPK8gmz8vh5Lu2zE2QTZ6X
o+VI4t3PGdnkeTlMqpzuGSVmk+fliMqYXRkYkU2el+Owxlb7jtfZ5Hk5dFdb
H9nwPJs8L0dSwST/B17Z5Hk50lM/Ty+7l02el+PY4lMD1W9kk+flCOLqLDJx
zCbPy/FhaVjcPZts8rwcHqHut9Its8nzcjTdOBj64UA2eS5//1zkFNU92eR5
Obwch7UtN84mzysws3boyH3rssnzCnxbrH/bTj+bPK/A74Nzd7otyCbPK2Dh
4njef3o2eV4Byynhn8K0ssnzCmh/25sRr55Nnss/31etJXl4NnlegW3h5/5L
HpBNnlfA7sHAtXE9ssnzCmzyO+IQ0p5Fnlfg0dDxA33fZ5HnFfDeL2hzqc8i
zytQeeD3IpuKLPK8AuJZG8tM8rPI8wqU6m0oWcDPIs8r4aToNlc5PYs8r8Tl
qMjWhrgs8rwSa+zX9YkPzSLPK5Hb2Gh/LSCLPK/EywJt401Ps8jzSgQc9L2p
5JFFnldiUK8GTeZWFnleiTtHPUY7X85CYpfnlVB4qH9m+bkset6tRFHp1Znv
T2RhaNeCrsQ37lejJ4eyyPNKrDOYXbDSNIs8r8TMs0yy1DiLPK/E7vwjA53W
ZZHnlbim9iBlrH4WeV4J7e0fiyLmZ5HnVWDyRpms0ssiz6sQMMcXzMQs8rwK
w/do39uhmkWeVyHh/Po1JUpZ5HkVRvb3O7qzbxZ5XoUrAt5n8S8OeV6FaPH+
JoM2DnlehfzjCutjmjnkeRU+LDMcNaGaQ55XQXcms9m5iEOeV6GXzcI2mZBD
nlch5qZm3/VsDnlehRUzJ9z0T+CQ51WYZVd5tj2MQ55XoSP5U+HaVxzyXIJ8
718vPZ5yaL9LMFLBR1rmziHfJeipdsZT4xaH9r8Ec4+px5te4pD3EtiGLtrs
acuhPJDg5k+LHXxLDvkvQaC/Ue5Pcw7lgwSL19xOn7KLQ31Agjxh4pR//uFQ
Xkgw++jVnlYGHOoHEjjfu7rVdQmH8kOCM332qgXN4lBfkGBSftTu1CkcyhMJ
dDdPVRaP5VB/kCBtyL8ry4dzKF8k6Pf9p6y2P4f6hAQ3FvoMbfiTSXkjwakV
srfSL5nULyS4xFzPqpJlUv5IIKsfYVZQnUl9Q4L6vEUnOUWZlEcSuEx9/DtC
mEn9QwKNrNKBTzIyKZ/k1yP0fegYn0l9RILM125+ZqGZlFcS+A/dqrfwZSb1
Ewm2/Li1cMiTTMovCcTBVewq10zqKxL0iPiWG3w9k/JMgmnl5w/YOGRSf5Gg
dfXgs4usMinfJHDYtGvI9yOZ1Geq8dKnz9Qos0zKu2oM1U7gWWzNpH5TDYvx
mh/V12VS/lXjfb+Kp7zlmdR3qnHkhXfOmbmZlIfVOKfQ987oqZnUf6px8nSm
OE4zk/KxGjlul59uG5lJfagaT1ZJP8sGZFJeys8n9HG+o0Im9aNqLDLYqD/4
K5vysxp9E18seChjU1+qhmTwP4nq1WzK02qYXv7Kf1rIpv5UjVvPDC1UBWzK
12qoL5J53k9jU5+qRvhBV2PFWDblbTV+Xax5ahPMpn5VjbnT756XPGdT/lZj
/i79esOHbOpb1bg0K6Au0IVNeVyN03r/2SheYVP/qsb6Aase7TvLpnyW/zy/
wCjKkk19TH4/EvO8e5uzKa+rsdlSdsFoJ5v6WTV4Ufy2hxvZlN/VqImc2LNs
BZv6WjWURX4BYxawKc/l779tr9mqy6b+Vo3YFQWxzuPZlO81+JrYqJU4ik19
rgazXGv1GgeyKe9rYG1lK1bqwaZ+VwPWduMh875mUP7XQP24duM2WQb1vRr8
nBC095Qkgzyowe4ZzlY3CjKo/9VA4dbZSY95GeRDDfIdptgEpmZQH6xB7tsN
hyKiMsiLGoj1Hn6JfZ1B/bAG064nT473ySA/arA53ep7tHsG9cUazD95/ETI
zQx0xb9tDWKum173u5BB3wfVIGX5zxX3rTLoebEGU6M6nl84kkHfD9Vg04mR
rw6aZtDzYw3SM9u3rNmSQd8X1eDmRhN/LcMMep6sAaxrn/xZnEF9swa3CtYs
LZiRQR7VYNGz2dcCJmVQ/6xBH87Ws2fGZJBP8vM9cGD40iEZ1EdrcGSMzm6F
XhnkVQ2kv65uZH1Lp35ag7BRJ2X2LenkVw3u5P5YMKc6nfpqDXYcnzGnviCd
PJMfrw+3woOXTv21Fj2Ppi9Aajr5Vgvd/ERII9Opz9aitMPj0/XAdPJO/vPO
qzZOeppO/bYWFh3WG5Pd0sm/WgQ4BvQ2vp5OfbcWd92OJ9bYpZOHtThRp7D0
1Ml06r+1+OyVdeTLgXTysRaGI9If2JukUx+WH6+jzrl9Yzp5WQvHrLYxtivS
qR/X4pbK5tPN89LJz1rY6b3fs29qOvXlWqjKWibyNdLJ01qsdFlot2B4OvXn
WmzcuSz5cd908rUWnpzj13//TKM+LT9+89U1uz6kkbe18EjfdD2qLo36dS2u
a37hKJakkb+1OFyWcWGXMI36tvx8WxT1/dPSyONabOaKT7dGp1H/roWCl3Hc
9KA08rkWXg67j57ySaM+Xou5te3zXt9PI69rYVx780jN9TTq57XQc9JOVbZP
I79rUXfzvM2qk2nU12sxufD7ruMH0sjzOsRYzPNy35lGntdB1dN6UOSGNPK8
Dl+ESQW5SCPP69C3w7u8aU4aeV6H+m/D5vbQTiPP6yBwtRcPVU8jz+uwMHZZ
vIZSGnleB9tdmu8m9U4jz+vQHPjP8WntLPJcfryFT5fotLDI8zpoDDIzmiJh
ked1GMkekqqezyLP65Dz5uIJ5WwWeV6H85fcHP8kssjzOqhtKuC3hLLI8zp8
8jK8lOPPIs/rcMX14omYhyzyvA6fm4x592+zyPM6/FJ4YXryIos8r0P8uCrz
VWdY5HkdJutZeqscYZHn8nGBilHtbhZ5XocVcX3mhm5mked1mPNYz8tqJYs8
r4O3qZ/O/Pks8rwOnD/bVnzUYZHndbBsPHs1eCyLPK9DLzfOln3DWOR5HR7M
Z61R7sMiz+uQ4XPh2fmPqeR5HU79Y/VdVJxKntdh896OK8NZqeS5FFGL120x
eZVKnkvRX+f+bpe7qeS5FDuaXf1ZNqnkuRSf/JnZdaap5LkUXwdWdPRdnUqe
SzHBaNNotWmp5LkUjUu4x6Yrp5LnUiy+8kZl1vcU8lyKz7/av86RpJDnUlw9
fH/Z5KwU8lyKoQkq4aNDUshzKdR/hHv+8Eghz6WIiSp+UW6fQp5LcVExfUaI
eQp5Lj/+wG+VF9elkOdSeGheGbliZgp5LkVZ2DzLniop5LkUA57Fb4v8lUye
S/Hs3327DtYlk+dSLPRZ8KM3P5k8l6LfS8PIl+HJ5LkUkW25yvO9kslzKdrY
mdc5jsnkufx+zrJ4Y3gomTyXYgY3RcLZkEyeSzH2Ua14/uxk8lyK/afVRAGj
k8lzKerH6rkq/kkiz6XInyXcc1iaRJ5LMWLf0q/R/CTyXIrNekLPPhFJ5Hk9
LvgOUTLwSiLP62E3Xd3FyTGJPK9HIC+wOfJgEnlej5MB6Wtr1yeR5/X4sV/F
veesJPK8HnX+4pLxKknkeT1SL50YNetXInlej9lis436tYnkeT1My7iXwU0k
z+tRY+H8dnloInlej5SwjTV6DxLJ83qsXGE3YKx9Inlej2P88QYd+xPJ83oY
h+w9VWaYSM+H9fjqYB8bpJtI3wfV44SrZct55UTyvB5zPdwNF7UnkOf1uLKu
+nZ7RQJ5Xg/1/W/+vMpIIM/r0RrZw3Tn6wTyvB65/gM/fL2bQJ7Xo3GiqoWn
dQJ5Xo+zD3prTd6dQJ7XQ9vMMSMaCeR5PVSKW9/M00ogz+ux29XZJnpAAnle
j7Czk+9rfYgnz+vxeIfPnQcF8eR5PVjVI6RfEuLJ83pUBk4es8M3njyvh0vt
5IiAa/HkeQOcqty1vlnEk+cNWOqXo7jQKJ48b4BO0F7WuXnx5HkD7j10+/Ba
NZ48b8CO/n2/lf6JI88bkHS72aGjLo48b8DvTSOKxvLiyPMGTHY/Ej8jNI48
b4BAZeSJFR5x5HkDpqs8iVx1Po48b4BLr2dcg71x5HkD0rw0zi9cFUeeN0D/
0T/fpmrHkecN2FtyX2XI4DjyvAGzZbzeHz/GkucN+O/9M292YSx53oCG60l/
HibGkucNeDP8y0hT31jyvAFfNYu+aF6LJc8b8OnVWrf8Y7HkuXx8P7/t5uZY
8rwBTTNN1KfPiSXPG3CqymZAnkosed6A4zsb2Uc7YsjzBrAnXV39WxJDnjfg
ejnbyykzhjxvAOcRP2xAUAx53gAjL9bLy3djyPMGaNzSMmu3iiHPG1BtFf19
384Y8rwBDv+c2Jm1JIY8b0TzPic/zXEx5HkjYjfeenu2dwx53oisnSNDWI3R
5HkjahoO/tdfGE2eN0Jt286pq8KjyXP58Zw+vHB4EE2eNyJgvb7Wq/PR5Hkj
ii5NNs8xiybPG2E9URjcsiKaPG/EMb2+kX0nR5PnjZgQ34MZPiCaPG+ES9aj
l5rvosjzRlzKaXyknhtFnjeizrZlzZiYKPK8EQ0jPdT6Po4izxuhu3pEYNuF
KPK8ESwldfO8f6PI80a8UNHLDzeIIs8b4afla39ZJ4o8l19/6K5So8FR5Hkj
7O4a2g77GEmeN6LlaUZ2Tn4keS6/nq1L91+NiyTPG8HRf/J2rncked6IQoPo
NUUXI8nzRuQnqzw8fyCSPG/E6l+yxYPXRJLnjejTYevuOzWSPG9EiHD8Wq0h
keR5I1Se/Qrr/H/Bfz2Xfz7T54JmQQR53ohKhW+/POIiyPMmXHoZ3vTzSQR5
3gQt3eib5hcjyPMmLK8IfZxgHkGeN+Fzoes+ZcMI8rwJPZ2++OzRiSDPm8Az
bXJ9MSiCPG/C4K3S3lXvw8nzJiyMnzRtTF44eS4//vPG0tUx4eR5E9iXQ5ee
ehROnjfB0vTkjDsO4eR5EwwlHXmv94WT503Y0euDUtzKcPK8CbZ3r//J1Aon
z5vw81nDncx+4eR5E+qFAiFbFkaeN6EioyQqWhRGnjdh6YEdmwLCw8jzJhhc
NPK46RFGnjfhkVuYi8XZMPK8CfZm5YuX7w4jz5ugPfzk42HLwsjzJjjsHRFb
qBlGnsvv1wjda096hpHnTTCtmjbjBS+UPG/CXBOlWCXXUPK8Cap5/Qv3bw8l
z5swP2qbSZhqKHneBOuBKpdqq0LI8yZwvl8cOOplCHnehNtxUet1LULI82YY
PPneumJGCHneDOU4o61L2t6S5814GTlv7Nz4t+R5M+JuHYpVcnxLnjdjSEdU
TMvKt+R5MxzW2nkE931LnjfjTnLv4uOCYPK8Gf08J/Qb6hZMnjcjipviE749
mDxvhqX77xkLVYPJ82bYHHPWTql8Q54340RRgo62/xvyvBmOxirubkfekOfN
eL1PaXjVtDfkeTPMnk3pmPYhiDxvhqoTu79ZVBB9/9uMvSnXLt85F0R/72mG
cWvgNL+lQfR9cDN+HOq/IkYhiP7+0wz5bHmGsF+T582ou+tpEnDzNXneDIuT
149e2fiaPG9GkOnYejOl1+R5M9Z935c6Nj+QPG+GkubjvhUPA8nzZvjenRp/
aU8ged6MNwtHlk3UDCTPm+Ef1nbmTc0r8rwZC8f6O84OeEWeN0Otuniwz7FX
5HkzDuKgUn+9V+S5DPovfr0w+RBAnstgoHgt5FVkAHkuw65DD3aW2QaQ5zIM
Slt2dsjiAPJcBg/rylWTf70kz2W49Tj35jLWS/JchhNfJ9xcdPUleS6D4l33
HvMMX5LnMmwtjls5sv9L8lyGYzvK/7TxX5DnMrAzetyPv/uCPJfh8LERfhe2
vCDPZVg54rjH5BEvyHMZnGtCFJlCf/JchhmZ/x01feRPnstw1GHqxqY9/uS5
DLzjd3X3aPiT5zKsdhrmJpD4kecyTJts9meCvx95LsNN7vfP5w75kecyGLnZ
/Imc4keey7Dc3cn9XdNz8lwGlwTHDUOCn5PnMqS6772rd+I5eS5DkPK0nrNn
PifPZfhehl7zP/mS5zIYH1q4UjPKlzyXoUAkU+pn60uey9/nnJxauMCXPJdB
OMU8eM3nZ+S5DPuUN0S+tX1Gnrfg67C8WuUfPuR5C5IOWFWsvOBDnregzLat
j5WCD3nego0FU4dZXn1KnrdA5h9gdEjxKXnegsDGfS46zt7keQtODJP0aB3o
TZ63gDNv+B37u0/I8xY0LH27s/+wJ+R5C6y2mG4xd39Mnreg34OZrgkjH5Pn
LVgZdlSl8uEj8rwFd/f5NSmoPiLPW3DT3X7s+yde5Ln8eh4a+ZWP9SLPW3BI
2vr8wbOH5HkL2iQ+7ZvGPyTPWyDWnl6b4+dJnrfA4V/FadsneZLnLdizk6X5
4uUD8rwFIaEjz32a/IA8b8Fu7jLPQYEe5HkL7CJOaUzW8SDP5dczYfu1gUHu
5HkLlt4Um36Y6k6et6CPNm/a8zf3yfMWJJ/qZbVF9z553oIncTbZwmA38rwF
V962eK/TcyPPWzDyhcFjt7eu5HkLTlk4qZfouZLnLWBNP88q2XOPPG/F2GWh
+xRM75LnrVjTURuRuucOed6K+R+H6jrucSHPW+FXNPFWwe7b5HkrEuwequvu
vkWet6K9TwJbbZczed6KoeZloQNMbpLnrZA+Naq+v+MGed6KW98eHVTdfp08
b4X+iYS9S7ZeI89bsVUjIX7PFifyvBWWUZ8SR/5zlTxvxaFBG6YzG6+Q563w
fK9+bsL6y+R5K4J0nFbYrLlEnrfi7J7+WuybjuR5q7xfOku9rziQ562Q3Fw8
MsjejjxvxYngKVdjrM+R562I2duL9c3SljxvxcGv2LPwkDV5Lr8+78ZJIaZW
5Hkrgns7/jdx2ynyvBXGMXY3vB9YkuetqD8Ue+bjlaPkeSsMThosijhxkDyX
/76eKy5b7d5PnreC/U6dtdzZhDxvhe7la/29zIzI81awjOZ+eWimT5630j5X
UPjr+Tv8D5TaU9g=
          "]]}}}, {}, {}, {{}, {}}}, {{{{}, {}, {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{0, Small}]], 
         LineBox[CompressedData["
1:eJwV0Hk4lAkAx/GS1lO50pSzLa3dR5TErrZW/Qyy5IocsYoSk5uimKeRego9
hthtFFLryFHIjHI2McbRKzmLHB0vM8YMMx6ULtXaP77P9/+P7vEI1wC5ZcuW
OS71//MlddHPknbuq6kXjtIpMgTLrW/iUFTRUqadGbdOhgUNeuVVymb03nJx
jlWTwbywTD+eYoypi1xejKoMb8StJ2IoFthkzyqKVJSBzeyTi6IcRNKIdWSg
vAxar1/2hlP8cHixYIXrOym6fvCpC6NE4tPe4wZbn0tBIR29UnkJWAPGmfA0
KaJMcsZXCpOR8NyA4+ooxY/RKdLuiHT0LYSPMZSk+Bx17HsZ/xreZbqstXgy
jYqtyho5z24g7mnbjrykaXjK99toGuWimzHskEWdRk6y+gYK918s5146+nJx
Ch+mjBX1HueDlc7zrX40hS4/D6VzkkJ8Jm/6Gp6dQoaJKGN0tgjN7audYTaF
yFx+1MqZEgTuUTHNXpCgQ7PM54z6PYwYcNYz2RKozn/vmNEqB+e+SKQTJUHv
K19rtt19eHMaaq0NJRisvMzcWFOJ19Rf4qsmxDDXzaidqGajNeAnU16RGEey
t0gOdXLAUGicCDgmxnte0JH93VW4vld6pXSzGPZzZgPDoge4MFtneGl4EkYz
pefcvjyErcnG5jusSSRm951wXazGKYV1toHuk7jpdMH1nVotwryLO7kqk9Bn
Cy9oqdehg9pl8aBLBMu3M6/1NtRDvjqldDZNBE2NBGq/QQOUS0SqbXYi0L61
CldufwS60QBt9yoRTkszro5ac1Fj4s+14k9AsXQF7brnY/TyExVY8RPQWmeY
MODZCCexOfXyvgnMW4Z2j5o1IZuZEaf4SYhr/bnn02ubcKAlNs+kVohzB/Jt
qnfxMJC8wL0dKwS/NUi1gseDyVO1oQJTIfZrKH6hWTZjLo83bjMvwM8RUZPz
z5pxcUFZmlAugEUue4F6kI/oNzKhV6gA+ewWbbkePqzcA/rjtgng35Ftdc27
BWO29EZj0Th86+2ZkyMtEPTo5iQWjaO+onFQ+WQragZoMaf9xuFz5Yc9xbOt
CAyyti7WHsfuP/S5y0+1ITa9So4+MoboWUUro69t8P6N1zjOGoMkvlOsc74d
t8OPhU67jaF47mgx41s7mn69oWS+fgz84Ae0yuQn4MSGlW/pIaFVL7C9s4qA
gssL85KrJL4y5LWEawhsiNjvlpxG4i1Vb0pPmYBe6sOQk6kkigj/1EI1AlSC
la2fQsJ0aKy3QJsAnerxsSSRhMPHt9752wnIdg5WlTJIMMxehd52ITCgNmRw
L4SE3+fFvW8OERAY21mmBJOwfqyjssmDwJxTnVdIEInVNj7sW94EVFKykg1p
JDLdR97n+hOwW+E9ce84iYroofibMQS488N5ZV4kMn7/5Dx6lkDnWvs65mES
0Ysaujp0AsM7GnpCPUnsuXSYnxNP4ENIzvdt7iTa/xlUyEkiYCz460j5QRJ3
PT+8HL5CAHKd0anOJNK01e9qMQk4bjZnhjmRcCvwcMhOJxDso9Ow3YHELtqZ
jcN/E4ilM/uU7Jf8DDNlmiwCSTcWxVK7JT/Zw0av6wQyq0OXd9ku+XFepGdl
ESh8PqpR8SeJ/wAjRXT4
          "]]}}}, {}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.2523392861927455}, {0, 0.9380000000000001}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"u\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 0.2523392861927455}, {0, 0.9380000000000001}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.1\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.4\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6749925605620003`*^9, 3.674992740605*^9, {3.674992965369*^9, 
   3.674992991646*^9}, {3.674993037257*^9, 3.674993061079*^9}, 
   3.674993102899*^9, 3.674993294267*^9, 3.674994048384*^9, {
   3.674995333873*^9, 3.674995362803*^9}, 3.6749967086730003`*^9, 
   3.6750006595769997`*^9, 3.6750009194639997`*^9, 3.675001224058*^9, 
   3.675002214627*^9, 3.6782786201188*^9, 3.6782790719108*^9, 
   3.6963372244230003`*^9, 3.696352952333*^9, 3.6967425997612*^9, 
   3.6974341018356*^9, 3.698224251741*^9, 3.698224309238*^9, {
   3.698224652766*^9, 3.6982246687139997`*^9}, 3.698225023359*^9, 
   3.698226640297*^9, 3.6982267872060003`*^9, 3.698227141278*^9, 
   3.698326834868*^9, 3.698327023804*^9, 3.698327414766*^9, 
   3.6983330610629997`*^9, 3.69833434575*^9, {3.698336625323*^9, 
   3.698336630541*^9}, 3.698337928428*^9, 3.6983395733389997`*^9, 
   3.698377789868*^9, 3.698389115512*^9, {3.698389242883*^9, 
   3.69838927234*^9}, {3.6983893737699995`*^9, 3.69838938668*^9}, {
   3.6983894183199997`*^9, 3.698389446811*^9}, 3.6983895063059998`*^9, {
   3.698389538871*^9, 3.6983895438599997`*^9}, {3.6983895793009996`*^9, 
   3.698389583937*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"desvit", "=", " ", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"vitesse", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"(", "i", " ", ")"}], "h"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "@", 
           RowBox[{"vitesse", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "4"}], "}"}]}], "]"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "teps"}],
       "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"u\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], " ", "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.698389655269*^9, 3.6983896580109997`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJw9mXVcFPkbx9FTDzsQz8BEEfQHGGfHxzi7sBU95ezuDkSxW+xGQGmka3fZ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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJw9mHdcjf0bx5PMx0xIohARoSiV+JCZiiihJ3tlZRN6jCJ7JEQkJS1p73nO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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJw92HdczfsfB3A3LteMbkZZIUnGtUfhRcOsJFf2uFahbEkihEhIKhFpaJf2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         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJw92nk8VG0fBnBt2ktaFKJNUbTv26WF9h5pU1E92uVpESqkTYtSEUkliZIk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         "]]}}}, {}, {}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.2523392861927455}, {0, 0.9380000000000001}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"u\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 0.2523392861927455}, {0, 0.9380000000000001}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.1\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.4\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.69838965888*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ProfileVit.eps\>\"", ",", "desvit", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674995397123*^9, 3.674995407914*^9}}],

Cell[BoxData["\<\"ProfileVit.eps\"\>"], "Output",
 CellChangeTimes->{3.674995408965*^9, 3.6750006630480003`*^9, 
  3.696337243127*^9, 3.698225029484*^9, 3.6982271467279997`*^9, 
  3.698339583907*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "calculation", " ", "of", " ", "times", " ", "according", " ", "to", " ", 
     RowBox[{"(", "B6", ")"}]}], ",", " ", 
    RowBox[{"see", " ", "Appendix", " ", "B", ".2"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"tps", "[", "1", "]"}], "=", "0"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tps", "[", "2", "]"}], "=", 
    RowBox[{"tinit", "+", 
     RowBox[{
      RowBox[{"h", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tps", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"tps", "[", "2", "]"}], "+", 
     RowBox[{
      RowBox[{"h", "/", "3"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"4", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tps", "[", "k", "]"}], "=", 
      RowBox[{
       RowBox[{"tps", "[", 
        RowBox[{"k", "-", "2"}], "]"}], "+", 
       RowBox[{
        RowBox[{"h", "/", "3"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "+", 
          RowBox[{"4", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "1"}], "]"}], "]"}]}], "+", 
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "2"}], "]"}], "]"}]}]}], ")"}]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "4", ",", 
       RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674401245474*^9, 3.6744014430889997`*^9}, {
   3.674401481816*^9, 3.674401511163*^9}, {3.674406079924*^9, 
   3.6744060817799997`*^9}, 3.6745290582546024`*^9, 3.674994600677*^9, {
   3.698474026314*^9, 3.69847403473*^9}, {3.6984740677860003`*^9, 
   3.6984740833780003`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, {
   3.696337247788*^9, 3.696337263354*^9}, 3.696339409084*^9, 
   3.698225032921*^9, 3.698225309112*^9, 3.698226656039*^9, 3.698226818771*^9,
    3.698227150076*^9, 3.698326845472*^9, 3.698327026436*^9, 
   3.6983272271610003`*^9, 3.698327417318*^9, 3.69833306474*^9, 
   3.698334350696*^9, 3.698336659094*^9, 3.69833793821*^9, 
   3.6983395875620003`*^9, 3.6983777971589994`*^9, 3.6983891183849998`*^9}],

Cell[BoxData["0.0028196334083076895`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, {
   3.696337247788*^9, 3.696337263354*^9}, 3.696339409084*^9, 
   3.698225032921*^9, 3.698225309112*^9, 3.698226656039*^9, 3.698226818771*^9,
    3.698227150076*^9, 3.698326845472*^9, 3.698327026436*^9, 
   3.6983272271610003`*^9, 3.698327417318*^9, 3.69833306474*^9, 
   3.698334350696*^9, 3.698336659094*^9, 3.69833793821*^9, 
   3.6983395875620003`*^9, 3.6983777971589994`*^9, 3.6983891183879995`*^9}],

Cell[BoxData["0.008218411327738278`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, {
   3.696337247788*^9, 3.696337263354*^9}, 3.696339409084*^9, 
   3.698225032921*^9, 3.698225309112*^9, 3.698226656039*^9, 3.698226818771*^9,
    3.698227150076*^9, 3.698326845472*^9, 3.698327026436*^9, 
   3.6983272271610003`*^9, 3.698327417318*^9, 3.69833306474*^9, 
   3.698334350696*^9, 3.698336659094*^9, 3.69833793821*^9, 
   3.6983395875620003`*^9, 3.6983777971589994`*^9, 3.69838911839*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tabtps", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"tps", "[", "i", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "FileGamma", "]"}], ",", "2"}], "}"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "interface", " ", "velocity", " ", "exhibits", " ", "oscillations"}], ",",
     " ", 
    RowBox[{"I", " ", "take", " ", "every", " ", "two", " ", "values"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"poly", "=", 
  RowBox[{"Interpolation", "[", 
   RowBox[{"tabtps", ",", 
    RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xlow", ",", "xup"}], "}"}], "=", 
  RowBox[{
   RowBox[{"poly", "[", "\"\<Domain\>\"", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"poly", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xlow", ",", "xup"}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 CellChangeTimes->{{3.674994059425*^9, 3.674994066933*^9}, {3.674994134277*^9,
    3.674994144508*^9}, {3.67499420802*^9, 3.674994218811*^9}, {
   3.674994287916*^9, 3.674994304627*^9}, {3.6749945129630003`*^9, 
   3.674994520703*^9}, {3.674994577651*^9, 3.67499469562*^9}, {
   3.674994728869*^9, 3.674994758707*^9}, {3.674994788994*^9, 
   3.674994826995*^9}, {3.674994861763*^9, 3.674994864499*^9}, 
   3.698226662492*^9, {3.698227167285*^9, 3.6982271675810003`*^9}, 
   3.698326852131*^9, {3.698335286699*^9, 3.6983352983529997`*^9}, {
   3.698474094035*^9, 3.698474094427*^9}, {3.698474134666*^9, 
   3.698474162837*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVjXk4lAkcgCfkMSmZkWonueZRk+witNk18/u5sw1isdV2LIlUm5Rx79hc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      "]]}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1., 2001.}, {0., 1.3773457035840697`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.698326891615*^9, 3.69832691208*^9}, {3.698327032146*^9, 
   3.6983270383050003`*^9}, 3.698327230668*^9, 3.698327421645*^9, 
   3.6983330679820004`*^9, 3.698334354623*^9, {3.698335290466*^9, 
   3.698335300323*^9}, 3.6983366625290003`*^9, 3.698337941238*^9, 
   3.6983395909630003`*^9, 3.6983778012999997`*^9, 3.698389123988*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "calculation", " ", "of", " ", "k", " ", "correspoding", " ", "to", " ", 
    "the", " ", "desired", " ", "times"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"poly", "[", "x", "]"}], "\[Equal]", "0.1"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "20"}], "}"}], ",", 
     RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"poly", "[", "x", "]"}], "\[Equal]", "0.2"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "77"}], "}"}], ",", 
     RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"poly", "[", "x", "]"}], "\[Equal]", "0.4"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "600"}], "}"}], ",", 
     RowBox[{"AccuracyGoal", "\[Rule]", "6"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.698334509218*^9, 3.698334521123*^9}, {3.698335035823*^9,
   3.6983350523859997`*^9}, {3.698335139707*^9, 3.698335152362*^9}, {
  3.698335229098*^9, 3.698335265898*^9}, {3.698335318041*^9, 
  3.6983353665550003`*^9}, {3.6983367259700003`*^9, 3.6983367413529997`*^9}, {
  3.698474110947*^9, 3.6984741277939997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", "\[Rule]", "51.04182800724577`"}], "}"}]], "Output",
 CellChangeTimes->{{3.698334510434*^9, 3.698334521507*^9}, 
   3.698335113171*^9, {3.69833514675*^9, 3.6983351530889997`*^9}, {
   3.6983352314969997`*^9, 3.698335266288*^9}, {3.6983353033199997`*^9, 
   3.6983353261140003`*^9}, {3.6983353575299997`*^9, 3.698335366855*^9}, 
   3.698336664073*^9, 3.698336742127*^9, 3.698337942828*^9, 3.698339593021*^9,
    3.6983778035*^9, 3.698389125661*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", "\[Rule]", "125.68136008016634`"}], "}"}]], "Output",
 CellChangeTimes->{{3.698334510434*^9, 3.698334521507*^9}, 
   3.698335113171*^9, {3.69833514675*^9, 3.6983351530889997`*^9}, {
   3.6983352314969997`*^9, 3.698335266288*^9}, {3.6983353033199997`*^9, 
   3.6983353261140003`*^9}, {3.6983353575299997`*^9, 3.698335366855*^9}, 
   3.698336664073*^9, 3.698336742127*^9, 3.698337942828*^9, 3.698339593021*^9,
    3.6983778035*^9, 3.6983891256679997`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", "\[Rule]", "337.9412450655037`"}], "}"}]], "Output",
 CellChangeTimes->{{3.698334510434*^9, 3.698334521507*^9}, 
   3.698335113171*^9, {3.69833514675*^9, 3.6983351530889997`*^9}, {
   3.6983352314969997`*^9, 3.698335266288*^9}, {3.6983353033199997`*^9, 
   3.6983353261140003`*^9}, {3.6983353575299997`*^9, 3.698335366855*^9}, 
   3.698336664073*^9, 3.698336742127*^9, 3.698337942828*^9, 3.698339593021*^9,
    3.6983778035*^9, 3.698389125673*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"des", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tps", "[", "k", "]"}], ",", 
          RowBox[{"s0", "+", 
           RowBox[{"k", " ", "h"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "FileGamma", "]"}], ",", "2"}], "}"}]}], 
       "]"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "->", "\"\<Times\>\""}], ",", "12"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"s\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\""}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{"s0", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "tinit"}], ")"}], " ", "/", "a"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "1.4"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1.4"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Dotted", ",", "Black"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.674401540975*^9, 3.674401584967*^9}, {3.674406462454*^9,
    3.674406525742*^9}, {3.674468922807*^9, 3.674468923031*^9}, {
   3.6745236140116024`*^9, 3.674523614251602*^9}, {3.6745242133616023`*^9, 
   3.6745242138486023`*^9}, 3.674552896487*^9, {3.6745530048380003`*^9, 
   3.674553094742*^9}, {3.674557687903*^9, 3.674557695582*^9}, {
   3.6749941606140003`*^9, 3.6749941770480003`*^9}, {3.6963371689560003`*^9, 
   3.6963371808129997`*^9}, 3.6963394213269997`*^9, 3.698225101259*^9, 
   3.6982266852860003`*^9, 3.698327096061*^9, {3.698334427398*^9, 
   3.69833445594*^9}, {3.6983383165959997`*^9, 3.6983383170179996`*^9}, {
   3.698380301927*^9, 3.698380346847*^9}, {3.69838038447*^9, 
   3.698380385278*^9}, {3.6983891417339997`*^9, 3.698389149278*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], 
      StyleBox[PointBox[CompressedData["
1:eJw12ndYE0vXAPA0xXYVO2JH7GLv7YwKir1eK4rCVVREFLEXbNgbAnaRotgL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        "]],
       FontFamily->"Times"]}, {}}, {}, {}, {{}, {}}}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0fs/03scwPGZS9nXpRoHTamm9pCj0U5M0fszO0yzSisqyf1S8UARWqpz
olZyuh11zkNOTg+34qx4IKFSJJOSLqqFaHMZsY22L8dMp/PD6/H8A17LIxL5
0UQCgbD5e/97Lcg7p1QUsrHxY/82BkMGzCf2nUx7D4jyiGV5rJeBqLwrRUvl
gfH1cWdvlgz22a1p7aEGAz98xnznVhl47w5KekGNh6FhcocgTgY/paqetFAz
wETjw20qlEF51gblY2oO7DIXeW2zGIBhLNzgETUfJthHGImaAfi8yTe4li+C
RI/7S7N7h2DFcxotWlwDHqt0GbxiOTCw6r7y5vtAcF3muDRqFOrYh0PdHJtg
Qde4tMN3DFKjTGqGq1ogIbrOlGaqgGeF00sCz7SB9Sm6V8iUEszpt1bJuC9g
7yA7kj+mgvSOsuzQmE54R1CGtD2fgOrc8nM/bn4N6sjEPvqjSQBe2be/yW+h
rjHB5kDhV2hyONds/6oLBGtCtY4n1XDp6g+XhNXvQTpgH9GbrIHb6oJXl9Ik
oPp9/8mIAByspG8oR8O6oTg7k/Z+0xSka0ZqklEvBOaeT3njPg20GV0TmdAH
oqvWRwtt/oWFnE/xbYf6oaw/zSjSZAbunr1fGRzwGfypgX64Ygb0LJKO9nGl
kCcytjwyoAXfSovxkQ0ykHJvn87smgVXDtNabDsAnf2vKsPv6uCZvYv4yoJB
iHr4LJxeNgeG2psubupBuJ7r1d752zfwGFjIDnszBF8eBigyXAnIxtJfkt4y
DLvfp7ifvUNAf200dYgulQMlfnv4iWV6qPVOgQ7lj0BFUb7feJ4eGmdQBUU5
o9Ac88nYjkxE9RUrK7rjv8Dq4r6i9ZlE5HRYd4AYNgaRQj9ixywRcdbu6Jv1
GgfVYKqHX4I+2kvM1x5frgDtizxuTq8+sllcl69apATJbgeKd6ABylgdMLVO
rQQsIk08/NQAebEi49alqMDczJlJZBmivP3dte5DKoh1vZllVGWIkii8D3qB
E+Apty7uWGGEbA7SGlgvJ2DIUy00yzdCluwmQRyaBKn5BQ7TdB4auNc6a9Iw
CZWnctskwnnI5V4L/xDjK8xlXbYDwnz0mpF56vH37wUEf/75pPnIZ3u54MwS
NZCXpXMCRucjU+VlnvsFNXxsCLUxCjZGfIvkSdGcGuw+Q6Og3Rgd6H0QlJem
AbeybFrszyT0boW4IEmugUJlbrxnDQl5KppT941qgNRwkb2uloSK6ho3h41p
4ODpnMVOdSR00L9Wu1WlgY1LssS2D0jI5HjJTvq0BiTcZPvZJyTEkmSZK+bh
YFayraf+LQn9c4F1Io6Gw5FgMx5TTULkPZ6BkQ449NNIVGechASr3J32OOLA
+Wo4Q5smIc4D524uHQeLbF2p1SwJSUft3Fa74XCndkx/Sh9D1j5zCrkPDoOL
2htqyBg6sXCmpd8XB96np5dFlhga6tHkf+DiUHWraX+xFYaqkse54i04/ILq
ra5QMLTlRk9JaSAOlIRbySlUDFXHfzhWsAuHX92LufErMURhvt3xRxAOcoMb
y6NoGJJ3tBOFITjUXPvz5XZHDG3Na5UcD8PBNja3xM8JQ3ejmytSI3DIXHvx
GJuOIVuXRmFCFA4junM7NrhgKHO2PiQmBgf/NqEjg4Gh/wDC+0VL
       "]]}}, {}, {}}, {{{}, {}, 
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], Dashing[{0, Small}], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPTvKtWf52jg7BjD4YL+6xfr9QeUeexj/OXciywHl
OXD+Q0+PmO1Ba+F8pTPq6qkntsL5xtxb7q8+vAfO3+lcGm+ufQjOL0vh2fp8
81E4/9TiH7JhHSfhfH79lWqPvc7C+RXnVnXFp12A87dMWd2t43sJzrf3WfV/
gfAVOP+QZvdhlYtX4fyJ08Qmtm+5Duev+zL/4sTym3C++KPL0tUJtxH2fX25
tdjhLpyv/uvvIWGG+3C+oPu9nJNFD+D8bZ17NsaEPoTzGUUKqu97PYLzPTaK
vH1p/RjON3O3kDgh8wThfxXDE1MFnsL5rL9XGJp/QfBtngg6J1x+BudLigbc
rDj6HM6fa8ermbr8BZx/fP38vw5zXsL5b42Vq5b0vILzd21Q3XA75zWcr1v6
N4sp4Q2c724Ucv+P01s4P5Zpzu86xXcI+6V2zvkg9B7Or9EK/W76BcF3ckzO
Ni35AOfPyry93fIZgl8g7XODMewjwrxC9d2O5xF8UedDVdkOn+D8JzuO/+HZ
jeAb7jgaVGT8Gc6/ZNzcenAxgu8WvLqqQ/YLnM/7fpKPZT+CHyRS/GntPwQ/
6+7eqFnlX+H8a0on5he8QPDX9DvWZ6t/g/Ob/+yKS0tD8AEpyBBd
       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times", 12},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"s\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{791.6666666666677, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6744015417860003`*^9, 3.674401585866*^9, {3.674406434427*^9, 
   3.674406463814*^9}, {3.6744064989630003`*^9, 3.674406526631*^9}, {
   3.67446891675*^9, 3.674468923367*^9}, 3.674469617216*^9, 
   3.6744829009834003`*^9, {3.6745236027306023`*^9, 3.6745236146066027`*^9}, {
   3.6745242046796026`*^9, 3.6745242146106024`*^9}, 3.6745430990756006`*^9, {
   3.6745528921549997`*^9, 3.674552896891*^9}, {3.674553021333*^9, 
   3.674553049718*^9}, {3.674553082395*^9, 3.674553095638*^9}, {
   3.674557690033*^9, 3.674557695924*^9}, {3.674994154193*^9, 
   3.6749941786610003`*^9}, 3.67500124404*^9, 3.6782786360108004`*^9, 
   3.6782790801598005`*^9, 3.696337268677*^9, {3.696339416641*^9, 
   3.696339421729*^9}, 3.698225038342*^9, {3.698226667717*^9, 
   3.6982266861809998`*^9}, 3.6982268229779997`*^9, 3.6982271742060003`*^9, 
   3.6983270418570004`*^9, 3.6983270964849997`*^9, 3.698327235865*^9, 
   3.698327428087*^9, 3.69833307262*^9, 3.698334359324*^9, {3.698334429061*^9,
    3.698334456309*^9}, 3.6983353052130003`*^9, 3.698336665744*^9, 
   3.698337946668*^9, 3.698338317355*^9, 3.698339594957*^9, 
   3.698377807882*^9, {3.6983803282109995`*^9, 3.6983803475499997`*^9}, 
   3.698380385547*^9, {3.6983891280369997`*^9, 3.6983891519539995`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<Comparaison1.eps\>\"", ",", "des", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674553106828*^9, 3.674553122342*^9}, 3.674557994455*^9, 
   3.6983891564679995`*^9}],

Cell[BoxData["\<\"Comparaison1.eps\"\>"], "Output",
 CellChangeTimes->{
  3.674553125358*^9, 3.674557997682*^9, 3.6749945492790003`*^9, 
   3.696339427683*^9, 3.698339596868*^9, {3.698380381021*^9, 
   3.6983803877839994`*^9}, 3.6983891619209995`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.675002546646*^9, 3.67500255109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "calculation", " ", "of", " ", "the", " ", "stress", " ", "by", " ", 
    "numerical", " ", "differentiation", " ", "of", " ", "the", " ", 
    "velocity", " ", "profile"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Print", "@", "k"}], ";", "\[IndentingNewLine]", 
     RowBox[{"dt", "=", 
      RowBox[{"h", "/", 
       RowBox[{"detailG", "[", 
        RowBox[{"[", "k", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"k", ">", "1"}], ",", 
       RowBox[{"dudt", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"vitesse", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], ",", 
                RowBox[{"{", "0", "}"}]}], "]"}]}], " ", "+", 
             RowBox[{"vitesse1", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], " ", ")"}], "/", "dt"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"dudt", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"vitesse", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], " ", "+", 
             RowBox[{"vitesse1", "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], " ", ")"}], "/", "dt"}], ",", 
          RowBox[{"-", "2"}]}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"inter", "=", 
      RowBox[{"Interpolation", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", " ", "*", "h"}], ",", 
           RowBox[{"dudt", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"vitesse1", "[", 
              RowBox[{"[", "k", "]"}], "]"}], "]"}], "-", "2"}]}], "}"}]}], 
        "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"zlim", "=", 
      RowBox[{
       RowBox[{"inter", "[", "\"\<Domain\>\"", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tableTau", "[", "k", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{"1", "-", 
             RowBox[{"inter", "[", "z", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", "0", ",", "zz"}], "}"}]}], "]"}], ",", "zz"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"zz", ",", "0", ",", "zlim", ",", 
          RowBox[{"zlim", "/", "50"}]}], "}"}]}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.674827948160738*^9, 3.6748279846487617`*^9}, {
   3.6748280291469955`*^9, 3.6748280394814577`*^9}, {3.674828196162238*^9, 
   3.674828245309845*^9}, {3.6748285729105873`*^9, 3.674828588627369*^9}, {
   3.674828631559437*^9, 3.67482864134344*^9}, {3.6748832015590982`*^9, 
   3.674883205627924*^9}, {3.6748832825173206`*^9, 3.6748832865099077`*^9}, {
   3.6750007696549997`*^9, 3.675000792057*^9}, {3.675000864815*^9, 
   3.675000869752*^9}, {3.675001293097*^9, 3.675001300608*^9}, 
   3.675001390273*^9, 3.675002230799*^9, {3.6750023940950003`*^9, 
   3.675002446263*^9}, {3.675002501561*^9, 3.675002530329*^9}, {
   3.6750025807530003`*^9, 3.6750026400109997`*^9}, {3.675002832707*^9, 
   3.675002872527*^9}, 3.675003056002*^9, 3.6782792370928*^9, {
   3.698377850526*^9, 3.6983778512629995`*^9}, {3.6983781019119997`*^9, 
   3.6983781060439997`*^9}, {3.698474173227*^9, 3.69847420533*^9}}],

Cell[CellGroupData[{

Cell[BoxData["2"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792407568*^9, 3.696337276924*^9, 
   3.698225081184*^9, 3.698226833249*^9, 3.698337961288*^9, 3.698339613483*^9,
    3.698377856154*^9, {3.698378102238*^9, 3.698378117521*^9}, 
   3.69838916429*^9}],

Cell[BoxData["3"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792407568*^9, 3.696337276924*^9, 
   3.698225081184*^9, 3.698226833249*^9, 3.698337961288*^9, 3.698339613483*^9,
    3.698377856154*^9, {3.698378102238*^9, 3.698378117521*^9}, 
   3.698389176097*^9}],

Cell[BoxData["4"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792407568*^9, 3.696337276924*^9, 
   3.698225081184*^9, 3.698226833249*^9, 3.698337961288*^9, 3.698339613483*^9,
    3.698377856154*^9, {3.698378102238*^9, 3.698378117521*^9}, 
   3.6983891894989996`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "calculation", " ", "of", " ", "the", " ", "stress", " ", "by", " ", 
    "differentiation", " ", "of", " ", "the", " ", "initial", " ", "velocity",
     " ", "profile"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"tableTau", "[", "1", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"1", ",", "0", ",", "0"}], "]"}], "[", "g", "]"}], "[", 
         RowBox[{
          RowBox[{"i", " ", "h"}], ",", "s0", ",", "a"}], "]"}]}], ",", 
       RowBox[{"i", " ", "h"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "N1"}], "}"}]}], "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.6983780945179996`*^9, 3.6983781241879997`*^9}, {
  3.6983781764839997`*^9, 3.6983781861749997`*^9}, {3.6983787141189995`*^9, 
  3.6983787361419997`*^9}, {3.6983787959349995`*^9, 3.698378931974*^9}, {
  3.698474212163*^9, 3.698474221145*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdmHmUZGV5xglyCEeJicQAYYxRVGKiHuQkkROMeTFiEhzFhYSDRoWDmKAG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      "]]}, {}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.5}, {0, 0.6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.698378092514*^9, 3.698378096911*^9}, {
   3.6983781606829996`*^9, 3.698378186516*^9}, {3.6983787286949997`*^9, 
   3.69837873713*^9}, 3.6983787971119995`*^9, {3.6983788403669996`*^9, 
   3.698378884074*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"desTau", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"tableTau", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", "  ", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "teps"}],
       "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\[CapitalDelta]\!\(\*
StyleBox[OverscriptBox[\"\[Tau]\", \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6748286745998344`*^9, 3.6748287354485617`*^9}, {
   3.675001426007*^9, 3.675001461783*^9}, {3.6750024190699997`*^9, 
   3.675002424955*^9}, {3.675002745388*^9, 3.675002766949*^9}, 
   3.675002899296*^9, {3.675002942023*^9, 3.6750029871029997`*^9}, {
   3.6782792456438003`*^9, 3.6782792462358003`*^9}, {3.696337192829*^9, 
   3.696337194068*^9}, 3.698225095682*^9, {3.698378041975*^9, 
   3.698378046904*^9}, 3.698378925335*^9, {3.698378956087*^9, 
   3.698379024415*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJxdmHmUZGV5xglyCEeJicQAYYxRVGKiHuQkkROMeTFiEhzFhYSDRoWDmKAG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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxdkX8sFGAcxs2ULXXKyE1Cml8lVKLY9dSKkmTUSashxR9nw4SZNjcr1C1L
qk1hd6ZjrMVcHJezc+HOdX7duR+OcziaYotdnYmS296/+m7v3r17v+/zfZ7P
eyg1Kz7N2srK6uT2suz/18QnZvqbshKEfZTm97BZaBPKWfFlr8n5LUT8xkRP
Lw78y/ZPDK/VQ8sYcDpayiX3zZgZzZir+dqMd9m0XZr6VtyNXi7yPdxK+nmo
OdEcXqFoA6/2R+NANB9BfqkOOcXt5L0Av907rwoCO9Erq4voMAnRRWVS6HoB
0ROhMI8eF8ASYnGjaVURI8Zf2fEV6gER0f+MHCuPZm52L7IcHolkdf3QRBfZ
8vrFZJ4EserAmhCXPph97zwX/5LCxc1b75XZT+bL4Ljzg1t+7wCKcCpJECVH
LlVT6eooJX6G4BRlvkRJH8SOBMqxttoRFKRE+Jzjy4i/UXyx55gabOWI7DD9
GS8Yw25O8uXQm0PErwI3KAlVC9xhsM6nLIx6KtGV8s2/wTRC/CvhoW2sDOGM
YkhuqXHQosxhzpFjJI8KK66LpsylMexLPLPtWA0m3f9ZaIWC5NNA+aqwmxGs
BN3Ire7z0OKJpMTHWqskebXwKt26tVY4jqpMi+AEBpPeyy4cVJH8OsgzWLqZ
HhWm1osY3bmTCC62U0mS1YTHFMT0pJXVLTXcS5biOt308JnmxySyNYSPHix1
9bqJpsW9vRaD09hsz14WTmoJLwPiNyV2LQUTUMakbnfM4OnG+hGRo47wm0Gn
dI/t9xYd8l5SbRIosxDkayK8rkwSnrMo93hczTBOwnmb1nXjLMz1bF7bwynC
dw7WWeylnw56dLlZDM7BRkfzC2jSE95GULwfeF47O43b98MNseVGpFx8YU9X
TBP+RjCpPPvTaQZsWuRS52HzNqhixWwg/zGPf+1MpnA=
         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJxdknlIE1Acx21oVoh45gWSGhSYmAnBvL5ImvWHRhqRt3nkklmmIsO8lx2W
iY4UylLJ2zSPpanTlpnH1Onm3JzXnHPT6MJWmcSkOd5f/eDxeLz3vr/v9/Oe
Q+zN4ASKnp6eu3bszf+XoTqC6nPqLqz1Lxu7dBYjLt/In+tWTtbPUWi1a9lW
Ww0zJpdX41+PO+yGgTeu9WS/Fc0xrMSu3haUDP06HlHSCSe30FduNe3kfDde
yIKU3PguPDnzkL7xtxcOnj3pCce6yf0BKGtFNM3mWwTFmlyhsrkwjnMYvdbU
T/SGEFgX9TCXNogZx8WdnKRh8Gmhs2YsLtEfAcOWnmu39R6XFHXPho+MgT3f
1n0u6APpN47IguzoB83DEL9M8T4kmYCHUXbopMEI6T+F237h2XoxowiL95Rd
KJ7GxYKnlRa9Y8TPDAQT1/O3TXi4oWsoQIND0beKxAniTwjDNN+qdc4k2lNp
pV+zZsHaDQ+YNOETvyIwg71Y3nHT2BIGahXn8DNewzIPmyH+xfCK5Qn69wng
risJuMbl/MeNApJnHsWNLUJmkBDprD3HUrhG+DqVqYUknxSVhR2UjopZdKs1
IsanBehLOO0SDxHJuwhF3lySZkmE7ZA9wSVUZ6XRbXLmSP5lFKpufXe0F4PK
HssYrFpBPyXjhOmAmPCQYZwXE74YJoFWTKu4itNN77oY2xLCZxU/fFKTV8vm
EdV33ojiLEcWdZp70EVKeMlB863Y/PxRitwkjjbCGiLsTa1zIhcIvzWInSmK
HvUCqmxdl4/uV+CqQd6jkvuLhKcCyX5nQzR2S9D9JrUCVZl4/ad1ifBdB32B
mc3wWYY806ItQL4Oe/+81LSpZcJbCZv0zVJ52AoozvcOS/lKWNKjJX2qFcJf
BfOTB6x+p8igk+Oo4O+d/qVoR0beYwP/AKNmi/Y=
         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxdkX0sFGAcx6+sK8PSbZmMFlc07/OyWPHNzKjJTGVeyhp5iaYpZwsxyvu0
8nrz0pyK2jqN0+TldByOY945zp1znDvnLa1EIWV7/urZfnv27Pk939/3+3mM
Qx/4hR+mUCj2/+pg/38p2Kc/neVkQaCXblhkW4j8hEu9pg2l5PwajLqUgoAu
FsxN+OazvR9Av53Mo9XVknsONgw4Rm3FbDyuqKY37zaB23MnK5JbT/rbEJAY
ZRRW14j1sW/MNCEPTHWJ9/PKJvKeD3pI4pea3BZUBdKqakq6oWUS4x/N4BI9
AY74upT2W/PgJ7Or7Q8VIpXtNM5gdRD9AQh81i8U0vjQCL9et2E9BEeZnptG
eheZNwxnxWbZ26/dCN5sFufujcAqe/dMULCAzB/DC1HCPKW7F/ZOV0Mqw8bx
q8PdNNFSSPxMQDObGVvzsh/aSWL5x75JxEmHkiN+DBB/IrhRPW6W3xjEIjc6
vNNmGj2uF91NG4aIXzEaBqJi4zOH0U7ZWRovnkFVY9rTULsR4l+C4gZx8qBk
BKXuefdVO1L85qhY7zNGSR4Zeq7URy5ajsGJr7O9azsHqsb6w0ejYyTfHN61
Gpd5JIzjjWLCmXpXDh9Wh+qa/gTJK8dKpXdFyucJnKC+SjpeOo9uzflDQv9J
kn8BFo6MFvr3STwxi+DqCxfQO+k0mpwvIjwUiOaOuAnPTWHZy3rfeE+Be7wW
h/3WKcJnEbyo1CUd32n4R/+8bGGrxNEiq2er8mnCS4k9A2VnfpwY/Lz2dIcw
FeJcm88r/4gJPxXoW2naqzkzsGFndrmULEEiYrAKaBLCUw2zQlHRMFOC8kEf
qmefGv2e+dvlhlLCdxkZ7Fsx6kopjm3oefnuLmNLe8i63nCW8F7BjK3SXM2c
RfwJWU6gzSp0tYJOZdNkhP8qQvIiT2blyCA/kAtdQ3WsrpF0T0b+Yw1/AXZe
oQY=
         "]]}}}, {}, {}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.5}, {0, 0.9370000000000002}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\[CapitalDelta]\\!\\(\\*\\nStyleBox[OverscriptBox[\\\"\[Tau]\\\", \
\\\"^\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", 18, StripOnInput -> False], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 0.5}, {0, 0.9370000000000002}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.1\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.4\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.674828693819915*^9, 3.6748287371571302`*^9, {3.675001441113*^9, 
   3.675001462705*^9}, 3.675002796612*^9, {3.675002965855*^9, 
   3.675002988558*^9}, 3.6750031430559998`*^9, 3.6782791599678*^9, 
   3.6782792764908*^9, 3.6963373174*^9, 3.6982251277200003`*^9, 
   3.698225161737*^9, 3.69833800258*^9, 3.69833966281*^9, 
   3.6983779032269998`*^9, 3.698378042606*^9, 3.698378925703*^9, {
   3.698379020286*^9, 3.6983790257869997`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ProfileTau.eps\>\"", ",", "desTau", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674995397123*^9, 3.674995407914*^9}, {3.675003168638*^9,
   3.675003175078*^9}}],

Cell[BoxData["\<\"ProfileTau.eps\"\>"], "Output",
 CellChangeTimes->{3.674995408965*^9, 3.6750006630480003`*^9, 
  3.675003175973*^9, 3.696337320217*^9, 3.698225164599*^9, 
  3.6983790361239996`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1904, 1118},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
Magnification:>1.2 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 722, 20, 307, "Text"],
Cell[CellGroupData[{
Cell[1305, 44, 112, 1, 76, "Section"],
Cell[1420, 47, 124, 2, 126, "Input"],
Cell[CellGroupData[{
Cell[1569, 53, 7372, 194, 2625, "Input"],
Cell[8944, 249, 871, 13, 84, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[9864, 268, 710, 14, 58, "Section"],
Cell[CellGroupData[{
Cell[10599, 286, 9647, 224, 1082, "Input"],
Cell[20249, 512, 2161, 32, 44, "Output"],
Cell[22413, 546, 2179, 32, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24629, 583, 372, 10, 74, "Input"],
Cell[25004, 595, 110, 2, 44, "Output"],
Cell[25117, 599, 111, 2, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25265, 606, 423, 8, 44, "Input"],
Cell[25691, 616, 458, 6, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26186, 627, 8282, 181, 794, "Input"],
Cell[34471, 810, 1645, 24, 44, "Output"],
Cell[36119, 836, 1606, 23, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37762, 864, 861, 21, 80, "Input"],
Cell[38626, 887, 3691, 72, 340, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42354, 964, 2105, 63, 132, "Input"],
Cell[44462, 1029, 552, 8, 44, "Output"],
Cell[45017, 1039, 548, 8, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45602, 1052, 2175, 55, 192, "Input"],
Cell[47780, 1109, 42038, 705, 358, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89855, 1819, 193, 4, 44, "Input"],
Cell[90051, 1825, 112, 1, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90200, 1831, 647, 21, 111, "Input"],
Cell[90850, 1854, 156, 3, 44, "Output"],
Cell[91009, 1859, 106, 1, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91152, 1865, 230, 6, 44, "Input"],
Cell[91385, 1873, 102, 2, 44, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[91536, 1881, 870, 19, 60, "Section"],
Cell[92409, 1902, 11793, 253, 974, "Input"],
Cell[CellGroupData[{
Cell[104227, 2159, 403, 10, 62, "Input"],
Cell[104633, 2171, 714, 10, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105384, 2186, 1235, 37, 86, "Input"],
Cell[106622, 2225, 620, 9, 37, "Output"],
Cell[107245, 2236, 617, 9, 37, "Output"]
}, Open  ]],
Cell[107877, 2248, 1892, 41, 158, "Input"],
Cell[CellGroupData[{
Cell[109794, 2293, 9566, 213, 686, "Input"],
Cell[119363, 2508, 939, 15, 37, "Output"]
}, Open  ]],
Cell[120317, 2526, 310, 7, 62, "Input"],
Cell[CellGroupData[{
Cell[120652, 2537, 1319, 29, 62, "Input"],
Cell[121974, 2568, 11680, 309, 37, "Output"],
Cell[133657, 2879, 790, 13, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134484, 2897, 2924, 79, 67, "Input"],
Cell[137411, 2978, 66969, 1188, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204417, 4171, 1897, 58, 67, "Input"],
Cell[206317, 4231, 63922, 1135, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270276, 5371, 191, 4, 37, "Input"],
Cell[270470, 5377, 199, 3, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270706, 5385, 2530, 74, 134, "Input"],
Cell[273239, 5461, 868, 13, 37, "Output"],
Cell[274110, 5476, 889, 13, 37, "Output"],
Cell[275002, 5491, 882, 13, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275921, 5509, 1880, 48, 182, "Input"],
Cell[277804, 5559, 3920, 77, 281, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281761, 5641, 1351, 32, 110, "Input"],
Cell[283115, 5675, 491, 8, 37, "Output"],
Cell[283609, 5685, 497, 8, 37, "Output"],
Cell[284109, 5695, 491, 8, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[284637, 5708, 2715, 70, 90, "Input"],
Cell[287355, 5780, 21068, 360, 622, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308460, 6145, 237, 5, 37, "Input"],
Cell[308700, 6152, 251, 4, 37, "Output"]
}, Open  ]],
Cell[308966, 6159, 85, 1, 37, "Input"],
Cell[CellGroupData[{
Cell[309076, 6164, 4144, 100, 206, "Input"],
Cell[CellGroupData[{
Cell[313245, 6268, 408, 7, 26, "Print"],
Cell[313656, 6277, 409, 7, 26, "Print"],
Cell[314068, 6286, 414, 7, 26, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[314531, 6299, 1067, 26, 62, "Input"],
Cell[315601, 6327, 6928, 126, 291, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322566, 6458, 1895, 50, 67, "Input"],
Cell[324464, 6510, 29332, 569, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353833, 7084, 234, 5, 37, "Input"],
Cell[354070, 7091, 199, 3, 37, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

