(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    237244,       5039]
NotebookOptionsPosition[    233906,       4924]
NotebookOutlinePosition[    234306,       4941]
CellTagsIndexPosition[    234263,       4938]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Electronic supplement to

@article{
ancey16jnnfm,
   Author = {Ancey, C. and Bates, B.M.},
   Title = {Setting in motion and entraining a Herschel-Bulkley fluid},
   Journal = {Journal of Non-Newtonian Fluid Mechanics},
   Volume = {submitted},
 Year = {2016} }

Copyright C. Ancey May 2016

Run when initializing the code before all computations. The details of the \
code are given in the appendices of the paper.

WARNING: this notebook uses variants of the boundary conditions (see Appendix \
B)\
\>", "Text",
 CellChangeTimes->{{3.6782725741048*^9, 3.6782726077578*^9}, {
  3.6782747248998003`*^9, 3.6782747255588*^9}, {3.6782748298678*^9, 
  3.6782748486678*^9}, {3.698473723349*^9, 3.698473748177*^9}}],

Cell[CellGroupData[{

Cell["Definition of functions", "Section",
 CellChangeTimes->{{3.6782727990188003`*^9, 3.6782728116438003`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6782728135938005`*^9, 3.6782728290938005`*^9}, 
   3.6782747233808002`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"UserDirectory", "=", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\"\<FileName\>\"", "/.", 
      RowBox[{"NotebookInformation", "[", 
       RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ")"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetDirectory", "[", "UserDirectory", "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Qmatrix", "[", 
    RowBox[{"n_", ",", "r_", ",", "\[CapitalGamma]_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Q1", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", "l"}]}], "\[Rule]", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", "r"}], ")"}]}], "+", "\[CapitalGamma]"}]}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Q2", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "-", "1"}]}]}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r"}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Q3", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "+", "1"}]}]}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r"}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Q", "=", 
      RowBox[{"Normal", "[", 
       RowBox[{"Q1", " ", "+", " ", "Q2", "+", "Q3"}], "]"}]}]}], "  ", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rvector", "[", 
    RowBox[{"n_", ",", "h_"}], "]"}], ":=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{
     RowBox[{"h", "^", "2"}], ",", "n"}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P3matrix", "[", 
    RowBox[{"n_", ",", "r_", ",", "\[CapitalGamma]_"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P1", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", "l"}]}], "\[Rule]", 
           RowBox[{
            RowBox[{"2", "r"}], "+", "\[CapitalGamma]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"P2", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "-", "1"}]}]}], "\[Rule]", 
           RowBox[{"-", "r"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], " ", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"P3", "=", " ", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
            RowBox[{"k", "==", 
             RowBox[{"l", "+", "1"}]}]}], "\[Rule]", 
           RowBox[{"-", "r"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}]}], " ", "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"P", "=", 
       RowBox[{"Normal", "[", 
        RowBox[{"P1", " ", "+", " ", "P2", "+", "P3"}], "]"}]}], " ", ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", "n"}], "]"}], "]"}], "=", "r"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", 
          RowBox[{"n", "-", "1"}]}], "]"}], "]"}], "=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"n", ",", 
          RowBox[{"n", "-", "2"}]}], "]"}], "]"}], "=", 
       RowBox[{"-", "r"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", "r"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"-", "r"}]}], ";", "P"}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673519836729*^9, 3.673519839715*^9}, {3.673519974267*^9,
    3.67352007606*^9}, {3.6735201186940002`*^9, 3.673520157052*^9}, {
   3.673520225333*^9, 3.6735202312860003`*^9}, {3.6735202989969997`*^9, 
   3.6735204178199997`*^9}, {3.673520465983*^9, 3.673520467894*^9}, {
   3.673933585831375*^9, 3.6739336253549824`*^9}, {3.673934412367329*^9, 
   3.673934414789464*^9}, {3.674224574240368*^9, 3.674224612260051*^9}, {
   3.6743888214645185`*^9, 3.6743888219898863`*^9}, {3.6744633847262077`*^9, 
   3.6744633852422075`*^9}, {3.6744635078592076`*^9, 3.674463536304208*^9}, {
   3.6744697089440002`*^9, 3.6744697297209997`*^9}, {3.6744822796024*^9, 
   3.6744823142254*^9}, {3.6744829757714*^9, 3.6744830328884*^9}, {
   3.6744836346714*^9, 3.6744836369944*^9}, {3.674738196498*^9, 
   3.67473820008*^9}, {3.6749668440980015`*^9, 3.674966852913001*^9}, 
   3.674967075761001*^9, {3.6749673111140013`*^9, 3.6749673574820013`*^9}, {
   3.674967592404001*^9, 3.6749676188500013`*^9}, {3.674968680113001*^9, 
   3.674968772826001*^9}, {3.6782734125458*^9, 3.6782734209608*^9}}],

Cell[BoxData["\<\"D:\\\\Echange\\\\JNNFM\\\\article_1(theory)\\\\figshare\\\\\
\"\>"], "Output",
 CellChangeTimes->{3.6747382009*^9, 3.674824422137*^9, 3.674965493812001*^9, 
  3.6749673605580015`*^9, 3.674967473182001*^9, 3.674967620307001*^9, 
  3.674968692970001*^9, 3.674968775670001*^9, 3.674977881699404*^9, 
  3.674978585223404*^9, 3.674979691866404*^9, 3.6782747278448*^9, 
  3.6782786843328*^9, 3.698381296259*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Boundary ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "z"], TraditionalForm]]],
 " u = - a s (Eq. B10) --- Figure B13"
}], "Section",
 CellChangeTimes->{{3.6739665004081616`*^9, 3.6739665088465996`*^9}, {
   3.6739701396406593`*^9, 3.6739701506262136`*^9}, {3.6739768840636225`*^9, 
   3.6739768858450317`*^9}, {3.6742269616087046`*^9, 3.674226963655799*^9}, 
   3.674404850061*^9, {3.6744616820462074`*^9, 3.6744616836282077`*^9}, {
   3.674469746836*^9, 3.674469748141*^9}, {3.6782729577258005`*^9, 
   3.6782729598208003`*^9}, 3.6782734398698*^9, {3.6782734799688005`*^9, 
   3.6782735088608003`*^9}, {3.6782748017558002`*^9, 3.6782748151478004`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"boundary", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"a_", ",", "k_", ",", "h_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"-", "a"}], " ", "k", " ", "h"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Usol", "[", 
     RowBox[{"x_", ",", "t_", ",", "a_"}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xf", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"2", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "a"}], ")"}], "/", "a"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"t", " ", 
       RowBox[{
        RowBox[{"xf", "^", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"xf", "^", "2"}]}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "^", "2"}], "/", 
           RowBox[{"xf", "^", "2"}]}], "/", "t"}]}], ")"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Xisol", "[", "a_", "]"}], ":=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], "/", "a"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "finding", " ", "the", " ", "0", " ", "of", " ", "s", " ", "using", " ", 
     "the", " ", "secant", " ", "method"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fnc", "[", 
     RowBox[{"gamma_", ",", "gk_", ",", "k_", ",", "U_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "ukp", ",", "Us", ",", "gsmiddle", ",", "Smat", ",", "U1", ",", 
        "Gsmiddle"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ukp", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
         RowBox[{"0.5", 
          RowBox[{"h", "^", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"gk", " ", 
             RowBox[{"F", "[", 
              RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Us", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"U", ",", 
          RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"gsmiddle", "=", 
        RowBox[{
         RowBox[{"kr", " ", "gk"}], "+", 
         RowBox[{"gamma", 
          RowBox[{"(", 
           RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Gsmiddle", "=", 
        RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Smat", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Qmatrix", "[", 
            RowBox[{
             RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], ".",
            "Us"}], "+", 
          RowBox[{"Rvector", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Smat", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}]}], ";", 
       RowBox[{
        RowBox[{"Smat", "[", 
         RowBox[{"[", 
          RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", 
            RowBox[{"-", "3"}], "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
         RowBox[{"2", "h", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", 
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"U1", "=", 
        RowBox[{
         RowBox[{"Inverse", "[", 
          RowBox[{"P3matrix", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], 
          "]"}], ".", "Smat"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"U1", "[", 
        RowBox[{"[", 
         RowBox[{"k", "+", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "parameters", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kr", "=", "0.0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"N1", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"s0", "=", 
    RowBox[{"N1", " ", "h"}]}], "\[IndentingNewLine]", 
   RowBox[{"tinit", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s0", "/", 
       RowBox[{"Xisol", "[", "a", "]"}]}], ")"}], "^", "2"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "conditions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Usol", "[", 
        RowBox[{
         RowBox[{"i", " ", "h"}], ",", "tinit", ",", "a"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "N1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t1", "=", "tinit"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"Usol", "[", 
             RowBox[{"x", ",", "tinit", ",", "a"}], "]"}], ",", "x", ",", 
            "x"}], "]"}]}], "/.", 
         RowBox[{"x", "\[Rule]", "s0"}]}], ")"}]}], "/", 
      RowBox[{"F", "[", 
       RowBox[{"a", ",", "N1", ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temps", "=", 
     RowBox[{"{", "t1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FileGamma", "=", 
     RowBox[{"{", "g1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6739291182704935`*^9, 3.673929229485534*^9}, {
   3.6739293428258495`*^9, 3.67392939347196*^9}, {3.673929590604376*^9, 
   3.6739295943391967`*^9}, {3.6739670738931627`*^9, 3.673967141228506*^9}, {
   3.6739680319267387`*^9, 3.6739680477565284`*^9}, {3.673968161300024*^9, 
   3.6739681659099035`*^9}, 3.6739683634936314`*^9, 3.673969959636938*^9, {
   3.673970921686137*^9, 3.6739709218736563`*^9}, 3.6739777694458017`*^9, {
   3.673977888755495*^9, 3.6739779063198833`*^9}, {3.6739784566446724`*^9, 
   3.6739784626765747`*^9}, {3.6739785742354403`*^9, 3.673978591299775*^9}, {
   3.6739786252565527`*^9, 3.6739786254596977`*^9}, {3.6739787155318804`*^9, 
   3.6739787189384975`*^9}, 3.6740093860723753`*^9, 3.674009487036134*^9, {
   3.67400994474065*^9, 3.6740099531635857`*^9}, {3.6742270049570503`*^9, 
   3.674227009285633*^9}, 3.674228227061883*^9, 3.6742282710040298`*^9, {
   3.6742283563568144`*^9, 3.674228363435691*^9}, {3.674228838905471*^9, 
   3.674228856782359*^9}, 3.6742298096929507`*^9, {3.6742299850239697`*^9, 
   3.674229989243194*^9}, {3.674316421293583*^9, 3.674316466235029*^9}, 
   3.6743165230019073`*^9, 3.674316879418*^9, 3.674317315226*^9, 
   3.674317360684*^9, {3.6743182695*^9, 3.6743182769700003`*^9}, {
   3.6743989727132587`*^9, 3.674398973493326*^9}, 3.674399221369187*^9, {
   3.6743996650494323`*^9, 3.674399686002122*^9}, {3.6743999100826592`*^9, 
   3.674399910694292*^9}, {3.674400007407155*^9, 3.6744000078663387`*^9}, 
   3.6744035918570004`*^9, 3.674403624744*^9, {3.674403740209*^9, 
   3.674403784679*^9}, {3.67440486255*^9, 3.674404864105*^9}, 
   3.6744049388710003`*^9, {3.674405195928*^9, 3.6744052264779997`*^9}, {
   3.67440526416*^9, 3.674405322318*^9}, {3.674405609501*^9, 
   3.674405629849*^9}, {3.674405761408*^9, 3.6744057669119997`*^9}, {
   3.674405806807*^9, 3.674405837641*^9}, 3.6744612301762075`*^9, {
   3.6744612697822075`*^9, 3.6744612849092073`*^9}, 3.674461388519208*^9, {
   3.674461817672208*^9, 3.6744619275892076`*^9}, {3.674461988960208*^9, 
   3.674462026118208*^9}, {3.6744625809052076`*^9, 3.6744625815692077`*^9}, {
   3.674468050223*^9, 3.674468070862*^9}, 3.674468976007*^9, {
   3.6744823696754*^9, 3.6744823716884003`*^9}, {3.6744824255064*^9, 
   3.6744824341384*^9}, {3.6745236327366023`*^9, 3.6745236362876024`*^9}, 
   3.6745423102896004`*^9, {3.6782735316798*^9, 3.6782736139898005`*^9}, {
   3.6782736852208004`*^9, 3.6782736898298*^9}}],

Cell[BoxData["0.05`"], "Output",
 CellChangeTimes->{
  3.674317316421*^9, 3.674317361016*^9, 3.674318278676*^9, 3.67431876766*^9, 
   3.674388831064004*^9, 3.674389031708366*^9, 3.6743891342347918`*^9, 
   3.674389674610982*^9, 3.674399222627493*^9, 3.674399252682413*^9, 
   3.6743995893040714`*^9, 3.674399759369116*^9, 3.674399927587222*^9, 
   3.674400335782*^9, 3.674400409392*^9, 3.674403597803*^9, 
   3.6744036561540003`*^9, 3.674403687608*^9, {3.674403764921*^9, 
   3.674403802057*^9}, 3.6744049437469997`*^9, 3.674405856578*^9, 
   3.674405893824*^9, 3.6744612902652073`*^9, 3.674461389677208*^9, 
   3.6744618997032075`*^9, 3.6744619343592076`*^9, {3.674461989870208*^9, 
   3.674462026436208*^9}, 3.6744625829052076`*^9, 3.674468071578*^9, 
   3.6744689783859997`*^9, 3.6744823269594*^9, 3.6744823995334*^9, 
   3.6744824427743998`*^9, 3.6745231733816023`*^9, 3.6745236365956025`*^9, {
   3.6745423035556006`*^9, 3.6745423110586004`*^9}, 3.6745431132786007`*^9, {
   3.6782747351878004`*^9, 3.6782747538858004`*^9}}],

Cell[BoxData["0.00125`"], "Output",
 CellChangeTimes->{
  3.674317316421*^9, 3.674317361016*^9, 3.674318278676*^9, 3.67431876766*^9, 
   3.674388831064004*^9, 3.674389031708366*^9, 3.6743891342347918`*^9, 
   3.674389674610982*^9, 3.674399222627493*^9, 3.674399252682413*^9, 
   3.6743995893040714`*^9, 3.674399759369116*^9, 3.674399927587222*^9, 
   3.674400335782*^9, 3.674400409392*^9, 3.674403597803*^9, 
   3.6744036561540003`*^9, 3.674403687608*^9, {3.674403764921*^9, 
   3.674403802057*^9}, 3.6744049437469997`*^9, 3.674405856578*^9, 
   3.674405893824*^9, 3.6744612902652073`*^9, 3.674461389677208*^9, 
   3.6744618997032075`*^9, 3.6744619343592076`*^9, {3.674461989870208*^9, 
   3.674462026436208*^9}, 3.6744625829052076`*^9, 3.674468071578*^9, 
   3.6744689783859997`*^9, 3.6744823269594*^9, 3.6744823995334*^9, 
   3.6744824427743998`*^9, 3.6745231733816023`*^9, 3.6745236365956025`*^9, {
   3.6745423035556006`*^9, 3.6745423110586004`*^9}, 3.6745431132786007`*^9, {
   3.6782747351878004`*^9, 3.6782747538878*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", "U0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gk", "=", "g1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etape", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{"Dynamic", "[", "etape", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nmax", "=", 
   RowBox[{"N1", "+", "10000"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"etape", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "-", "N1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"Nmax", "-", "N1"}], ")"}]}]}], ";", " ", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"ii", "=", "2"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "1", "]"}], "=", "gk"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "2", "]"}], "=", 
     RowBox[{"1.5", "gk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ecart", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"xx", "[", "2", "]"}], "-", 
       RowBox[{"xx", "[", "1", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ecart", ">", 
       RowBox[{
        RowBox[{"h", "^", "2"}], " ", 
        RowBox[{"xx", "[", "ii", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"ii", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"xx", "[", "ii", "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xx", "[", "ii", "]"}], "-", 
             RowBox[{"xx", "[", 
              RowBox[{"ii", "-", "1"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}], "-", 
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", 
                RowBox[{"ii", "-", "1"}], "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}]}], ")"}]}], 
          RowBox[{"fnc", "[", 
           RowBox[{
            RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", "U"}], 
           "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ecart", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"xx", "[", "ii", "]"}], "-", 
          RowBox[{"xx", "[", 
           RowBox[{"ii", "+", "1"}], "]"}]}], "]"}]}], ";", 
       RowBox[{"ii", "+=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"gs", "=", 
     RowBox[{"xx", "[", "ii", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ukp", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
      RowBox[{"0.5", 
       RowBox[{"h", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"gk", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Us", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"U", ",", 
       RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gsmiddle", "=", 
     RowBox[{
      RowBox[{"kr", " ", "gk"}], "+", 
      RowBox[{"gs", 
       RowBox[{"(", 
        RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Gsmiddle", "=", 
     RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Smat", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Qmatrix", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], ".", 
        "Us"}], "+", 
       RowBox[{"Rvector", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Smat", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}]}], ";", 
    RowBox[{
     RowBox[{"Smat", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", 
         RowBox[{"-", "3"}], "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
      RowBox[{"2", "h", " ", 
       RowBox[{"F", "[", 
        RowBox[{"a", ",", 
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"U1", "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"P3matrix", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "r", ",", "Gsmiddle"}], "]"}], "]"}], 
      ".", "Smat"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"FileGamma", ",", "gs"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"U", "=", "U1"}], ";", 
    RowBox[{"gk", "=", "gs"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", "0"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", "N1", ",", "Nmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673966517050609*^9, 3.673966648861612*^9}, {
   3.6739666797556033`*^9, 3.6739667339020443`*^9}, {3.6739667659054856`*^9, 
   3.6739668163015313`*^9}, {3.6739668732540045`*^9, 3.67396691474284*^9}, {
   3.673966958903792*^9, 3.673966961216581*^9}, {3.6739670161994834`*^9, 
   3.67396701752775*^9}, {3.6739679274154677`*^9, 3.6739679396824503`*^9}, {
   3.6739679876094847`*^9, 3.6739679968292255`*^9}, {3.6739680750720124`*^9, 
   3.6739680801819315`*^9}, {3.673968127327625*^9, 3.673968206945562*^9}, 
   3.6739682994086266`*^9, {3.6739683921685934`*^9, 3.6739683927467794`*^9}, {
   3.6739699452135077`*^9, 3.6739699819987087`*^9}, {3.6739709681598845`*^9, 
   3.673970974316795*^9}, {3.6739710618261585`*^9, 3.673971119363633*^9}, {
   3.673971182432926*^9, 3.673971276177367*^9}, {3.673971315759741*^9, 
   3.6739713318083544`*^9}, {3.673971391814762*^9, 3.673971418208219*^9}, {
   3.6739717154078617`*^9, 3.6739717156578884`*^9}, 3.673971807183363*^9, {
   3.6739718759094987`*^9, 3.6739718888952217`*^9}, {3.6739765537468605`*^9, 
   3.6739765628884764`*^9}, {3.6739766217541704`*^9, 
   3.6739766366151457`*^9}, {3.673976769988827*^9, 3.673976821213117*^9}, 
   3.673976967306955*^9, {3.6740099737124968`*^9, 3.674009978291089*^9}, {
   3.674227038851217*^9, 3.6742270638694887`*^9}, {3.6742272186202755`*^9, 
   3.6742272204485545`*^9}, {3.6742272616717043`*^9, 3.67422729129984*^9}, {
   3.6742282940689316`*^9, 3.6742282961160192`*^9}, {3.674228382203255*^9, 
   3.67422840751849*^9}, {3.6742285603915777`*^9, 3.674228576971459*^9}, {
   3.6742295568536983`*^9, 3.674229615125483*^9}, {3.6742296550515847`*^9, 
   3.674229744920472*^9}, {3.674229826100938*^9, 3.6742298407743626`*^9}, {
   3.674229932627836*^9, 3.6742299537863226`*^9}, 3.674230023590584*^9, 
   3.6742302341199503`*^9, {3.6742327273011885`*^9, 3.6742327591326485`*^9}, 
   3.674232834953163*^9, {3.6743147973416324`*^9, 3.6743148918267193`*^9}, {
   3.6743156882281895`*^9, 3.6743157043149037`*^9}, {3.6743157502710843`*^9, 
   3.6743157663497877`*^9}, {3.6743158145639315`*^9, 
   3.6743158519423094`*^9}, {3.6743161713331785`*^9, 3.674316175726901*^9}, {
   3.6743162639664307`*^9, 3.674316268007161*^9}, {3.6743163070900087`*^9, 
   3.6743163356198316`*^9}, 3.674316497458014*^9, {3.6743165323978844`*^9, 
   3.674316532905239*^9}, 3.67431685601*^9, {3.674318740052*^9, 
   3.674318772635*^9}, {3.6743888447684307`*^9, 3.674388951511136*^9}, {
   3.674388990361424*^9, 3.674388996832595*^9}, 3.6743890440401077`*^9, {
   3.67438920945475*^9, 3.6743892144690447`*^9}, {3.674389317973166*^9, 
   3.674389320486865*^9}, {3.674398897753016*^9, 3.674398937115638*^9}, {
   3.674398997458021*^9, 3.6743991214656167`*^9}, {3.674399325794737*^9, 
   3.674399333855121*^9}, {3.6743993711944*^9, 3.6743994502043953`*^9}, 
   3.674399485407956*^9, {3.674399524548998*^9, 3.6743995284914713`*^9}, {
   3.6743996996895046`*^9, 3.674399728790809*^9}, {3.6744000691983523`*^9, 
   3.6744000767915335`*^9}, {3.67440018919532*^9, 3.6744001969348583`*^9}, 
   3.674400350852*^9, 3.674400402828*^9, {3.674404954777*^9, 
   3.6744049571280003`*^9}, {3.674405889367*^9, 3.674405889743*^9}, 
   3.674406570192*^9, 3.6744824552974*^9, {3.6745431096206007`*^9, 
   3.6745431253316007`*^9}}],

Cell[BoxData[
 ProgressIndicatorBox[Dynamic[$CellContext`etape]]], "Output",
 CellChangeTimes->{
  3.6742295516499763`*^9, 3.6742297545933266`*^9, 3.6742298419931965`*^9, {
   3.6742299400660725`*^9, 3.6742299544738812`*^9}, {3.674229995415718*^9, 
   3.6742300243406134`*^9}, 3.6742302394017534`*^9, 3.67423276067968*^9, 
   3.6742328081847034`*^9, 3.674232854642743*^9, 3.6743148929025774`*^9, 
   3.6743158571420975`*^9, 3.6743158874306035`*^9, 3.6743162794284806`*^9, 
   3.674316370184701*^9, {3.674316473151373*^9, 3.674316498488763*^9}, 
   3.674316533989072*^9, {3.674316852803*^9, 3.674316881249*^9}, 
   3.6743187767320004`*^9, 3.6743890037971377`*^9, 3.674389045364587*^9, 
   3.6743896799400973`*^9, 3.674399529708704*^9, 3.674399770074535*^9, 
   3.674400198190196*^9, {3.6744003432980003`*^9, 3.674400351166*^9}, 
   3.674400418021*^9, 3.674403660801*^9, 3.674403716627*^9, 3.674403768797*^9,
    3.67440380629*^9, 3.674404957752*^9, {3.674405875675*^9, 
   3.6744058980290003`*^9}, 3.6744680903459997`*^9, 3.6744689869960003`*^9, 
   3.6744824604393997`*^9, 3.674523184048602*^9, 3.6745236583816023`*^9, 
   3.674542334611601*^9, 3.6745431264456005`*^9, {3.6782747374008*^9, 
   3.6782747571238003`*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.6742295516499763`*^9, 3.6742297545933266`*^9, 3.6742298419931965`*^9, {
   3.6742299400660725`*^9, 3.6742299544738812`*^9}, {3.674229995415718*^9, 
   3.6742300243406134`*^9}, 3.6742302394017534`*^9, 3.67423276067968*^9, 
   3.6742328081847034`*^9, 3.674232854642743*^9, 3.6743148929025774`*^9, 
   3.6743158571420975`*^9, 3.6743158874306035`*^9, 3.6743162794284806`*^9, 
   3.674316370184701*^9, {3.674316473151373*^9, 3.674316498488763*^9}, 
   3.674316533989072*^9, {3.674316852803*^9, 3.674316881249*^9}, 
   3.6743187767320004`*^9, 3.6743890037971377`*^9, 3.674389045364587*^9, 
   3.6743896799400973`*^9, 3.674399529708704*^9, 3.674399770074535*^9, 
   3.674400198190196*^9, {3.6744003432980003`*^9, 3.674400351166*^9}, 
   3.674400418021*^9, 3.674403660801*^9, 3.674403716627*^9, 3.674403768797*^9,
    3.67440380629*^9, 3.674404957752*^9, {3.674405875675*^9, 
   3.6744058980290003`*^9}, 3.6744680903459997`*^9, 3.6744689869960003`*^9, 
   3.6744824604393997`*^9, 3.674523184048602*^9, 3.6745236583816023`*^9, 
   3.674542334611601*^9, 3.6745431264456005`*^9, 3.6782747374008*^9, 
   3.6782782965718*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{"s0", "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        RowBox[{"1", "-", "a"}]]}], 
      SqrtBox["a"]], " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"t", "-", "tinit"}], " ", "]"}]}]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.673971840765055*^9, 3.673971841030751*^9}, {
   3.6742330759309063`*^9, 3.674233077212247*^9}, {3.674233235226675*^9, 
   3.6742332547912445`*^9}, {3.6744011321870003`*^9, 3.674401163651*^9}, {
   3.674401596632*^9, 3.674401608967*^9}, {3.674401805447*^9, 
   3.674401805767*^9}, {3.674403563542*^9, 3.6744035642060003`*^9}, 
   3.674404507383*^9, {3.674406050126*^9, 3.674406068204*^9}, {
   3.674406441612*^9, 3.6744064420950003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0Gk81IsCh/GxhFMd3WQJJeNkZAtJpdLvok1Sok4kFOrDcY9t2uQmGrsW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1.2}, {0., 1.5983862409038672`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6744011505290003`*^9, 3.674401164582*^9}, {
   3.674401601624*^9, 3.674401610568*^9}, {3.674401798417*^9, 
   3.674401806126*^9}, 3.6744035645290003`*^9, 3.67440446508*^9, 
   3.6744045081809998`*^9, {3.674406429849*^9, 3.6744064424300003`*^9}, 
   3.674469612951*^9, 3.6782782991838*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"tps", "[", "2", "]"}], "=", 
    RowBox[{"tinit", "+", 
     RowBox[{
      RowBox[{"h", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tps", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"tps", "[", "2", "]"}], "+", 
     RowBox[{
      RowBox[{"h", "/", "3"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"4", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tps", "[", "k", "]"}], "=", 
      RowBox[{
       RowBox[{"tps", "[", 
        RowBox[{"k", "-", "2"}], "]"}], "+", 
       RowBox[{
        RowBox[{"h", "/", "3"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "+", 
          RowBox[{"4", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "1"}], "]"}], "]"}]}], "+", 
          RowBox[{"1", "/", 
           RowBox[{"FileGamma", "[", 
            RowBox[{"[", 
             RowBox[{"k", "-", "2"}], "]"}], "]"}]}]}], ")"}]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "4", ",", 
       RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674401245474*^9, 3.6744014430889997`*^9}, {
   3.674401481816*^9, 3.674401511163*^9}, {3.674406079924*^9, 
   3.6744060817799997`*^9}, 3.674523199246602*^9, 3.6782741213088*^9}],

Cell[BoxData["0.001306973935338964`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674468914316*^9, 3.674469615178*^9, 3.6744828985794*^9, 
   3.6745236007506027`*^9, 3.6745242020596027`*^9, 3.6745430951536007`*^9, 
   3.67455288995*^9, 3.6782783018318005`*^9}],

Cell[BoxData["0.0014258565755897474`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674468914316*^9, 3.674469615178*^9, 3.6744828985794*^9, 
   3.6745236007506027`*^9, 3.6745242020596027`*^9, 3.6745430951536007`*^9, 
   3.67455288995*^9, 3.6782783018358*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"figure", " ", "B13"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"des", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"tps", "[", "k", "]"}], ",", 
           RowBox[{"s0", "+", 
            RowBox[{"k", " ", "h"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", 
           RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "->", "\"\<Times\>\""}], ",", "12"}], "}"}]}],
        ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[SubscriptBox[\"x\", \"f\"],
FontSlant->\"Italic\"]\)\>\""}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", " ", 
      RowBox[{
       RowBox[{"s0", "+", 
        RowBox[{
         FractionBox[
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox[
            RowBox[{"1", "-", "a"}]]}], 
          SqrtBox["a"]], " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"t", "-", "tinit"}], " ", "]"}]}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674401540975*^9, 3.674401584967*^9}, {3.674406462454*^9,
    3.674406525742*^9}, {3.674468922807*^9, 3.674468923031*^9}, {
   3.6745236140116024`*^9, 3.674523614251602*^9}, {3.6745242133616023`*^9, 
   3.6745242138486023`*^9}, 3.674552896487*^9, {3.6745530048380003`*^9, 
   3.674553094742*^9}, {3.6782737355348005`*^9, 3.6782737470788*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], 
      StyleBox[PointBox[CompressedData["
1:eJws2nVYU28fBnAMBBXBVkwEW+zO21ZsFLtFUewABH8mIBYqKAYWIWLS0t3d
3RtjGxsM1htY79j75R8vLvBwdp7z3J/7OecZc+zC9hNdNTQ0SrQ0NDr/7RmX
9rzCcicW/cywifP4Bu1w/XK7A7vxcMURdoHhd/h2m7pw7MzdqMpT7GB9+g4H
65kS83l7MenA0yTZxB9wMtzb9ExrL+x442dq//iB93a1fIH+fmSqjjZsuh/i
ss6MCRTug373XbpTg/2wCeN0PXUOwtJVcB1z/XHj6liNY80HEDnqbrNphD+a
GO36zXqHof1jxL7jiwNQXPZ83iDFIexZ2HmCAZi3eeVF7WdHYMb69DbFIBA3
LRPTCh8cwe+voqLNxwIhr7w81MnnKHwuLu1V/jEQY7vYW93xPIpN8x+oPlEg
YgZ1c7eMPwbpnxJb3vggNL8de+ql6vt3qoNdPhWEPg/3rAtsMMfqR2e5v74G
4cP9IYa6XHO0mEaozjAI1r1iAvbonoDbUPUHwr+uCwdyB5/Akvqtj1+dD8ah
5jF1R1daoFF9esH4ecHWwmCrBZw7DycKhji3fVb2zZOYM7vzKwQJod98I5+e
RE37zdMxViHQTT27wy35FBwSsrzWhIUg/VuFe3DFKUy5N7gyTxGCfa9uDYrt
exrFm4/1VV0TLDkybkLvyafx30D/dcxrPyHdlXtujcUZGFV3HvAnfn56tSnZ
4QyyVUeT/PmJ84GHzKemnMWVU50DEIq2kwuGVLPPYvj02rE97oRC0/aetvXk
80iWTVSNcCgCZu54v33beZyJsXo+tHsYWk49thnhfgH9/3+CaPj7smNS8gVE
meh0nXIvDFeYx9j97l+E+uwywhCRmuc7w+MiVIOhGpFw7Oi69VnquksIft/2
OW1jOH63Tdn/+8glqAZbdQXD4bZ7/PavvS+jq/oDh2P4H4fJyvGX8a1zePtG
4Mux33Niiy9je4T6hkFOWdbYsaLL6Oi8fM8jsOrG6w1dPK/Au/PjlkRgZ57L
3tvxV7Ch8/QGR2Ke80Zv64tWEHcebk8k5lxglus8s8Ib986vSKwUl20YtsYa
Kztv/+pIRCfM8M88ZQ1+5+09Igq7Bh7e3jbSBs86b99DUWgcs50ftsqG5k8U
TvieSJN22KDhWueARMHimrV7ieFVmk/RODY2M2RyzVXMUt/g0RjuOjHDsIct
za9oXPqUPt410Rb2L1ap7sBo3NXZb+8lsKX5FgPbnG5TJn63Q6GheoDxbcTx
4m2VdjT/YjDo38PsttfXMEZ1N7sKYuA3tGfajMxrNB9jcX5zTf+mh//hUuf0
uBiLa28cj6+I/Y/mZyzc/dp69btzHYmdoyuJxdXUxxH2oddpvsZhzIqlsaf/
u4F+/5+QcHc4nC0NukHzNw6yGymzZHY3cbTz8rXHIeN5/KdXwTfRUz2f4+E1
aoBV4PVbUJ/e9Xjkm2luOxN+i+Z3PLqyPq3OW3EbGuqvBPAN+vLmH7lN8z0B
ggmDYw+k38aXtI2qGZ0A/1757kWc2zT/E8Bj9fzcbesdbFPNRtU9CjuTiti7
F+5QHiRgR7fuPZIr7kC5o/OACZh5w32PaccdyocEdLl+sPbNcXt4DuucEImI
ebr73Nx79pQXidBIXTfjkdge65mdA5yIjKEz/80c7ED5kYjD4/K7uNk7QPi5
8wQTkf3aoN+6zw6UJ4l4WlNjFjrQEa87zy4rEe+e/P1ktciR8iURsnELjdu+
OGK56uYy0UmC62mHhKh8R8qbJNTrP364AnfR9KvzAydhwCETc/2Tdyl/ktD7
4vHLP8rvwiVJPYExXi/PxUXDifIoCZsMp3OmX3bCgs6PW5AE56lWGw3eOVE+
JSFTurIpW/ceGJ2H65+MHQLHFxkL71FeJaNnY8212373cL8zjnYkw91y5qUH
lfcov5Lx4z9Dz81b7mNGZ5y8SIZR63PGsf/uw1EdF8k4M8ho32zRfajjoDwZ
s6YFsc1GP6B8S4ZYs/LbzJcPcKtzOg9NgfS4nf3h1AeUdymY+HOy2/qlDzGh
czruS4GrRWaE/bmHlH8p8PZoHmLLeYh8hXqA8fLdmYdxQx5RHqZg/Z7a+Qmu
j3C1czrUpsBRNrS9f8ojyscU+JoHygzgjNGdt/OoVGxOsetx+7Iz5WUq8gdp
7njT6oz0ztvvSCp+u47/qWn0mPIzFbqHzpoaez7GBXVApiKb9aWbT+lj/H84
UtF895S4bMcTqC8fKxWxkv/k+x4+gfrjdk9DDuvc/Dc9n0J9emPTcOBInyeT
VzylvE1Dyl3WGJvEp7BQf6XBPj82u3/HU8rfNDxrct0butQFqsncmbCYm3qx
4sE+F8rjNKx2XiaPfuuCznS05aUh4d4Rj8GRLpTP6Vg80J2b1+GCQ+oDpiM+
d1N0wFBXyut0bD25dFrrPleoBlcVUOnQLMsz3mnnSvmdjs9TkrL0Y1zRORoD
/dNxIfaatEe1K+V5Oo51jYw1HfUMu9QnmA5JeH3/1KXPKN8zcCLBX+vlnWf4
2zndZmZg2vr79596PaO8V33/ccpXDvsZfDtv58sZ2HqlY6dFj+eU/xmIdwjx
XrXxObb8/wPjiyj8P5Ozz8mDDGRrpkl/BD2HvHM4ZBmIOLisY0Hxc/IhE16p
dR6G+m740Plx52dC54hW0ZzFbuRFJjzsrX187rhhrfoCZiK48n63pT5u5Ecm
Tq//23V2sxta1TxkIrXX3Kemui/Ik0y8fcGLzt35Ai874/1XJtwirllftntB
vmQh7JZPvlXiCyxTD0gWAranhnmwX5A3WTAqf71s4rSX4HTG680snO9/Y0fl
9pfkTxaurJvas+ntSzxRx18W3o7Q2jQ68SV5lIVJV1On/+z1CvPUA5yNrV6p
npdmvCKfsjFgfFKw87VXqOucvquyMVIxZHuB5yvyKhsbTO48u9T8Ck6d0+Nu
Nu5H7DuyuP9r8isbqeMP5R87+BrT1DdMNqxqudnBjq/Js2wcvhBkeaTgNco6
h1c7B6mlg1/MU77GZLVvOVi+u/Do6dXuuNl5+UxykO2xJCbtrDuK1N7lYLFf
v4jbke4Yr74Bc7CG+X2FeYM7rqn9y8FqcfLZj9PfIC9H/YUbv36O09n7BgZq
cHLQcW7+7SLfN+icbbt0c/HbwPdUYsEbZKh9zMW9VZHiPqPfYoT6hs6F4+ns
Xg4mb6Hm42Iukh3dUna+fgt13Lvm4nDTeR3T5Lf4fx3Mhf+a/vKv/d9BHadF
uar7pOLclGXvoI4/SS4K/ezu9XryDuq4GpiHaTpbp/ePegd1vMzNw8Wefe2u
9noPdRzsykPJlsGmmvPfQ3032+TBqmpotvDee6in26s8jDa4VNw99D3+X4fy
MJNbesOmxwfo/H/C4d95z7C+cz5Affu158Hb5J6rttMHqG+XYfkQOrI6Jv78
QH07H+Y3z/T43MMD6uE4kI+Jg2w9N8/1IK/z0edyfI3pfQ+oP+77fKSsf/P5
ZrgH+Z2PJ+sOP3TU9IT6cPX5KLVYqX1opCd5XoCk46a7LdZ50nwvwPiLEQL7
w57kewHu79y+M++BJ83/AtyaurH7NG9P8r4AuoE3HGNyPCkPCjC5ftCmw2xP
8r8Ap460Ns7o60X5UIARo2enDp7kRX2gAMMC4mymmHlRXhQggB1zweycF/WD
Alis0V7047UX5UcBUp/kbBwa7EV9oQDXZzVOC6n1ojwpwLm6a3uPKbyoPxRg
ifD0zuVG3pQvBUjXZLyetdSb+kQh+lr+9Nth6U15U4iYzwN6PXDwpn5RCJ2O
8vmCAG/Kn0KsqDX2O5HlTX2jEIm2LRIdhTflUSG2LFxpn9HvI/WPQuyZp90Q
vOwj5VMhhuZaPgja+5H6SCGCu6/oWu/0kfKqEDenRCYZeH+kflKISwt/mLnm
f6T8KsSdc2umDW7+SH2lEOZBhyozh/pQnhXi4lyjHNc5PtRfCvGp5KzL/WM+
lG+FaA2yePf8pg/1mSKw3fl2uT98KO+K0Oxl5DE804f6TREmPmh+8VrhQ/lX
hFF7zpVMGviJ+k4R3sXbN/JWfqI8LMLVmF1L4g5/ov5TBKEo6UTik0+Uj0WY
biouq/j+Cerb+WkRVl2M0x9d/Qnq29WjCHfnbPexU37C/5eTRSidcE+j20Rf
/L8+FiHG6L6P5xpf/H94izDDd9qwc9a+UA8HswhlNz6Vb37ui0f/n/BwG5Fm
cTDZV51eOl2L0bAmeukdpi/Up9e/GL+OHOIU9/sM9eEMi9F1fFXZohmfoa5X
s4sRLdJyLzjyGer6tKoYCy/1/3jt1meo69GOYnRTFt3cEfgZ6vpzvBhaE6y8
l+d/hrreWBWjZn3+qwMaX6CuL3eLkSHRLXUe/QXqevKiGPmndBqbt32Bun58
KsayOeJFhy9+ofVmMb49djfv4v0F/68PxWiTG5eEJ36hvlaMSZ53B7+XfIGa
f24xrvzL9Xw54Cv1t2KELq3/HbfmK0rV+V6C6jSW568TX6nPleBu9M/BJ19/
pfVMCQxuXi/hRHylflcCkwkDj79o/oob6itYAqGe7+I9Ot+o75WgxqQ32wTf
aP1TgqFG58u2HvlG/a8E9l8+uzs+/4Zxah9KcG5Eg0/uz2/UB0sgdZLfWdP0
jdZLJcgcpfe5sOd36oclMGrq/sF56XfkqvkowT3drrX7D3+nvqg6P9d6wd7n
32l9VYJm1/S1Z0O/U38swe+ezy/58b7DWu1LKZT9zzZ21flBfbIUlz2mTLq3
/Aetx0phm/grdLT5D+qXpXA6HjqQ++oHRqr9KYWhm310UtQP6pulcJu9ZE5u
2w9av5Wij4mOrLm/H/XPUrwNyL63cL0fUtU+lSL0pM+xt2f8qI+W4tKaC3rG
Xn7kVSk+rtzVvTDFj/ppKaZOm5Xt0+FHfpXCpN24ynmUP/XVUnifHx390cyf
PCtFytXZjXm2/tRfy7C5akX9xAB/8q1MlVdWhq+K/anPlkFrgM/8Ob0CyLsy
uDl1uLGnBVC/LYPi0baU1BMB5F8Z9H/nL456GEB9twzX75verU0MIA/LsKDH
v8GDuAHUf8vQw2VP7FK9QPKxDJeL1g/4NSaQ+nAZit4vKcpfGkhelkFWuj7U
f1sg9WPV+eTs7fLpbCD5WYZfdo6XPt0KpL5chn3TQzfEvg0kT8sw3kBjfb1/
IPXncjjq7fAfmh1IvpZjX3rCggN1gdSny3HYaIFxeEcgeVuOjZrZq0boBlG/
LsfsjlMprycHkb/lyNxrZDl6WRD17XL068e3id0XRB6X49DMvC8nzgdR/y7H
/cL4VeMeBZHP5XjMye/a9iGI+rjq+M9aJxdEB5HX5ShLNL4anR9E/bwcv19c
M45rCSK/y7H/V5NmtkYw9fVyvO5zan3byGDyvAIGUdoBI2cFk+cV8B8SfdN8
azB5XoFjA10uh5gHk+cVCEq8mj/sTjB5XoGjeg7bnF8Ek+cV+KPtvWhQSDB5
XoEKD/b6L+nB5HkFQquWJmxnB5Pnqt//Gr1fqyOYPK+ApP/WI8VDQsjzCqzp
1vPBV+MQ8rwCI29VDnu1IYQ8r0CPS4UFTw6HkOcV+FXDaHt/I4Q8r0Dl16Gz
w5+FkOcV0K8+Vc8NDCHPK7FhZ0OAYVoIeV4Jgb41z6oxhDyvxGSdWesK20PI
80qcm9JTd83Qn+S56vu9vduTpv4kzytx9fnEzXs2/STPKyGNvJSqOPqTPK/E
v/QyX//bP8nzSgS+O/Xjwsuf5HklrGYOGb4+9Cd5Xoksc4nf5Oyf+P/jqkpc
nCL4Opb/E/9fHlQi13xQ1kSNUKg5qq7EhO4HdqweHQo1H82V6MEu1Dg9NxTq
uP9VifN/LIZ8NgvF/4GrQpKh8fbW06FQx+mIKrzb1E++6WEo1PE3tQojN02I
C/UMhTqullah97BDbXMTQqGOl81VOOiYtjqhLBTqODhUBTuHbd2OyUOhnr7n
q+DVoMPp0ycM6ul2swoGb5pnFhqHkedV6Hf5j9eHVWHkeRWemM/6z8E8jDyv
QtSst7aXr4WR51X4Wzmh3vZNGHlehcXDeKqCFEaeV2Fwa97BoMIw8rwKsv58
a1ZTGHlejQMOkxXGPcPJ82qM+O357rZBOHleDW3rpd+bl4eT59Xo961v3ZE9
4eR5NeY963VNYBtOnldjIXfxIkeXcPK8Gpc93cxnBYWT59U4ZzUuiJ8RTp5X
I25f3ckoXjh5Xo0yrYKVbl0iyPNqOF7mO901jCDPq7F0y7K224siyPNqrHKJ
Tni+P4I8r0Yx/3JY4JUI8rwaSaZmg9huEeR5NWyvXnxt5BdBntfAflO4o11e
BHleg7MOC19UciLI8xo80+HqmmpHkuc1WPKq4EeRQSR5XoO2AZyQMysjyfMa
CGYsqNfdH0me1+BHbdiVzOuR5HkNTqVdNn7yIpI8r4Fl9f4tp8MjyfMaHEq1
d9tWEEme1+C8dfmqLeJI8lz191xPD9nVO4o8r8FgHWMz66lR5HkNVj8wDv2w
Noo8r4Gpcv+t+lNR5HkNHP5lnZtsH0We12LdQ8tUZ58o8rwWR1asX9EeG0We
q37ee/f4G4wo8rwW/Ge+03t3RJHntVgRPd47cEQ0eV6LPTObFhyZF02e10JQ
XLVgwt5o8rwWz031DiovR5PntVh5z5rPeBFNntdikuGod8UB0fT8thab/ynD
aoui6fl9LT5mDpaLWqJxTj3hauF/6OSHkX1jyPNajDz56/SOyTHkeS2uJiZ5
em6OIc/rUDkgr0NxMoY8r4PXkj5xFo9iyPM6SBgun+o/xZDndThft15+ITOG
PK9DSeWaM70aY8jzOtT6XTWJ0Yolz+two2vbRlvDWPK8DmN+vA3fuDaWPK/D
qt1P1k06Gkue12FOcdjyUXdjyfM6TMwfp1pexpLndXg3JLtxdkoseV6HiP3h
T83qY8nzOky3qPro3C2OPK9DGGd1Td6oOPK8Dm98OTcmroojz+tx2axglfOh
OPK8HgMjRZe1HOLI83pVXu1Pc/4QR57XQ2z3x35Schx5Xo8Nm5rMC+riyPN6
DInr7f+kWzx5Xo+U27Yjdo+OJ8/rMWDnKOm81fHkeT0Ugj5CgyPx5Hk9fLXn
7zS8G0+e14O171vdVK948rwesve7C7elxZPn9Qi7v7XpRkM8eV6PQt7yOcxu
CeR5PUrcbzlp908gzxnoE7T/cfTYBJrvDEx/cNBXMiuBfGdg79/fV8LXJND8
Z8D4TNIODbME8p6B9K/jmkosEigPGEgdFPBkmnUC+c9A9b0y3oD7CZQPDOgd
GLv75ssE6gMMDD3T187qawLlBQMP9Iz82sITqB8w0GFY8kKelUD5wYD73+8u
9pUJ1BcYcLpuuPxNSwLlCQOTZPFd5v9KoP7AwNqVv68e1k2kfGGgX+xhjT4j
E6lPMKCz9NjStTMSKW8Y+DjS2bk7EqlfMLBl9k6XLdsTKX8YyK9e4zvyaCL1
DQY+N5VetLVKpDxioDTy8eY9DonUPxhgjGLXJb9MpHxi4IjtcfufnxKpjzBQ
5eZQNSMykfKKgRWlWatnZSRSP2Hgu1aweXx1IuUXAwLnRLdCfiL1FQYWzrp0
7cLfRMozBt7sMbn8rE8S9RcGbuUmjloxJonyjYFHwmO1VjOSqM8w8fupz7Y5
q5Mo75iqdbheme2OJOo3TIyaNqyvyckkyj8m+uzdcuCDTRL1HSa67Tc6eOth
EuUhE2FPxlxkuydR/2FiV1rC/HK/JMpHJgbtf9BvS2wS9SEmUkdJPLYVJlFe
MjH9jNPyCkYS9SMmWvpGv2iWJlF+qs73tP4fh+7J1JeY0Fqvr/9laDLlKRND
uq9aZzoxmfoTE5PO6k52WpJM+crE+dpuo5dvSqY+xcSOsW8z7h5Jprxl4vb7
A47bLiZTv2LCZlCC1NcxmfKXCW7T5qv2bsnUt5jIabjhz/uSTHnMxIWjFYrS
iGR6nsKEfGqpbHNuMuUzE4LPvzU31ibT8xUmNrxKyyoWJVNeM2G6P9qL2SWF
nrcwcShm+9T/BqdgiDq/mTg3dFC2+/gUev7CxOcF10auXpxC7++YCLnWy/7K
xhR6HsPEws9L3047kkLvcxsgGP4u7fzFFHo+04D+Xu99F91NwSB1wDRA0y3r
9aMXKfS8pgGTY9/g1LcUxKvzvwHWdi+VmVEp9PymAV9c51qE56fQ+8IG6B/V
4ExipNDznAaMCD4/bKIsBQPUPjTga5320e+aqfR8pwGrg9YeiBqWili1Fw3Y
7RBouWVKKj3vaYCpQdyU88tTcVLtRwPM6hX/+pum0vOfBlx7Unp/lUUqvZ9s
wPI79UbtNqn0PKgBjAePryxyTkW02pcG3JKfLNV4n0rvyxqQ/Z7TvD04FSfU
3jTgVJbrwMnJqfR8vQFlO5ki54pU6Kn9aUCv+weZVrxUer/WgHeLb95t+ptK
70MbcC48ezFTL42ex6t+vzzW98S4NJirfWpAd0aN0YV5afQ+rgF9Azx3dt+U
hj7qAG9AxT1X91EH0+j5fQMur5/wLOVyGsLVfjVg1Gz+uzaHNHp/14DICdsP
+Lqn0fvXBjw7wZ3a8C2NnvezYJA/5ufXhDT0VvvGgsTrwSZ5YRq972NhfMJL
9zxuGkLV3rEw+FShckp7Gr0fYMH7WpDOIL10HFb7x8KtefGzHAzS6f0gC1du
XO5zY146ve9lYaPzjo5f69LpfYLq+Guq3vY4lI4QtY+q7zlPtr68kE7vE1lI
28ILD7qbjoNqL1kwir80a/urdHr/wELTQM+jN/3SoaX2kwUH19/e0+PT6f0j
CzP7/Xt9tjQdQWpPWdAtm+41jZtO7ytYmBjT49D1P+nYr/aVhcDuOlO36mXQ
+0oWnjqHB/qNy4CmGkgW7ri5rnWdn0HvN1j4ruznqrElAwFqf1l435EgkB7O
oPebLLRZD/5nZZOBvWqPWej+443htfsZ9D6EBdnV1I5eHhnopvaZhS3DR7MN
gjJQoe7jLLhdGu2YlJ4BP7XXLDRGbZnLq8yg9ycsZBaPfftWmIHdar9ZOPBr
0oDirpkwVvd1Fg7rleGlfia6qD1vxMDNQTfrpmTS+5ZGrHg++3LwykzyvBEX
RrGv9t6ZSZ43Qjtv6SzhmUzyvBE2tal/997MJM8bkWYsu7X1RSZ53ogo+Y4B
WZ8zyfNGLBi+b39BXCZ53giP0qeh+wszyfNGzNA8l3K5KZM8b4Qn246t+yuT
PG/EG7Np0fP6Z5HnjbB42v8ja2wWed6IO5c/YMSSLPK8EUuW7Gut3JJFnjfi
ZHqsqZFFFnneiPnbTdNFtlnkeSOeRjqLNrpkkeeN8F+gnDrlYxZ53ogDAb1H
v4zKIs8bob9rq6FTbhZ53ojjuoururCzyPNGfNDd7dNVmUWeNyJg0XCjp3rZ
5HkjtqXp/fQ0zCbPGyF89aN96aJs8rwRsfV2pkc2Z5Pnqr93v+2g7ols8rwR
pTEvrq+wzSbPG5F7pnGrhks2ed6IkfHmc1d/zCbPG6H0eZQ/IDqbPGdj4LrG
/07lZZPnbCiesWvWc7LJczbygods82/PJs/ZyHkuvurRL4c8Z4Nz5G/QoHE5
5DkbfXuEeA5ZmkOes2Hl/9rrw7Yc8pwN43UTdgedyiHP2bBp54wyuZ5DnrMh
Dd769qxbDnnOxoj3vEmDvuSQ52wc9DE+Z5KQQ56zcUfqmdS1JIc8ZyPFJi5n
XUsOec7Gpb19eP00cslzNn45aEadHJpLnrNxeNz09yuNc8lzNnLHdp37dXUu
ec6GbWCPerc9ueQ5GyeDfi7VuZRLnqs+/w43f+27ueQ5G+LbI0tc3ueS52xI
jlf0/hCUS56zMYy/RDkvK5c8Vx1/UbHcrC6XPGfj9qoB3/7Kc8lzNkIn370w
tXceec5GFsOTxzXKI8/ZGPCw1XrCgjzyXHX9B3PCxNvyyHM2ZvzQ67XqRB55
zsGnBax+o2/mkeccrGI1Tbn9LI885yDE/XXH2e955DkH/RyuVdfF55Hnqp87
97hUU5FHnnNQUZMy9LAgjzzn4OvRqdbneuST5xzMWpHB0hieT55z4Hm6j5bB
nHzynIMTXe4uSVmfT55z0CT3HS89mk+ec7D27C/Drzb55DkHS3Z1FPOe5pPn
HKQWTnkV4JNPnnMgLdPS6xKXT55z8O3mYPfyonzynIOwtPzyhS355DkHtxgH
3Vw0CshzDpYvnDRkQ58C8pyDx5I+RmlDCshzDqIGrO95f2wBec7B/A9vbXWm
F5DnHLx7vTqpbHEBec4Bemi9MF9bQJ6r/p5g1Mp5OwrIc9Xn3bbNNvtgAXnO
Qf788vu+pwvIcw4G+lw1XG1dQJ5z4P3u3MsJ9gXkOQcWY288z3UuIM85eL+8
4XSkewF5zsVk+ZHskz4F5DkXjuvn9jgQVECec2G31Cirf0wBec6FboXFKb3M
AvKcC+WolKd5xQXkORc9Blx1LWYUkOdcTI1dNeJtcwF5zsWfERZ3vigLyHMu
WIu9L9h2KyTPuTioP2fBk76F5DkXvnH1DyyGF5LnXPyezAx1nFhInnPx/uTv
0ydmF5LnXIyyOtfxaHkhec7Fjb3K/tYbC8lzLryGVGr67Ckkz7kwDSu+88K8
kDznYv/8sRU5FwvJcy5uej4JT/uvkDznIla65VKPB4XkORdPF076qe1WSJ5z
kXFpb+E2r0LynItuHz9e3f+jkDznYmP+KuX3yELynIvjf/50iU8pJM+5uDtN
lzOkqJA85+Kc5YIds2sLyXMuBgZGvHHjF5LnXOzR3nEmQlZInnPharVqsGG3
IvKcC2775g1bdIvI8yZw3/rvSRheRJ43ofngJKF0fBG+qz1vwoG1HUcvzCnC
bbXnTcgxYx/4gSLyvAnaz8fPmr65iDxvwpy/d1ys9hSR503w8pqd+e9EEXne
hALbfw83Xyoiz1V/32XMBObNIvK8CR2sg5vmPywiz5uw87ZwY/GrIvK8CYcO
vS+Z+bGIPG/CrCee88sCi8jzJjT0iDNaGlNEnjdhb+VMPi+ziDxvQvav+IV7
S4vI8yaY3/Ix12UVkedNeLrv42Cn1iLyvAnOH5QfV/0uIs+bMHTFqahkrWLy
vAnTzKZ9fzComDxvwpBc3XH9xxST501ojF1jx5hWTJ43gTf81a5Li4rJ8yYU
Kpfprl9fTJ434e6GLluZO4rJ8yZYGg47nXC0mDxvwh/rzbrHzhWT500YsLvc
2eS/YvK8CX+j/nOTOBWT502oCLGxYbkVk+dNkM91Zr7wLCbPeXhqphz/xL+Y
POehsest2fqoYvKch1M7D3wwySgmz3mwXGZWoFNSTJ7zEFbkXTOooZg85yGq
m85lpqCYPOdhOzebKf5VTJ7z4HXetypNq4Q858EhoNyPMaiEPOfB/o1Rr9gx
JeQ5D+PWpi2vn15CnvNQ4u2gkbK4hDznoUv6qzetJiXkOQ9BXmmx1TtLyHMe
TDZtitY9XkKe83AhuGVF94sl5DkP84Qsb9wsIc95WCSUOS99WEKe8yDPPWR6
53UJec5DuFXDh3s+JeQ5D1b/YtKKg0vIcx7O7w2+2hBXQp7z4P3hb9f5uSXk
OQ/ciBNDtlSWkOc8aKcZ9fjOLSHPeejn9/tGlqSEPOfh5BPjguldS8lz1fXb
evX7bt1S8pyHG/30j6aOKCXPebgVWeohm1hKnvNw7RQv4sz8UvKcj7/dhu73
WVVKnvOR/ON9ueH2UvKcj0Prl9WaHyolz/mwU8yN5Z8tJc/5OOqxfvwcu1Ly
nA8cCbZMvldKnvPxfMz8eYPcSslzPlgaA2p/eJeS53yc4PbsoxVQSp7zMVi0
e8jn2FLynI9r2onfemaVkud8vDe5MzS4opQ858Py/QG9kexS8pyPJYZPGbmS
UvKcj8VxNYtWaJSR53zcfnbnQoduGXnOh4f9iqk2w8vIcz58gvekzp9cRp7z
IenyiBM9r4w856O/+8CGu2vKyHPV8cwiLfpvLyPP+eh3MDS18UgZec6Hi0uO
n925MvKcj3ODF180u15GnvOxNjclWnS/jDznw6HmE7PkVRl5zkfOGG+Xaz5l
5DkfxmkyfYuQMvKcDwuf48YDE8rIcz7CeJP1tfPLyHM+8s/oPI2rLiPPm2F5
cE19FL+MPG+G+Il7hJ2ijDxvxoP5a87e7FFOnjeDaaTzdc2AcvK8Gf8eT07Y
blhOnjfj9fLjRwynl5PnzWBclVXNX1ZOnjdjwi+vOr2N5eR5M5Q9fWOm7isn
z5uhb5lqpHuynDxXHX/fkhNzbMrJ82bM8cybPtKhnDxvxshbESUbn5WT583Q
CIvtutSjnDxvxnjnYb2t/MvJ82bEJDx7dy66nDxvxqpXx7T9ssrJ82Zwizf/
8S8vJ8+bcTPMJUfOKSfPmzFJs21sF2k5ed6MAX99dpt2qyDPm/HM0mbA8b4V
5Hkz1tl7fI0ZXUGeN6N6UGNGuXEFed6M3XtuJy1YUkGeN+PuqAVrDphUkOfN
+PZinXfqngryvBkNLy/fF52oIM+bsXyLbL25dQV53oy458+fvbKvIM+bcebl
g7B+zyrI8xZMmPzWfItHBXnegrLb3ZsL/CvI8xb4nXvwa1BMBXnegnhDC45n
dgV2qj1vgdXlQ/taKypo/2QLtrr4f7nTVIF/as9bMHXTsNvlsgqUqD1vwfPq
2plXNCvJ8xas1Is9W9i/kjxvQVd96R1rw0ryvAWD89Ya1EyvJM9bsOWA6PV9
VJLnLbj2LvyNYlMled6CmxGlNj8OVJLnLWh21qsxOl1JnrdgyXKv4Uy7SvK8
BUdCtjQeuVdJnrfgjpbZvfGvKslz1c/HWIf4+1SS5y1IN2iNvP6zkjxvwexm
e5M+SZXkuer4HhdCWIWV5HkL7hrZ+l6vryTPW7DBreLK/rZK8lz1+WrMsn7/
riTPWxA3YNIvlk4Ved6CMRP0Qx8PqyLPW5A7/ajJjclV5HkLbg9JtZi+oIo8
b4Gw4/ahCeuryPMWFMXtqWfurCLPW+DpdH9Rw4kq8lwAoxkloz5dqSLPBTjX
eLXWz6GKPBfgz/X54+xcq8hzAT6O37ruoVcVeS7AlnB78cGAKvJcgJxDurZX
46vIcwFGi0OdduRWkecCnPUIvWBdW0WeC9CwpJC5t7mKPBcgU7l6muOvKvJc
gF3fSrpd6llNngvw5EZMyEf9avJcgAEbE1peT6gmzwW4tmyERsn8avJcgFEz
3d4VrqkmzwVw2Hx8wKBd1eS5AM7ntg0YfryaPBfgUpSbwMKqmjwXIKCvbJu1
fTV5LoDxK78nmc+qyXMBfI3tdzI8q8lzAd5K/eVLgqrJcwH2FCoMDsRXk+cC
bGa9HpeYX02eC5CityukqbaaPBeg8MqZ4btaq8lzAayU73ScfleT5wIsCR9f
8UunhjwX4OrbHOM5w2vIcwEWxWXtD55SQ54LUKrNHiBZWEOet6Ls1W5fuw01
5Hkrbm7nJCbtqSHPW7HeLDfc1LKGPG+FwKlg3serNeR5Kyw1jV0W3a8hz1tR
E/7xstvLGvK8Fbujrkyf87mGPG/FYclh65ehNeR5K/7a+7xYllZDnrcic4Mm
vpbUkOetYJyLS9rLriHPW+Ge+zw/R1JDnqvOzzkx7G73WvK8FV4Pe0/oMqCW
PG/FOIHfpSSjWvK8FU+fnV2zdlYted4KKw8Hid6qWvK8Fb2kYZPfmdaS561I
C1m55PyxWvK8FU5x/LKul2rJ81b4LmjeWHunljxX/X5X7Q3XXGrJ81ZIlt4w
POhVS5634mqermPXwFryvBVVRcp4QUIted4K6fR/jm/za8nzVuRrHhr7lFFL
nrfix/zKTWvaaslz1fXl/Ni6QqOOPG9Fq/Rd9T/dOvK8FfMd2Cu6G9SR521Y
bb1hZva0OvK8DfubtX6ptCXP27Akg7n585Y68rwNYuOB/8UcriPP2yD4fWym
2/k68rwN/J29koJu1ZHnbegwyKt2fVJHnrdhgQ0/P9yjjjxvQ/MKo82e/nXk
eRtGvf3pkxdfR563Yf6FY3fj8+rI8zYkFZ1aLq+vI8/boBn+yLGttY48b4Ph
VK2P0zTqyfM2PJzgsWGGXj153gbLsKc5Vw3qyfM21Oa9K78zvZ48b0PIja6x
hcvryfM2lEc5TmncWk+et6GXy2GrJUfryfM2vG7ftXb3xXryvA2Ov33F4Xfq
yfM2bH49YGK1Sz153ga3gor5q73ryfM29POJKrgQVE+etyFsmGwVM6mePG+D
ufGm5YOK6snzNiRzfg1+yqonz9vwcmmGTba4njxvg4eXTcX4rgzyvA1nrgxZ
lNmTQe/PhdjzofH+k/4Mmu9CLBu2fMTcYQx6ny5EoDD93V9DBs1/IVL1645+
ncyg5/FCZHgYDLw6m0F5IMRzW1Gv8YsZ9HxeCNOg1lbFKgblgxABS68N+b6R
Qet7IfKnzJp6x4xBeSHEmwu29xYcYNB6X4iZg5vz+p9g0P4sIW4NbNmXd5ZB
638hJl7VL/lhzaD9HEJsmV3qevYGg54HCPHSLHbJVicG7ecSoqpwtvGAJwzq
E0IMCC3T7njJoP0fQugotCYnfWBQvxBiuMeJBX6fGbT/S4jDX00f2QUwqG8I
sUj/dPapCAbtFxHidWvfbQsTGNQ/hNCf1JhonMmg/WKq4+Wuse1SyKA+IkRa
afHw9koG7S8RwmyjsFsRk0H9RIhP4xZW5vIZtL9MiLzzfSXfxAzqK0L4jxrY
8e0Xg/ajCHFsme8a525M6i9CnE87ftNFh0n70YQ4mBD0y3ogk/qMEHVGUyxu
jmTS/hXV9emYNejUOCb1GyGeLDkZZDWNSfvXhBghmfTs2Dwm9R3V+A/WP3IF
TNrvIkSPwJeXT6xjUv8RYkXE8svXtjFpv5sQ3+bbhV3cw6Q+JMTx8XXcB0eZ
tD9GiN5PCw86WjKpH6mu1ylRgtdlJu2PE0Ia43HK8xqT+pIQJxyu/Ul0YNJ+
GiGQzipLecSk/iRE7A2793w3Ju2nE2JuyPsvondM6lNCdD/Y6jncl0n7b4Qw
vJdbO96fSf1KCMvxlVo7w5mUv0LcW3/F5ng8k/qWENsZC4teZjApj4Vw/PPk
8rcCJvUvIYa69NVgVjIpn1Xn992gSMlkUh8TotuSg66zm5mU10Ik7574YquE
Sf1MiCTeaKcnv5mU30IEaftG+3dvoL6mGv8Pe+pEfRooz4UYkuy+ZvDgBupv
qvl2ROvNwdENlO8i7HncbbbThAbqcyIEzTWOLJzRQHkvwuuzLIe/Cxqo34ng
Y5i+eMvKBsp/EdwtFi64taGB+p4I46ZWjCne0UAeiPDntuY27QMN1P9E0Nh3
+MyREw3kgwiuieuy3c81UB8UwSzgwFC5TQN5IcLWqRrfZt9qoH4owoFZBRPd
7jfQ/kQRRmVOayl1aaC+KML6psh3i9400H4mET6+LXa97d1A/VF1/mX6Vrzv
DbSfUQSDr61vZv9soD4pwu+uQn/P2Aba/yRCL8UtrbbUBuqXIgy+smTzkfwG
2v8owrxH98qDyxuob4rAnvJvy0RmA+2XEiHLUrP3LV4D9U8ROLMW/FSKG2i/
pAjC1+1eO341UB8V4awz93phdxbtrxKhaOTxdzP6sKifihC5tM/X4MEs2l8p
wvQ/qzsGjWZRXxUhZNPXBe8msmg/lghHl7yL7jaTRf1VNd5x0VOeLGLRfkwR
njIsGe0rWdRnRXjxarX9/U0s2r8lgmer3ymlGYv6rWr8alcteXSIRfs3RbA5
e8rsnwWL+q4IF59H7n15kUX7vURIOeT+UdeORf1XBOeET1Vf7Vm031OEv5nL
d41/xKI+LMIFS+34VDcW7Q8ToSzk0Nm171nUj1Xj9ZzZg+/Lov2hItw1kLDP
B7CoL4vQsWJm8OBIFu0nE0F/0N8kj0QW9WcRIv5TJGzMZtF+UhGGvLrVrbKY
RX1adb+unjP7QS2L9p+JwPh29fMwDov6tQj3vLna+W0s2n8qwuKdHP/jShb1
bRFSX/dbObJrI+1XE0H3bbZ+eK9G6t8i3DQOrrsysJH2q6rG886Epn4jG6mP
q87HPLOuaHwj7W8ToV2nQ996eiP1cxH+Ld+9ctHCRtrfKoL5ilUBjBWN1NdF
GJO9v+e3jY3kuRgio25fzMwayXMxzvQon214qJE8F+N35MLuhRaN5LkYRxUZ
id4XG8lzMay0uMk77RrJczEmec8MmeLQSJ6L8bhfb27Do0byXAzf3v20Y180
kudiNNV8Omf7oZE8F6N5wcmEXV8ayXMxdM6H7x4c1EjrATGuTZtTo4xqJM/F
KMnAp5jkRlofiBEgvLr/Y24jeS7GZfGyXWfKGmm9IMYIx1nLdjEayXMxitp+
njbkNdL6QYwlAnPHfpJG8lyMXqleDcxfjbSeECN0us60Uk02eS4G11oz7qsu
m9YXYpwynbLYayibPBdjpxbjt90YNq03xEjbmfjdegqbPBej6sZMj+1z2LT+
EGPiirxb25exyXMxntS1+8xex6b1iBiLhm4Pn2/KJs/FuGu8UHfkPjatT8R4
Wr9p+7jjbPJcjO3n2qp0z7FpvaI6vzdx24ZfZZPnYmT6jOjd8zab1i9iHNvy
OVj/IZs8F0NQlvCh93M2rWdU5/Ovh63BezZ5LkaYVs2Lwb5sWt+I0R5U6zk9
kE2ei1G6+LxwUiSb1jti8CynTF2XzCbPxdh89ar/mhw2rX/EMDEWjjhZxibP
xYiPU+Rb1rNpPSTGjd9TLj7lsclzMYIGtZm9FLNpfSTGq7q68Qm/2eS5GLfu
HFyarcmh9ZIY88u1V7TrcchzMXr2WPVAW59D6ycx1vK/xi0y4pDnYpT7eizY
Yswhz8X4MjzJw3EehzxXzZdTVza+A4c8F2PMBdPGMhMOeS7Giy1xieLtHPJc
DC3+bueZBznkuRjRB2+/NbXgkOdiaLiUvnK7yCHPVeP9JrIiwo5DnovR/3hW
Dw1HDnmuOn/t03YTH3PIc9X1PT2v8sorDnkuRt431xuenhzyXAK7L/p6wm8c
8lwCE6cZbIOfHPJcApcxVl+s4jjkuQQDPdYGfk3nkOcS9Khc86lLEYc8l2BJ
e3HdomoOeS5BadETzVdsDnkuQcCrioslrRzyXIKkAVsz57RzyHMJam6YWdh0
5ZLnEkR6OAmrdLjkuQTpAeviDQZzaT0owYdrc/97YMAlzyXwmhn8X/EkLq0P
JejzZb/l8jlc8lyCCdpub58s5ZLnEsgmt0f9W8clzyXQmi8Ytd2US55LVO7q
XkzfzyXPJdBIitUcdYJLnksQs/LN/VcXuOS5BLXfNbeJbbnkuQSn6t93v+jA
Jc8lMG1P+ZPnzCXPJShiDG3c9opLnktw1v+X7k9PLnkugfHG3hMWfeeS5xJo
5n918PrJJc8l8BtjnTslnkueS1Tjmr//VQaXPJeAe2pX+bhiLnkuAfPw2Vcv
arjkuQQ5YwNWT+RyyXMJ7pTdnvdOyCXPJTi259ag2b+45LkEgzJ0Fn7v3kSe
S6DokW6yVq+JPJdg/by+HklDm8hzCe7NdWIeNWoizyUIH/foVINxE3kuQU9u
TM3d+U3kuQRD3W+86LWiiTyXwGHUmcXBG5vIcwlGunHHLd7ZRJ5LsI3h8odz
uIk8l8BoeKa+lWUTeS7B0unTjMZaNZHnEryeaXgp9EYTeS6Bjd6qH5b3m8hz
CTyqxFP+uTaR56r7yzH/dfi7JvJcgvf6izeY+jaR5xJselbc1CeoiTyX4JC4
I/t7VBN5LoHF4q3vzqY2kecS6FrOCtLNbyLPJcizXxlSXNlEnksw/g6z3Y7V
RJ5LUHbGb+qq1ibyXIK6pdq+AkUTea4aj19Pe0d35ZHnEph7+4Za6vDIcymi
5vA3LR7CI8+liA+KmdhqwCPPpbAZFiNKnsIjz6X4c2HDv2tzeeS5FDEBmh1m
y3nkuRQGzK0L+27gkedShLannWg145HnUkzWyi3zO8Qjz6X41f5vjosljzyX
opydWL7jCo88l8LpZ+DJRTd55LkUFremLel6n0eeS1FkXPmn5RmPPJfiZUX/
7pHveOS5FMNP2ik+f+aR51KMkp6fbhvEI8+lmGnhanYmhkeeS7GqdGUc0njk
uRR9jMcMml/II8+lSLv1JFCvmkeeS/E3ZuLC3hweeS7FE7lpj6Y2HnkuxYoR
XxK4HTzyXHW9lz6Oz+jOJ8+lKNjo8T1Hj0+eSxG0Z3lNkD6fPJdizzbdjsix
fPJcijsmZw58nMYnz6VInCL7HrCQT56rjjdAd/n7VXzyXIperB2Jflv45LkU
WlET73ns4ZPnUkyxnbzopzmfPFed7/Lomd/O8clzKW622g5OtuWT51KUfUlF
rD2fPJfigQl2VT3mk+dSCOTrgipe8clzKaTON9rbvfnkuRSLpq10+v2DT55L
wYyarWEYwSfPpajd9jNuYhKfPJdiSNnR09tz+eS5FEnmH/YdLOeT51IYsrQW
PGrgk+dSFFtq7HvTwifPpVCyxlnmKPjkuRR6J6pi6rs0k+dSKKqj/wzq00ye
S+Gwx9hh6pBm8lyK+7mZspOGzeS5FCnr5D8cjJvJcymuRG81TZrfTJ5LcXbu
gkUNK5rJcykufNvcd9zmZvJcinvjxJNNdjeT51L8fpc8y+VYM3kuhUR/7K2I
s83kuRTT3YIiutk2k+dSbB2cN2+GfTN5LsX+F0O8bz1uJs9V13+40DTwVTN5
LsV7b1lrt4/N5LkMzdMeFizwaybPZbCJ3+jhEtFMnstQs/1dcGZSM3kug3mr
fsi4vGbyXPXzB+OVxyqayXMZxs48MjmZ1Uyey3C1fKJX99Zm8lwGy0ejNC3b
m8lzGb7ho59/txbyXIbxGjtXDdFrIc9lMEt+MfKofgt5LsMe127s3LEt5LkM
d05oiIZPbyHPZXiyejLfeVELeS6DZBJrQv3qFvJchoBhmdvNtrXQ81/V+fZf
lvRtXwt5rjreYMaosRYt5LkM7mP6Jdy82EKey8BdfGHL7/9ayHMZfu47MGa/
Uwt5LlOtr22YNa4t5LkM1YmjOXjXQp7LYKAjL0/93EKeyzBy735VcreQ5zJ0
iRXMDI9tIc9lMDTUe2OY0UKeyzDH+2BbYHELea76/TGLHxjUtZDnMhyPXdM3
hNdCnsuwdW999XhpC3kug3M/X7fYfy3kuQzJOb9c5/YSkOeq6+d983rBIAF5
LoPndZfvmwwE5LkM467kpzdPEZDnMvifez/x7DwBeS4Dz/G1jd5KAXkuw28v
w55umwTkuQxlVZX3F+8RkOcypA832JxyTECey3DD9vnfC+cF5LkMpbUvpL9t
BeS5DEsOp5b/cBSQ5zIsanH4t/SpgDyXQfrswkDxGwF5LoN4Hf/cvU8C8lwG
/qBnPxEkIM9liJZkoDJaQJ7L8JhvHPEiXUCey3BQPNp6dpGAPJfhw8Dlo6W1
AvJcBuXatj4vmwTkuQznXmTz9kkF5LkM96XzenX5JyDPZVh+MX9IVq9W8lyG
jX/kllaDWslzGSZ93vh1xZhW8lwGH/PpU4VTWslzGQYsXf4hcX4reS6DzmTG
DquVreS5DI1z/OQmW1rJcznctves09jbSp7LMdX1WXDV8VbyXI7rjG/ZLy60
kudy1JoJC6/810qey+FdljJitlMreS7HudtpZoOetZLnckjn7S6seNdKnssx
YMigxfFfWslzOY5pHuM5hbSS53IMHFnjeCm+lTyXo2kF+/jSrFbyXA5Dt+Gz
jMtayXM5zosYq34zWslzOeKvF69sa2klz+V4M3CnU7KilTxXfb7qbuFR3drI
czmmBawwfq7bRp7LcTT4x5Mnw9rIczk0U3znnhnXRp7Lcbx7XubpmW3kuRxT
djp6b1zSRp7L4Vp08tTW9W3kuRyWx6suz9nRRp7LsWHMtdNLDreR53KYSL/4
jjvdRp7LkSHuXjDTpo08l0OgJVw6+k4beS5H/Xpt9+mP28hzOf7zDFgw5nUb
eS7HiXGOqXN92shzOc4kcl9OCWgjz+X49dB25+roNvJcjptnX+9ZltZGnsvR
6z/2+v1FbeS5arw/Jd7YW9tGnssR3p7lcY3XRp7LsfGceY8b0jbyXA5Tx4FT
TTWE5LkcV1nL7Eo0heS5HDal/xbzegvJczn892l7ne8nJM/lcLj0+frdIULy
XI6ZI5906IwUkudy7Nrbu22ckZA8l+PLlIK7AROF5LkcCY+nPM+aJiTP5Yi4
l7dy1xwheS7Hvb7allcWCclzOYxmPZjZZbmQPJcjv8HzosFaIXmuuh7GGtsD
NwrJczlCNOVfC02F5Lnq+tjM9jHfLSTP5bhipzXo3kEheS7HtgFGE4ebC8lz
OfxQGrTcUkiey8Homl9bdl5InssRs/fw7b9WQvJcjodr56e+vCYkz+UYk/np
dsJtIXkuR039/rp9TkLyXI7Mx1+CnZyF5LkcgflLJhk9E5LnCph8OznY9LWQ
PFfAfUjVp7b3QvJcgcmjWd9H+wjJcwWCI2abJXwVkucKJLUMuyIOEJLnCmwP
MZnzIlRIniuQO1DvbGa0kDxXwKDniLXnE4XkuQLHX8e/9EkXkucKnI3+9mBj
rpA8V2CXrbHEoVhIniswMlv217hSSJ4rcCds552T9ULyXIG4hX8+9WcLyXMF
vHcsXrG1WUieK7BRK/Hmb6GQPFegZlvtrMUKIXmuwPu5Kx7wfwvp/a4C3QMW
75rSTUSeK6BIvZFaoy0izxU4dmHX99F6IvJcgeQIm9nFA0XkuQIDn0+dNXS4
iDxXIEXXuDjXQESeK3B/eCJ/4AQRea76/5nvfXKMReS5AmN79isdNFtEnisQ
xs/+nL9ARJ4r0PXgSNEwiMhzBQ5eDqspWy0izxUIGcpZNnajiDxX4Omxg6sa
tonIcwXWLzkTN3O3iDxXIDo6oVp0QESeKxCa+ePCKnMRea6A+S3GJ01LEXmu
QHrit+17L4jIcwX4fjFeI61F5LkCnHEnTl75T0SeK3B6/c78hXdE5LkCfRTV
fq73ROS5Ag7bvk3b91hEnivw31y98T+fi8hzBV6nRcffdBeR56rr0/A3v8pD
RJ4rcP77A/vPn0TkuQJf/n77rvlDRJ4r8FFj4NWSIBF5rsAH5wGRcyJE5LkC
HWn73mvGichz1fxwXqA8mSIizxUI+ndQtihLRJ4rkPVX39KjQESeq+6H7yNv
WZWJyHMFtrDDe1fXiMhzBQbluC8KbhCR56q/v7w/YxhPRJ4rMPVY0QRpq4g8
V2Bvv0mcQzIRea7AvfPpaxf9EpHnCuTs+T3ycxcxea6Ajtj2laOWmDxXwmyo
8z1JHzF5rkShgKNfPEBMnivxaFuF4ephYvJciVHH+uWNMxCT50qEd2W2vR4v
Js+VuGaqDLluLCbPlcB031bRLDF5rsT36LfZ5QvE5LkSzuUTRm+FmDxXosH7
18D5a8TkuRI9f5+4E7hRTJ4rkdJjqMsbUzF5rkTA+yODBu8Rk+dK2DYJl3Q9
JCbPleiIG1J967iYPFdimYnT8POnxeS5EsMOPyoSXBST50osmVwxpc5GTJ4r
0fd29K/DN8TkuRLrnTnntjuIyXMlXhp+2VX2QEyeK2FyMYiZ9VRMnqt+vs6U
te2lmDxXIqNswb1178Tkuep4wjCvfG8xea4EI+H6oYwvYvJcibYRla7bA8Tk
uRKzp984uTlUTJ4roZUfHlIZLSbPlag3WuRdligmz1V/T2uH1okMMXmuxGiP
EN3jeWLyXInj6d+cpSVi8lyJMi/eD1mVmDxXwlo3ftV9ppg8V8Jhas31R1wx
ea5EUO1TY4NWMXmuhOnKRzfHScXkuRIu80eui+kQk+dKmDPlQckaEvJcCf6I
k88PaEnIcyU+9h49xKKPhDxXQvPJuX5dBkrIcyUGJHXz1xkmIc+VsHk0I/Gr
gYQ8VyK7+yeb8PES8lyJi4MDvXdNlZDnSsSXdr1kMVtCnisRMb0lVGuRhDxX
ot+8ke/1l0vIcyUeljd2xKyVkOeq8R0v7SjYJCHPlYjVe3PJZoeEPFd9//ne
Q+e9EvJcCXlF72FzjkjIcyUORpVv3GQhIc+VWDBnkVR2VkKeK3HhcOOyvlck
5LkS5WPGacTYSchzJa6/8jOvuCUhz5Vo9M5Z6uQkIc+ViDGfHeXjLCHPlZgY
OcPP7LmEPG/HvxTrldbuEvK8HRNOmG6Z4Ckhz9thGW3128RXQp6rfv/ztDF/
f0jI83Ykr5/RZBgiIc/bMdY+Y1xlpIQ8b4fg7BdNjQQJed6OdumoAxFpEvK8
HfxJtWbMHAl53o79GrNS3hZLyPN2pN7KK02rlJDn7dD41OWQA0NCnrfj+8Xr
9wM5EvK8HS6sx5MuCCTkeTssfnPOfpBIyPN2jIwtG3+4Q0Ket4M3VtfBRUNK
nrfj6OyanTu0pOR5Oz7zRVlOfaTkeTs4az+EbRwopf1b7dDe8mz1nWFS8rwd
9soRJuvHSGk/Vzuct7S13ZogJc/bcWz9nj4m06TkeTvOtmrn2s+RkuftqF2w
rduWxVLyvB2vp9VXdz43/L/n7fiW2X3K7vVS8rwdAXqXR7zYIiXP2+H7y9rx
+E4ped6Oj66JT3z2S8nzdsws+Khnc0xKnrfDMzR3VsQpKXnejg3rnuQ8uiAl
z9sx/OZL7QJrKXmu+jxH50Z/ui4lz9uh1Ty8b4u9lDxX/f4Y9+rkB1LyvB27
fh800XGRkuftqHaKnMp5KSXP23E65MDPGe+l5Hk7nj17GaTjIyXP26HoN9R0
7zcped4O6eoZJ+cHScnzdkiGuIx2CpeS5+3Y7eG0xSJOSp63Iyw1ZXR4ipQ8
V91P3u4n3bOl5Hk73o0IM20plJLn7Xix1TK4oEJKnrdj+sjjoePqpeR5O/76
yqbpcKTkuep4GXkbzFuk5Hk7rnxZVrtRIiXP21E1Wt7vU7uUPG/H0p2rY59q
yMhz1fUxqurV3ENGnrfD2r9HfnkfGXnejosl1+bOHSgjz1XXJ/Ru/7HDZeR5
O9xmVbg6jJGR56rxOJN4z2qijDzvQH+IR5dNk5HnHViZHzktc66MPO9AZkdG
vfESGXneAa3G81qGq2TkeQf+WBwovGciI887sO4ro9+tbTLyvAPJDj+knF0y
8rwD/qP1tjAOysjzDiwyjTTZcFxGnndAsbYjes0ZGXneAYNC+4KgSzLyvAOO
Y7z3B9jKyHPV+XTv+WDkLRl53gFZQI+pI51k5HkHPPkbrzx2lpHnHbART5jx
9LmMPO9Ayt2NT7u8kZHnHXjO0zyh6SUjzztwsEyr1u6zjDzvwPSXntm3/GXk
eQd2194+IP8pI8870KhUmP+NlpHnHRC/CetzNUlGnnegpr/OtDuZMvK8A2b9
vgp//a+lO4/LKfsfAH5CGFtkMI0smfwiNGOpieRzioyQLS22yVIzXypLiZCl
sQ9CI0RlaVrGEoqkYghJsk3Zw5ixZ43u8zz3nnvP77zmfP6snufe89zPOZ/3
5/PqOfder0PPVch9Wt298Z069FyFYxBsvfphHXquQsDcWUG/Pa1Dz1Xo6XRh
hG1NHXquQv7x4/ldauvQcxV2lb05n26uQ89VeJFb9EM+r0PPVQh1/Cuyf0MF
PVchOXx5k1HNFfRcvN9jvm9lawU9V2HnY268+lpBz1WgLSoD5zko6LkKY1t6
dv21m4Keq3Ax9V1S628V9FwFF8NtqYubgp6rkFhT2rBwoIKeq7D9wNuGdwYr
6LkK2aZJf4QOV9BzFdzaTCtZOVZBz1VwKjm8tHWwgp6Lv8PWI/1CFPRchcCR
xStLwxT0XIWN3ZZdexWhoOcqfLVjbdHSaAU9V+H2X06d0hcr6LkK1r/bdO0f
r6DnKhQPStg3dZ2CnquQFTX+rDlBQc9VmBt+LKDLdgU9F/GqH7ipOEVBz1Uo
mrTV42W6gp6rkBf05cZVBxT0XIU2Ni7+uccU9FwFmzmbi8cUKOi5CvFr16as
+FNBz1UoH36po0Opgp6rMPhiajv/qwp6rsLQmqLcukoFPdfgz7K5F7o/UNBz
DXaPi4y99kRBzzVQE0l6g1cKeq7BmRUP5hx8r6DnGtg7+uX9qyjouQZXFzRM
3qgr6LkGXeIC60obmNBzDRb3e/dpXlMTeq6BV4r9zBzR50vPNQgqTFwxyc6E
nmuwdvWeFrs6m9BzDdY0/jzI18mEnmtQ7f742XoXE3quwUAH2289XE3ouQaN
8h+8WzrQhJ5rENDg7Zjeoi+XnmuwVd/WfcFwE3quwYi8Vb/3GGtCzzWIsW26
PUr03dJzDTq73OvuHGJCzzWIrvXsF/2TCT3X4PsFr//uGWlCzzVot7dXg1jR
R0vPNXDfUHC57xITfl9bg9qv71vH/2JCzzV4PXvw00GiT5bf39YgKnRw/4Qt
JvRcg7LOG74btcOEnmuQHzczbU+aCT0X12/f5pxpou+Vnou/h450PXHIhJ5r
sL92zI+L8kzouQZ3O7zRr4m+VnqugX/r65B0zoSeazA+e5j5TZkJPddgWMMm
/ieum9BzDXo1mO5oI/pU6bkGPa5Y7bz30ISea3Czt/svrs9M6LkG8dPzW9R7
Y0LPNTD3udJqqug7pecaWF1zOumimtBzDVwata9MsDKj5xo0axG4NUT0ldJz
DRocdSo9Z2NGz8XrHbxSt7U1o+caTO318bW5gxk918D2i1f3r4o+UXquwbEV
C7369TSj5xrkXfIb3rSvGT0X8+2PwsvRA8zouYjX5Dk1I0XfJz3X4H524cqT
w8zouQZTLvudSRxtRs81eLZ84Rwu+jrpuQbXm70qqZ5iRs/FfPru48YRYWb0
XKy3bl4W5wgzeq5B3Cmn6t3RZvRcXP8OgdOWir5Mei7G2779lA/xZvRczL8a
J61ynRk9Z5AbdMXGd4sZPWdwMjG/1EX0WdJzBsMj3T9npJnRcwZP29S7sCnD
jJ4z8PxxepNGh83oOYPy+U0+fcgzo+cMJjv7josoMqPnDPYfue4fXGJGzxlk
V765cuuyGT1ncLd07PPzog+SnjP4aqLfwsF3zeg5g8iiLQf6Pjaj5wx8z8wa
f+K5GT1nULtp494s0ddIzxl0Ij4zeog+RnrOoBn4lHViZvScwaXO1ekZ9S3o
OYN51wsdUkSfIj1n0NPhu7aOoi+RnjPQ4e0hezsLes4gz8qrMLOzBT1n8HZz
9cx9Thb0nEHFuRZbeok+Q3rO4Kdz64Kd3SzoOYMfZyTvKPC0oOcM9lZ+jD05
xIKeMzA9//vGDyMt6DmDbZfaXRkm+gTpOYNFfs88Hky0oOcMxu9RRz2aZkHP
GVzZkXk3aqYFPWfgPnFXg1hR90vPGRRdcMxqIep86TmD2Walps1yC3rO4PDt
kKycNRb0nIG2uKV1gajjpecM/K4G3Rsn6nbpOYO+/z4f/WOKBT1nsCK7maeW
bkHPGdj1XlzR+KAFPWdwc+ayv7JEHS49ZzA/tHzxyVMW9JyBT6vDycHnLOi5
mJ/L7kycVWZBzxkM27MzsfkNC3rOoEv8vggHUUdLzxn0+9LrdOkjC3rO4Nvw
bkern1nQcwa752XarXprQc/F/PaM6Jry2YKeM+hwsizLh1nQcwYHLBEVIfVV
9JzBlOdZPzdtqqLnDGLTnDOcbFX0nMEsPnjCLTsVPWewo1fGkU+ijpWei+PV
S41LF3Wr9JzBqOzqmvPfqug5gwsfc2/GfK+i5wzut7g5YecgFT1n8PHK6uCR
Q1X0nMHqkF8sc0XdKT0X6yuxTSunABU912F66odyv8kqeq7D2KHTNetQFT3X
wbqs/TWXcBU912H+i/B2r0TdKD3XIepx/fpfijpReq7D2pg+YTfiVfRch8f/
Zs/U16nouQ5Na088Ldqiouc6RNxpUq9G1H3Scx0CJytJB0WdJz3XYV5h94rq
TBU916HZyU+xe3JU9FyHgI3WZX+dUNFzHWKscjbtOK2i5zp4jkqrqxB1mvRc
h0GeXat+E3WZ9FyHQ1afx1+pVNFzcfxZE0Zue6Ci5zoMz2z4/Oo/KnquQ9W6
4crO1yp6rsO7gbezq0RdJT3XwTfZfHOfqKOk5zpA6fTUx0RDz8X1SpnxOKex
hp7rsMz70Pl3Nhp6rkO7xA0dz7bT0HMd8nNz29frpKHnOmyNm7v5lqh75P4s
HW60XZBh56Kh5zq8n2jb572rhp7r8OdsZaqrp4ae6zDKZV7D5j4aeq7DkuK+
owJGaui5Dt+ZNjb7dryGnuuwmfeKXDRJQ891WJUfNiRghoaei8/T/9npfbM0
9FyHjuHa4eVRGnoufp41gV5bpKHnOsS3G+WbI+oK6bkOH7b++tlYp6HnOrQv
ntL2yRYNPdeh/Ejs/b47NfRch9fBzm2+2quh5zo4X/ymNiJLQ891yHmb5+N/
REPPdSir2uBxQLgvPdfhh8VqVqJwXnquw96HR/NrLmrouQ69rAyP21c19FyH
7k8SZ/S+paHn4vy/nLHq+FBDz8X4H/X2XvJUQ891cOQelplvNPRch3u3N427
LByWnovxxSzoUijclZ7rYC7P3Na+PkPPdZjxPHJpi6YMPddhQ1Fc4yhbhp7r
EOnfpcnPXzP0XIfkbJucCgeGnutgdea3svPdGXpuQNLWkNU9hIvScwOedS0p
cBQOSs8NWBsbkZBAGXpuQOMNh++vH8bQcwN2TnG7XDeaoecGNHsX4PIpiKHn
BpTDaddpIQw9N2DJ6KK8qT8z9NyARZ2tqm4Ip6TnBsQefTjrL+GS9Fwcz6re
70OEQ9Jzcb5Wp/2HrWHouQHR//yZUbyJoecG2EdPmF2SxNBzA+JLBtxzT2Xo
uQE+t3ILaQZDzw24nR416JRwQ3puQAf3y+7nhRPScwPc1/58y1O4ID03YE1K
yktf4YD03IAn4XZppVcYei6OV69XeVUlQ8/F+/3X7fR/wNBzA6rCFz+c8S9D
zw245nn8wtPXDD034O2dVV1MtQw9NyC4R2qXxSpDzw0YMWxkcoLIy9JzA2za
D85tLfKw9FzEr/iGl7PIu9JzA8zNM6OP2enouQG7XW3tyx109NyAe9alP/l3
19FzA47mtuw2u7eOnhsQVT99g8VdR8/F9XGtCGvrpaPnIn6NPP9JH6aj5waM
Pz3kVskYHT034J+W22aNE3lPem7ApuGLF0SLPCc9N2C2Q7ajtchr0nMDXjyO
8O0m8pj0XIxnwKKWxQt19FwcL85+1JPlOnpuQMdJjVwWrtXRcwP2dl6/Km2z
jp4bcGDluKVuO3T03IBTV3PfhOzR0XMDdhyfaFgydfTcgEe/JK/pekRHzw04
/a7TsXMij0jPDejm5Tnuvcgb0nMDLvfen7RJ5AnpuXh/47TRp0VekJ4bsHzZ
k4NTbuvouQH37xct2/xIR8/F/Kl6+Kn3cx09N+DSye2Pw97p6LmIj9uOyCaK
jp4bMH2PSxQ1dPTcgOMZze1eWBvouVg/iSvdOrUw0HMD1nfyUi61MdBzDulb
knrW62ig5xwqfu9tfbirgZ5zuLM7dPwrsc6k5xw+uD322S7WlfScw5m8D4er
xDqSnnMIuOVbsFKsG+k5h9R7/ftfEOtEes5hYfy8yTEBBnrO4WYzqpycYqDn
HOwGBvYJDzPQcw6X/eo/OxJpoOccXtQ39w+LMdBzDq3TVlofWmqg5xxWPAiM
nrHaQM85fGJngw5tMtBzDn1Loh6FJRnoOQdzeNGDo6kGes7hWsGIJREZBnrO
4eDrqK2nDhvoOYdmZ5/4LjxhoOccNi56EVt62kDPxfW402/4mosGes7B+mu7
xDtXDfScQwnxiUu+ZaDnHIZeafTwjZgX0nMOxwfY/n1UzAPpOYdtCXkTGr4z
0HMOTmtSYipEnKXn4vOE2jd2NAz0nAM8/XfgG2uO+685DBnh/dJHxE16zmFE
0EvXliJO0nMOJp+uariIi/ScQ/TDP6a6izhIzzmQ8Rc9t7tw9JzDgQXdToe6
cfScg+2CLnkXBnH0nMMpx9ARSUM5es4h4uDAiaZRHD3nQJ9PbloeyNFzDuV1
rfu6hHD0nENNsa1e72eOnnNIC8z2nDmHo+ciHtmrO9OFHD3nUFBhWZS9nKPn
HGIOnIiJX8vRcw4tgxu/rNnM0XNxvpL9rHQHR885DFAr1/bdy9FzDvz9yBMt
szl6zqFz3uQJy49y9JxDWL/je34s4Og5h9Er90++fpaj5+L6b7lbdLSMo+fi
c4dnbP3mJkfPxXyxLvyi0T2OnnPoGhFmXvKEo+ccpv8WvH7aK46ecwha/c+W
ux85es7h7/7HB5y1cPScg8fkhMP2VoRKz8Xrlz5PaGVNqPSc0I31fu0x+gsi
ua5HaNPwsXY+zQmV9/MntINraMnKVoTK9U9or2e7ihe3IVR6T+iwOvuoQjtC
5f3vCbXUlMTmdiBUPgCD0EPexwd8ciBU5gdCbVZc9nvTlVBZDxDq38HZ3sWZ
UPl8DEKT9+V4dHMhVD4/QJx/zbK24X0IlfmD0PZjo7x/ciNU1guEpsYd635g
AKHyfvuEdkn4cnrmIELl80UITbA6H1DjTajML4Tun5C06+VQQmU9QWjal3m7
XEYQKp/HQeiUvM81PUcTKp9XQOi+/HhztD+hMv+I3+/uExgdRKisNwj9/oXL
nKJJhMr7+4vz2o6+VxRCqNwvT6h3VqHRIJRQmZ/E+OyGxzT8H6GyHiH0qOKY
NSaCULm/VlzfnG+c/ecSKvfTE1p0K/J/afPFOP/LX4QuqHxg2hdLqKxXCM0d
kuT9Lo5Quf+W0Gbroh7VriBU7rcndKf3ble6mlCZ38S4Kl489FlPqKxnRLxu
LPfatolQuZ+H0Fb7PJRdWwmV+/EJ/ea990+vk0Sc/8t/YvzWs51qkwmV9Q6h
G1KfpnuniXH8lw9FfNRl80bsJ1Tu1yc0sjpUTckUcfwvYYjXLZ9dlXmAUFkP
EVp38PxMSw6h8vtGYrzbB45pkEeo3M9P6KJmVrVBJwmV+ZPQNoNePZ1RRKis
lwjluv1vBX8SKr+PROidhfMTL54nVO73F+OOb+fXvoxQmV/FvPN+FNy9glBZ
T4l5nfSh04obhMr/bxK6bc//uW+uIlTeD4DQHh7ZTV/cJfS/8knELT3B7ztT
NaGy3iI0LmpQyzFPCJX//yT0vo2/17RnhMr7BRBa4JHXq+gVofJ5kIT+P2NV
kzg=
        "]],
       FontFamily->"Times"]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVjns41Ikeh8cMv3GdX+VSU2qWNJLjspop2vT9lmqLlUWu0SGL9dBlKw7W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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times", 12},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"x\\\", \
\\\"f\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6744015417860003`*^9, 3.674401585866*^9, {3.674406434427*^9, 
   3.674406463814*^9}, {3.6744064989630003`*^9, 3.674406526631*^9}, {
   3.67446891675*^9, 3.674468923367*^9}, 3.674469617216*^9, 
   3.6744829009834003`*^9, {3.6745236027306023`*^9, 3.6745236146066027`*^9}, {
   3.6745242046796026`*^9, 3.6745242146106024`*^9}, 3.6745430990756006`*^9, {
   3.6745528921549997`*^9, 3.674552896891*^9}, {3.674553021333*^9, 
   3.674553049718*^9}, {3.674553082395*^9, 3.674553095638*^9}, 
   3.6782783050868*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ComparaisonF(a).eps\>\"", ",", "des", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674553106828*^9, 3.674553122342*^9}}],

Cell[BoxData["\<\"ComparaisonF(a).eps\"\>"], "Output",
 CellChangeTimes->{3.674553125358*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Boundary condition ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "z"], TraditionalForm]]],
 " u = -a (Equation B 4 with a = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Gamma]", "."], "c"], TraditionalForm]]],
 ")---Figures 6 to 8"
}], "Section",
 CellChangeTimes->{{3.6739665004081616`*^9, 3.6739665088465996`*^9}, {
   3.6739701396406593`*^9, 3.6739701506262136`*^9}, {3.6739768840636225`*^9, 
   3.6739768858450317`*^9}, {3.6742269616087046`*^9, 3.674226963655799*^9}, 
   3.674404850061*^9, 3.6744442207022076`*^9, 3.6744633655892076`*^9, {
   3.674471336668*^9, 3.674471342572*^9}, {3.6782741411178*^9, 
   3.6782741506538*^9}, {3.6782741893878*^9, 3.6782742300718*^9}, {
   3.6782742604068003`*^9, 3.6782742621198*^9}, {3.6782747905878*^9, 
   3.6782747950918*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"boundary", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"a_", ",", "k_", ",", "h_"}], "]"}], ":=", 
    RowBox[{"-", "a"}]}], "  ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"x_", ",", "xl_", ",", "a_"}], "]"}], ":=", 
    RowBox[{"a", "  ", "xl", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "/", "xl"}], ")"}], "^", "2"}]}], ")"}], " ", "/", 
      "2"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"secant", " ", "method"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fnc", "[", 
     RowBox[{"gamma_", ",", "gk_", ",", "k_", ",", "U_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "ukp", ",", "Us", ",", "gsmiddle", ",", "Smat", ",", "U1", ",", 
        "Gsmiddle"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ukp", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
         RowBox[{"0.5", 
          RowBox[{"h", "^", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            RowBox[{"Rey", "*", "gk", " ", 
             RowBox[{"F", "[", 
              RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Us", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"U", ",", 
          RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"gsmiddle", "=", 
        RowBox[{
         RowBox[{"kr", " ", "gk"}], "+", 
         RowBox[{"gamma", 
          RowBox[{"(", 
           RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Gsmiddle", "=", 
        RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Smat", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Qmatrix", "[", 
            RowBox[{
             RowBox[{"k", "+", "1"}], ",", "r", ",", 
             RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], ".", "Us"}], "+", 
          RowBox[{"Rvector", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Smat", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "=", "0"}], ";", 
       RowBox[{
        RowBox[{"Smat", "[", 
         RowBox[{"[", 
          RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", 
            RowBox[{"-", "3"}], "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "r"}], ")"}], 
          RowBox[{"Us", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
         RowBox[{"2", "h", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", 
            RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"U1", "=", 
        RowBox[{
         RowBox[{"Inverse", "[", 
          RowBox[{"P3matrix", "[", 
           RowBox[{
            RowBox[{"k", "+", "1"}], ",", "r", ",", 
            RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], "]"}], ".", "Smat"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"U1", "[", 
        RowBox[{"[", 
         RowBox[{"k", "+", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Usol", "[", 
     RowBox[{"x_", ",", "t_", ",", "a_"}], "]"}], ":=", 
    RowBox[{"t", "-", 
     RowBox[{"a", " ", "t"}], "-", 
     FractionBox[
      RowBox[{"a", " ", 
       SuperscriptBox["x", "2"]}], "2"]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Xisol", "[", "a_", "]"}], ":=", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       RowBox[{"1", "-", "a"}]]}], 
     SqrtBox["a"]]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "parameters", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h", "=", "0.005"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"mesh", " ", "size"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"a", "=", "0.5"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"a", "=", 
      FormBox[
       SubscriptBox[
        OverscriptBox["\[Gamma]", "."], "c"],
       TraditionalForm]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"r", "=", "0.5"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "free", " ", "parameter", " ", "implicit", " ", "discretization"}], ",",
       " ", 
      RowBox[{"k", " ", "=", " ", 
       RowBox[{
       "0.5", " ", "for", " ", "the", " ", "Crank", " ", "Nicolson", " ", 
        "scheme"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"kr", "=", "0.0"}], ";", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "free", " ", "parameter", " ", "implicit", " ", "discretization"}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Rey", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"N1", "=", 
     RowBox[{"60", "*", "2"}]}], ";", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "size", " ", "of", " ", "the", " ", "initial", " ", "disturbance"}], " ",
      "*)"}], "\[IndentingNewLine]", 
    RowBox[{"s0", "=", 
     RowBox[{"N1", " ", "h"}]}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "front", " ", "position"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"tinit", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s0", "/", 
       RowBox[{"Xisol", "[", "a", "]"}]}], ")"}], "^", "2"}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "time"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"initial", " ", "condition"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"i", " ", "h"}], ",", "s0", ",", "a"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "N1"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t1", "=", "tinit"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"x", ",", "s0", ",", "a"}], "]"}], ",", "x", ",", "x"}], 
           "]"}]}], "/.", 
         RowBox[{"x", "\[Rule]", "s0"}]}], ")"}]}], "/", 
      RowBox[{"F", "[", 
       RowBox[{"a", ",", "N1", ",", "h"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temps", "=", 
     RowBox[{"{", "t1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FileGamma", "=", 
     RowBox[{"{", "g1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6739291182704935`*^9, 3.673929229485534*^9}, {
   3.6739293428258495`*^9, 3.67392939347196*^9}, {3.673929590604376*^9, 
   3.6739295943391967`*^9}, {3.6739670738931627`*^9, 3.673967141228506*^9}, {
   3.6739680319267387`*^9, 3.6739680477565284`*^9}, {3.673968161300024*^9, 
   3.6739681659099035`*^9}, 3.6739683634936314`*^9, 3.673969959636938*^9, {
   3.673970921686137*^9, 3.6739709218736563`*^9}, 3.6739777694458017`*^9, {
   3.673977888755495*^9, 3.6739779063198833`*^9}, {3.6739784566446724`*^9, 
   3.6739784626765747`*^9}, {3.6739785742354403`*^9, 3.673978591299775*^9}, {
   3.6739786252565527`*^9, 3.6739786254596977`*^9}, {3.6739787155318804`*^9, 
   3.6739787189384975`*^9}, 3.6740093860723753`*^9, 3.674009487036134*^9, {
   3.67400994474065*^9, 3.6740099531635857`*^9}, {3.6742270049570503`*^9, 
   3.674227009285633*^9}, 3.674228227061883*^9, 3.6742282710040298`*^9, {
   3.6742283563568144`*^9, 3.674228363435691*^9}, {3.674228838905471*^9, 
   3.674228856782359*^9}, 3.6742298096929507`*^9, {3.6742299850239697`*^9, 
   3.674229989243194*^9}, {3.674316421293583*^9, 3.674316466235029*^9}, 
   3.6743165230019073`*^9, 3.674316879418*^9, 3.674317315226*^9, 
   3.674317360684*^9, {3.6743182695*^9, 3.6743182769700003`*^9}, {
   3.6743989727132587`*^9, 3.674398973493326*^9}, 3.674399221369187*^9, {
   3.6743996650494323`*^9, 3.674399686002122*^9}, {3.6743999100826592`*^9, 
   3.674399910694292*^9}, {3.674400007407155*^9, 3.6744000078663387`*^9}, 
   3.6744035918570004`*^9, 3.674403624744*^9, {3.674403740209*^9, 
   3.674403784679*^9}, {3.67440486255*^9, 3.674404864105*^9}, 
   3.6744049388710003`*^9, {3.674405195928*^9, 3.6744052264779997`*^9}, {
   3.67440526416*^9, 3.674405322318*^9}, {3.674405609501*^9, 
   3.674405629849*^9}, {3.674405761408*^9, 3.6744057669119997`*^9}, {
   3.674405806807*^9, 3.674405837641*^9}, 3.674444228283208*^9, 
   3.674471346639*^9, {3.674528733520602*^9, 3.6745287413756027`*^9}, {
   3.6745531358050003`*^9, 3.674553184454*^9}, 3.674995963836*^9, {
   3.6749960042209997`*^9, 3.6749960331870003`*^9}, {3.674996276995*^9, 
   3.674996277434*^9}, {3.6749963076809998`*^9, 3.674996334329*^9}, {
   3.6782735544398003`*^9, 3.6782735554158*^9}, {3.6782742697278004`*^9, 
   3.6782743068848*^9}, {3.6782744069568005`*^9, 3.6782744199818*^9}, {
   3.6782745081648*^9, 3.6782745135728*^9}, {3.6782746536868*^9, 
   3.6782746822928*^9}, {3.6782748885318003`*^9, 3.6782750013078003`*^9}, {
   3.6983820435339994`*^9, 3.698382069884*^9}}],

Cell[BoxData["0.6`"], "Output",
 CellChangeTimes->{3.6782783133648005`*^9, 3.6782786873178005`*^9, 
  3.698381303299*^9, 3.698382070219*^9, 3.698382225085*^9}],

Cell[BoxData["0.17999999999999994`"], "Output",
 CellChangeTimes->{3.6782783133648005`*^9, 3.6782786873178005`*^9, 
  3.698381303299*^9, 3.698382070219*^9, 3.6983822250889997`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tempsGarder", "=", " ", 
    RowBox[{"{", 
     RowBox[{"267", ",", "665", ",", "1065"}], "}"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "times", " ", "at", " ", "which", " ", "the", " ", "solution", " ", "is", 
    " ", "plit"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vitesse", "=", 
   RowBox[{"{", "U0", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vitesse1", "=", 
   RowBox[{"{", "U0", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"acceleration0", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"detailG", "=", 
   RowBox[{"{", "g1", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6747145904519997`*^9, 3.6747146184820004`*^9}, {
   3.674714661651*^9, 3.67471466609*^9}, {3.674824441616*^9, 
   3.6748244440620003`*^9}, {3.6749655028100014`*^9, 3.674965509632001*^9}, {
   3.674994901243*^9, 3.674994937771*^9}, {3.6750001498789997`*^9, 
   3.675000151304*^9}, {3.675000820224*^9, 3.675000820863*^9}, 
   3.675001597612*^9, {3.6782743425328*^9, 3.6782743613978004`*^9}, 
   3.6782744205798*^9, {3.6782750169878*^9, 3.6782750194038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", "U0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gk", "=", "g1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"etape", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{"Dynamic", "[", "etape", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Nmax", "=", 
   RowBox[{"N1", "+", "1000"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"etape", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "-", "N1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"Nmax", "-", "N1"}], ")"}]}]}], ";", " ", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"ii", "=", "2"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "1", "]"}], "=", "gk"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xx", "[", "2", "]"}], "=", 
     RowBox[{".75", "gk"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ecart", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"xx", "[", "2", "]"}], "-", 
       RowBox[{"xx", "[", "1", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ecart", ">", 
       RowBox[{
        RowBox[{"h", "^", "2"}], " ", 
        RowBox[{"xx", "[", "ii", "]"}]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"xx", "[", 
         RowBox[{"ii", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"xx", "[", "ii", "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xx", "[", "ii", "]"}], "-", 
             RowBox[{"xx", "[", 
              RowBox[{"ii", "-", "1"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}], "-", 
             RowBox[{"fnc", "[", 
              RowBox[{
               RowBox[{"xx", "[", 
                RowBox[{"ii", "-", "1"}], "]"}], ",", "gk", ",", "k", ",", 
               "U"}], "]"}]}], ")"}]}], 
          RowBox[{"fnc", "[", 
           RowBox[{
            RowBox[{"xx", "[", "ii", "]"}], ",", "gk", ",", "k", ",", "U"}], 
           "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ecart", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"xx", "[", "ii", "]"}], "-", 
          RowBox[{"xx", "[", 
           RowBox[{"ii", "+", "1"}], "]"}]}], "]"}]}], ";", 
       RowBox[{"ii", "+=", "1"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"gs", "=", 
     RowBox[{"xx", "[", "ii", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ukp", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"a", ",", "k", ",", "h"}], "]"}], "h"}], "+", 
      RowBox[{"0.5", 
       RowBox[{"h", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"gk", " ", 
          RowBox[{"F", "[", 
           RowBox[{"a", ",", "k", ",", "h"}], "]"}]}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Us", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"U", ",", 
       RowBox[{"{", "ukp", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gsmiddle", "=", 
     RowBox[{
      RowBox[{"kr", " ", "gk"}], "+", 
      RowBox[{"gs", 
       RowBox[{"(", 
        RowBox[{"1", "-", "kr"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Gsmiddle", "=", 
     RowBox[{"h", " ", "gsmiddle"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Smat", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Qmatrix", "[", 
         RowBox[{
          RowBox[{"k", "+", "1"}], ",", "r", ",", 
          RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], ".", "Us"}], "+", 
       RowBox[{"Rvector", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}], ")"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Smat", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "=", "0"}], ";", 
    RowBox[{
     RowBox[{"Smat", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", 
         RowBox[{"-", "3"}], "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "r"}], ")"}], 
       RowBox[{"Us", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}], "+", 
      RowBox[{"2", "h", " ", 
       RowBox[{"F", "[", 
        RowBox[{"a", ",", 
         RowBox[{"k", "+", "1"}], ",", "h"}], "]"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"U1", "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{"P3matrix", "[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "r", ",", 
         RowBox[{"Rey", "*", "Gsmiddle"}]}], "]"}], "]"}], ".", "Smat"}]}], 
    ";", 
    RowBox[{
     RowBox[{"U1", "[", 
      RowBox[{"[", 
       RowBox[{"k", "+", "1"}], "]"}], "]"}], "=", "0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MemberQ", "[", 
       RowBox[{"tempsGarder", ",", "k"}], "]"}], ",", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"vitesse1", ",", "U1"}], "]"}], ";", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"vitesse", ",", "U"}], "]"}], ";", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"detailG", ",", "gs"}], "]"}]}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"FileGamma", ",", "gs"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"acceleration0", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"U1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", 
          RowBox[{"U", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "h"}], "/", "gs"}]}],
      "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"U", "=", "U1"}], ";", 
    RowBox[{"gk", "=", "gs"}]}], ",", "\[IndentingNewLine]", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"k", ",", "N1", ",", "Nmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.673966517050609*^9, 3.673966648861612*^9}, {
   3.6739666797556033`*^9, 3.6739667339020443`*^9}, {3.6739667659054856`*^9, 
   3.6739668163015313`*^9}, {3.6739668732540045`*^9, 3.67396691474284*^9}, {
   3.673966958903792*^9, 3.673966961216581*^9}, {3.6739670161994834`*^9, 
   3.67396701752775*^9}, {3.6739679274154677`*^9, 3.6739679396824503`*^9}, {
   3.6739679876094847`*^9, 3.6739679968292255`*^9}, {3.6739680750720124`*^9, 
   3.6739680801819315`*^9}, {3.673968127327625*^9, 3.673968206945562*^9}, 
   3.6739682994086266`*^9, {3.6739683921685934`*^9, 3.6739683927467794`*^9}, {
   3.6739699452135077`*^9, 3.6739699819987087`*^9}, {3.6739709681598845`*^9, 
   3.673970974316795*^9}, {3.6739710618261585`*^9, 3.673971119363633*^9}, {
   3.673971182432926*^9, 3.673971276177367*^9}, {3.673971315759741*^9, 
   3.6739713318083544`*^9}, {3.673971391814762*^9, 3.673971418208219*^9}, {
   3.6739717154078617`*^9, 3.6739717156578884`*^9}, 3.673971807183363*^9, {
   3.6739718759094987`*^9, 3.6739718888952217`*^9}, {3.6739765537468605`*^9, 
   3.6739765628884764`*^9}, {3.6739766217541704`*^9, 
   3.6739766366151457`*^9}, {3.673976769988827*^9, 3.673976821213117*^9}, 
   3.673976967306955*^9, {3.6740099737124968`*^9, 3.674009978291089*^9}, {
   3.674227038851217*^9, 3.6742270638694887`*^9}, {3.6742272186202755`*^9, 
   3.6742272204485545`*^9}, {3.6742272616717043`*^9, 3.67422729129984*^9}, {
   3.6742282940689316`*^9, 3.6742282961160192`*^9}, {3.674228382203255*^9, 
   3.67422840751849*^9}, {3.6742285603915777`*^9, 3.674228576971459*^9}, {
   3.6742295568536983`*^9, 3.674229615125483*^9}, {3.6742296550515847`*^9, 
   3.674229744920472*^9}, {3.674229826100938*^9, 3.6742298407743626`*^9}, {
   3.674229932627836*^9, 3.6742299537863226`*^9}, 3.674230023590584*^9, 
   3.6742302341199503`*^9, {3.6742327273011885`*^9, 3.6742327591326485`*^9}, 
   3.674232834953163*^9, {3.6743147973416324`*^9, 3.6743148918267193`*^9}, {
   3.6743156882281895`*^9, 3.6743157043149037`*^9}, {3.6743157502710843`*^9, 
   3.6743157663497877`*^9}, {3.6743158145639315`*^9, 
   3.6743158519423094`*^9}, {3.6743161713331785`*^9, 3.674316175726901*^9}, {
   3.6743162639664307`*^9, 3.674316268007161*^9}, {3.6743163070900087`*^9, 
   3.6743163356198316`*^9}, 3.674316497458014*^9, {3.6743165323978844`*^9, 
   3.674316532905239*^9}, 3.67431685601*^9, {3.674318740052*^9, 
   3.674318772635*^9}, {3.6743888447684307`*^9, 3.674388951511136*^9}, {
   3.674388990361424*^9, 3.674388996832595*^9}, 3.6743890440401077`*^9, {
   3.67438920945475*^9, 3.6743892144690447`*^9}, {3.674389317973166*^9, 
   3.674389320486865*^9}, {3.674398897753016*^9, 3.674398937115638*^9}, {
   3.674398997458021*^9, 3.6743991214656167`*^9}, {3.674399325794737*^9, 
   3.674399333855121*^9}, {3.6743993711944*^9, 3.6743994502043953`*^9}, 
   3.674399485407956*^9, {3.674399524548998*^9, 3.6743995284914713`*^9}, {
   3.6743996996895046`*^9, 3.674399728790809*^9}, {3.6744000691983523`*^9, 
   3.6744000767915335`*^9}, {3.67440018919532*^9, 3.6744001969348583`*^9}, 
   3.674400350852*^9, 3.674400402828*^9, {3.674404954777*^9, 
   3.6744049571280003`*^9}, {3.674405889367*^9, 3.674405889743*^9}, 
   3.674406570192*^9, 3.6745532295360003`*^9, {3.674714673302*^9, 
   3.6747146995880003`*^9}, {3.674824468844*^9, 3.67482452548*^9}, {
   3.674965562012001*^9, 3.674965618154001*^9}, 3.674981584487404*^9, {
   3.674994954341*^9, 3.6749949547650003`*^9}, {3.675000121108*^9, 
   3.6750001448900003`*^9}, 3.675001578362*^9, {3.675001614281*^9, 
   3.6750016149049997`*^9}, {3.6782745520148*^9, 3.6782745806388*^9}, 
   3.698381325134*^9, 3.6983814403989997`*^9, 3.698381869351*^9, {
   3.698382212663*^9, 3.6983822130299997`*^9}}],

Cell[BoxData[
 ProgressIndicatorBox[Dynamic[$CellContext`etape]]], "Output",
 CellChangeTimes->{
  3.6742295516499763`*^9, 3.6742297545933266`*^9, 3.6742298419931965`*^9, {
   3.6742299400660725`*^9, 3.6742299544738812`*^9}, {3.674229995415718*^9, 
   3.6742300243406134`*^9}, 3.6742302394017534`*^9, 3.67423276067968*^9, 
   3.6742328081847034`*^9, 3.674232854642743*^9, 3.6743148929025774`*^9, 
   3.6743158571420975`*^9, 3.6743158874306035`*^9, 3.6743162794284806`*^9, 
   3.674316370184701*^9, {3.674316473151373*^9, 3.674316498488763*^9}, 
   3.674316533989072*^9, {3.674316852803*^9, 3.674316881249*^9}, 
   3.6743187767320004`*^9, 3.6743890037971377`*^9, 3.674389045364587*^9, 
   3.6743896799400973`*^9, 3.674399529708704*^9, 3.674399770074535*^9, 
   3.674400198190196*^9, {3.6744003432980003`*^9, 3.674400351166*^9}, 
   3.674400418021*^9, 3.674403660801*^9, 3.674403716627*^9, 3.674403768797*^9,
    3.67440380629*^9, 3.674404957752*^9, {3.674405875675*^9, 
   3.6744058980290003`*^9}, 3.6744442449212074`*^9, 3.67447137715*^9, 
   3.6745287597166023`*^9, 3.674553192823*^9, 3.6745532298129997`*^9, 
   3.674711868455*^9, 3.674714718021*^9, 3.674824535594*^9, {
   3.6749656191660013`*^9, 3.674965633821001*^9}, 3.674978779664404*^9, 
   3.6749815880694036`*^9, 3.674994958999*^9, 3.674996349148*^9, 
   3.675000167352*^9, 3.675000935392*^9, 3.6750015797939997`*^9, 
   3.6750016172*^9, 3.6782783175978003`*^9, {3.6782786884158*^9, 
   3.6782786951658*^9}, 3.6983813255569997`*^9, 3.6983814438849998`*^9, 
   3.698381872722*^9, 3.698382074611*^9, {3.698382213776*^9, 
   3.698382228253*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"style", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"DotDashed", ",", "Thick", ",", "Purple"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Red", ",", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Blue", ",", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", " ", "Black"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"teps", "=", 
  RowBox[{"{", 
   RowBox[{"0", ",", "2", ",", "4", ",", "6"}], "}"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "dimensionless", " ", "times", " ", "at", " ", "which", " ", "the", " ", 
    "solution", " ", "is", " ", "plit"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.672589687756*^9, 3.67258971424*^9}, {
   3.672627707759601*^9, 3.6726277814736013`*^9}, {3.672627922897601*^9, 
   3.6726279244806013`*^9}, {3.6726424826786013`*^9, 3.672642495366601*^9}, {
   3.6726428232496014`*^9, 3.6726428305496016`*^9}, {3.674992914133*^9, 
   3.674992956604*^9}, 3.674994032932*^9, {3.674995342915*^9, 
   3.674995355082*^9}, {3.6782744526848*^9, 3.6782744577248*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Dashing", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], "}"}], "]"}], 
     ",", 
     RowBox[{"Thickness", "[", "Large", "]"}], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0.5, 0, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.33333333333333337`, 0., 0.33333333333333337`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0.5, 0, 0.5]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0.5, 0, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0.5, 0, 0.5],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->GrayLevel[0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "GrayLevel[0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["GrayLevelColorValueSelector"], {
             0, {Left, Bottom}}, {Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      GrayLevel[0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->GrayLevel[0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "GrayLevel[0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["GrayLevelColorValueSelector"], {
           0, {Left, Bottom}}, {Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    GrayLevel[0],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6749929080150003`*^9, 3.674992956921*^9, 3.674994035119*^9, {
   3.67499533206*^9, 3.674995355664*^9}, 3.675000658763*^9, 3.675001221899*^9,
    3.6750022130950003`*^9, 3.6782786182728004`*^9, 3.6782790709268003`*^9, 
   3.698381393698*^9, 3.698382599108*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "2", ",", "4", ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6749929080150003`*^9, 3.674992956921*^9, 3.674994035119*^9, {
   3.67499533206*^9, 3.674995355664*^9}, 3.675000658763*^9, 3.675001221899*^9,
    3.6750022130950003`*^9, 3.6782786182728004`*^9, 3.6782790709268003`*^9, 
   3.698381393698*^9, 3.698382599118*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"desvit", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"vitesse", "[", 
           RowBox[{"[", 
            RowBox[{"k", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"(", "i", " ", ")"}], "h"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "@", 
           RowBox[{"vitesse", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "4"}], "}"}]}], "]"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "teps"}],
       "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"u\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.674716751762*^9, {3.674992478973*^9, 3.674992559709*^9}, {
   3.674992735513*^9, 3.6749927398129997`*^9}, 3.674992905258*^9, {
   3.6749929641289997`*^9, 3.674992990105*^9}, {3.6749930367060003`*^9, 
   3.674993059422*^9}, 3.67499310205*^9, {3.674993292458*^9, 
   3.6749932928199997`*^9}, 3.674994047824*^9, {3.6749953602130003`*^9, 
   3.674995361733*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJw1lAtQlGUUhslxChwnZaALNVJSIV1IoGkw096xJszpgphdZKzIxJqwsAbj
kkMUWDGFRlxESwxBQQQCgeW2y+7/rwIhEtddbnuDyZJyaga3vET2f9++e2Z2
dvbf7z/nvO9zvrN8W/KmxAU+Pj5p2kd8f3JP4eBklBkfB9atd2WkIPGSrmY0
0vs7BzPHvjt9d4QZrcF7f49r3Ydr0U8GGcK9/xeiWsQDZhw6KAOX5kfSLoR6
z5fCEqlkp4eY8UeceFKGjTHJZ+OXed+vwPbHHbF5t5mxyFq+a+2iSvjL8OY7
gVe6Fy4572fG/Vv3q+6wGjz6evuGxQu8+etQO6oVuKKiQnvbWl4PQ3jS7uf+
UlmvATtEnFfxiIxGVEnBKus3ITv96H95AyrM7jCtQjMuvygUq+ynBVr13Kst
KjZ5Cnr0Vqvsrw0XQiN9a75X4coQCduhyIQq+9UjSjzIVPGBaG+XAULugfdV
9t8Ju02L11T4yDAhSArw6jHh4h5N8moVz8gCCuKXBawpWeHVp+DNUk1RoApR
TSvJPF69ZqwSuLRzUo7VDD8JWKH+0/jwnfyLe4wK7hLtBJ+BZl5CaZVCP854
eOQreFsa2YUY3ZxGWKE/3RDdzL6hQGQLrOuGUL8xRqFfPUgXBj2k4G+Rzt1D
vgr9+wmivSS3CU/IhL1YvODBL24dN9HPXohpCdCbINvbexZJskET/e3z6M0y
4VyfDDwsD5jo9znIcV5nwi2ywX5slgNtov/9OOhU1sRdN0Km2/ozOmQY6eMA
lr76WFPPR0bqGUBx8+rQtAgj+QzghRGjf+9vndQ3gFXa6c4jneQ1iJdkdFLv
II62JNbu8+skv0GETF7JfFdvoP4hyHTvGchzCPJ4sIF+DMEjU0++wwh0J+dE
ZejpzzDy7KJDPXkPIzp3XcIvAx30awQB8nwH+Y9geYiIDvo3gm1ScDvnYZT9
tNPPUaRGxGqP2jkfo3hevtBGfy3YLPW2cV4s2O8X3BfgbqXfFlzV1KYUtHJ+
rCiSfrbSfyuk3L4WzpPVc393tJDHGEokLx15jOHfO8u+thfryGMM396+8OWb
w3XkMYZ4y6z2SjN5jLO/ZvIYR1bRU1/t/LWJPMZhk4CbyGMCO7ecfOuzm5rw
jeQxgZW2e2/8tKiRPCboXyN5TGJ9WLmG7BR5TOLwn5Vdz0afIo9J3JcmDGwg
jylIOTEN5DFFDvX8nsKsFFxPHjakyPv5I3nYkCoXUB152GDzFRe8ljzsqJT7
qoY87LD0/6NtuJPkYed9qiYPh2efFJ4gDwdaNogbWUUeDuxOFVFJHk4cWDHr
8E08Tj1OBMWLjX6MfJy4QezP6ArqcyJW7v9y8nLi2nURZdTrxBKxTxw/kJ8T
/nJej1C/C3rtdt2x8jB5urB2XgzAIfrhQvaXIkrI14XP5TwU0x8Xtsj5KiBv
Fy7HCGD59Gsax3vLntbN5ZH/NOaXin2VS/+mMZcgDMrh/ZxGV0qBViGTfk7D
JMY5NoXzMY0s6c92+jtD33x8PPMyg/8BD6WgoA==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxV1GdUlNcWBuBBlCYEFWwJoGIDY0EI3ETBV9QbWRZswQaEXCN2RUFETWID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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJxV2HlcTO37B/CZmplmxhZCkSRK9MgWPdbrlmTNLltEZF+iLClCHpIkKWRN
UUlCoUSrEm3a932bmWZv3/sNrvN9vX7nj3rds9z3fX3e15lzZsZbn9hgo0Sj
0XwVf37/N+FtKQ1YKwdHtbBl1eft4f+Pr0LPdhvlJ4pxlNZ/wvVRHhA59vrG
2/973hssxySmnVeMH/r+OUCgqXvU6n+vfwqxo+KNFirGovW/H3kOddVBumr/
e/8LuPS0dVHdGjlwCwNsF3KDIPbK90tv1lDzvYLBovnCE4rxZMvbia36obDs
gONFgzXU/GFw5k3YvCpzObxQvLsw4B1M9FfW9jCn1nsP6zeGGs5WjGf9OSJg
Q2fF/vzV1PofILwt/8dxxfhbq75ihY+QVPhrE301tZ9IkK8fMuDWKjls+Lsg
xC8pFQ5dRe3vM4giLrbfXimH6vO/J4wGkr3cUGUltd+v0CJ39zy7Qg4nf2/P
NgaM7/prVS+n9h8LF7fWFy1RjGl/jngwGPAx7tkyqp54eO57OrfFTA7L/yyQ
AE0jb6stMaPqSwBW9DEXt6Vy+L2aYknoL7usnWZK1fsNHHpAxFCM/5RT+A1y
P2nzjJdQ9SeBVZrf0H0mchj3eztayRChsfjojcVUHsmQ43etPYjI4cD+38d3
MLrYFREHVD4pIBNN9s9aJIffs6mFpYD20sDEkoVUXj/AtYsxsmKBHNp+T9f6
A9oeVT4umU/l9xPYOblbsubJYdGfCVPBa5fLsri5VJ6pMHCM99Ggf+XwZ3v/
pcGAjrcprsZUvumQ03112945cshI/3PA8cXJOsazqbwzwLZdbyLDSA4j/mww
E0Za7duVOpPKPxMupc7PuTFDDn+ms/wFwx6fuGQynfLIggVLvx9qMaTqyYKH
ptzbz6ZSPllgrcuVL/mHqi8Lki488KyeQnllwz7xzePnJlP1ZsN7zbibbH3K
Lxu8olUFd/So+nMgwXHvdTVdyjMHutWfHvCcQOWRA8nmr92YOpRvLgQXOMjt
tKl8cmGwbc/jUi3KOxeO5U32WDCWyisPKqJ7ku+NofzzwCffbmmjBpVfHgzO
ujPIWJ3qh3yINt857sJIKs980ONXOX5Vo/ojHyymGkxsHUblWwAqT9doTBpK
9UsBmIXusdwwhMq7ALQ+X5ScGUT1TyHsH56U5T2Ayr8QPFs3MkI5VD8Vwsir
m9y+qlAeRXAgTbr3O5PyKIJNsRu9fipTHkVQMCt85Hc65VEE1+pJ05d+GXoU
g8mxuXqve2XoUQwuS4oj7nbL0KMYVsfseXy6U4YeJaDOVa9e1y4Dzz8eJTB4
5lIX3VYZepQo9j/nanOTDD1KYeie+fXRMhl6lMJwv1dBjhIZepTCVd3i9Nki
GXqUQaianoVAIEOPMthkKTO9x5OhRxnM+fjo4YJ6GXqUw/hnt7eW1cjQoxw2
WRlfOl0lQ49yCO6lD2dXyNCjAjpNrId5l8rQowJYnzKdNYpl6FEB0b4Jlg8K
ZOhRCe8bo0JU82ToUQmvLeccuZItQ49KmL417pk4U4YeVeDcUbZiQzpVTxXc
ZGseefdThj5VoEMfxGSnUPVVAZ9pqrEtSYZeVeBTs/VVQAJVbxUksHmfeLEy
9KuCVI9bS3S/UvVXw8Np0nWWnynPaohdEl7l/onKoxrehl5q+RRB+VbD6nQV
j5J3VD7V4FjVEdb+hvKuhsCXnG2DX1N51YD3y6ZbWsGUfw2UlR1cq/+Syq8G
LAV6zwz8ZXh+1sDUwwbO+s+oPGvAa/NiudZjqj9q4JKDZstgXyrfWqi8OeFe
hw/VL7XgGu8SXepF5V0L/fwM36jbVP/UQmeCK8/Dncq/Fswj/RhWN6h+qoUp
RwQ39a9RHnWw5lQPT3iF8qgDv4kd4cHOlEcdXCpavNnKifKoA/9cqyNDHCiP
Orjg+nrH59OURx34vA1MsjxFedSBpfUPbtdxyqMervmczPQ8QnnUQ27q1lPj
D1Ie9WCz8umD1/soj3pw797oP20P5VEPV41h1pudlEc9qHEaQiZupzwawN3l
UZiPBeXRADYFJx7TNlIeDRASYzjGZi3l0QBb7l67/m0V5dEAfPvgG2OWUx4N
MH5Ds9MxU8qDB4sKhNzPhPLggeaT8Ft9CygPHlQsHfJu4VzKgwdkQEvqmdmU
Bw/Ote1wezWD8uDBpzwNs4KplAcf9J3NX/dMpjz4sGB/lOpYPcqDD20n7kw0
1qE8+HCwxWfBKi3Kgw+r61nsbaMpDz4YDgop3T2S8uBDjkbsAethlIcA9CaP
pe0aTHkI4H17++aNXMpDADbzl381YVEeAjgUrFtvoER5CODB5YNLtXqk6CGA
wmVZa4uapejRCJJHs9yvCaXo0QgnnMZZ69dK0aMRNOYmnIotkeLnZSNcPGQ8
aXmOFD0aQW/aonHff0rRoxGK7eySjROk6CEEi4xZUU+ipOghBEK/ubf9rRQ9
hFAnu7ZvaZAUPYQw0t1T//pTKXoI4bb62VUxPlL0EELHR9l8nrsUPURw/fQT
b+ZVKXqI4NzWk8mjHKXoIYL93cIDWqek6CECI+/pYvVDUvQQwYdjoWKV3VL0
EEFDeUBpo4UUPUTw8KjzmkRzKXqIYSX3/udbplL0EMNs5x0R5vOl6CGG91sM
3tFnStFDDKyx7ktD9KXoIYaGMwV8s3GUhxgkH94ZFo2gPCSQeWfPrZ0DKQ8J
REV8eVCoRHlIIG8dP2VppwQ9JDDGVf4mWCpBDwlEVxQm9tdL0EMCuwJ5D1aV
SdBDCqpCcfDNHAl6SGHVDZer8T8k6CGFpa+NXwpiJeghhebwzkcqHyXoIYW5
Jaq1Gq8l6CEF29fp3PHPJeghg/hPOh6a9yVYjwyu9qX1DLwlQR8Z2NP25siv
SLA+GTw2Hv407ZwEvRTX5eZhZb7HJfCn3P0y8C9nj9m5T4J+iueXxBaqbZfg
54Pic+XoTr+EtRL0lMEmtXlN1kupPBTnzWrujs55EvSVQUBTwNar06l8ZBCT
vu4cQ0+C3jJgpe3+12EMlZccUkd91q1VlaC/HEoqx8QtZlH5ySFdf+gdn24x
9oMctscmj66QiTFPOYjjj/DHNIixPxT3jTPvOqwpFWO+cjDbPm77mSwx9osc
5s3r4dxNFmPecgganaz2MlqM/SOHYe3RXa/fijF/OeQkGS8LfiHGfpJD4LPU
87/77q9HE9x75aV9yUOMHk2gb7v/8w4XMXo0gcX96Vn/nBOjRxMc9WU3NB0V
o0cTnP0Z8l/YHjH2XxNwph+abmUhRo8mIAWFtsxVYvRognaNCz/8QIweTcB+
kpoww0iMHk1g1GNfEakvRo8mODwzO3jWWDF6NAF30lf/F0PF6NEEszLsLAaw
xOjRDMZX2pce6BKhRzO4v7frjpKI0KMZNM8xOvtrROjRDGaaqT8WFIrQoxkq
q9pFx9NE6NEMW6cGSe/FidCjGVaJNDd+iBChRzNEZNs+TwkSoUczMAa2WGY9
EqFHMyx5kzDk120RejTD6bIZC765iNCjGa4pHzz65qwIPVpg4uBYnVtHROjR
Ao/99gmsrUTo0QJ95uEmhhtF6NEC/gmCKKmZCD1aIHrqtszAeSL0aIEXPdsG
bTIUoUcLxA2Y2tE2XoQeLeCkv0zDc4QIPRTv7ypo0uKI0KMFTExPDnnRI0SP
FmC/mirXkgnRowV+7ErW8awVokcLGC030msvEKJHKzy4YHltU6oQPVohyk4j
OShGiB6toHr1/DH5OyF6tMJU9Tn0GS+E6NEK5qNvDThwX4geraC2feDgu25C
9GgFyd0p3h8vCNGjFcqczMZl2grRoxWGFKrOL98rRI9WOPPz48EaCyF6tEKf
yUSjihVC9GgF69PrtbIWCNGjDUbePx4RNU2IHm3gdWO2/X0dIXq0gaR4rPjo
CCF6tMH2n8+f/ssWokcbmBKXEd1djejRBv6+HdkR4kb0aIPRasP27K1qRI82
sOXHmHByG9GjDewf72IEJjeiRxsMVbunO1dxXf3r0QYhjLFG30Ia0aMNzHJN
3y550ogebeBtqq37RXFd/uvRDkWaoWqTrzSiRzscZG8b6GHfiB7tcFY1zU2g
uK7/9WiHKN88rQXbGtGjHboqvpr9t6oRPdrhV8qXO8mK+4K/Hu1QEhF5oWda
I3q0w7Hs9Q+n6DSiRztsfzrAZq3ivuKvRzuMWtN87AirET3aIcxx/MyLHQL0
UKyvPsLEtVGAHh2wrtph9I0yAXp0wI+5S1ZfzhSgRwcMZodutI0XoEcHdOWM
S7QIF6BHB5yP3Dfc6IUAPTogkWtdzL4nQI8OyJthczvvugCvnx2Q2pGXct9B
gB4d0KJ9pXf9EQF6dECZl8U35Z0C9OiARy7+d0PXCNCjA6IeFtDNiQA9FPt/
FHu9boYAPTrByH3zZ7sJAvTohOWlFUO61ATo0QlJ7rXjzrEE6NEJ8YWjrcXt
fPTohILtz45sF/DRoxPs5jz4EFvCR49OKFv0MWe04j7yr0cnWD67sfB4DB89
OsG7Z+fNz2F89OgExtups3qe8dGjE44kl6fNucNHj07g8zPSDl7ho0cXlBu4
pHrZ8dGjC469jln4YR8fPbpg76jAmIzNfPTogn0Tt8VVmPHRowvSPgeW8oz5
6NEFqWaM63zFffNfjy7oviraXq3BR48u0EyYnJbN5aNHF5zXqT8Z3c1Djy6Y
1jo38aGIhx5dMPOI8ha7ch56dEG47JX/kkweenRBxe5YMjCOhx7dYHCgyT/9
LQ89usFI39PmPz8eenTDtVCPztl3eOjRDRcZrd0Vl3no0Q3733eXOZ/ioUc3
6Gw6PE9jLw89umEKLdIlZCMPPbrBwuPYFiNTHnp0w7EvCyd+MuKhRzeYmjje
mK7LQ49u2PNkQKv/CB56KOYbNVhlMIuHHj0wtdP3n5NtDejRA6zMJ6yMhgb0
6IFrX3fRxxc2oEcPqJs+jT2W0oAePRBgl/YqPLIBPXrg0tmLNrKgBvTogXDz
1ZZ6DxrQowcM3INmbHZtQI8emDdh2Vqncw3o0QPauY7bHh9sQI8eeHxh9OcP
WxvQowfccjYP/768AT16QPZMM+vXvw3o0Qvea6/75Og3oEcvRN55mJqh3oAe
vXB429aRiewG9OiFo1MKK8I66tGjF4o2s9K9+fXo0Qta47hL7Irq0aMX3IZ8
E638UY8evbBoqNXUMVH16NELQckRYXVB9ejRC4OeteQG3q9Hj14YuFC2zPp6
PXr0Qubp0qMjz9ajRx/05VyWfNtfjx59kL1vhOFhi3r06IN3d6yLOGb16NEH
u+y8zf1n16NHH/xj5jTfSLcePfqA3T6XHqdWjx59MOxBkPkSRj169AEJzb8Y
31yHHn2QqfPa1Li2Dj364EPWxJ7AnDr06IMQz3kWqol16NEHkkXZYafe16FH
H1yIbI3M9KtDj34Y7G6bPsGzDj36wSjywLNTznXo0Q91ei5u0cfr0KMfeBos
k56ddejRD7sd7LSMzevQox/krdPyjyyoQ49+0B/gE+NrUIce/XBp6FSPhNF1
6NEPhwMnPKnh1KFHP5xlT/Xv7ahFj36YcNGkaSi/Fj364bqdmZl2YS160EiC
Rbd80vdarIdGngw983byx1r0oRGNdwuzJ76oxfpoZHDzk2Gj79aiF414yMuT
2FdqsV4aWR149YXcthb9aIT2wJueZ1WL9dPImgN5vu/W1KInjby06f1ybWEt
5kEjdWtHT9ryTy1+n6GRhrv39MePqcV8aKTKLflSPacWvWlkokq8Y0BHDeZF
I/dd9Up38Grw/oFGtlyNFgwqqMH8aMRr9vHD0Uk12A808oYfGLg7ogbzpBHn
WW+s6f412B804r73v4ZHnjWYL434DM9tn+5cg/1CI8XvjcrjjtVg3jSy7+6b
nSssa7B/aGSC5cnY9JU1mL8i31Jeysq5NdhPNPKrNS8mcVINetCJKJ5zePbI
GvSgEy+r/MH+jBr0oJOzrLNnOc3V6EEnldykusPV1ehBJyYBxyek/KpGDzpR
fJM7NTa2Gj3opJbNfX48tBo96KTJpl34+WE1etBJwNEFE2g3qtGDTlTMdVzI
2Wo83+jEbVhOmaNNNXrQSch51pH3G6vRg05YT0/QahZXoweddJw0Khg4vRo9
6OTSrjvxM3//jvnHg06ej1Rr3zCwGj3oRNPLbe3xrir0oJPuptp+F34VetAJ
rfBqpXdBFXrQifrlKB2/pCr0UDx/ytk/MLwKPehkpLfjnSC/KvSgE1nAmtQA
jyr0oJP0EOGFh05V6EEnV1QeubofrkIPJZKx6pGGw9Yq9FAi+8VVg/eYVaGH
EjlvLfNZYlSFHkqE9uWEx3idKvRQIkbPJkzsGlKFHkrE916O7ePuSvRQIvrh
zo1zCyvRQ4lovbjimBleiR5KpKzOxH6rRyV6KJF1VxyeFh+qRA8lonxRaLZu
aSV6KJFdu2vmxWpXoocSqS+2/za+pwI9lMhRd9f3ToUV6KFEFlY6rMwIr0AP
JaK6usB6hEcFeiiRsOJZCzYeqkAPJRIdlRvmalqBHkokZKtDR8S4CvRQIi1+
uq0FXeXooUQYw2MqpPnl6KFEDI8P9KG9L0cPJfI1c+AaFfdy9FAijYP3ipkH
ytFDiXw2V33ZtbgcPZRJUP0TS55mOXook/xFbJPU9jL0UCbDv/4kL3PK0EOZ
7J+VceXMmzL0UCaGX9zawbUMPZSJg29mUr91GXook0cHxlRELixDD2WSGj3U
Zr96GXook6/+q9YPai5FD2WSGTc9PiSjFD2UyfV3zm9IcCl6KJOOyG0zM66U
oocysV78ds2GnaXooUw4geajMo1L0UOZbL28z9NkWCl6KBODO1apb0Ql6KFM
Vhp8yRiaUoIeyiTvoV3g0ecl6KFM+vys9sQ7lqCHMhGq9zEHWJSghzKJVvF4
uWZ6CXoo8vygtOQGtwQ9FHkcGtryta4YPZTJVI/hkbzYYvRQvL7EJHCAbzF6
MMjdfeu+6NkVoweD2L9gj5hvXoweDHIq0SbYbFIxejCIxC7/wSp6MXowiM00
94JlpUXowSBet4JuLPxYhB4M4mtz/cmU20XowSArmWwYeqgIPRjksvvLTVKT
IvRgkEXdHNUUzSL0YJCPZ2M33GsrRA8GGVK+YqNVViF6MIhd40zJuJBC9GAQ
2WvRrhKXQvRgkOpKoZP7zkL0YJAPZs9c/zUuRA8G4Rdu21SmWogeDKL52Uf3
fGMBejDIRH37n0OSCtCDQbbfdnN79qQAPRikaX3U9ElnC9CDQRiGsQNerStA
DwapsZxcoTOlAD0YJM2wreeecgF6MIjl7LW6yuX56MEkbxKc3h/6lI8eTKKq
Omfbj9v56MEkL4ZpO40/lI8eTDIt51j6KZN89GCSBxEz3saOyUcPJtl/gZOt
1JqHHkxyaMC1x4sz89CDSWY+fxp1LigPPZgk+oedT8ilPPRgkspfpnl52/LQ
g0lKtuU2ds7MQw8mqVX3sR81MA89mCT0YJ9oWn0uejDJzWuvBCQ2Fz2YZNGO
X8LV93PRg0nmPNd0WW+bix5MElLkN2f9ilz0YJLVbWzPFTq56MEkVzaYay7s
zkEPJokIYFtNzstBDybx8zIUqr7JQQ8m4fKNFsn/y0EPJtE0HytP35WDHkzy
7pOu43PjHPRgkmGRto4nVXPQg0VerZNbzxNkoweLzBzfV9CXkI0eLHK+2sDk
68Ns9GARtfvq607bZaMHi3hq8/ZNWp2NHiySeMVzZv7EbPRgEX7b+5FOvVno
wSLrN0X81CrIQg8W6dZ/4B8dloUeLGJouGr3hutZ6MEiRQydjbVWWejBInN8
nhLbf7PQg0XuqW061aaahR4scndl1UF5zi/0YJGeVzvv8l1+oQeLjPfu4RQZ
/UIPFsmvsjSNrs9EDxbpa2e2ed/LRA8WId3ertbLMtGDRXyUDsTod2SgB4vc
uCaUVgdnoAeLXNx/SXp3WwZ6sEhX73zOXG4GerDIjtvBowuj09GDRZ7s2WJ9
8Eg6eqgQ+wUG6U1j0tFDhTjnK7vapqehhwq5OmGFJ88pDT1USNayHuaGqWno
oUICHxk3fSxPRQ8Vwh8n2z/IIxU9VEjBWm2nXYtS0UOF7G29YhQg+YkeKsS6
Szuy+ulP9FAh4WtXtw9f+xM9VIj75FUGpP8Heij2c6Jwzu63P9BDhfwz6IXV
easf6KHYv3aAg+uQH+ihQnpXTSzxjEtBDxUy/M74pbdOpKCHChlTFjnu6rgU
9FAh6ZOjxp749R09VMi5ooUfNjl/Rw8VwtoTd81w2nf0UCFFm1xHK1cmo4cK
sfC5opTukYweKsRuhWXe7UXJ6KFC+tTJsOWSJPRQIbRfJ627nyShB5vsfD15
ToB5EnqwSXC2valZ7zf0YJM7YCMuD/2GHmzF9YjZaWv5DT3YZIPbwE8dA76h
B5uom3/qdfySiB5sIh+iP6jlcCJ6sIlpsPKvA6MT0YNNnoQEHs/6mYAebHLJ
bz3fyCEBPdhEr+/oZg/9BPRgkzf/aSfVFsajB5vM3Bs33/B6PHqwiZfl3TL7
OfH4/ZNNVBIuzNmTFocebLJceHp99uQ49GCTBekHvhm4xqIHm0QZlq5xbohB
DzZxUZVNizGNQQ824V1a4NTi/xU9FPUP+r5hJP0rerDJ1gdxpTOsvqAHm+iP
YKj/GxONHmzSIHfb8O+YaPRgkyPao/ZPcPiMHhyyx+B8MrswCj04ZJ/6GZ1i
oyj04JCuyKfqL7wi0YNDvjTaTN8u+4QeHLI5TtNwwJpP6MEhZYIa26DXH9GD
Q+4e7KhfxPmIHhwyxaIwMWH/B/TgEO4aPS2SFIEeHKKWPEs5ZHwEenDI5bEP
w4c4h6MHhzwzlgzcU/YePTiE5mR2IWzue/TgkHfZLVG8e+/Qg0OGJGmEzuO/
RQ8O0Y+f8vWCfxh6cIj9joW60ZZv0IND1H9FPM8cGYoeHHLRMnRgeVYIenDI
MKeU79/cXqEHhySGT2e8NA1GDw75mPYpdVdfIHpwiJHRx+DhUS/Rg0N+xuov
f37yBXpwSPDRIq8pBgHowSVOh5QK3OueoweXTNk7davwiR96cMnMy/KhZmFP
0YNLltcMHf1W+zF6cMmDlIbGVC9f9OCSH7Yu7tWM++jBJbd84/a8PuONHlxy
YavjrJP8O+jBJS3zdpnmR3igB5e4NpKTifduoAeX6Nnffj7K4Sp6cEkB+2J5
zqeL6MElz8+PEy47b48eXKJ2bfKK04770INL8HcI2l8PLvk/sdQg2g==
         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.008333333333333333], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxV2ndczf3/+PH2HmeVlZSMiMiMC68nhSSUmZ2MspLsmRlCQkJIlNBV2SRJ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         "]]}}}, {}, {}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 1.8665791980238229`}, {0, 5.325}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"u\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 1.8665791980238229`}, {0, 5.325}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 4\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 6\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.075], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.008333333333333333`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6749925605620003`*^9, 3.674992740605*^9, {3.674992965369*^9, 
   3.674992991646*^9}, {3.674993037257*^9, 3.674993061079*^9}, 
   3.674993102899*^9, 3.674993294267*^9, 3.674994048384*^9, {
   3.674995333873*^9, 3.674995362803*^9}, 3.6749967086730003`*^9, 
   3.6750006595769997`*^9, 3.6750009194639997`*^9, 3.675001224058*^9, 
   3.675002214627*^9, 3.6782786201188*^9, 3.6782790719108*^9, 
   3.698381395394*^9, 3.69838218471*^9, 3.698382600067*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ProfileVit.eps\>\"", ",", "desvit", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674995397123*^9, 3.674995407914*^9}}],

Cell[BoxData["\<\"ProfileVit.eps\"\>"], "Output",
 CellChangeTimes->{3.674995408965*^9, 3.6750006630480003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"ListCorrelate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"vitesse", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], "]"}], "/", "0.01"}], "]"}]], "Input",
 CellChangeTimes->{{3.6747382306219997`*^9, 3.6747382477*^9}, {
  3.674738285205*^9, 3.6747383090179996`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.008333333333333333], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxV2XlYjXsXN/A7x5A5KmU8m1AcQ6aEsCKEsBGSsMnQ3JYmUt2lYTdvQyRk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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 1064.}, {0, 0.5000006124288012}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6747382370290003`*^9, 3.6747383099630003`*^9, 
  3.6782786304318*^9, 3.6782790740308*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tps", "[", "1", "]"}], "=", "0"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tps", "[", "2", "]"}], "=", 
  RowBox[{"tinit", "+", 
   RowBox[{
    RowBox[{"h", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"FileGamma", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"FileGamma", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], 
     ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tps", "[", "3", "]"}], "=", 
  RowBox[{
   RowBox[{"tps", "[", "2", "]"}], "+", 
   RowBox[{
    RowBox[{"h", "/", "3"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"FileGamma", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "+", 
      RowBox[{"4", "/", 
       RowBox[{"FileGamma", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "+", 
      RowBox[{"1", "/", 
       RowBox[{"FileGamma", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], 
     ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"tps", "[", "k", "]"}], "=", 
    RowBox[{
     RowBox[{"tps", "[", 
      RowBox[{"k", "-", "2"}], "]"}], "+", 
     RowBox[{
      RowBox[{"h", "/", "3"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], "+", 
        RowBox[{"4", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", 
           RowBox[{"k", "-", "1"}], "]"}], "]"}]}], "+", 
        RowBox[{"1", "/", 
         RowBox[{"FileGamma", "[", 
          RowBox[{"[", 
           RowBox[{"k", "-", "2"}], "]"}], "]"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "4", ",", 
     RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.674401245474*^9, 3.6744014430889997`*^9}, {
   3.674401481816*^9, 3.674401511163*^9}, {3.674406079924*^9, 
   3.6744060817799997`*^9}, 3.6745290582546024`*^9, 3.674994600677*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, 
   3.6983814002419996`*^9, 3.698381851232*^9, {3.698381941982*^9, 
   3.6983819491589994`*^9}, 3.6983821878589997`*^9, 3.6983826039709997`*^9}],

Cell[BoxData["0.19503479238221794`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, 
   3.6983814002419996`*^9, 3.698381851232*^9, {3.698381941982*^9, 
   3.6983819491589994`*^9}, 3.6983821878589997`*^9, 3.698382603975*^9}],

Cell[BoxData["0.22390160498606548`"], "Output",
 CellChangeTimes->{
  3.6744012143529997`*^9, {3.6744013823120003`*^9, 3.674401395916*^9}, {
   3.6744015299820004`*^9, 3.674401535127*^9}, 3.674406432224*^9, 
   3.674471741796*^9, 3.6745290586016026`*^9, 3.6745576606400003`*^9, 
   3.674714079631*^9, 3.674994024551*^9, 3.674994055738*^9, 3.674994148083*^9,
    3.674994193177*^9, 3.674994602127*^9, 3.675001230211*^9, 
   3.675002218803*^9, 3.6782786321138*^9, 3.6782790753618*^9, 
   3.6983814002419996`*^9, 3.698381851232*^9, {3.698381941982*^9, 
   3.6983819491589994`*^9}, 3.6983821878589997`*^9, 3.698382603982*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tabtps", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"tps", "[", "i", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"des", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tps", "[", "k", "]"}], ",", 
          RowBox[{"s0", "+", 
           RowBox[{"k", " ", "h"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Length", "[", "FileGamma", "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "->", "\"\<Times\>\""}], ",", "12"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"s\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\""}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{"s0", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "tinit"}], ")"}], " ", "/", "a"}]}], " ", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "3"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<(a)\>\"", ",", "14"}], "]"}], ",", 
       RowBox[{"Scaled", "[", 
        RowBox[{"{", 
         RowBox[{"0.1", ",", "0.9"}], "}"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 CellChangeTimes->{{3.674994059425*^9, 3.674994066933*^9}, {3.674994134277*^9,
   3.674994144508*^9}, {3.67499420802*^9, 3.674994218811*^9}, {
  3.674994287916*^9, 3.674994304627*^9}, {3.6749945129630003`*^9, 
  3.674994520703*^9}, {3.674994577651*^9, 3.67499469562*^9}, {
  3.674994728869*^9, 3.674994758707*^9}, {3.674994788994*^9, 
  3.674994826995*^9}, {3.674994861763*^9, 3.674994864499*^9}, {
  3.698473761793*^9, 3.698473780516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.674401540975*^9, 3.674401584967*^9}, {3.674406462454*^9,
    3.674406525742*^9}, {3.674468922807*^9, 3.674468923031*^9}, {
   3.6745236140116024`*^9, 3.674523614251602*^9}, {3.6745242133616023`*^9, 
   3.6745242138486023`*^9}, 3.674552896487*^9, {3.6745530048380003`*^9, 
   3.674553094742*^9}, {3.674557687903*^9, 3.674557695582*^9}, {
   3.6749941606140003`*^9, 3.6749941770480003`*^9}, 3.698381414272*^9, {
   3.6983818998099995`*^9, 3.698381935029*^9}, {3.6983819828879995`*^9, 
   3.69838201643*^9}, {3.698382612878*^9, 3.69838264295*^9}, 3.69847377426*^9}
  ],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], 
      StyleBox[PointBox[CompressedData["
1:eJw123dczd8fwPG7723fGaGEJCE7mef9k4QiRQopsjJCVlSSUcjIyEhoIDIz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        "]],
       FontFamily->"Times"]}, {}}, {}, {}, {{}, {}}}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVxXk41HkcAODB8NVUy6DpV1LUmJR62F2JLX0+1S6VpMgVKQZRGrKVa4Xk
NpOr1NooLXLUPo12RNeQNCpaEespd7LjPpOYZnf/eJ9XzzPAzluRRqPZ/Of/
P1vzru0PCNyWbhA2YXe/AeK81hq85uyDuJNvE3OnGqB+5MNxPscdQoTGekPG
r2GsbGeKP4cHblv7bWOLXsN51uQKN8450DAobnG1+QtePt/TZ88RwLstS00E
2xoh4PrZOltODvhzx0cmdJugKiXlgQ3nDgiE+V4P+1pAWSWISI8/gaPp4aHX
mJ2wO9Ij9k/H53CQpFsEuPRCeah3e35jAyTRM/36Wf3QduiEUVBwEyTk7S2O
0x8EphXfpwpbQSzgdb8dGQH1Zm/hZtd30MW/ySq4MA5rdP2LYj07QVrG0bBJ
mASz9pMvt6d3g3p0h+pev2mo+hK1tzm7F67kjCd2BM2A7xOJ5PH5PkCuuUqd
yyxc5RYuX3K0HwIJ5bxq8xxsdO7+9NVbCvT5AyYLLGTQMWnbgLsHQZQlXmit
K4eJzmXGLIdh6Nv+zFT9Mg1TS8KOOTmNwr3CM2+MsxSQo6ZqE5I9Bhoe4hOy
OEUUBUaVCHLHIa/a7IVmshI262eQA+kTIA625rRE0JEd02Rw+OokqL9Ntuq5
oIzm+ztNcrOnQD8vy54dr4LtgbHb+CnTUFdtcVgjhKDQ3GXxs7RPkJPM3LAn
QhVZjs/bbsXOgOKtyM8bTy1A6KGlVZ/+DIYmFX9YHWXgVZbvYk7ILMT66m4o
4S7E8zl+8ZuOfwHemF5BpcMivNZwpVYQOAeJugf6NN0WYwQvY0wnaB78xNZq
Nw9/g4MeBpSLpwxay7pMO2zUMFk2QO/w+QoPChvTvl2njpVDVqPfHJKD/Soa
eZGnji36Zj0/sGn4al/mKdkyJvqu4xpl5NPQ3e7JY4dsJlY5uoZvX6mA5ZHl
DLqWBn7vPFCkdUMBDaItzVsva6B/jGWrhbYiepbm+dCYmpjgo/pFIUMRz130
SqxJ0MRHOh7yAS0lFFo+EtxmaGHF1zil9QIlvLO2N30oRgsbynYO8Jl0rHmf
G7qfLMFnuj61Kel0rNxd7WCbsAQvlDvc6GYoY1jXXePfaSx0W/3e3ZWvjHbW
ZiM6MSycExlpGxIVHOtMLh6eZ+EvStJXl86pYNCGn9ycTy9FFtvcQ59GcJHN
pbH+6aUYzHOcYoQS9M8SxtTzKFxh6iXhhBPUOCJ2kgZSKJad+m1HBEERp8FQ
+WcKGXz+j2HRBGkiadPWYApzSmoypYkEM5t12aWRFNb+890mya8EHzIv1iSl
UqjFVTsb+5AgI+WE8i4hhRXrdfbceEzwjn1oG/cehe4T61c+EhM8qB1/O1JE
4a1oy9qpGoI5xXkO5ZUUbrkewfKqJ2hc15bPeUqhZ/ugaEcHQWeVXZbKzRSS
/Nkk9y6C8/UOy/VaKCz1J0fCegjmXeKObP2bwk9zq4nwI8EhduTl0+8pTFp+
yElvlGDUTtHH3g8UGvUcM7QYJ8heWFMp/0hhc9EZufMkwRdvGgXaUgpXmqcV
ps4Q1PIcNrUfpvApLTe8dJbg/XVzjIBRCn0lpbaSOYLu46qdSeMULkqtXPNB
RlCxglVWMEnhXSfJjFxOsCCKHV89TeG/7gYmcg==
       "]]}}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times", 12},
  DisplayFunction->Identity,
  Epilog->InsetBox[
    FormBox[
     StyleBox["\"(a)\"", 14, StripOnInput -> False], TraditionalForm], 
    Scaled[{0.1, 0.9}]],
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"s\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\"", TraditionalForm], None}, {
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6744015417860003`*^9, 3.674401585866*^9, {3.674406434427*^9, 
   3.674406463814*^9}, {3.6744064989630003`*^9, 3.674406526631*^9}, {
   3.67446891675*^9, 3.674468923367*^9}, 3.674469617216*^9, 
   3.6744829009834003`*^9, {3.6745236027306023`*^9, 3.6745236146066027`*^9}, {
   3.6745242046796026`*^9, 3.6745242146106024`*^9}, 3.6745430990756006`*^9, {
   3.6745528921549997`*^9, 3.674552896891*^9}, {3.674553021333*^9, 
   3.674553049718*^9}, {3.674553082395*^9, 3.674553095638*^9}, {
   3.674557690033*^9, 3.674557695924*^9}, {3.674994154193*^9, 
   3.6749941786610003`*^9}, 3.67500124404*^9, 3.6782786360108004`*^9, 
   3.6782790801598005`*^9, {3.6983814051679997`*^9, 3.698381414679*^9}, {
   3.69838183449*^9, 3.698381855757*^9}, 3.6983819529799995`*^9, {
   3.698381996186*^9, 3.69838201672*^9}, 3.6983821922179995`*^9, {
   3.6983826062799997`*^9, 3.698382643441*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<Comparaison1.eps\>\"", ",", "des", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674553106828*^9, 3.674553122342*^9}, 3.674557994455*^9, 
   3.698382651995*^9}],

Cell[BoxData["\<\"Comparaison1.eps\"\>"], "Output",
 CellChangeTimes->{3.674553125358*^9, 3.674557997682*^9, 
  3.6749945492790003`*^9, 3.698382654299*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.675002546646*^9, 3.67500255109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "@", "k"}], ";", "\[IndentingNewLine]", 
    RowBox[{"dt", "=", 
     RowBox[{"h", "/", 
      RowBox[{"detailG", "[", 
       RowBox[{"[", "k", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"k", ">", "1"}], ",", 
      RowBox[{"dudt", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"vitesse", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"{", "0", "}"}]}], "]"}]}], " ", "+", 
            RowBox[{"vitesse1", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], " ", ")"}], "/", "dt"}], ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"dudt", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"vitesse", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], " ", "+", 
            RowBox[{"vitesse1", "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], " ", ")"}], "/", "dt"}], ",", 
         RowBox[{"-", "2"}]}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"inter", "=", 
     RowBox[{"Interpolation", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"i", " ", "h"}], ",", 
          RowBox[{"dudt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"vitesse1", "[", 
             RowBox[{"[", "k", "]"}], "]"}], "]"}], "-", "2"}]}], "}"}]}], 
       "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"zlim", "=", 
     RowBox[{
      RowBox[{"inter", "[", "\"\<Domain\>\"", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tableTau", "[", "k", "]"}], "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"1", "-", 
            RowBox[{"inter", "[", "z", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "0", ",", "zz"}], "}"}]}], "]"}], ",", "zz"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zz", ",", "0", ",", "zlim", ",", 
         RowBox[{"zlim", "/", "50"}]}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "2", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.674827948160738*^9, 3.6748279846487617`*^9}, {
   3.6748280291469955`*^9, 3.6748280394814577`*^9}, {3.674828196162238*^9, 
   3.674828245309845*^9}, {3.6748285729105873`*^9, 3.674828588627369*^9}, {
   3.674828631559437*^9, 3.67482864134344*^9}, {3.6748832015590982`*^9, 
   3.674883205627924*^9}, {3.6748832825173206`*^9, 3.6748832865099077`*^9}, {
   3.6750007696549997`*^9, 3.675000792057*^9}, {3.675000864815*^9, 
   3.675000869752*^9}, {3.675001293097*^9, 3.675001300608*^9}, 
   3.675001390273*^9, 3.675002230799*^9, {3.6750023940950003`*^9, 
   3.675002446263*^9}, {3.675002501561*^9, 3.675002530329*^9}, {
   3.6750025807530003`*^9, 3.6750026400109997`*^9}, {3.675002832707*^9, 
   3.675002872527*^9}, 3.675003056002*^9, 3.6782792370928*^9, 
   3.698473789251*^9}],

Cell[CellGroupData[{

Cell[BoxData["2"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792407568*^9}],

Cell[BoxData["3"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792454248*^9}],

Cell[BoxData["4"], "Print",
 CellChangeTimes->{
  3.675002511509*^9, {3.675002611667*^9, 3.6750026407279997`*^9}, 
   3.675002876717*^9, 3.675003058865*^9, 3.6782786390448003`*^9, 
   3.6782790835878*^9, 3.6782792577788*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"desTau", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"tableTau", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2", ",", "4"}], "}"}]}], "]"}], ",", "  ", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "teps"}],
       "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[\"\[Tau]\", \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6748286745998344`*^9, 3.6748287354485617`*^9}, {
   3.675001426007*^9, 3.675001461783*^9}, {3.6750024190699997`*^9, 
   3.675002424955*^9}, {3.675002745388*^9, 3.675002766949*^9}, 
   3.675002899296*^9, {3.675002942023*^9, 3.6750029871029997`*^9}, {
   3.6782792456438003`*^9, 3.6782792462358003`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.01388888888888889], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJxdkX0s1HEcx+/OuVCHnCVnq515yLSxsKs79fkpQqZk7uaU8lCxFKpZycLK
WMpzIXkKm6dJkdFEFAkZxz2fe0B5KOnceUgOZfv+1Xf77Lvvvp/v+/N+v760
sBj/ywQcDuf0r7b3/1eZPsbUC8qGoWCfzzuO1kNDJg4zDixH53b45ZzcH5FY
A0GphwW913ug0a+SWnv6FbofBGbs9AtDzhsopzrIrEhcINrblhgFt6F+HqR4
RWWc57wDitpt+ApfCPhvMie2TRd6L4X5liSunPoB0voDumuq5KAzG1lar9+D
9CagZXS3xErdC/dGmjnLbyeBIz2mbR3rQ/pfwbQvwkbU0A901w7/fNo0uDaH
ZW4mDaJ5M+DSK56o8x4CVfUnH/rDOdgINK8INxhG838AZ3OAKQ0ZgTrKiLtI
NQ8kpeZIMZ2L/CwAK9qZ56Y/Ck3v50tdD6pgOtVDWcUfRf4WgaWZscwqHoOs
uBsWZOUi+BlYuMwG85BfNTSJlq3TzfkQZb9SIMvTQFF3x/2zw3zkfwk4bL1G
xyQBeE3cNX3puQwe1bpCsp0Q5VmB0CZh/NgXIVgXbGUnrq+AqTK2KPmqCOVb
BdNN1iyJIAaCbwr5TONvEHzfee1CnhjlXYPU9tjG3H0SUBD00/eH/wHnJMGu
8koJyr8OCwzvc48spdDelkFS7dGCkW3XWtRzKeKhBUGtSZ2n4TgURps86BrY
AAqnwdghYRzx2YQiTT7dfXIc4qy2DW7BKWVa1ZMTMsQLh7EdjXOYZTKw+0nu
dHyGw8odAg5cWpYhfniM2Rn/kXZSDmZeftq9t/BYwnFMXJgjRzzxmOYmdXJd
KAdSZS4D70vAKkRPp0LNFYgvAXsczXBaZSlgaYN3Z85GB2NIw2s0GQrEWwd7
fTuAHdOtgKlAs1YujojlUnoOlagUiD8RC5ltY8vISuBuy0mImEBdezGSpkT/
oYv9BZtxjAk=
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.01388888888888889], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxdkXss1WEYx49LuTvuhDmjy1AyZSWV5ykmTI51poSmiZAiqVBCo4TEIR1j
YSkyRGcuC606IpfioI7jcM7vrJHbLJcwt6T2/tW7vXv37H3f7/P9fh7TgIhT
QbI0Gm3/5v57/r8+hscXTzhzIJN1fQdn4z0w4gpMGx3KSM0H4b7nv1iBr+H0
nVf1AQmDIH8mhmti3EDupRC5VFrow2uGqBD2dByMwnq1k+1Fiw/k/QSwBXN5
tSMtYJ/dleDybhoMKjvjrNlt5P8MzNoKjdStOkBGIquUxpgHZm89q6K+i+gt
QLPVRvyDPd0wOsfoi/Bfgo4KpZ9lznyivwxRv70PToX1QrvC0QKvolXIPqec
/+heH+m3DhlG9TSLnH6oNPYJPExtgG++piD48VfSn4b0s1Zi9dRv0J7X9CSL
LouuKyY9S1cFxI8cpq8c52q6D4D9drfbSdbyWJNTTDtvKCT+tqAjL714eUgI
lVVC/5vMrSj+slaiwB4kfhUw3TtztuWQCEzsgp1CIxSxvFTmc7RARPwroXIs
w/ZW8BBk8hbM/TKVsShtnLV3eojkUUGjJrtumZBhkDmZrMasVsXctl75MOEw
yaeGff2rSWMOYoga0Jo71qOO3cG1HisFYpKXjju9np2wnBHDfI1nWH60BtZO
irppRyQkvwbyFPg2iokS2L3IEeekaCJr9UB4Z7OE8NDC8Yc3jPhzEtgUY2Zw
tDCDK9EvMqMIH22kS8z5b9wpeJq4i3e/TBsrFxfCCyMpwksH61KzB1vZFAha
r9gmNuigm+oIp6SKIvx0cT3Zy+RFKwV0lbrS2E+6WFIbamcjoghPPfz+1jfr
5RQFLp5rBlEDeuhxKbUrcIUifPUxIITL9JOTwt1cx/TLY/q41XryQoyilPA2
QEvXfM9yVSk0itLWg5YMkJurXaOuISX8t6GbGeNaq5YU5v+NyxCHUlwLfuhI
yTwM8Q/ThX9G
         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.01388888888888889], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQjQ7qNTIVQyrn2J+N9T7Bbnva3j5DIdkycw2Uf9ve
n3nhJk+rrfZRbRbXjuY+sU+VEt/Dqb4HKv/aPkSb17Cw8qD9Ain9uypsH+3z
Dx5kVTt9BKr+i71g8hoNVdYT9sKfHM+nXf1ub2Qmu9xB5TRU/2/7y7Lduxar
nrNvPxlycMWSf/aaO61f5DRfgJrH6HDa/O2pl48u2tde2Bz5dSeTQ1/rkb8l
Bpeh5rM4eM6cPzs/+4q9uc3eoGmKbA6T1Nxe5k2+CrWP3aGpevUnqxXX7D8s
P+Zt3snp4PLLM+jMyutQ+7kdnFZUWHvOuGG/SviCy40PPA4KbZpPGEtuQt3D
5xDX8iYnx/aW/ab9b+bZ6Ag4fJGrSlf4egvqPkEHxkc+Mpdm37bvLy2U5n0g
6MCizrve1+gO1L1CDoWNrA5FO+/YZ2t/m353srCDZVyImq7RXaj7RRx27amJ
Lp17197jYZXIOndRBx3/Kbruf+5C/SPmoJFq6bnA/5696vT/E+p+izmclp6m
UTPjHtR/4g4eH599uHD9nj2Tbwuv/3oJB4eZMw738N2H+lfSoZ3hV8tk2/v2
95k4u+STpRxWVNqK7029D/W/tEM741GWK+337Xfv6GX7ICbjEFV2dfKUJfeh
4SHjoG72z2rNnvv2M/KEmg+cknWoZhLP3nnhPjR85BwO12gt8354375UBeRA
eYc93gnXHr+7Dw0vBYc1nkU3vvy8b6/5lnefwUwFhztbV0oWMT6Ahp+iQ/Ac
pzJW1gf24h4BfySKFR3ufVtrcZv9ATQ8FR0+Wb8/KcL1wJ5t8SQrRl8lhzK9
ZwfPcT+Ahq+SQ+zmhlRF3gf2X/5eqXippuxgZRunpsj3ABreyg5H9HZ/vgfk
P44Q336RQcXB99wDjUz+B9DwV3G4mHc6/DSQfxFk3C0Vh3eBc1j5BB5A40PV
AQASXG2g
         "]]}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.504078089564781}, {0, 10.64}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\\"\[Tau]\\\", \
\\\"^\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", 18, StripOnInput -> False], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, Method -> {}, 
     PlotRange -> {{0, 0.504078089564781}, {0, 10.64}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 4\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 6\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.01388888888888889`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[0.5, 0, 0.5]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.01388888888888889`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.01388888888888889`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "RGBColor[1, 0, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.674828693819915*^9, 3.6748287371571302`*^9, {3.675001441113*^9, 
   3.675001462705*^9}, 3.675002796612*^9, {3.675002965855*^9, 
   3.675002988558*^9}, 3.6750031430559998`*^9, 3.6782791599678*^9, 
   3.6782792764908*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<ProfileTau.eps\>\"", ",", "desTau", ",", "\"\<EPS\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674995397123*^9, 3.674995407914*^9}, {3.675003168638*^9,
   3.675003175078*^9}}],

Cell[BoxData["\<\"ProfileTau.eps\"\>"], "Output",
 CellChangeTimes->{3.674995408965*^9, 3.6750006630480003`*^9, 
  3.675003175973*^9}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1904, 1118},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
Magnification:>1.2 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 719, 21, 352, "Text"],
Cell[CellGroupData[{
Cell[1302, 45, 112, 1, 76, "Section"],
Cell[1417, 48, 124, 2, 51, "Input"],
Cell[CellGroupData[{
Cell[1566, 54, 6665, 174, 1012, "Input"],
Cell[8234, 230, 423, 6, 84, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[8706, 242, 687, 13, 58, "Section"],
Cell[CellGroupData[{
Cell[9418, 259, 9424, 238, 1053, "Input"],
Cell[18845, 499, 1029, 15, 44, "Output"],
Cell[19877, 516, 1028, 15, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20942, 536, 9078, 213, 823, "Input"],
Cell[30023, 751, 1219, 18, 44, "Output"],
Cell[31245, 771, 1172, 17, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32454, 793, 861, 21, 80, "Input"],
Cell[33318, 816, 3691, 72, 340, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37046, 893, 2105, 63, 132, "Input"],
Cell[39154, 958, 392, 6, 44, "Output"],
Cell[39549, 966, 389, 6, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39975, 977, 2030, 53, 192, "Input"],
Cell[42008, 1032, 33752, 570, 364, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75797, 1607, 193, 4, 44, "Input"],
Cell[75993, 1613, 93, 1, 44, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[76135, 1620, 825, 19, 60, "Section"],
Cell[CellGroupData[{
Cell[76985, 1643, 9997, 246, 957, "Input"],
Cell[86985, 1891, 159, 2, 37, "Output"],
Cell[87147, 1895, 180, 2, 37, "Output"]
}, Open  ]],
Cell[87342, 1900, 1186, 28, 134, "Input"],
Cell[CellGroupData[{
Cell[88553, 1932, 10044, 233, 710, "Input"],
Cell[98600, 2167, 1602, 24, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100239, 2196, 1240, 28, 62, "Input"],
Cell[101482, 2226, 11274, 303, 37, "Output"],
Cell[112759, 2531, 377, 7, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113173, 2543, 2206, 64, 67, "Input"],
Cell[115382, 2609, 50829, 920, 418, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166248, 3534, 191, 4, 37, "Input"],
Cell[166442, 3540, 112, 1, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166591, 3546, 408, 11, 37, "Input"],
Cell[167002, 3559, 13763, 237, 291, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180802, 3801, 2029, 62, 110, "Input"],
Cell[182834, 3865, 607, 9, 37, "Output"],
Cell[183444, 3876, 621, 9, 37, "Output"],
Cell[184068, 3887, 621, 9, 37, "Output"]
}, Open  ]],
Cell[184704, 3899, 2750, 78, 138, "Input"],
Cell[CellGroupData[{
Cell[187479, 3981, 614, 9, 37, "Input"],
Cell[188096, 3992, 19192, 332, 308, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207325, 4329, 232, 5, 37, "Input"],
Cell[207560, 4336, 155, 2, 37, "Output"]
}, Open  ]],
Cell[207730, 4341, 85, 1, 37, "Input"],
Cell[CellGroupData[{
Cell[207840, 4346, 3679, 93, 182, "Input"],
Cell[CellGroupData[{
Cell[211544, 4443, 224, 4, 26, "Print"],
Cell[211771, 4449, 224, 4, 26, "Print"],
Cell[211998, 4455, 224, 4, 26, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[212271, 4465, 1710, 47, 67, "Input"],
Cell[213984, 4514, 19486, 392, 413, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233507, 4911, 234, 5, 37, "Input"],
Cell[233744, 4918, 134, 2, 37, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

