(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    315261,       5911]
NotebookOptionsPosition[    313158,       5836]
NotebookOutlinePosition[    313528,       5852]
CellTagsIndexPosition[    313485,       5849]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Electronic supplement to

@article{
ancey16jnnfm,
   Author = {Ancey, C. and Bates, B.M.},
   Title = {Setting in motion and entraining a Herschel-Bulkley fluid},
   Journal = {Journal of Non-Newtonian Fluid Mechanics},
   Volume = {submitted},
 Year = {2016} }

Copyright C. Ancey May 2016\
\>", "Text",
 CellChangeTimes->{{3.6782725741048*^9, 3.6782726077578*^9}}],

Cell[CellGroupData[{

Cell["Numerical solution to (11) and (12)", "Section",
 CellChangeTimes->{{3.672414874233*^9, 3.672414885252*^9}, {
  3.6724150965109997`*^9, 3.672415104991*^9}, {3.672463062261204*^9, 
  3.6724630754152036`*^9}, {3.6726358289746013`*^9, 3.6726358308956013`*^9}, {
  3.6782724697928*^9, 3.6782724951958003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"UserDirectory", "=", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\"\<FileName\>\"", "/.", 
      RowBox[{"NotebookInformation", "[", 
       RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ")"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", "UserDirectory", "]"}], ";"}]}], "Input"],

Cell[BoxData["\<\"D:\\\\Echange\\\\JNNFM\\\\article_1(theory)\\\\figshare\\\\\
\"\>"], "Output",
 CellChangeTimes->{3.6937460331184998`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "parameters", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", "0"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"lower", " ", "bound", " ", "of", " ", "the", " ", "domain"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", "1."}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"upper", " ", "bound", " ", "of", " ", "the", " ", "domain"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nb", "=", "1000"}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"number", " ", "of", " ", "nodes"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"De", " ", "=", "0.1"}], ";"}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"Deborah", " ", "number"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bi", " ", "=", "0.5"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Bingham", " ", "number"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rey", " ", "=", " ", "10"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"Reynolds", " ", "number"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]", "=", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Rey", " ", "De"}], "]"}]}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"characteristic", " ", "velocity"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Eta]", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Rey", " ", "/", "De"}], "]"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "0.33"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"shear", " ", "thinning"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"F", "[", "contrainte_", "]"}], ":=", " ", 
    RowBox[{"contrainte", "*", 
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Abs", "[", "contrainte", "]"}], "-", "Bi"}], ")"}], "/", 
         " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Abs", "[", "contrainte", "]"}], "+", 
            RowBox[{"10", "^", 
             RowBox[{"-", "8"}]}]}], ")"}], "^", "n"}]}]}], " ", "]"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "n"}], ")"}]}]}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"source", " ", "term"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"tc", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Rey", " ", "De"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nbS", "=", "10000"}], ";", 
    RowBox[{"(*", " ", 
     RowBox[{"number", " ", "of", " ", "simulations"}], " ", 
     "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.672551859274293*^9, 3.672551859570693*^9}, {
   3.6725520020457435`*^9, 3.6725520022329435`*^9}, {3.6725615306714315`*^9, 
   3.6725615309834323`*^9}, {3.672561850977994*^9, 3.672561859121208*^9}, {
   3.67258101837*^9, 3.672581019796*^9}, 3.672583986579*^9, 
   3.6725854915629997`*^9, {3.672586137042*^9, 3.672586146226*^9}, 
   3.672586262274*^9, 3.672587054058*^9, {3.672587633282*^9, 
   3.672587637666*^9}, {3.672588748019*^9, 3.6725887561289997`*^9}, {
   3.672589011594*^9, 3.672589025802*^9}, {3.6725907211689997`*^9, 
   3.6725907305369997`*^9}, {3.672627642578601*^9, 3.6726276430726013`*^9}, {
   3.672638236083601*^9, 3.672638281338601*^9}, {3.672638368203601*^9, 
   3.6726384050596013`*^9}, {3.672638467300601*^9, 3.672638484416601*^9}, {
   3.6726387244576015`*^9, 3.672638747601601*^9}, {3.672638898288601*^9, 
   3.6726388985926013`*^9}, 3.6726389368166013`*^9, 3.672639247608601*^9, {
   3.672640899583601*^9, 3.672640903670601*^9}, 3.672641185760601*^9, 
   3.6726414600326014`*^9, {3.672641504873601*^9, 3.672641505439601*^9}, {
   3.672642086528601*^9, 3.6726421338236012`*^9}, {3.6726448235186014`*^9, 
   3.6726448587576013`*^9}, {3.672651720751601*^9, 3.672651739765601*^9}, {
   3.6726539387506013`*^9, 3.6726539402546015`*^9}, {3.672655652222601*^9, 
   3.6726556615736012`*^9}, {3.672656728845601*^9, 3.672656749292601*^9}, {
   3.6726575556056013`*^9, 3.6726575705726013`*^9}, {3.6726576684616013`*^9, 
   3.6726576841246014`*^9}, 3.672657879621601*^9, {3.6726580544926014`*^9, 
   3.6726580692616014`*^9}, {3.672658409325601*^9, 3.672658419196601*^9}, {
   3.672658562965601*^9, 3.672658575764601*^9}, {3.6782722519788003`*^9, 
   3.6782724110718*^9}, {3.6938005919042*^9, 3.6938005993082*^9}, {
   3.6938018218532*^9, 3.6938018291661997`*^9}, 3.6938026267752*^9, {
   3.6938883532251997`*^9, 3.6938883708002*^9}, 3.6938898161521997`*^9, 
   3.6939020433078003`*^9}],

Cell[BoxData["10.`"], "Output",
 CellChangeTimes->{
  3.672644869281601*^9, {3.6726517253096013`*^9, 3.6726517405116014`*^9}, {
   3.672653917788601*^9, 3.6726539419876013`*^9}, {3.6726556525566015`*^9, 
   3.6726556659976015`*^9}, {3.672656730450601*^9, 3.672656750762601*^9}, {
   3.672657561163601*^9, 3.672657571038601*^9}, {3.6726576696156015`*^9, 
   3.6726576852876015`*^9}, 3.672657879877601*^9, {3.672658054797601*^9, 
   3.6726580695076013`*^9}, 3.6726584199086013`*^9, {3.6726585645076013`*^9, 
   3.672658576578601*^9}, 3.672659991825601*^9, 3.6937459609885*^9, 
   3.6937460336045*^9, 3.6938006008782*^9, 3.6938018430092*^9, 
   3.6938026274632*^9, {3.6938883572702*^9, 3.6938883786001997`*^9}, 
   3.6938898164681997`*^9, {3.6939020289968*^9, 3.6939020435688*^9}}],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{
  3.672644869281601*^9, {3.6726517253096013`*^9, 3.6726517405116014`*^9}, {
   3.672653917788601*^9, 3.6726539419876013`*^9}, {3.6726556525566015`*^9, 
   3.6726556659976015`*^9}, {3.672656730450601*^9, 3.672656750762601*^9}, {
   3.672657561163601*^9, 3.672657571038601*^9}, {3.6726576696156015`*^9, 
   3.6726576852876015`*^9}, 3.672657879877601*^9, {3.672658054797601*^9, 
   3.6726580695076013`*^9}, 3.6726584199086013`*^9, {3.6726585645076013`*^9, 
   3.672658576578601*^9}, 3.672659991825601*^9, 3.6937459609885*^9, 
   3.6937460336045*^9, 3.6938006008782*^9, 3.6938018430092*^9, 
   3.6938026274632*^9, {3.6938883572702*^9, 3.6938883786001997`*^9}, 
   3.6938898164681997`*^9, {3.6939020289968*^9, 3.6939020435738*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm", "Subsection",
 CellChangeTimes->{{3.672545147742801*^9, 3.6725451785678015`*^9}, 
   3.6725795180348015`*^9, 3.672588114873*^9, {3.6782724592228003`*^9, 
   3.6782724597908*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Initial", " ", "values"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"s0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tau0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v0", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"dz", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "-", "a"}], ")"}], "/", "nb"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"mesh", " ", "size"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"dt", "=", 
    RowBox[{
     RowBox[{"dz", "/", " ", "\[Lambda]"}], " ", "/", "2"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"time", " ", "step"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "times", " ", "at", " ", "which", " ", "we", " ", "plot", " ", "the", " ",
      "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"tps", "=", 
    RowBox[{"{", " ", 
     RowBox[{
     "0.20", ",", "0.21", ",", "0.22", ",", "0.23", ",", "0.24", ",", 
      "0.25"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"tps", "=", 
    RowBox[{"{", 
     RowBox[{
     "0.1", ",", "0.2", ",", "0.5", ",", "1", ",", "2", ",", "5", ",", "10"}],
      "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"tps", "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.1", ",", "0.2", ",", "0.5", ",", "1", ",", "2", ",", "5", ",", 
       "10"}], "}"}], "/", "tc"}]}], "\[IndentingNewLine]", 
   RowBox[{"index", "=", 
    RowBox[{"Round", "@", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"tps", "/", "dt"}], " ", "/", "2"}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.672588120244*^9, 3.672588147889*^9}, {3.672588360585*^9,
    3.672588392242*^9}, {3.672588770875*^9, 3.672588772057*^9}, {
   3.672588982321*^9, 3.672588998929*^9}, {3.672589151946*^9, 
   3.672589155507*^9}, {3.67259066098*^9, 3.672590690729*^9}, {
   3.672627635600601*^9, 3.672627637227601*^9}, {3.672638551338601*^9, 
   3.672638551701601*^9}, {3.672638919144601*^9, 3.6726389294086013`*^9}, {
   3.672641485120601*^9, 3.672641493088601*^9}, {3.6726421098096013`*^9, 
   3.672642119936601*^9}, {3.6726424494486012`*^9, 3.672642452328601*^9}, {
   3.6726539076646013`*^9, 3.672653909906601*^9}, {3.6782725175598*^9, 
   3.6782725514318*^9}, {3.6938017632612*^9, 3.6938017636742*^9}, {
   3.6938018339412003`*^9, 3.6938018378842*^9}, 3.6938898051142*^9, {
   3.6939020324578*^9, 3.6939020354418*^9}}],

Cell[BoxData["0.001`"], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357028*^9}],

Cell[BoxData["0.0005`"], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357058*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.2`", ",", "0.21`", ",", "0.22`", ",", "0.23`", ",", "0.24`", ",", 
   "0.25`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357088003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1`", ",", "0.2`", ",", "0.5`", ",", "1", ",", "2", ",", "5", ",", "10"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357138*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1`", ",", "0.2`", ",", "0.5`", ",", "1.`", ",", "2.`", ",", "5.`", ",", 
   "10.`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357198*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100", ",", "200", ",", "500", ",", "1000", ",", "2000", ",", "5000", ",", 
   "10000"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6937460368655*^9, 3.6938006033022003`*^9, 3.6938018455402*^9, 
   3.6938026299732*^9, {3.6938883587942*^9, 3.6938883800922003`*^9}, {
   3.6938898108532*^9, 3.6938898183472*^9}, 3.6939020357228003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ind", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"ProgressIndicator", "[", 
    RowBox[{"Dynamic", "[", "ind", "]"}], " ", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"outcomeVit", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"outcomeTau", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s", "=", "s0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "r0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v", "=", "v0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tau", "=", "tau0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temps", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ind", "=", 
       RowBox[{"k", "/", "nbS"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ss", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"s", "+", 
          RowBox[{"dt", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"Rey", " ", "De"}], "]"}]}], "-", " ", 
               RowBox[{
                RowBox[{"1", "/", "De"}], "*", "  ", 
                RowBox[{"F", "[", "#", "]"}]}]}], " ", "&"}], "/@", "tau"}], 
            ")"}]}]}], ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rr", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"r", "-", 
          RowBox[{"dt", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"1", "/", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"Rey", " ", "De"}], "]"}]}], "+", " ", 
               RowBox[{
                RowBox[{"1", "/", "De"}], "*", "    ", 
                RowBox[{"F", "[", "#", "]"}]}]}], " ", "&"}], "/@", "tau"}], 
            ")"}]}]}], ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"tautau", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"rr", "+", "ss"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"vv", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "rr"}], "+", "ss"}], ")"}], "/", "2"}], "/", 
        RowBox[{"Sqrt", "[", "\[Lambda]", "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"temps", "+=", "dt"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sss", "=", 
       RowBox[{"ss", "+", " ", 
        RowBox[{"dt", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"Rey", " ", "De"}], "]"}]}], "-", " ", 
             RowBox[{
              RowBox[{"1", "/", "De"}], " ", "*", 
              RowBox[{"F", "[", "#", "]"}]}]}], " ", "&"}], "/@", "tautau"}], 
          ")"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rrr", "=", " ", 
       RowBox[{"rr", " ", "-", " ", 
        RowBox[{"dt", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"Rey", " ", "De"}], "]"}]}], "+", " ", 
             RowBox[{
              RowBox[{"1", "/", "De"}], "*", "  ", 
              RowBox[{"F", "[", "#", "]"}]}]}], " ", "&"}], "/@", "tautau"}], 
          ")"}]}]}]}], ";", "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
      RowBox[{"PrependTo", "[", 
       RowBox[{"rrr", ",", 
        RowBox[{"First", "@", "sss"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"sss", ",", 
        RowBox[{"-", 
         RowBox[{"Last", "@", "rrr"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"tautautau", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"rrr", "+", "sss"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"vvv", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "rrr"}], "+", "sss"}], ")"}], "/", "2"}], "/", 
        RowBox[{"Sqrt", "[", "\[Lambda]", "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"temps", "+=", "dt"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"s", "=", "sss"}], ";", "\[IndentingNewLine]", 
      RowBox[{"r", "=", "rrr"}], ";", "\[IndentingNewLine]", 
      RowBox[{"tau", "=", "tautautau"}], ";", "\[IndentingNewLine]", 
      RowBox[{"v", "=", "vvv"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "@", 
          RowBox[{"Cases", "[", 
           RowBox[{"index", ",", "k"}], " ", "]"}]}], ">", "0"}], ",", 
        RowBox[{
         RowBox[{"AppendTo", "[", 
          RowBox[{"outcomeVit", ",", "v"}], "]"}], ";", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outcomeTau", ",", "tau"}], "]"}]}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"k", ",", "nbS"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   "temps", " ", "\[IndentingNewLine]", " "}]}]], "Input",
 CellChangeTimes->{{3.672414888578*^9, 3.67241507455*^9}, {
   3.6724151177279997`*^9, 3.672415128158*^9}, {3.672415211751*^9, 
   3.672415220639*^9}, {3.672415324392*^9, 3.6724154506540003`*^9}, {
   3.672415527167*^9, 3.6724156745179996`*^9}, {3.6724157067679996`*^9, 
   3.672415801326*^9}, {3.672415834198*^9, 3.672415855823*^9}, {
   3.672415891943*^9, 3.672415900389*^9}, {3.672416010943*^9, 
   3.672416013535*^9}, {3.672416179198*^9, 3.6724162922720003`*^9}, {
   3.6724553411792035`*^9, 3.672455359976204*^9}, {3.672455407127204*^9, 
   3.6724554094472036`*^9}, {3.672455740174204*^9, 3.672455740872204*^9}, {
   3.6724557729732037`*^9, 3.6724557882062035`*^9}, {3.672455857094204*^9, 
   3.6724558873662033`*^9}, {3.6724559227902036`*^9, 3.6724559569662037`*^9}, 
   3.6724560195902033`*^9, {3.6724560692062035`*^9, 3.672456185511204*^9}, {
   3.672457220759204*^9, 3.6724572230392036`*^9}, 3.6724572870482035`*^9, 
   3.6724573299272037`*^9, {3.672458581655204*^9, 3.6724585840142035`*^9}, {
   3.6724587149202037`*^9, 3.6724587748562036`*^9}, 3.6724588334412036`*^9, {
   3.6724588824812036`*^9, 3.672458893570204*^9}, {3.6724589633562036`*^9, 
   3.6724589843812037`*^9}, {3.6724591212372036`*^9, 3.672459121549204*^9}, 
   3.6724591636142035`*^9, 3.6724591954852037`*^9, {3.672459488469204*^9, 
   3.6724594946052036`*^9}, {3.6724596730522037`*^9, 3.672459684372204*^9}, {
   3.672459927332204*^9, 3.6724599367882037`*^9}, 3.6724619478892035`*^9, 
   3.6724622118732033`*^9, 3.6724622459522038`*^9, {3.6724626055522037`*^9, 
   3.6724626060392036`*^9}, {3.6724629255212035`*^9, 3.6724629487042036`*^9}, 
   3.6724629790012035`*^9, {3.672480707448535*^9, 3.672480751955413*^9}, 
   3.6724809198897085`*^9, {3.6724809656601887`*^9, 3.6724809769078083`*^9}, {
   3.67248241872902*^9, 3.67248245273708*^9}, {3.6724824973843584`*^9, 
   3.6724825056055727`*^9}, 3.6724825906101227`*^9, {3.6725446598438015`*^9, 
   3.6725446603008013`*^9}, {3.6725462604788013`*^9, 3.672546261132801*^9}, {
   3.6725516492713385`*^9, 3.672551677710965*^9}, {3.672552189823273*^9, 
   3.6725521900104733`*^9}, {3.6725522228329315`*^9, 3.672552223363332*^9}, {
   3.6725581507635794`*^9, 3.6725581548819866`*^9}, {3.672558207532079*^9, 
   3.672558210761285*^9}, 3.672558282661811*^9, 3.6725583940772066`*^9, {
   3.6725602070191684`*^9, 3.6725602561011724`*^9}, {3.6725603323423433`*^9, 
   3.6725603353898897`*^9}, {3.6725604073019943`*^9, 3.672560424141003*^9}, 
   3.6725605240700383`*^9, {3.672560656303319*^9, 3.672560656493322*^9}, {
   3.672560693907647*^9, 3.672560746645957*^9}, {3.672560837083596*^9, 
   3.6725608951394873`*^9}, {3.672561029354762*^9, 3.6725610539872055`*^9}, {
   3.6725615414198503`*^9, 3.6725615522306695`*^9}, {3.672583930133*^9, 
   3.67258395754*^9}, {3.672584207708*^9, 3.67258421079*^9}, {
   3.6725870143380003`*^9, 3.672587019244*^9}, {3.6725875428929996`*^9, 
   3.6725876057720003`*^9}, {3.672588159523*^9, 3.6725881931099997`*^9}, {
   3.6725886222650003`*^9, 3.672588670836*^9}, {3.6725887150030003`*^9, 
   3.672588715859*^9}, 3.672588769014*^9, {3.672588956803*^9, 
   3.6725889647460003`*^9}, {3.6726385898676014`*^9, 3.672638685741601*^9}, {
   3.672640640639601*^9, 3.672640648232601*^9}, 3.6938883440922003`*^9, 
   3.6938897577382*^9}],

Cell[BoxData[
 ProgressIndicatorBox[Dynamic[$CellContext`ind]]], "Output",
 CellChangeTimes->{
  3.6725615577062793`*^9, 3.6725618653144193`*^9, 3.672579522311801*^9, 
   3.672579808282801*^9, 3.672581279455*^9, 3.672584211955*^9, 
   3.672585920498*^9, 3.67258615833*^9, 3.672586194847*^9, 3.672586271698*^9, 
   3.672587020237*^9, 3.6725870635620003`*^9, {3.672587579708*^9, 
   3.6725876075559998`*^9}, 3.6725876728059998`*^9, {3.672588667351*^9, 
   3.672588671224*^9}, 3.672588716582*^9, 3.672588779359*^9, 
   3.672589028534*^9, 3.6725907341070004`*^9, 3.672627647844601*^9, 
   3.6726387541846013`*^9, 3.672638945076601*^9, 3.672640648824601*^9, 
   3.6726409132706013`*^9, 3.672641200833601*^9, 3.672641514486601*^9, 
   3.6726421383556013`*^9, 3.6726424730136013`*^9, 3.672651745660601*^9, 
   3.672653949127601*^9, 3.672655683637601*^9, 3.672656753462601*^9, 
   3.672657573899601*^9, 3.6726576891916013`*^9, 3.672657884361601*^9, 
   3.6726580728066015`*^9, 3.6726584356886015`*^9, 3.6726585794346013`*^9, 
   3.672659996667601*^9, 3.6937459913005*^9, 3.6937460454175*^9, 
   3.6938006054762*^9, 3.6938018533942003`*^9, 3.6938026323522*^9, {
   3.6938883608662*^9, 3.6938883817672*^9}, 3.6938898202302*^9, 
   3.6939020469568*^9}],

Cell[BoxData["10.00000000000073`"], "Output",
 CellChangeTimes->{
  3.6725615577062793`*^9, 3.6725618653144193`*^9, 3.672579522311801*^9, 
   3.672579808282801*^9, 3.672581279455*^9, 3.672584211955*^9, 
   3.672585920498*^9, 3.67258615833*^9, 3.672586194847*^9, 3.672586271698*^9, 
   3.672587020237*^9, 3.6725870635620003`*^9, {3.672587579708*^9, 
   3.6725876075559998`*^9}, 3.6725876728059998`*^9, {3.672588667351*^9, 
   3.672588671224*^9}, 3.672588716582*^9, 3.672588779359*^9, 
   3.672589028534*^9, 3.6725907341070004`*^9, 3.672627647844601*^9, 
   3.6726387541846013`*^9, 3.672638945076601*^9, 3.672640648824601*^9, 
   3.6726409132706013`*^9, 3.672641200833601*^9, 3.672641514486601*^9, 
   3.6726421383556013`*^9, 3.6726424730136013`*^9, 3.672651745660601*^9, 
   3.672653949127601*^9, 3.672655683637601*^9, 3.672656753462601*^9, 
   3.672657573899601*^9, 3.6726576891916013`*^9, 3.672657884361601*^9, 
   3.6726580728066015`*^9, 3.6726584356886015`*^9, 3.6726585794346013`*^9, 
   3.672659996667601*^9, 3.6937459913005*^9, 3.6937460454175*^9, 
   3.6938006054762*^9, 3.6938018533942003`*^9, 3.6938026323522*^9, {
   3.6938883608662*^9, 3.6938883817672*^9}, 3.6938898202302*^9, 
   3.6939023019128*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot velocity profiles", "Subsubsection",
 CellChangeTimes->{{3.67258879006*^9, 3.6725888088719997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "outcomeVit", "]"}]], "Input",
 CellChangeTimes->{{3.6725861281870003`*^9, 3.6725861295299997`*^9}, {
  3.6725886875369997`*^9, 3.672588696057*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1HvobFUVwPGNSUlEzh9iQ0ieRGzI6h4zc8zsLp93fN5z36NZ7kxzMvOe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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1n/sJHddx/FPoNGLEtkggQ02ODZN3QjYqYDdWrDv0pbbci2d+9G77d31
bu77c/khHUuFtZ70U1roAoUOCrIoyNSCXaDCKEhXQDqW2q7E4ITU9GuQMAQN
S5R0SG36JUh0Z+5lTJ/7z+Xx/dzn85n35/3+vGd+ae2GA5vPcM4tn+lc8++Z
X32Je/rP3Kd++I2r1yL9fY8cyx1zt7z+yzf94Uh+rsYTuWv+uZ/Z+52bb5LP
1v8fy4H57593wZ77TsvnaL6XzzX79jXv/dCb3i6fp/Vul3tWXPmsZ7zojnfK
v6L1J/KLzT6/eMtXPvZu+Ve1351yaMUL3/Ef++fvky/Q/qn8a5Y9FOQ3jt4v
v1TP8wfyy6z60duaDeWX6/k+IP+6Bed/69yfuvWD8oV63j+S+xZvXNysKF+k
55/Kv2HZh9uffLHi+WP5FVZ9/amD3/3En8ivVHwfkX/TgrMO/9xL/uqj8iWK
909ls/iidsEz9qb4M41fatGF77o0/nfZX6rzuFvjr7J6/3y1ouxfpfP5M41f
Zukbv/fjT/5Q9pfpvO7R+OUW3vG8f/n6U7K/XOf3cY1fYeXdV3zhiZ/I/gqd
5yc0/mpLVqfVPevPNf5qna/s9lrnsXuSV/7MvRrfq/OW3cDyJtzOTOMDnb/s
rrSoWe55n9T4lcqH7F5jdXPcZ39K469RfmS3z9LV6ZXnfFrj+5Qv2V1l4fG7
Hnyyd5/Gr1L+ZHe1lavVXnD+X2j8auVTdq+15P0/OH3Jyz+j8dcqv7K7xjr3
nX104+LPavwa5Vt2kQ1XxbNK6RlbpPzLPrLZ6vQeu0cuItWD7Pbb7k8eHX//
vL/U/P2qD9nvt8F7mgKQi/2qF9kdsGm3DUjzD6h+ZH/Alu3jycUB1ZPsDlr/
pc3vc5p/UPUl+4M2Kb62qiC5OKh6k90h21llf3jR5zX/kOpP9oes981mQbk4
pHqU3bU2HjUJ+GvNv1b1KftrbfFkb5VhubhW9foFzT9s3dvaB9T8w6pf2R+2
UfN0C7k4rHq+X/OP2Pyjj9/78D7Zjqi+ZX/E9ryoCVgujqje55o/tOG8LRjN
H6r+ZT+0WRPuo3Ix1H34G82/zp5qlhvKdp19rL0fsr/O9jbl/025uM4eb+/L
FzX/qH2oKd8Tsh21S9r7I/uj9r2bm4TIxVG7q71PX9L8Y3bhnqbAZTtm327v
l+yP2R0fvGxVgXJxzM5v79uXNf+4PXZOm2DNP263tPdP9sftl5vu/wO5OG7/
1N7Hv9X86+2tzfVIZLvefrEtZ9lfb4802X1CLq63G9r7+hXNP2HPH7YXUvNP
2ANtOmR/wrab4/uRXJywZ7f3+QHNP2n3N493WraTdrJdTvYn7awzEzX/pO67
7GK77+F9qxstB7Huv2yxHVrdxufcJsex+oHsY/vv5u3zkJzF6g//t19sH39B
cyH+7oyrWP1Cdqfsqu80CZaDU+ofsp2y/7q3eUA5PqV+IvtT9pHm6b4mZ6fU
X+TilF2+Kq4rn/Wg9j+lfiO7NfvPVTf5xtVysKb+I9uafeDB9gJr/zX1I9mv
2SuacEs5W1N/kos1+7dmued8VfuvqV/Jbt3ubNrRQTlYV/+Sbd1e1n4+yPG6
+pns1+1fm3bwmJytq7/Jxbrd3lzn7kPaf139TnYb9uLmOh6Vgw31P9k27NH2
80KON9QPZb9hp5vr8C0521B/lIsNO7cp5xf+vfbfUL+U3ab9Y1N+sRxsqn/K
tmlvbtJ7txxv2iNtOmS/ab/QHN935WzTbmj768Paf9O+2jzeuXK1ac9v+63s
tuwNW81PDrbsgbb/yrZlP7/6eFp1WO2/ZdttP5b9ln3piaag5WzLnt3250e0
/5atf7FZUK627P62X8tu23721qZBycG2nWz7t2zb9rm9zQWR42376bafy37b
jjVfd4/L2bZ9tu3vC+2/bc/859V1u0Cutu1I2+9lN7JPN+V8oxyM7H/az1nZ
RnawfT3K8cjubd8Hsh/Zj5t0PClnI7umfT/8g/Yf2T1NuBfK1UjvC9m9zvY1
y43l4HV6f8gGx7CHM7iAK9i9/ukOYINj2MMZXMAV7N6A/WGDY9jDGVzAFeze
iP1hg2PYwxlcwBXsfgv7wwbHsIczuIAr2L0J+8MGx7CHM7iAK9jdgP1hg2PY
wxlcwBXskqe7AwdwCBscwTGcwB5O4QzO4QIu4QquYffbiB8O4BA2OIJjOIE9
nMIZnMMFXMIVXMPuRsQPB3AIGxzBMZzAHk7hDM7hAi7hCq5h92bEDwdwCBsc
wTGcwB5O4QzO4QIu4QquYXcT4ocDOIQNjuAYTmAPp3AG53ABl3AF17D7HcQP
B3AIGxzBMZzAHk7hDM7hAi7hCq5h9xbEDwdwCBscwTGcwB5O4QzO4QIu4Qqu
YfdWxA8HcAgbHMExnMAeTuEMzuECLuEKrmE3RvxwAIewwREcwwns4RTO4Bwu
4BKu4Bp2v4v44QAOYYMjOIYT2MMpnME5XMAlXME17G5G/HAAh7DBERzDCezh
FM7gHC7gEq7gGna/h/jhAA5hgyM4hhPYwymcwTlcwCVcwTXsTiN+OIBD2OAI
juEE9nAKZ3AOF3AJV3ANu99H/HAAh7DBERzDCezhFM7gHC7gEq7gGnZvQ/xw
AIewwREcwwns4RTO4Bwu4BKu4Bp2tyB+OIBD2OAIjuEE9nAKZ3AOF3AJV3AN
O/9074E7cBcO4B4cwn3Y4AEcwUM4hkdwAo9hD0/gFJ7CGTyDc3gOF/ACLuEd
uIKXcA3vwu5W5B/uwF04gHtwCPdhgwdwBA/hGB7BCTyGPTyBU3gKZ/AMzuE5
XMALuIR34ApewjW8C7u3I/9wB+7CAdyDQ7gPGzyAI3gIx/AITuAx7OEJnMJT
OINncA7P4QJewCW8A1fwEq7hXdjdhvzDHbgLB3APDuE+bPAAjuAhHMMjOIHH
sIcncApP4QyewTk8hwt4AZfwDlzBS7iGd2F3O/IPd+AuHMA9OIT7sMEDOIKH
cAyP4AQewx6ewCk8hTN4BufwHC7gBVzCO3AFL+Ea3oXdO5B/uAN34QDuwSHc
hw0ewBE8hGN4BCfwGPbwBE7hKZzBMziH53ABL+AS3oEreAnX8C7s3on8wx24
CwdwDw7hPmzwAI7gIRzDIziBx7CHJ3AKT+EMnsE5PIcLeAGX8A5cwUu4hndh
dwfyD3fgLhzAPTiE+7DBAziCh3AMj+AEHsMensApPIUzeAbn8Bwu4AVcwjtw
BS/hGt6F3QT5hztwFw7gHhzCfdjgARzBQziGR3ACj2EPT+AUnsIZPINzeA4X
8AIu4R24gpdwDe/C7l3IP9yBu3AA9+AQ7sMGD+AIHsIxPIITeAx7eAKn8BTO
4Bmcw3O4gBdwCe/AFbyEa3gXdu9G/uEO3IUDuAeHcB82eABH8BCO4RGcwGPY
wxM4hadwBs/gHJ7DBbyAS3gHruAlXMO7sHsP8g934C4cwD04hPuwwQM4godw
DI/gBB7DHp7AKTyFM3gG5/AcLuAFXMI7cAUv4Rrehd2dyD/cgbtwAPfgEO7D
Bg/gCB7CMTyCE3gMe3gCp/AUzuAZnMNzuIAXcAnvwBW8hGt4F3bvRf7hDtyF
A7gHh3AfNngAR/AQjuERnMBj2MMTOIWncAbP4ByewwW8gEt4B67gJVzDu7B7
H/IPd+AuHMA9OIT7sMEDOIKHcAyP4AQewx6ewCk8hTN4BufwHC7gBVzCO3AF
L+Ea3oXdXcg/3IG7cAD34BDuw/b//l9jkxVf
      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd2HmUXGWZBvArOA6jGSyRwRqMeEHEdtiKYSDNhOWJEdIxhFQSklT2m95S
STrdt/fq7urOjTHQyFYMAs2wVSYD6chiKQotRLgChmYLxZpmAuRyOEhzEClO
DtIcRKfvm4fj8el/4Mflrt/3vc/71bG1LQsaDnEcZ/xQx4n/efCvcp7z938I
dn7w/NzaNP/7YQjNHp1AOLB+V8e1WfpIRHbcp5Pwjrxn1hu9HfRURPb/52gX
3jsnnHbYXXn6OFTs/IA+Hqn98668ofmH9Anw7Xo/oqtQmj3lkBMvvYT+N1Ts
+oP0SUj9crTrodt+TJ8C3+53BZ1C6Zit784fuYo+DRN2/wL97xh6zC21Za+h
T0e1Pc9/0f+BsY/thvQZyNnz/YQ+E8lTXzv+C5uvo6dhxJ73eroamfrp8RXp
szBhlxui/xNDN9ofPR3V9j7/TZ+NsT0fLXzz9pvoc5Cz97uZPhfJzy8+/ORf
3EKfhxF731tpIHOWXfCgA+DP9v5FHp+BC6ddNsN7iw5m4Gb7Htt4/Hv4w/z4
inTwPZxt3+d/eHwmrmh6+5OdH9DBTLxq32s7j38fJ1161Ct7PqKD7yNv3+9/
efx8PL3t/PsOfEoH52Oqfc/befwCNE1+reTn7+DxC7DLvi/tzMKUvdv9c764
g8dnYYV9b9qpwV3x6yaGebwGf7bvTzuzcWF8uaN28vhs3GzDQTs/wB/izz31
pzz+A5xtn5N25uCKya9XPu5OHp+DV228aOdCnLTi6kc+rLqLxy9E3saPdubi
6cmrHX3q3Tw+F1NtPGnnIjRd817+vDPu4fGLsMvGl3bmYcpdU5fVT/8Zj8/D
Chtv2klj8eTkmRzSg0Yaf7Hxp4M07pj8enu302EaF9l8oJ35+NOnL05OuZ/z
/Pm41eYHHczHBZfHE4AO5+OPNl9oZwGuPzhBef4CnGvzhw4W4Pf2eHS4AFfZ
fKKdhTjz9PjvXp6/EK/b/KKDhbgkfHJyBtHhQpxi8412LsbLk6M/uQZ4/sUY
sPlHBxfjhH3xBenwYuyx+Ug7i9CVjQfgVzx/EY6x+UkHi7D7w6rJEabDRWi2
+Xofz1+Mo7bYA/L8xXjI5i8dLEZj/HSjdLgYh9t8vp/nL8F9t7y/Y/ccGkuw
yuY3HSzBF06MX5gOl+Aem+8jPD+DxQcLAs/P4C82/+kggzvi132RDjO4yNbD
r3n+UvwpvlyGxlLcauuDDpbignj676PDpfijrZcHeP4yXB9P31U0luFcWz90
sAy/740HhA6X4SpbTw/y/OU487B4gtNYjtdtfdHBclxy3czJGUiHy3GKrbdd
PH8FXj7OBpjnr8CArT86WIET4ur/Hh2uwB5bj7/h+SvRFS8Pn8ZKHGPTmQ5W
Ync8ugfocCWabb0+xPNX4aiDBZjnr8JDNhx0sAqN8ef7mA5X4XBbzw/z/NW4
L368PI3VWGWXo4PVOPTgiTx/NZbYeqcdD3funjO5omnXw19t/dPwsHByNR6x
hfY87LB6QAcePonT5zG66GGe1YfP7udh+9HxgvjtQUcePrJ6QTtrMOeNeIBp
dw1us/pBYw0O7IgfkPbWYJbVEzpYg5vip3uSLq7B+1Zf6HANZk5OrtlTHuH9
1+AGqze0U4t3P4lfmHZrcZ7VHxq1uPYRW8C8fy3etnpEB7WYHr9umS7W4mqr
T3RYizfjyx3xKO9fi2lWr2inDpfH5Wgh7dZhv9UvGnU43doH2qvDpVYu6KAO
++JysJcu1uFUq290WIct8XJOPsb712Gv1TvaqceJ8XJcRrv12GT1j0Y9XrD2
gvbq8R1bLnRQj754ObxGF+vxrNVHOqzHt+LpfMzveP96dFu9pJ0GPBVPP492
G/BNq580GtAeD+822mvA4zYcdNCAr8ef70262IAWq6+7ef8GPBo/3vF01ICv
Wb2lnUZsaIz/aLcRD1v9pdGIr042T5MVlvdvxFqrx3TQiAcPxBOaLjbiy1af
H+f9G1H3QHxBOmrE/VavaWctvrQ5LlC0uxarrX7TWIt7Z8ULhPbW4h+tntPB
WiyPu7v36eJa/Mzq+yjvvxaHvhR3hHS0Fkus3tNOFnfG07mNdrP4q9V/Glks
tHikvSx2WB7QQRafxMPxIV3MYp7lwxO8fxbb49edRkdZfGR5QTvrMCe+XI52
1+E2yw8a63DA4oH21mGW5QkdrMNNcXn/hC6uw/uWL0/y/uswMy7P59DROtxg
eUM76/FuXF4HaHc9zrP8obEe11r5o731eNvyiA7WY3pcXg55ivdfj6stn+hw
Pd6Ml+9MOlqPaZZXtLMBl8fLYyvtbsB+yy8aG3C6TT/a24BLLc/oYAP2WcP/
NO+/AadavtHhBmyJP99sOtqAvZZ3tNOEE+PHu5x2m7DJ8o9GE1542v54/yZ8
x/KQDprQd21cUJ/h/ZvwrOUjHTbhW8viCU1HTei2vKSdjXjKtle0uxHftPyk
sRHtcTl9nvY24nHLUzrYiK/H5erIPbz/RrRYvtLhRjwal4PFdLQRX7O8pZ1m
bLDtF+0242HLXxrN+OohtuB4/2astTymg2Y8GE+Xo5/l/ZvxZctnOmxGXTwc
K+ioGfdbXtNOC75k2zPabcFqy28aLbg3vtx+2mthnpd5/xbcbeudLrYw3+mw
BZ+z9U9HLcx72vGxyOoBnfCZ/7TrY6fVBzrlsx+g4eNTqxd02md/QHs+5lv9
oH2f/cJnz+/jdqsndMFn//DZ+/j42OoLXfLZTzzH9/Mx1+oNXfbZX9CRj21W
f+iKz36DdlrxodUjOtHK/oN2WzHb6hOdamU/QqMVt1i9otOt7E9orxUfWP2i
/Vb2K3TQivOtntGFVvYvdLEVN1p9o0ut7Gee5/u34j2rd3S5lf0NHbVihtU/
utLKfod22nCd1UM60cb+h3bb8I7VRzrVxn6IRhvOsXpJp9vYH9FeG66x+kn7
beyX6KANb1k9pQtt7J/oYhvOsvr6At+/jf0UHbbhSqu3dLmN/RUdteENq790
pY39Fu204wyrx3Sinf0X7bbjMqvPdKqd/RiNdrxm9ZpOt7M/o712nGb1m/bb
2a/RQTu2Wj2nC+3s3+hiO16x+v4i37+d/RwdtuNkq/d0uZ39HR21Y7PVf7rS
zn6PdjrwkuUBnehg/0e7Hfiu5QOd6mA/SKMD/ZYXdLqD/SHtdeA5iw/a72C/
SAcd+LblCV3oYP9IFzvQY/nyEt+/g/0kHXbgGcsbutzB/pKOOnCs5Q9d6WC/
STud6LQ8ohOd7D9ptxNPWD7RqU72ozQ68Q3LKzrdyf6U9jrRatOZ9jvZr9JB
J35neUYXOtm/vsz378S/Wr7RpU72s3TYiY2Wd3S5k/0tHXXit5Z/dKWT/S7t
dOFfLA/pRBf7X9rtwjrLRzrVxX6YRhd+Y3lJp7vYH9NeF75i+Un7XeyX6aAL
DZandKGL/fNevn8Xfm35Spe62E/TYRf+2fKWLnexv6ajLqyx/KUrXey3aacb
v7I8phPd7L9ptxv/ZPlMp7rZj9PoxkrLazrdzf6c9rrxc8tv2u9mv04H3fgH
+5cxvn83+3e62I2llud0qZv9PB12427Lc7rczf6ejrrxuZ/GF6Qr3ez3aSeH
RZbndCLH/p92c9hpeU6nctwP0MjhU8tzOp3j/oD2cphveU77Oe4X6CCH2y3P
X+H757h/oIs5fGx5Tpdy3E/QYQ5zLc/pco77CzrKYZvlOV3Jcb9BOz340PKc
TvRw/0G7PZhteU6nergfodGDWyzP6XQP9ye014MPLM9pv4f7FTrowfmW5//H
9+/h/oUu9uBGy3O61MP9DB324D3Lc7rcw/0NHfVghuU5Xenhfod2enGd5Tmd
6OX+h3Z78Y7lOZ3q5X6IRi/OsTyn073cH9FeL66xPKf9Xu6X9vH9e/GW5Tld
6OX+iS724izLc7rUy/0UHfbiSstzutzL/RUd9eINy3O60sv9Fu304QzLczrR
x/0X7fbhMstzOtXH/RiNPrxm5YpO93F/Rnt9OM3ynPb7uF97le/fh62W53Sh
j/s3utiHVyzP6VIf93N02IeTLc/pch/3d3TUh82W53Slj/s92snjJctzOpHn
/o928/iu5TmdynM/SCOPfstzOp3n/pD28njO8pz289wvvsb3z+Pblud0Ic/9
I13Mo8fynC7luZ+kwzyesTyny3nuL+koj2Mtz+lKnvtN2ulHp+U5nejn/pN2
+/GE5Tmd6ud+lEY/vmF5Tqf7uT+lvX74luev8/37cbTlOR304zHLc7rQz9+H
6WI/kpbndKkfj1ie02E/mizP6XI/f0+mo36Elud0pR/rLc9pZwBHWp7TiQH+
/ky7A8hantOpARxh5ZnGAHZZntPpAf5eTXsDSFie7+f7D+ABy3M6GEC95Tld
GODv23RxACOW53RpALWW53Q4gCmW53R5gL+H09EAPMtzujKAL1qe084m/NLy
nE5s4u/ntLsJh1me06lN+IU9Ho1NWGF5Tqc3cX8e8f3FvjgQF8RFcUkcisvi
SFwRO8Hf+zBxQpwUu+IqcUpcLYa4RpwWZ8SeOCv2xTlxIB4UF8RD4qJ4WFwS
j4hD8ai4LB4TR+JxcUU8IXY2y/iLE+Kk2BVXiVPiajHENeK0OCP2xFmxL86J
A/GguCAeEhfFw+KSeEQcikfFZfGYOBKPiyviCbHzQxl/cUKcFLviKnFKXC2G
uEacFmfEnjgr9sU5cSAeFBfEQ+KieFhcEo+IQ/GouCweE0ficXFFPCF2tsj4
ixPipNgVV4lT4moxxDXitDgj9sRZsS/OiQPxoLggHhIXxcPiknhEHIpHxWXx
mDgSj4sr4gmx8yMZf3FCnBS74ipxSlwthrhGnBZnxJ44K/bFOXEgHhQXxEPi
onhYXBKPiEPxqLgsHhNH4nFxRTwhdrbK+IsT4qTYFVeJU+JqMcQ14rQ4I/bE
WbEvzokD8aC4IB4SF8XD4pJ4RByKR8Vl8Zg4Eo+LK+IJsXOJjL84IU6KXXGV
OCWuFkNcI06LM2JPnBX74pw4EA+KC+IhcVE8LC6JR8SheFRcFo+JI/G4uCKe
EDuXyviLE+Kk2BVXiVPiajHENeK0OCP2xFmxL86JA/GguCAeEhfFw+KSeEQc
ikfFZfGYOBKPiyviCbEzKOMvToiTYldcJU6Jq8UQ14jT4ozYE2fFvjgnDsSD
4oJ4SFwUD4tL4hFxKB4Vl8Vj4kg8Lq6IJ8TOZTL+4oQ4KXbFVeKUuFoMcY04
Lc6IPXFW7Itz4kA8KC6Ih8RF8bC4JB4Rh+JRcVk8Jo7E4+KKeELs/FjGX5wQ
J8WuuEqcEleLIa4Rp8UZsSfOin1xThyIB8UF8ZC4KB4Wl8Qj4lA8Ki6Lx8SR
eFxcEU+Inctl/MUJcVLsiqvEKXG1GOIacVqcEXvirNgX58SBeFBcEA+Ji+Jh
cUk8Ig7Fo+KyeEwcicfFFfGE2LlCxl+cECfFrrhKnBJXiyGuEafFGbEnzop9
cU4ciAfFBfGQuCgeFpfEI+JQPCoui8fEkXhcXBFPiJ0rZfzFCXFS7IqrxClx
tRjiGnFanBF74qzYF+fEgXhQXBAPiYviYXFJPCIOxaPisnhMHInHxRXxhNi5
SsZfnBAnxa64SpwSV4shrhGnxRmxJ86KfXFOHIgHxQXxkLgoHhaXxCPiUDwq
LovHxJF4XFwRT4idq2X8xQlxUuyKq8QpcbUYf/P/A1YalDs=
      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxV2HdcU9fj//FoHVStphYVrSPOYrVtnMVRfbtx1bhxFCMiIiCGveECAQIh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      "]]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxV23k4lG3cPvBJJRWhVbsWJamIFlLOSkVUWhEVQrY09p0xY8yMYWgRSkWL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      "]]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVm3lYzN3//yeF7C2WZCtCtkTIUjxL0Z1UlDbRok1S077XTE3TTDNNRdyh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      "]]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.002777777777777778], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxV13lUjG/cBvBByBKDkOXHIEqWki1Elz0pRkgURqVFpWmf9qdmaZqZpmQL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      "]]}, {}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageMargins->0.,
  ImagePadding->All,
  ImageSize->Automatic,
  ImageSizeRaw->Automatic,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 1000.}, {0, 0.9979999999999455}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.672586130165*^9, {3.672588696699*^9, 3.6725887260950003`*^9}, 
   3.672588881191*^9, 3.6725891688789997`*^9, 3.672590839586*^9, 
   3.672638777779601*^9, 3.6726391119246016`*^9, 3.672640879644601*^9, 
   3.6726411744646015`*^9, 3.672641443258601*^9, 3.672641987319601*^9, 
   3.6726424166366014`*^9, 3.6726427840996013`*^9, 3.6726527291126013`*^9, 
   3.672655641673601*^9, 3.6726567103136015`*^9, 3.672657527114601*^9, 
   3.6726576539476013`*^9, 3.672657837913601*^9, 3.672658033864601*^9, 
   3.6726584012076015`*^9, 3.6726585484806013`*^9, 3.6726591578746014`*^9, 
   3.6726606390136013`*^9, 3.6937467192425003`*^9, 3.6938017251102*^9, 
   3.6938025257981997`*^9, 3.6938030149992*^9, 3.6938891533592*^9, 
   3.6938909329662*^9, 3.6939097653640003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.01", ",", "0.05", ",", "0.1", ",", "0.2", ",", "0.5", ",", "1"}],
   "}"}]], "Input",
 CellChangeTimes->{{3.672589462427*^9, 3.6725894738970003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.01`", ",", "0.05`", ",", "0.1`", ",", "0.2`", ",", "0.5`", ",", "1"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6938025283742*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"style", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"DotDashed", ",", "Thick", ",", "Purple"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Red", ",", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", "Blue", ",", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", " ", "Black"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.672589687756*^9, 3.67258971424*^9}, {
  3.672627707759601*^9, 3.6726277814736013`*^9}, {3.672627922897601*^9, 
  3.6726279244806013`*^9}, {3.6726424826786013`*^9, 3.672642495366601*^9}, {
  3.6726428232496014`*^9, 3.6726428305496016`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Dashing", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], "}"}], "]"}], 
     ",", 
     RowBox[{"Thickness", "[", "Large", "]"}], ",", 
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0.5, 0, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.33333333333333337`, 0., 0.33333333333333337`],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0.5, 0, 0.5]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0.5, 0, 0.5]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0.5, 0, 0.5],
      Editable->False,
      Selectable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[1, 0, 0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[1, 0, 0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[1, 0, 0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[1, 0, 0],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->RGBColor[0., 0., 0.6666666666666666],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "RGBColor[0, 0, 1]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
             Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      RGBColor[0, 0, 1],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {RGBColor[0, 0, 1], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->RGBColor[0., 0., 0.6666666666666666],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "RGBColor[0, 0, 1]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[0, 0, 1]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
           Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    RGBColor[0, 0, 1],
    Editable->False,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      ButtonBox[
       TooltipBox[
        GraphicsBox[{
          {GrayLevel[0], RectangleBox[{0, 0}]}, 
          {GrayLevel[0], RectangleBox[{1, -1}]}, 
          {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
         AspectRatio->1,
         Frame->True,
         FrameStyle->GrayLevel[0.],
         FrameTicks->None,
         ImageSize->
          Dynamic[{
           Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
            Magnification]}],
         PlotRangePadding->None],
        "GrayLevel[0]"],
       Appearance->None,
       BaseStyle->{},
       BaselinePosition->Baseline,
       ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
         If[
          Not[
           AbsoluteCurrentValue["Deployed"]], 
          SelectionMove[Typeset`box$, All, Expression]; 
          FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
          FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
          FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
          MathLink`CallFrontEnd[
            FrontEnd`AttachCell[Typeset`box$, 
             FrontEndResource["GrayLevelColorValueSelector"], {
             0, {Left, Bottom}}, {Left, Top}, 
             "ClosingActions" -> {
              "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
       DefaultBaseStyle->{},
       Evaluator->Automatic,
       Method->"Preemptive"],
      GrayLevel[0],
      Editable->False,
      Selectable->False], ",", 
     RowBox[{"Dashing", "[", "Medium", "]"}]}], "}"}], ",", 
   InterpretationBox[
    ButtonBox[
     TooltipBox[
      GraphicsBox[{
        {GrayLevel[0], RectangleBox[{0, 0}]}, 
        {GrayLevel[0], RectangleBox[{1, -1}]}, 
        {GrayLevel[0], RectangleBox[{0, -1}, {2, 1}]}},
       AspectRatio->1,
       Frame->True,
       FrameStyle->GrayLevel[0.],
       FrameTicks->None,
       ImageSize->
        Dynamic[{
         Automatic, 1.35 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
          Magnification]}],
       PlotRangePadding->None],
      "GrayLevel[0]"],
     Appearance->None,
     BaseStyle->{},
     BaselinePosition->Baseline,
     ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
       If[
        Not[
         AbsoluteCurrentValue["Deployed"]], 
        SelectionMove[Typeset`box$, All, Expression]; 
        FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
        FrontEnd`Private`$ColorSelectorInitialColor = GrayLevel[0]; 
        FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
        MathLink`CallFrontEnd[
          FrontEnd`AttachCell[Typeset`box$, 
           FrontEndResource["GrayLevelColorValueSelector"], {
           0, {Left, Bottom}}, {Left, Top}, 
           "ClosingActions" -> {
            "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
     DefaultBaseStyle->{},
     Evaluator->Automatic,
     Method->"Preemptive"],
    GrayLevel[0],
    Editable->False,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6725897165039997`*^9, {3.672627764304601*^9, 3.672627782802601*^9}, 
   3.6726279264946012`*^9, 3.672638867430601*^9, 3.6726427894616013`*^9, 
   3.6726428310376015`*^9, 3.672652735995601*^9, 3.6726575308826013`*^9, 
   3.672659160205601*^9, 3.672660641140601*^9, 3.6937467238405*^9, 
   3.6938025317032003`*^9, 3.6938030180931997`*^9, 3.6938891572152*^9, 
   3.693909768324*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.672638804923601*^9, 3.672638853984601*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"t = 0.01\"\>", ",", "\<\"t = 0.05\"\>", ",", "\<\"t = 0.1\"\>",
    ",", "\<\"t = 0.2\"\>", ",", "\<\"t = 0.5\"\>", ",", "\<\"t = 1\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.672638809243601*^9, 3.6726388487576013`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dessin1", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"outcomeVit", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "i"}], "]"}], "]"}], ",", "  ", 
          RowBox[{"(", 
           RowBox[{"a", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"i", "-", "1"}], ")"}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"b", "-", "a"}], ")"}], "/", "nb"}]}]}], ")"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "nb"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "@", "outcomeVit"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "tps"}], 
      "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"u\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.672588863809*^9, 3.6725889001289997`*^9}, {
   3.672589354875*^9, 3.672589385226*^9}, {3.672589452939*^9, 
   3.672589538178*^9}, {3.672589722875*^9, 3.6725897635950003`*^9}, {
   3.672627799713601*^9, 3.6726278409386015`*^9}, {3.672627977498601*^9, 
   3.672627980218601*^9}, 3.672638859186601*^9, {3.6726527490336013`*^9, 
   3.672652778913601*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJxl2XvMlnUZwHFGzpxjYWZKZIJmanONmGus40VZmWmJ2sw1p4xl0hEyUzIC
TA0tC0REIkTO58PLy+F98QQqAuIBRIyMCAgVUBHNSI2snvv3vXZ/tzv++e0z
9eF5nvu+r+/1vp48aMhFV3bt0qXLvnd16VKd//dn/utbvjZoQPx7HicemB4Y
XUZ+7/5r7hgc/xrByT8fmv98aIw6bvE5u6+/Jn6eJ//+sPz3h8Wo/af1PWrh
8PhZnvz3o/K/HxX9d17w27t+9Mv4TJ683k35ejfFmnO7dT1z9K/i3jx5/Vvy
9W+J/ss3XPvgPb+OT+XJ33db/n23xZqTbn75ws7fRWee/P1j8+8fG1PX9m67
evDtMTlP3s+4fD/jYtfb5S+K7Xny/sbn+xsfvfvsOPXIG+6MD+bJ+52Q73dC
DPz2p6tXim/lyfufmO9/Ykz9ffkTk/Lk80zKzzMpdj315sV7Zv0hnsuTzzc5
P9/k6H3EJe/5WPvd8YE8+bxT8vNOiYGfLC8Ul+bJ55+an39qDOh36+cHvjA1
zs+T72Nafh/T4rULq1eaFq/kyfczPb+f6TH2B3sPz3t9evwmT76vGfl9zYiP
jz6+9dZnxJl58v3NzO9vZmye9qWVb7wzMx7Pk+9zVn6fs2Jo61vqccTs+H6e
fL+z8/udHcdsmzH0s0fPiaPz5Puek9/3nGirPuYxc2N+nnz/c/P7nxsXVC9z
/Lz4ap73lMswL6/HvDhYfc0nzo+X8ozyNc7P6zM/xrS+tc2nLIhb89xZrtOC
vF4Los9lYx4+dMbC+GieI8t1W5jXb2Fsar1Kzz6L4rE8e5XruCiv56IYcvuB
4fGJxfHdPFeX67o4r+/i6L7wxNZHXRJH5XlFuc5L8nq3ztZN07qU8Y08uf5t
ef3bYm7rW9s2oy1m5sn90Jb3Q1u89c7WYftPWxr/yJP7Y2neH0vjnHLhl8YX
8zxY7pOleb8sjbt6lA8S4/OMct+05/3THnvL22qPPXmOKfdRe95P7dHvrOrP
sjgrz53lvlqW99eyGL1mY+vOWRY35tmn3GfL8n5bFttaV731XcQzeY4s993y
vP+Wx+nlhZbHh/PcVO7D5Xk/Lo/rBldf/Ir4SZ69yn25Iu/PFbH+0BmtK7si
HslzSLlPV+b9ujJO4I3F+/JcXe7blXn/royrqne1YWUMyrN7uY878n7uiI67
D85Zd15HtOd5RbmvO/L+7oh3lw/aEV3zXFLu88683zvjm9wocVGe/y33fWfe
/50xp/qYWztjep48D6vyeVgVb1Yvc+mq+HuePB+r8vnQX6hu/+2a5+Xe2uOq
2/dyzfOjd19fXRDN83Rf7b7lBtc8X/qGO89u3TKa5+3+2k+fUi5wbZ4/fXI1
/Q9onscHav+4ejyGap5P/VB1dd/QPK8P1n4vD2RtLocuX9/bmud5de3y9oZr
Xk4T8zW1ed713HXntZ5ozfOvB7SexmNv1MwD/VZVn7Wa+aCn9qweiIdqMy/0
V8oF1swP/dqc6g1q5omeWL27jZr5ovu3bq5zuz1cm3mj9x2uPrBm/ujqbmnd
MrWZR7p83M2a+aTLyx37SG3mlS7j6GLN/NKsD5pxocs42KaZb7pkrcfa2sw7
fXp5gDTzT28q64VmHurrqsdhh2Y+6l7V7XzSo7WZl3p9dfsN1MxPPaS6vNM0
81SfUB54zXxdV3t19fZO1cxbfdV3qj+a+aur5ak1YWszj3U1HYft18zn9bUv
Ly+omdf6yDKgNPNbV1fjuMWaea7LdndQM9831P5P9bj11cx7Pbu6na/WzH/9
dT5wbXqg/1ldjkOaPjxWe0r1cftpeqG/XL5ATT/0qyUPmp7oCdV4P6zpy8ba
nysXRNMb/WI1Xkdo+qMZf5oe6TJeuj7e6JMuj+/Zml7p8njcrOmX5vbT9Ew/
W13eo55o9E3/orxDTe/0R8oNqOmffvKJ8qfRQ/3TO6qB+mSjj/pD5YbW9FI/
Wn680vRT/7Aap1s0PdXvLw/IU42+6geqcXCJprf6yvLjl6a/uhsPXKPHutwu
PTc1+qzL5bhM02vNj2eafuvycjs1Pd/ceN41fdc8/5rea+aBpv+a+aDZBzTz
QrMfaOaHZl/QzBPN/qCZL5p94unGvNHsF5r5o9k3NPNIs39o5pNmH9HMK81+
oplfmn1FM880+4tmvmn2mS2NeafZbzTzT7PvaOahZv/R5XYfodmHNL8+0OxH
mvmpubyaearZnzTz9Zna7FOaeavZrzTzV7NvaeaxZv/SzGfNPqaZ15r9TDO/
NfuaZp5r9jfNfN9am31OM+81+51m/mv2PU0PNPufpg+afVDTC81+qOmHZl/U
9ESzP2r68mxt9klNbzT7paY/mn1T0yPN/qnpk2Yf1fRKs59q+qXZVzU90+yv
f2z0TbPPanqn2W81/dPsu5oeavZfza8nNfuwppeadVHTT82+rOmpZn/e1uir
Zp/W9FazX2v6q9m3NT3W7N+aPmv2cU2vNeuCpt+afV3T8z81eq7puabnmp5r
eq7puabnmp5req7puabnmp5req7puabnmp4/1+i5pueanmt6rum5pueanmt6
rum5pueanmt6rum5pueanmt6/udGzzU91/Rc03NNzzU91/y8o8eWnmt+/tH0
XNNzTc81Pdf0XNPz7Y2ea3qu6bmm55qea3qu6bmm55qea3qu6bmm55pxpem5
pueanv+l0XNNzzU91/Rc03NNzzU91/Rc03NNzzU91/Rc03NNzzU91/R8R6Pn
mp5req7puabnmp5req7puabnmp5req7puabnmp5rev7XRs81Pdf0XNNzTc81
Pdf0XN9Xeq75eVd3Lze0pueanmvGs6bnmp5rer6z0XNNzzU91/Rc03NNzzU9
1/Rc03NNzzU91/Rc8/Y0Pdf0fFfjedf0XfP8a3qvmQea/mvmg2Yf0MwLzX6g
mR+afUEzTzT7g2a+aPYJzbzR7Bea+aPZNzTzSLN/aOaTZh/RzCvNfqKZX5p9
RTPPNPuLZr5p9pndjXmn2W8080+z72jmoWb/0cxHzT6kmZea/UgzPzX7kmae
avYnzXzV7FOaeavZrzTzV7NvaeaxZv/SzGfNPqaZ15r9TDO/NfuaZp5r9jfN
fP9bbfY5zbzX7Hea+a/Z9zQ90Ox/mj5o9kFNLzT7oaYfmn1Rl/F/reb3QZqf
FzW/H9L8/Kj5fZHm50nNvqnpkWb/1PRJs49qeqV5PDT90uyrmp5p9tc9jb5p
9llN7zT7raZ/mn1X00PN/qvpo2Yf1vRSsx9r+qnZlzU91ezPmr5q9mlNbzX7
taa/mn1b02PN/q3ps2Yf1/Ras59r+q3Z1zU9f77Rc03PNT3X9FzTc03PNT3X
9FzTc03PNT3X9FzTc03PNT3X9FzTc03PNT3X9FzTc03PNT3X9FzTc03PNT3X
9FzTc03PNT3X9PyFRs81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0
XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0/MVGzzU91/Rc
03NNzzU91/Rc03NNzzU91/Rc03NNzzU/H2p+H6Tpuabnmp5req7puabnmp5r
eq7puabnmp5req7puabnmp5rer630XNNzzU91/Rc03NNzzU91/Rc03NNzzU9
1/Rc03NNzzU91/Rc03NNzzU91/Rc03NNzzU91/Rc03NNzzU913xcTc81Pdf0
fF+j55qea3qu6bmm55qea3qu6bmm55qea3qu6bmm55qea3qu6bmm55qea3qu
6bmm55qea3qu6bmm55qea3qu6bmm55qea3qu6fn+Rs81Pdf0XNNzTc81Pdf0
XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0
XNNzTc81Pdf0/KVGzzU91/Rc03NNzzU91/Rc03NNzzU91/Rc03NNzzU91/Rc
8/tfzf/v0fw+WPP/fzQ91/Rc03NNzzU91/Rc03NNzzW3s6bnmp5rev5yo+ea
nmt6rum5pueanmt6rum5pueanmt6rum5pueanmt6rum5pueanmt6rum5puea
nmt6rum5pueanmt6rum5pueanmt6/kqj55qea3qu6bmm55qea3qu6bmm55qe
a3qu6bmm55qea3qu6bmm55qea3qu6bmm55qea3qu6bmm55qea3qu6bmm55qe
a3qu6fmBRs81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81
Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0/NVGzzU91/Rc03NNzzU9
1/Rc03NNzzU91/Rc03NNzzU91/Rc03NNzzU91/Rc8/979fOl55qea3qu6bmm
55qea3qu6bmm55qea3p+sNFzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNz
Tc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XNNzTc81Pdf0XPP2ND0/GP8Duel1
KA==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxl2XmMXWUZgPGmEGyQAKJCRWQTAYOkEDR1f1HUgqAUMEiUQIMidW1FhIoV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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJxdmXnUXWV5xSNQ6pCCRQsRKRQH0IUxulgaKcIupUApAiI1oqWYIlMVIVUL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         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxl2Wd0VNX/NXDgRxMQQg+9N0ENVQRkI71qKCIihlCll4CA1EhRpEmTXkOE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         "]]}, {
        Hue[0.6142719099991583, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1]], 
        LineBox[CompressedData["
1:eJxl23dcje0fB3BCViQze0aSkYxH4mNkZ5NSSEhWZO9RDyEjkoyMjDJ6UlkZ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         "]]}, {
        Hue[0.8503398874989481, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         GrayLevel[0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJxl22VYFdvbBnADu8HEVmzFQMVAb8DiKGKAGAcL85hgHQOwEUUJRY+BioCC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         "]]}, {
        Hue[0.08640786499873876, 0.6, 0.6], 
        Directive[
         PointSize[0.002777777777777778], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         GrayLevel[0]], 
        LineBox[CompressedData["
1:eJxl2Xdcje0fB/CQXYRsj5m994qP2d7jdM4RTwjZmyJkz0fJJoQQRZtK4wxp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         "]]}}}, {}, {}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.9979999999999455}, {0, 0.999}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"'\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"u\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\"", 18, StripOnInput -> False], TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 0.9979999999999455}, {0, 0.999}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.1\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.5\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 1.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 2.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 5.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 10.\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.025], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.002777777777777778`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
               ",", #7}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.672588901454*^9, 3.672589170442*^9, {3.672589380951*^9, 
   3.6725893855880003`*^9}, 3.672589453862*^9, 3.672589538752*^9, {
   3.672589731686*^9, 3.672589764014*^9}, 3.672590842586*^9, 
   3.6726277670326014`*^9, {3.672627819639601*^9, 3.672627841359601*^9}, 
   3.672627927927601*^9, 3.6726280263486013`*^9, 3.6726387872406015`*^9, {
   3.6726388603796015`*^9, 3.6726388695726013`*^9}, 3.6726391212426014`*^9, 
   3.672641996531601*^9, 3.6726424218816013`*^9, 3.6726427910846014`*^9, 
   3.672642832932601*^9, 3.672652762927601*^9, 3.6726528142406015`*^9, 
   3.6726575315926013`*^9, 3.672657656180601*^9, 3.672657842107601*^9, 
   3.672658036877601*^9, 3.6726585547236013`*^9, 3.6726591611506014`*^9, 
   3.672660642554601*^9, 3.6937467291895*^9, 3.6938025350422*^9, 
   3.6938030198691998`*^9, 3.6938891632972*^9, 3.6938897271401997`*^9, 
   3.6938909374312*^9, 3.693909770426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dessin2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"outcomeTau", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "i"}], "]"}], "]"}], ",", "  ", 
            RowBox[{"(", 
             RowBox[{"a", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"i", "-", "1"}], ")"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"b", "-", "a"}], ")"}], "/", "nb"}]}]}], ")"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nb"}], "}"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ")"}], "&"}]}], "]"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "@", "outcomeTau"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", "14"}], 
      "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "style"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"t\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\) = \>\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}]}], ")"}], "&"}], "/@", "tps"}], 
      "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"\[Tau]\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*
StyleBox[OverscriptBox[
StyleBox[\"z\",
FontSlant->\"Italic\"], \"^\"],
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)\>\"", ",", "18"}], "]"}]}], " ", "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.672588944499*^9, 3.672588944955*^9}, {3.672589897373*^9,
    3.6725899091870003`*^9}, {3.672590118227*^9, 3.6725901205620003`*^9}, {
   3.672590151403*^9, 3.672590188771*^9}, {3.672590467483*^9, 
   3.672590508323*^9}, 3.672590573244*^9, {3.6726279575636015`*^9, 
   3.6726279852826014`*^9}, 3.6726388756846013`*^9, {3.6726527836316013`*^9, 
   3.6726528098796015`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         Dashing[{0, Small, Small, Small}], 
         Thickness[Large], 
         RGBColor[0.5, 0, 0.5]], 
        LineBox[CompressedData["
1:eJw1VQtIU2EYHSIlEioUpSnaCzOkRkiIZh2DRCrDR5ES0USMVoZKSWmKs6zM
LM20zFfzPefbObcpoVJRlqBRgojUCAmxDLESqZR177/jBfnd3b3f953znXO2
NSEl5pyDQqFIlP7kU1suX31Q8Fr6cDzBLa4Py/oF6b8oRK5z8M/buPo5Hrow
06+VcQv+Zl98nlaihk2cFn6filiL9+3v0RZkbugI/3I9DZ3ybbfV59OxVqo2
OWpGxqzvXqe2LKgS91sjH5j5fg7M1fO618fMCJHuliXfhOtEfeoBZzPr3cJ5
t7gg47AJ/Ufkwe5gUJwm1r+LTblD72rDTAg2Dl8d0N5DinTX3dHEfvfxZtHv
TNGLXtjHLISP8tOONTd62f8hrqmLf2ShF1WvtnRdVhdjrFYGbOQ8j7Bz6o/U
yQhxpJVAI+Yycr5STMj0BRnhKeo+hlKGu9TDeZ8gT4zXg9MCdxmsok4P53+K
wAD56kGF2Es5ii7N/NMvGIinAjONldJkBkhFT0w3VgJiLgPxVaHM3fGUy24D
PMRRjfloGWk38T5DeIFcsBsyi1JBaAXObuKvwdLKePqsbzciAvMPxX+tQaQ4
u8hHLXTSNibquzAn6tbCJt7rIj91iJ0WA0K0WajDWdGnk3zVw6XNS4LeCSGD
pXoMiLk6yF8DkmX693VgRPDeAG+Bo518NmJUGnqzsh1JYq9NyBa428hvE/ZI
2130a4Oz0I0OnwVPreRbh0IJzfttrWgRumzGQUFDC/lvxrxczqsFR4Xu9bD7
Q8996OkHPb7xORvfC2adTtbNZx8V+05yDlfOtYtzDnLuDOJIIa63xOlD3B7k
YYy8XCBPGvJmIY9K8upEnq3kPY57KOJeTnJP4N6Wucd57rWBe9Zy7xHUQSR1
8Zs6sVE3VdSRiro6TJ0NUndz1KEPdVlKnWqo2xDq2EpdT1PnoO4L6AMtfRFA
n9jomyn6SEVf5dJng/SdP33oQ19+pE819G0mfWylr7fT56H0/QhzoIa5cIU5
oWix54Ync2SIufKSOZPD3EliDoUyl9YzpxQae271M8eGmGsJzLkc5p4zczCU
uWhgTtr751DfZvbLggNz1l4/nXq3sF4aYpjT9vdTqX8Ln1ejjjlv/z6efujj
5yj85O/EfziUC5A=
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJw1VwtM1XUUviOnzhqaOh/p8NV8zCVzzJiP/DA1KkxUnDhryMwU0wGpU0wH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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJw1mXtwlPW5x3MowzBMhmMp2pRSq9QLrVq1akGP5WvRUoqWWnQYhskwDIOW
WqrUUptaalVE8YqlFDkci4gUkCKNGGPIjSS72U2yl7zv7ru775u9BKsicixy
qKVILXPyPvls/lkF8tvf5Xm+l+d74bL7Ftw1pqam5uP/qKkJPz9TE/4cVg0/
9ROvOPDHj4b16av/l/n+stt1YOri5f81XP3/pRp/2RPnBelhnXnonvbVv1+h
Jdc39T3QWf37VWr67tsPTt4/rF9P3j/yX6s1YWG4YPXfN2jpyGo/eHZYv/rg
kqvH71uj5vtX/O5va6q//7BqH/nDzU+vHNaNI//qhXsf1bINPf+YXl9d7zG1
/PGj3bFbh9X6vdoxlz3xuCbusw2y/nott78Y1g3htl56Sq3hx5Tq9z2jcwqv
rPrWhGG1nL/uf3/Y8pzufs+ZVvykwvc/r/a//9tr+KCiF6MXNI5sTZPGhAeu
sJ+NWnHOopETV1T8xL5QnbZOhf1t0uTw+nZX9MUryxeNe+QPuic87gsV9rtZ
XfZZ0WK7hxd0XrjcAxX2v0Ur7w5/Ktr63/ajntW/rxu7sMJ5tqpubdfAy9+p
KEj/8453/vQ/unfk9nRdhfO9qOhLU0a+uaIvjLWL15RwW5MrnHebVrWHC1Zk
X9v5kmIjqzX/vcz5t2uqLVzWbTOe/PbS97br/vf/NfI3Ze7jZfWNvMaGnrI+
/GG44ss6376nzP3s0OpJ4QbLenpl+Is7NGDXWOa+XtEFdi9lWRn98xU98K0J
Iy9S5v52Knlr+MVlJcJt/XunptlFlbnPP6khLBeV9RM7xy6lw+e9ssz97tJF
4THPL2uCvfNuPRhe38Qy971bjq1b0t7wuOfs0SXh9v5W4v73aI0tV9K8cLnz
XlUmGf6UeI9XNd0OUtKx8Lqn7tVDdu8l3mevPHuWksLbc6b9WV8bFxZ0iff6
sx62c5b01fqwsPcpPy1csMT77dPl4bKLS+q3c72mR3XdktbvlXjP1+SP7HrR
9SX92N59v75u65R43/16LDxGXUnjrS/+oqGGcOES7/0XXWX3XtSdI7sceVI9
Hrbb+0Xev1Gl8NoKRe0MP15p1DfCco4VqYdGrQ/Lr7moj8M2ueR1VexcRerj
dV1rZV/ULVYAr+up8DnWFamX13XY6qCoTXV2IH3TNlqkfg7omXB7dxQ1ur0D
+mu43M1F6umAZl4T/hRlH9e8oefsnovU1xt6N1xmUlHWJs1v6IYlYWUUqbc3
9LytM6Ss3WOTjjwYPsgQ9dekG+3hhvQVW7BJG0dWW9s1RD026ajta0g/tzp8
U7Ps3Yeozze1KYSrDUOKWJ+8qWMhvDw0RL026yY755A+N7pBbQ6fcckQ9dus
D8N2+/6QbHd9zZpthTxEPb+lLXZvQ7JnufUtHbc6HKK+39ItYbnUDslgK/2W
tobP+6+Aem/RCXuHQAtGC0Zz7PoC6r9FL4bHHQi0Izyu16KT4fZaA/rhoOba
QwQ6GS636KC2WV8E9MdBfTyyqxlPBppt6x7UvHCZhoB+adV2q5NAG+3crTpl
6wT0T6tuC+nju4Hs4+1W7QiPOSOgn9p02uoukLXJ8jbNt30F9FebdobwNy6Q
0cj7bToTPsM/fPqtXbdbHftyre/atcvO6dN/7fo0bN+orwsNF9q1wB7Cpx87
tMf6wtfPDLc6dNbuzac/O3RnWH5rfXUbrnZob1gu9/v0a6dq7CF8fXa0IbXQ
3sGnfzu1L7y+b/uy6/ukU2NyYQP79PMhLbLG8GXbW3NI++1dffr7kMYai/vw
eZcWG58X6PcuNRpdFrTHvqdL46xOCvR/l+ptnYJut3N06YDxeQE86NJ4o5WC
Tts9dWmJ1V0BfOhSk+2roO32Dt2aYA9RAC+6tdT4vKC59sDdarY6LoAf3aq1
cxZ0wuqoW8usMQrgSbdajM8L2mJ12q2J1hcF8KVby+3e8rrJ+qBHrcbnefCm
R+dYueR11PqsR3dbn+XBnx612zvkZdvc0KNJxud58KhHK4y287LjOj3qtL7N
g089mmwPkZctNymie4zP8+BVRF3G53kZHN0R0XmGA3nwK6KVVid5jcqHiHqM
z/PgWUR1xud5jR47onsNV/LgW0RRq7ucfms8ENUUa4wceBfVKuPznC61Booq
ZsfMgX9RTbU6zmnQeCyq+43Pc+BhVH3G5zn90ngyqvNtoznwMarV1hc5fdl4
uFcDxuc58LJXFxhQ5RS3P+/VA/bnOfCzV0nrs5zus+/t1TRbJwee9qrB+Dyn
z9u5epW27/XA15gussbwdMjuLaYHbZ8eeBuTY3zu6Uf2LjFdYufywN+Y1hgO
eLK22R1Txu7BA49jmm587slg7YOYHrJ788DnuDzDFU9GO5fF9TW7Zw+8juth
43NPtszKuPL2Lh74HdflhlOe7Jn3x/WovaMHnsflG597sjb8KK6v27tnwfc+
PWa4l9XZsN2u7tOQ1UkWvO/TVbaRrHYZLvXpcaurLPjfp5LhaFbzRw+sb1gd
ZuGDPq03Ps/qlOFqnypWt1n4oV/XGlBltc1wu19PWZ1n4Yt+HTY+z2qOXWC/
vml9kYU/+vWM4XxWx40e+vVX66MsfNKvmXaxWW02XuvXc9Z3GfhlQO8ab2Q0
yx5kQDdYn2bgmwE9b7CW0RHj5QEdsb7OwD8DutE+MxqFvwFtNBzIwEcDOmq/
l7FXrB2T0Cxr9Az8lNAm+56M7NpuTuiY4UwGvkroJttXRlbW6xLabLiUgb8S
+tDOkdFo+SU0274oA58ltMXO7cpoYXxSxw33XPgtqVvsnlz9xnaY1FY7hgvf
JXXC7tXVxVaASc0x4HLhv6RetHdwlbI+Seqk4bALHyY1197N1S+sD1PaZrjt
wo8pfWzv7OpLVtApzbOLc+HLlLZbXbjqNRxJ6ZTxggt/pnSb1ZGrn9qzprTD
eMSFT1M6bXXn6FxrkLTmjwIx/JrWTqtTRx2Gs2mdMRhz4Nu0bre6dnSX4Xha
u4zXHPg3rU+tDxyNyoq0FlghOPBxWnusbxxZmUwZ1FnjTQd+HtSdtpAje476
Qe01nnXg60HV2MM5GrVng1poxOLA34N6zfrY0aitHdSoP3fgcwc/Pki/O/jv
QfjdwW8P0v8O/noQvnfw04PggYN/HoT/HfzyIPjg4I/T6AEHP5wGLxz8bxp9
4OB30+CHg79Noxcc/GwaPHHwr2n0g4NfTYMvDv40hZ5w8aMp8MbFf6bQFy5+
MwX+uPjLFHrDxU+mwCMX/5hCf7j4xRT45OIPk+gRFz+YBK9c/F8SfeLi95Lg
l4u/S6JXXPxcEjxz8W9J9IuLX0uCby7+LIGeyeDHEuBdBv+VQN9k8FsJ8C+D
v0qgdzL4qQR4mME/JdA/GfxSQu+Bc0fAvQ3g4EZw8Xpwcha4+Q44egxcfRac
3QzuzgCHZ4PLb4PTx8Htp8HxreD6deD8HHB/GB44CS88CU9sgzeugUfmwStl
eOYUvPMEPLQDXroanpoPbxXhsTPw2jp4bhe8dyU8uABeDODJs/DmWnh0L7x6
BTy7EN4twMOjer4PPM+i3/vQb1n0ehx899DncfSchx6Pg/ce+juOvvPQ23Hw
30Nfx9F7Hno6Dh946Oc4+s9DL8fgBw99HEMPeujhGHzhoX9j6EMPvRuDPzz0
bQy96KFnY/CJh36NoR899Gov/JJDn/aiJ3Po0V74Jof+7EVf5tCbvfBPDn3Z
i97MoSd74aMc+jGK/syhF6PwUw59GEWP5tCDUfgqh/6Lok9z6L0o/JVD30XR
qzn0XBQ+y6HfIujXPHotAr/l0WcR9GwePRaB7/Lorwj6No/eisB/efRVBL2b
R09F4MM8+qkH/ZtHL/VoOT7nCL5nIj5oI76oBZ80C9+0DB91DF9Vi8/ajO9q
xofNxpctxacdx7dNwMdtxdc14fPm4PuW4ANP4gvH4xO34RsP4CPn4Svr8Zmn
8J3j8KE78KWN+NT5+NbF+Ngz+Nqx+Nxd+N79+OAF+OJF+OSz+OYx+Oi9+Op9
+OyF+O6F+PAx+PIafHo9vn0vPr4JX38nPr8W3z/K5z7+thM+9/GrnfC5j//s
hM99/GQnfO7jDzvgcx+/1wGf+/i3Dvjcx491wOc+/qodPvfxS+3wuY//aYfP
ffxMO3zu40/a4PMAv9EGnwf4hzb4PMAPtMHnAfq+FT4P0Out8HmA/m6FzwP0
dCt8HqCPD8LnAXr3IHweoF8PwucBevQgfB6gL1vg8wC92AKfB+i/Fvg80D7m
bpuZw41lLncTc7p65nbHmOM1MdfbxJyvlrnfLOaAy5kLHmVO2M7ccCNzxMnM
FW9kzriSueMR5pBR5pLPM6ecytzyBuaYq5lrvsOcM8nc81nmoBcxF53BnHQN
c9O3maN6zFWfZs56OXPX65jDPsZcdpg5bYm57ZPMca9lrnsNc95nmPuWmQO/
y1z4CebE1bnx1cyRq3PlInPm6tx5HXPo6lz6SubU1bl1wBy7Otdey5y7Ove+
gjl4dS5eYE5enZs/why9Ole/jDl7de6eYw5fncv/ljl9dW7/Veb4K5jrZ5nz
1zH3/w05QB+5wKXkBA3kBi45wnRyhV+TM/jkDheTQ6wnlxgkp5hJbvErcoyj
5BpfIefYQu6RIgeZSy7yS3KS0+QmF5Kj7CFXSZCzLCJ3+QU5zHhymS+T07SQ
2/ST46wg1/k5OU8duc+XyIH6yIXi5EQN5EY/I0eaTq70RXImn9yplxxqPbnU
feRUM8mtvkCOdZRcK0LOtYXc66fkYHPJxT5PTnaa3KybHK2aq/2EnK2au51L
DldHLneInK6B3O7H5Hg+ud7nyPlmkvt1kANuIRf8ETnhaXLDz5IjLiJXbCNn
bCF3vIscso5c8j/JKRvILVvIMX1yzWXknDPJPWvJQbeQizaTk54mN11KjtpI
rjqBnHUVuWsTOexV5LJLyGlPkNuOJ8dtJNc9QM67ity3nhz4KnLhceTEJ8iN
G8mRl5IrLyZnPkzuPJYceim59H5y6sPk1ovIsbvItceQc3eRe+8jB3+YXHwh
Ofn/A7XKqSY=
         "]]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJw1m3V8VccWhXGH4oSgJbgWaKAUWTiFQNDi2iKBUgjF3d3dNbgHh4SEhAAJ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         "]]}, {
        Hue[0.6142719099991583, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         RGBColor[0, 0, 1]], 
        LineBox[CompressedData["
1:eJw12XdcjW0cBnAjvWRnJ0mKsskuLpsIyS682WSTZL5ERiWbjIgSJUlpoL33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         "]]}, {
        Hue[0.8503398874989481, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         GrayLevel[0], 
         Dashing[Medium]], 
        LineBox[CompressedData["
1:eJw12Xdcjf0fBvAQkoiUvWeUUTZ5LpIdsrN6skI0RPQkyfwZEaKMJGkpo4Um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         "]]}, {
        Hue[0.08640786499873876, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         AbsoluteThickness[1.6], FontFamily -> "Times", 
         GrayLevel[0]], 
        LineBox[CompressedData["
1:eJw12Xc81d8fB3DSlFLSHkoqjV9De3x7VVq0SXugQpMKlTRQ0qYpI7KKFlJK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         "]]}}}, {}, {}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 1.229420198304626}, {0, 0.998}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {FontFamily -> "Times", 14}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"z\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"'\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)\"", 18, StripOnInput -> False], TraditionalForm], None}, {
        FormBox[
         StyleBox[
         "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"\[Tau]\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"^\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", 18, StripOnInput -> False], 
         TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 1.229420198304626}, {0, 0.998}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.1\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.2\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 0.5\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 1.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 2.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 5.\"", 
       "\"\\!\\(\\*\\nStyleBox[OverscriptBox[\\n  \
StyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"], \\\"^\\\"],\\nFontSlant->\\\
\"Italic\\\"]\\) = 10.\""}, "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    Dashing[{0, Small, Small, Small}], 
                    Thickness[Large], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.033], 
                    AbsoluteThickness[1.6], FontFamily -> "Times", 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                   ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"Times\""}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, 
               ",", #7}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.672652810502601*^9, 3.672657860883601*^9, 
  3.672659171894601*^9, 3.6726606442046013`*^9, 3.6938891963501997`*^9, 
  3.693909776499*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Export", "[", 
  RowBox[{"\"\<plotV-z.eps\>\"", ",", "dessin1", ",", "\"\<EPS\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<plotTau-z.eps\>\"", ",", "dessin2", ",", "\"\<EPS\>\""}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.672628003429601*^9, 3.6726280414646015`*^9}}],

Cell[BoxData["\<\"plotV-z.eps\"\>"], "Output",
 CellChangeTimes->{3.672628043134601*^9, 3.672642855818601*^9, 
  3.6726528350306015`*^9, 3.6726591917946014`*^9, 3.672660647760601*^9, 
  3.6938892030162*^9, 3.6939097796619997`*^9}],

Cell[BoxData["\<\"plotTau-z.eps\"\>"], "Output",
 CellChangeTimes->{3.672628043134601*^9, 3.672642855818601*^9, 
  3.6726528350306015`*^9, 3.6726591917946014`*^9, 3.672660647760601*^9, 
  3.6938892030162*^9, 3.693909779816*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1904, 1102},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 376, 13, 220, "Text"],
Cell[CellGroupData[{
Cell[959, 37, 312, 4, 63, "Section"],
Cell[CellGroupData[{
Cell[1296, 45, 412, 10, 50, "Input"],
Cell[1711, 57, 140, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1888, 64, 4635, 101, 278, "Input"],
Cell[6526, 167, 778, 11, 30, "Output"],
Cell[7307, 180, 777, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8121, 196, 196, 3, 43, "Subsection"],
Cell[CellGroupData[{
Cell[8342, 203, 3124, 81, 259, "Input"],
Cell[11469, 286, 256, 4, 30, "Output"],
Cell[11728, 292, 257, 4, 30, "Output"],
Cell[11988, 298, 370, 8, 30, "Output"],
Cell[12361, 308, 362, 8, 30, "Output"],
Cell[12726, 318, 371, 8, 30, "Output"],
Cell[13100, 328, 376, 8, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13513, 341, 8722, 189, 696, "Input"],
Cell[22238, 532, 1241, 19, 32, "Output"],
Cell[23482, 553, 1212, 18, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24731, 576, 111, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[24867, 581, 188, 3, 30, "Input"],
Cell[25058, 586, 65199, 1087, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90294, 1678, 192, 4, 30, "Input"],
Cell[90489, 1684, 176, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90702, 1694, 799, 19, 30, "Input"],
Cell[91504, 1715, 11394, 305, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102935, 2025, 92, 1, 30, "Input"],
Cell[103030, 2028, 270, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103337, 2038, 2449, 71, 56, "Input"],
Cell[105789, 2111, 105714, 1867, 342, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211540, 3983, 2796, 80, 56, "Input"],
Cell[214339, 4065, 97936, 1743, 343, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312312, 5813, 331, 7, 50, "Input"],
Cell[312646, 5822, 230, 3, 30, "Output"],
Cell[312879, 5827, 227, 3, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

